// Copyright 2021 Samsung Electronics Co., Ltd. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

// AUTO GENERATED FILE, DO NOT EDIT.
//
// Generated by `package:ffigen`.
import 'dart:ffi' as ffi;

/// Provides Dart bindings and utility functions for using Tizen native APIs.
class Tizen40Native {
  /// Holds the symbol lookup function.
  final ffi.Pointer<T> Function<T extends ffi.NativeType>(String symbolName)
      _lookup;

  /// The symbols are looked up in [dynamicLibrary].
  Tizen40Native(ffi.DynamicLibrary dynamicLibrary)
      : _lookup = dynamicLibrary.lookup;

  /// The symbols are looked up with [lookup].
  Tizen40Native.fromLookup(
      ffi.Pointer<T> Function<T extends ffi.NativeType>(String symbolName)
          lookup)
      : _lookup = lookup;

  /// @brief Gets the last error code in the thread.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @details This function retrieves the last error code which is set by set_last_result()
  /// @return One of #tizen_error_e
  /// @see #tizen_error_e
  /// @see set_last_result()
  int get_last_result() {
    return _get_last_result();
  }

  late final _get_last_resultPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('get_last_result');
  late final _get_last_result =
      _get_last_resultPtr.asFunction<int Function()>();

  /// @brief Sets the last error code to be returned in the thread.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] err The error code to be returned
  /// @see #tizen_error_e
  /// @see get_last_result()
  void set_last_result(
    int err,
  ) {
    return _set_last_result(
      err,
    );
  }

  late final _set_last_resultPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function(ffi.Int)>>(
          'set_last_result');
  late final _set_last_result =
      _set_last_resultPtr.asFunction<void Function(int)>();

  /// @brief Gets the message for given the error code.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remark This function returns a static pointer; subsequent calls will overwrite it.
  /// @param[in] err The error value to be returned
  /// @return The error's message
  /// @see #tizen_error_e
  ///
  /// @code
  /// char* errMsg;
  /// location_manager_h location_handle;
  /// int result = location_manager_create(LOCATION_METHOD_GPS, &location_handle);
  ///
  /// if (LOCATIONS_ERROR_NONE != result) {
  /// errMsg = get_error_message(result);
  /// dlog_print(DLOG_INFO, "MyTag", "%s", errMsg);
  /// }
  /// @endcode
  ffi.Pointer<ffi.Char> get_error_message(
    int err,
  ) {
    return _get_error_message(
      err,
    );
  }

  late final _get_error_messagePtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function(ffi.Int)>>(
          'get_error_message');
  late final _get_error_message =
      _get_error_messagePtr.asFunction<ffi.Pointer<ffi.Char> Function(int)>();

  /// @brief Creates an app_control handle.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The @a app_control must be released using app_control_destroy().
  /// @param[out] app_control The app_control handle to be newly created on success
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_control_destroy()
  int app_control_create(
    ffi.Pointer<app_control_h> app_control,
  ) {
    return _app_control_create(
      app_control,
    );
  }

  late final _app_control_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<app_control_h>)>>(
          'app_control_create');
  late final _app_control_create = _app_control_createPtr
      .asFunction<int Function(ffi.Pointer<app_control_h>)>();

  /// @brief Destroys the app_control handle and releases all its resources.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] app_control The app_control handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_control_create()
  int app_control_destroy(
    app_control_h app_control,
  ) {
    return _app_control_destroy(
      app_control,
    );
  }

  late final _app_control_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_control_h)>>(
          'app_control_destroy');
  late final _app_control_destroy =
      _app_control_destroyPtr.asFunction<int Function(app_control_h)>();

  /// @brief Sets the operation to be performed.
  ///
  /// @details The @a operation is the mandatory information for the launch request.
  /// If the operation is not specified, #APP_CONTROL_OPERATION_DEFAULT is used for the launch request.
  /// If the operation is #APP_CONTROL_OPERATION_DEFAULT, the package information is mandatory to explicitly launch the application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] app_control The app_control handle
  /// @param[in] operation The operation to be performed (if the @a operation is @c NULL, it clears the previous value)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see app_control_get_operation()
  /// @see APP_CONTROL_OPERATION_DEFAULT
  /// @see APP_CONTROL_OPERATION_EDIT
  /// @see APP_CONTROL_OPERATION_VIEW
  /// @see APP_CONTROL_OPERATION_PICK
  /// @see APP_CONTROL_OPERATION_CREATE_CONTENT
  /// @see APP_CONTROL_OPERATION_CALL
  /// @see APP_CONTROL_OPERATION_SEND
  /// @see APP_CONTROL_OPERATION_SEND_TEXT
  /// @see APP_CONTROL_OPERATION_DIAL
  /// @see APP_CONTROL_OPERATION_SEARCH
  int app_control_set_operation(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> operation,
  ) {
    return _app_control_set_operation(
      app_control,
      operation,
    );
  }

  late final _app_control_set_operationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h,
              ffi.Pointer<ffi.Char>)>>('app_control_set_operation');
  late final _app_control_set_operation = _app_control_set_operationPtr
      .asFunction<int Function(app_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the operation to be performed.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The @a operation must be released using free().
  /// @param[in] app_control The app_control handle
  /// @param[out] operation The operation to be performed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_control_set_operation()
  int app_control_get_operation(
    app_control_h app_control,
    ffi.Pointer<ffi.Pointer<ffi.Char>> operation,
  ) {
    return _app_control_get_operation(
      app_control,
      operation,
    );
  }

  late final _app_control_get_operationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  app_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'app_control_get_operation');
  late final _app_control_get_operation =
      _app_control_get_operationPtr.asFunction<
          int Function(app_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the URI of the data.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Since Tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, if the parameter @a uri is started with 'file://' and it is a regular file in this application's data path which can be obtained by calling the app_get_data_path() function, it will be shared to the callee application. Framework will grant a temporary permission to the callee application for this file and revoke it when the callee application is terminated. The callee application can just read it.
  /// @param[in] app_control The app_control handle
  /// @param[in] uri The URI of the data this app_control is operating on (if the @a uri is @c NULL, it clears the previous value)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see app_control_get_uri()
  int app_control_set_uri(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> uri,
  ) {
    return _app_control_set_uri(
      app_control,
      uri,
    );
  }

  late final _app_control_set_uriPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_control_h, ffi.Pointer<ffi.Char>)>>('app_control_set_uri');
  late final _app_control_set_uri = _app_control_set_uriPtr
      .asFunction<int Function(app_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the URI of the data.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The @a uri must be released using free().
  /// @param[in] app_control The app_control handle
  /// @param[out] uri The URI of the data this app_control is operating on
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_control_set_uri()
  int app_control_get_uri(
    app_control_h app_control,
    ffi.Pointer<ffi.Pointer<ffi.Char>> uri,
  ) {
    return _app_control_get_uri(
      app_control,
      uri,
    );
  }

  late final _app_control_get_uriPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_control_get_uri');
  late final _app_control_get_uri = _app_control_get_uriPtr.asFunction<
      int Function(app_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the explicit MIME type of the data.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] app_control The app_control handle
  /// @param[in] mime The explicit MIME type of the data this app_control is operating on (if the @a mime is @c NULL, it clears the previous value)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see app_control_get_mime()
  int app_control_set_mime(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> mime,
  ) {
    return _app_control_set_mime(
      app_control,
      mime,
    );
  }

  late final _app_control_set_mimePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_control_h, ffi.Pointer<ffi.Char>)>>('app_control_set_mime');
  late final _app_control_set_mime = _app_control_set_mimePtr
      .asFunction<int Function(app_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the explicit MIME type of the data.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The @a uri must be released using free().
  /// @param[in] app_control The app_control handle
  /// @param[out] mime The explicit MIME type of the data this app_control is operating on
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_control_set_mime()
  int app_control_get_mime(
    app_control_h app_control,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mime,
  ) {
    return _app_control_get_mime(
      app_control,
      mime,
    );
  }

  late final _app_control_get_mimePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_control_get_mime');
  late final _app_control_get_mime = _app_control_get_mimePtr.asFunction<
      int Function(app_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the explicit category.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] app_control The app_control handle
  /// @param[in] category The explicit category (if the @a category is @c NULL, it clears the previous value)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see app_control_get_category()
  int app_control_set_category(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> category,
  ) {
    return _app_control_set_category(
      app_control,
      category,
    );
  }

  late final _app_control_set_categoryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h,
              ffi.Pointer<ffi.Char>)>>('app_control_set_category');
  late final _app_control_set_category = _app_control_set_categoryPtr
      .asFunction<int Function(app_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the explicit category.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The @a category must be released using free().
  /// @param[in] app_control The app_control handle
  /// @param[out] category The explicit category
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_control_set_category()
  int app_control_get_category(
    app_control_h app_control,
    ffi.Pointer<ffi.Pointer<ffi.Char>> category,
  ) {
    return _app_control_get_category(
      app_control,
      category,
    );
  }

  late final _app_control_get_categoryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_control_get_category');
  late final _app_control_get_category =
      _app_control_get_categoryPtr.asFunction<
          int Function(app_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the ID of the application to explicitly launch.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] app_control The app_control handle
  /// @param[in] app_id The ID of the application to explicitly launch (if the @a app_id is @c NULL, it clears the previous value)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_control_get_app_id()
  int app_control_set_app_id(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> app_id,
  ) {
    return _app_control_set_app_id(
      app_control,
      app_id,
    );
  }

  late final _app_control_set_app_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_control_h, ffi.Pointer<ffi.Char>)>>('app_control_set_app_id');
  late final _app_control_set_app_id = _app_control_set_app_idPtr
      .asFunction<int Function(app_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the ID of the application to explicitly launch.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The @a app_id must be released with free().
  /// @param[in] app_control The app_control handle
  /// @param[out] app_id The ID of the application to explicitly launch
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_control_set_app_id()
  int app_control_get_app_id(
    app_control_h app_control,
    ffi.Pointer<ffi.Pointer<ffi.Char>> app_id,
  ) {
    return _app_control_get_app_id(
      app_control,
      app_id,
    );
  }

  late final _app_control_get_app_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_control_get_app_id');
  late final _app_control_get_app_id = _app_control_get_app_idPtr.asFunction<
      int Function(app_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Adds extra data to the app_control.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The function replaces any existing value for the given key.
  /// @remarks The function returns #APP_CONTROL_ERROR_INVALID_PARAMETER if @a key or @a value is a zero-length string.
  /// @remarks The function returns #APP_CONTROL_ERROR_KEY_REJECTED if the application tries to use the same key with the system-defined key.
  /// @param[in] app_control The app_control handle
  /// @param[in] key The name of the extra data
  /// @param[in] value The value associated with the given key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_KEY_REJECTED Key not available
  /// @see app_control_add_extra_data_array()
  /// @see app_control_remove_extra_data()
  /// @see app_control_get_extra_data()
  int app_control_add_extra_data(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _app_control_add_extra_data(
      app_control,
      key,
      value,
    );
  }

  late final _app_control_add_extra_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('app_control_add_extra_data');
  late final _app_control_add_extra_data =
      _app_control_add_extra_dataPtr.asFunction<
          int Function(
              app_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Adds the extra data array to the app_control.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The function replaces any existing value for the given key.
  /// @remarks The function returns #APP_CONTROL_ERROR_INVALID_PARAMETER if @a key is a zero-length string.
  /// @remarks The function returns #APP_CONTROL_ERROR_KEY_REJECTED if the application tries to use the same key with the system-defined key.
  /// @param[in] app_control The app_control handle
  /// @param[in] key The name of the extra data
  /// @param[in] value The array value associated with the given key
  /// @param[in] length The length of the array
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_KEY_REJECTED Key not available
  /// @see app_control_add_extra_data()
  /// @see app_control_remove_extra_data()
  /// @see app_control_get_extra_data()
  int app_control_add_extra_data_array(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
    int length,
  ) {
    return _app_control_add_extra_data_array(
      app_control,
      key,
      value,
      length,
    );
  }

  late final _app_control_add_extra_data_arrayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_control_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Int)>>('app_control_add_extra_data_array');
  late final _app_control_add_extra_data_array =
      _app_control_add_extra_data_arrayPtr.asFunction<
          int Function(app_control_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>, int)>();

  /// @brief Removes the extra data from the app_control.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] app_control The app_control handle
  /// @param[in] key The name of the extra data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_KEY_NOT_FOUND Specified key not found
  /// @retval #APP_CONTROL_ERROR_KEY_REJECTED Key not available
  /// @see app_control_add_extra_data()
  /// @see app_control_add_extra_data_array()
  /// @see app_control_get_extra_data()
  int app_control_remove_extra_data(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> key,
  ) {
    return _app_control_remove_extra_data(
      app_control,
      key,
    );
  }

  late final _app_control_remove_extra_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h,
              ffi.Pointer<ffi.Char>)>>('app_control_remove_extra_data');
  late final _app_control_remove_extra_data = _app_control_remove_extra_dataPtr
      .asFunction<int Function(app_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the extra data from the app_control.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The @a value must be released using free().
  /// @remarks The function returns #APP_CONTROL_ERROR_INVALID_DATA_TYPE if @a value is of array data type.
  /// @param[in] app_control The app_control handle
  /// @param[in] key The name of the extra data
  /// @param[out] value The value associated with the given key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_KEY_NOT_FOUND Specified key not found
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #APP_CONTROL_ERROR_INVALID_DATA_TYPE Invalid data type
  /// @retval #APP_CONTROL_ERROR_KEY_REJECTED Key not available
  /// @see app_control_add_extra_data()
  /// @see app_control_add_extra_data_array()
  /// @see app_control_get_extra_data()
  /// @see app_control_remove_extra_data()
  /// @see app_control_foreach_extra_data()
  int app_control_get_extra_data(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _app_control_get_extra_data(
      app_control,
      key,
      value,
    );
  }

  late final _app_control_get_extra_dataPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(app_control_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'app_control_get_extra_data');
  late final _app_control_get_extra_data =
      _app_control_get_extra_dataPtr.asFunction<
          int Function(app_control_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the extra data array from the app_control.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The @a value must be released using free().
  /// @remarks The function returns #APP_CONTROL_ERROR_INVALID_DATA_TYPE if @a value is not of array data type.
  /// @param[in] app_control The app_control handle
  /// @param[in] key The name of the extra data
  /// @param[out] value The array value associated with the given key
  /// @param[out] length The length of the array
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_KEY_NOT_FOUND Specified key not found
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #APP_CONTROL_ERROR_INVALID_DATA_TYPE Invalid data type
  /// @retval #APP_CONTROL_ERROR_KEY_REJECTED Key not available
  /// @see app_control_add_extra_data()
  /// @see app_control_add_extra_data_array()
  /// @see app_control_remove_extra_data()
  /// @see app_control_foreach_extra_data()
  int app_control_get_extra_data_array(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>> value,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _app_control_get_extra_data_array(
      app_control,
      key,
      value,
      length,
    );
  }

  late final _app_control_get_extra_data_arrayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_control_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>)>>('app_control_get_extra_data_array');
  late final _app_control_get_extra_data_array =
      _app_control_get_extra_data_arrayPtr.asFunction<
          int Function(
              app_control_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Checks whether the extra data associated with the given @a key is of array data type.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] app_control The app_control handle
  /// @param[in] key The name of the extra data
  /// @param[out] array If @c true the extra data is of array data type,
  /// otherwise @c false
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see app_control_add_extra_data()
  /// @see app_control_add_extra_data_array()
  /// @see app_control_remove_extra_data()
  /// @see app_control_foreach_extra_data()
  int app_control_is_extra_data_array(
    app_control_h app_control,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Bool> array,
  ) {
    return _app_control_is_extra_data_array(
      app_control,
      key,
      array,
    );
  }

  late final _app_control_is_extra_data_arrayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('app_control_is_extra_data_array');
  late final _app_control_is_extra_data_array =
      _app_control_is_extra_data_arrayPtr.asFunction<
          int Function(
              app_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief Retrieves all extra data contained in app_control.
  /// @details This function calls app_control_extra_data_cb() once for each key-value pair for extra data contained in app_control. \n
  /// If the app_control_extra_data_cb() callback function returns @c false, then iteration will be finished.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] app_control The app_control handle
  /// @param[in] callback The iteration callback function
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post This function invokes app_control_extra_data_cb().
  /// @see app_control_extra_data_cb()
  int app_control_foreach_extra_data(
    app_control_h app_control,
    app_control_extra_data_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_control_foreach_extra_data(
      app_control,
      callback,
      user_data,
    );
  }

  late final _app_control_foreach_extra_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h, app_control_extra_data_cb,
              ffi.Pointer<ffi.Void>)>>('app_control_foreach_extra_data');
  late final _app_control_foreach_extra_data =
      _app_control_foreach_extra_dataPtr.asFunction<
          int Function(app_control_h, app_control_extra_data_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves all applications that can be launched to handle the given app_control request.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] app_control The app_control handle
  /// @param[in] callback The iteration callback function
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Success
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post This function invokes app_control_app_matched_cb().
  /// @see app_control_app_matched_cb()
  int app_control_foreach_app_matched(
    app_control_h app_control,
    app_control_app_matched_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_control_foreach_app_matched(
      app_control,
      callback,
      user_data,
    );
  }

  late final _app_control_foreach_app_matchedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h, app_control_app_matched_cb,
              ffi.Pointer<ffi.Void>)>>('app_control_foreach_app_matched');
  late final _app_control_foreach_app_matched =
      _app_control_foreach_app_matchedPtr.asFunction<
          int Function(app_control_h, app_control_app_matched_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sends the launch request.
  ///
  /// @details The operation is mandatory information for the launch request. \n
  /// If the operation is not specified, #APP_CONTROL_OPERATION_DEFAULT is used by default.
  /// If the operation is #APP_CONTROL_OPERATION_DEFAULT, the application ID is mandatory to explicitly launch the application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/appmanager.launch
  /// @remarks The function returns #APP_CONTROL_ERROR_LAUNCH_REJECTED if the operation value is #APP_CONTROL_OPERATION_LAUNCH_ON_EVENT which is only for handling the event from the platform or other application, refer to the @a Event module.
  /// @remarks Since Tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, the launch request of the service application over out of packages is restricted by the platform. Also, implicit launch requests are NOT delivered to service applications since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. To launch a service application, an explicit launch request with application ID given by the app_control_set_app_id() must be sent.
  /// @param[in] app_control The app_control handle
  /// @param[in] callback The callback function to be called when the reply is delivered
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #APP_CONTROL_ERROR_APP_NOT_FOUND The application to run the given launch request is not found
  /// @retval #APP_CONTROL_ERROR_LAUNCH_REJECTED The application cannot be launched in current context
  /// @retval #APP_CONTROL_ERROR_LAUNCH_FAILED Failed to launch the application
  /// @retval #APP_CONTROL_ERROR_TIMED_OUT Failed due to timeout. The application that handles @a app_control may be busy
  /// @retval #APP_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  /// @post If the launch request is sent for the result, the result will come back through the app_control_reply_cb() from the callee application. Additional replies may be delivered on the app_control_enable_app_started_result_event() called.
  /// @see app_control_reply_to_launch_request()
  /// @see app_control_reply_cb()
  /// @see app_control_enable_app_started_result_event()
  int app_control_send_launch_request(
    app_control_h app_control,
    app_control_reply_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_control_send_launch_request(
      app_control,
      callback,
      user_data,
    );
  }

  late final _app_control_send_launch_requestPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h, app_control_reply_cb,
              ffi.Pointer<ffi.Void>)>>('app_control_send_launch_request');
  late final _app_control_send_launch_request =
      _app_control_send_launch_requestPtr.asFunction<
          int Function(
              app_control_h, app_control_reply_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sends the terminate request to the application that is launched by app_control. This API is only effective for some applications that are provided by default for handling platform default app_controls. You are not allowed to terminate other general applications using this API.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Since Tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, this API can be used to terminate sub-applications which were launched as group mode by the caller application.
  /// Once callee application is being terminated by this API, other applications which were launched by the callee application as a group mode will be terminated as well.
  /// @param[in] app_control The app_control handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  /// @see app_control_send_launch_request()
  /// @see app_control_set_launch_mode()
  int app_control_send_terminate_request(
    app_control_h app_control,
  ) {
    return _app_control_send_terminate_request(
      app_control,
    );
  }

  late final _app_control_send_terminate_requestPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_control_h)>>(
          'app_control_send_terminate_request');
  late final _app_control_send_terminate_request =
      _app_control_send_terminate_requestPtr
          .asFunction<int Function(app_control_h)>();

  /// @brief Replies to the launch request sent by the caller.
  /// @details If the caller application sent the launch request to receive the result, the callee application can return the result back to the caller.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The function is not allowed to send reply #APP_CONTROL_RESULT_APP_STARTED as @a result which is reserved for platform developers.
  /// @param[in] reply The app_control handle in which the results of the callee are contained
  /// @param[in] request The app_control handle sent by the caller
  /// @param[in] result The result code of the launch request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_control_send_launch_request()
  int app_control_reply_to_launch_request(
    app_control_h reply,
    app_control_h request,
    int result,
  ) {
    return _app_control_reply_to_launch_request(
      reply,
      request,
      result,
    );
  }

  late final _app_control_reply_to_launch_requestPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h, app_control_h,
              ffi.Int32)>>('app_control_reply_to_launch_request');
  late final _app_control_reply_to_launch_request =
      _app_control_reply_to_launch_requestPtr
          .asFunction<int Function(app_control_h, app_control_h, int)>();

  /// @brief Creates and returns a copy of the given app_control handle.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks A newly created app_control should be destroyed by calling the app_control_destroy() if it is no longer needed.
  ///
  /// @param[out] clone If successful, a newly created app_control handle will be returned
  /// @param[in] app_control The app_control handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_control_destroy()
  int app_control_clone(
    ffi.Pointer<app_control_h> clone,
    app_control_h app_control,
  ) {
    return _app_control_clone(
      clone,
      app_control,
    );
  }

  late final _app_control_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<app_control_h>, app_control_h)>>('app_control_clone');
  late final _app_control_clone = _app_control_clonePtr
      .asFunction<int Function(ffi.Pointer<app_control_h>, app_control_h)>();

  /// @brief Gets the application ID of the caller from the launch request.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The @a app_control must be the launch request from app_control_cb().
  /// @remarks This function returns #APP_CONTROL_ERROR_INVALID_PARAMETER if the given app_control is not the launch request.
  /// @remarks The @a id must be released using free().
  /// @param[in] app_control The app_control handle from app_control_cb()
  /// @param[out] id The application ID of the caller
  /// @return @a 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  int app_control_get_caller(
    app_control_h app_control,
    ffi.Pointer<ffi.Pointer<ffi.Char>> id,
  ) {
    return _app_control_get_caller(
      app_control,
      id,
    );
  }

  late final _app_control_get_callerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_control_get_caller');
  late final _app_control_get_caller = _app_control_get_callerPtr.asFunction<
      int Function(app_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Checks whether the caller is requesting a reply from the launch request.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The @a app_control must be the launch request from app_control_cb().
  /// @remarks This function returns #APP_CONTROL_ERROR_INVALID_PARAMETER if the given app_control is not the launch request.
  /// @param[in] app_control The app_control handle from app_control_cb()
  /// @param[out] requested If @c true a reply is requested by the caller,
  /// otherwise @c false
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  int app_control_is_reply_requested(
    app_control_h app_control,
    ffi.Pointer<ffi.Bool> requested,
  ) {
    return _app_control_is_reply_requested(
      app_control,
      requested,
    );
  }

  late final _app_control_is_reply_requestedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h,
              ffi.Pointer<ffi.Bool>)>>('app_control_is_reply_requested');
  late final _app_control_is_reply_requested =
      _app_control_is_reply_requestedPtr
          .asFunction<int Function(app_control_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the launch mode of the application.
  ///
  /// @details This function allows the callee application to be launched as a group or as a single mode.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks Although launch_mode were set as #APP_CONTROL_LAUNCH_MODE_GROUP, the callee application would be launched as a single mode if the manifest file of callee application defined the launch mode as "single".
  /// This function can just set the preference of the caller application to launch an application.
  /// @remarks Sub-applications which were launched as a group mode always have own process.
  ///
  /// @param[in] app_control The app_control handle
  /// @param[in] mode The launch mode of the application
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see app_control_set_launch_mode()
  /// @see app_control_launch_mode_e
  int app_control_set_launch_mode(
    app_control_h app_control,
    int mode,
  ) {
    return _app_control_set_launch_mode(
      app_control,
      mode,
    );
  }

  late final _app_control_set_launch_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_control_h, ffi.Int32)>>(
          'app_control_set_launch_mode');
  late final _app_control_set_launch_mode = _app_control_set_launch_modePtr
      .asFunction<int Function(app_control_h, int)>();

  /// @brief Gets the launch mode of the application.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks Since Tizen 3.0, if launch mode is not set in the caller application control,
  /// the function returns the #APP_CONTROL_LAUNCH_MODE_SINGLE launch mode.
  /// @param[in] app_control The app_control handle
  /// @param[out] mode The launch mode of the application
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see app_control_get_launch_mode()
  /// @see app_control_launch_mode_e
  int app_control_get_launch_mode(
    app_control_h app_control,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _app_control_get_launch_mode(
      app_control,
      mode,
    );
  }

  late final _app_control_get_launch_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h,
              ffi.Pointer<ffi.Int32>)>>('app_control_get_launch_mode');
  late final _app_control_get_launch_mode = _app_control_get_launch_modePtr
      .asFunction<int Function(app_control_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Enables an additional launch result event on the launch request.
  ///
  /// @details The function allows to receive the #APP_CONTROL_RESULT_APP_STARTED event on\n
  /// application get launched by the app_control.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks app_control_reply_cb() will be called on the APP_CONTROL_RESULT_APP_STARTED event received.
  /// @param[in] app_control The app_control handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_CONTROL_ERROR_NONE Successful
  /// @retval #APP_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see app_control_send_launch_request()
  /// @see #APP_CONTROL_RESULT_APP_STARTED
  int app_control_enable_app_started_result_event(
    app_control_h app_control,
  ) {
    return _app_control_enable_app_started_result_event(
      app_control,
    );
  }

  late final _app_control_enable_app_started_result_eventPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_control_h)>>(
          'app_control_enable_app_started_result_event');
  late final _app_control_enable_app_started_result_event =
      _app_control_enable_app_started_result_eventPtr
          .asFunction<int Function(app_control_h)>();

  /// @brief Gets the low memory status from the given event info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] event_info The system event info
  /// @param[out] status The low memory status
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT Invalid event context
  /// @see app_event_info_h
  /// @see app_event_low_memory_status_e
  int app_event_get_low_memory_status(
    app_event_info_h event_info,
    ffi.Pointer<ffi.Int32> status,
  ) {
    return _app_event_get_low_memory_status(
      event_info,
      status,
    );
  }

  late final _app_event_get_low_memory_statusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_event_info_h,
              ffi.Pointer<ffi.Int32>)>>('app_event_get_low_memory_status');
  late final _app_event_get_low_memory_status =
      _app_event_get_low_memory_statusPtr
          .asFunction<int Function(app_event_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the low battery status from given event info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] event_info The system event info
  /// @param[out] status The low battery status
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT Invalid event context
  /// @see app_event_info_h
  /// @see app_event_low_battery_status_e
  int app_event_get_low_battery_status(
    app_event_info_h event_info,
    ffi.Pointer<ffi.Int32> status,
  ) {
    return _app_event_get_low_battery_status(
      event_info,
      status,
    );
  }

  late final _app_event_get_low_battery_statusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_event_info_h,
              ffi.Pointer<ffi.Int32>)>>('app_event_get_low_battery_status');
  late final _app_event_get_low_battery_status =
      _app_event_get_low_battery_statusPtr
          .asFunction<int Function(app_event_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the language from the given event info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks @a lang must be released using free().
  /// @param[in] event_info The system event info
  /// @param[out] lang The language changed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT Invalid event context
  /// @see app_event_info_h
  int app_event_get_language(
    app_event_info_h event_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> lang,
  ) {
    return _app_event_get_language(
      event_info,
      lang,
    );
  }

  late final _app_event_get_languagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_event_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_event_get_language');
  late final _app_event_get_language = _app_event_get_languagePtr.asFunction<
      int Function(app_event_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the region format from the given event info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks @a region must be released using free().
  /// @param[in] event_info The system event info
  /// @param[out] region The region format changed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT Invalid event context
  /// @see app_event_info_h
  int app_event_get_region_format(
    app_event_info_h event_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> region,
  ) {
    return _app_event_get_region_format(
      event_info,
      region,
    );
  }

  late final _app_event_get_region_formatPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  app_event_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'app_event_get_region_format');
  late final _app_event_get_region_format =
      _app_event_get_region_formatPtr.asFunction<
          int Function(app_event_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the device orientation from the given event info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] event_info The system event info
  /// @param[out] orientation The device orientation changed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT Invalid event context
  /// @see app_event_info_h
  /// @see app_device_orientation_e
  int app_event_get_device_orientation(
    app_event_info_h event_info,
    ffi.Pointer<ffi.Int32> orientation,
  ) {
    return _app_event_get_device_orientation(
      event_info,
      orientation,
    );
  }

  late final _app_event_get_device_orientationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_event_info_h,
              ffi.Pointer<ffi.Int32>)>>('app_event_get_device_orientation');
  late final _app_event_get_device_orientation =
      _app_event_get_device_orientationPtr
          .asFunction<int Function(app_event_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the suspended state of the application from the given event info.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks The application should not use any asynchronous operations in #APP_SUSPENDED_STATE_WILL_ENTER event.
  /// Because applications will be changed to suspended state just after #APP_SUSPENDED_STATE_WILL_ENTER, asynchronous calls are not guaranteed to work properly.
  /// @param[in] event_info The handle for getting the suspended state
  /// @param[out] state The suspended state of the application
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT Invalid event context
  int app_event_get_suspended_state(
    app_event_info_h event_info,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _app_event_get_suspended_state(
      event_info,
      state,
    );
  }

  late final _app_event_get_suspended_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_event_info_h,
              ffi.Pointer<ffi.Int32>)>>('app_event_get_suspended_state');
  late final _app_event_get_suspended_state = _app_event_get_suspended_statePtr
      .asFunction<int Function(app_event_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the ID of the application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks @a id must be released using free().
  /// @param[out] id The ID of the application
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT The application is launched illegally, not launched by the launch system
  /// @retval #APP_ERROR_OUT_OF_MEMORY Out of memory
  int app_get_id(
    ffi.Pointer<ffi.Pointer<ffi.Char>> id,
  ) {
    return _app_get_id(
      id,
    );
  }

  late final _app_get_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_get_id');
  late final _app_get_id = _app_get_idPtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the localized name of the application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks @a name must be released using free().
  /// @param[out] name The name of the application
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT The application is launched illegally, not launched by the launch system
  /// @retval #APP_ERROR_OUT_OF_MEMORY Out of memory
  int app_get_name(
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _app_get_name(
      name,
    );
  }

  late final _app_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_get_name');
  late final _app_get_name = _app_get_namePtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the version of the application package.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks @a version must be released using free().
  /// @param[out] version The version of the application
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT The application is launched illegally, not launched by the launch system
  /// @retval #APP_ERROR_OUT_OF_MEMORY Out of memory
  int app_get_version(
    ffi.Pointer<ffi.Pointer<ffi.Char>> version,
  ) {
    return _app_get_version(
      version,
    );
  }

  late final _app_get_versionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_get_version');
  late final _app_get_version = _app_get_versionPtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the absolute path to the application's data directory which is used to store private data of the application.
  /// @details	An application can read and write its own files in the application's data directory.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks	The returned path should be released.
  /// @return The absolute path to the application's data directory, @n
  /// otherwise a null pointer if the memory is insufficient
  ffi.Pointer<ffi.Char> app_get_data_path() {
    return _app_get_data_path();
  }

  late final _app_get_data_pathPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function()>>(
          'app_get_data_path');
  late final _app_get_data_path =
      _app_get_data_pathPtr.asFunction<ffi.Pointer<ffi.Char> Function()>();

  /// @brief Gets the absolute path to the application's cache directory which is used to store temporary data of the application.
  /// @details	An application can read and write its own files in the application's cache directory.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks	The returned path should be released. @n
  /// The files stored in the application's cache directory can be removed by setting application or platform while the application is running.
  /// @return The absolute path to the application's cache directory, @n
  /// otherwise a null pointer if the memory is insufficient
  ffi.Pointer<ffi.Char> app_get_cache_path() {
    return _app_get_cache_path();
  }

  late final _app_get_cache_pathPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function()>>(
          'app_get_cache_path');
  late final _app_get_cache_path =
      _app_get_cache_pathPtr.asFunction<ffi.Pointer<ffi.Char> Function()>();

  /// @brief Gets the absolute path to the application resource directory. The resource files are delivered with the application package.
  /// @details	An application can only read its own files in the application's resource directory.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks	The returned path should be released.
  /// @return The absolute path to the application's resource directory, @n
  /// otherwise a null pointer if the memory is insufficient
  ffi.Pointer<ffi.Char> app_get_resource_path() {
    return _app_get_resource_path();
  }

  late final _app_get_resource_pathPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function()>>(
          'app_get_resource_path');
  late final _app_get_resource_path =
      _app_get_resource_pathPtr.asFunction<ffi.Pointer<ffi.Char> Function()>();

  /// @brief Gets the absolute path to the application's shared data directory which is used to share data with other applications.
  /// @details	An application can read and write its own files in the application's shared data directory and others can only read the files.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel	public
  /// @privilege	%http://tizen.org/privilege/appdir.shareddata
  /// @remarks	The returned path should be released. @n
  /// Since Tizen 3.0, an application that want to use shared/data directory must declare http://tizen.org/privilege/appdir.shareddata privilege. If the application doesn't declare the privilege, the framework will not create shared/data directory for the application.
  /// Carefully consider the privacy implications when deciding whether to use the shared/data directory, since the application cannot control access to this directory by other applications.
  /// If you want to share files with other applications, consider passing path via @ref CAPI_APP_CONTROL_MODULE API.
  /// The @ref CAPI_APP_CONTROL_MODULE API supports giving permission to other applications by passing path via app_control. @n
  /// The specific error code can be obtained using the get_last_result(). Error codes are described in Exception section.
  ///
  /// @return	The absolute path to the application's shared data directory, @n
  /// otherwise a null pointer if the memory is insufficient. It will return NULL for applications with api-version 3.0 or later, and set #APP_ERROR_PERMISSION_DENIED if the application does not declare the shareddata privilege.
  /// @exception APP_ERROR_NONE Success
  /// @exception APP_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception APP_ERROR_PERMISSION_DENIED Permission denied
  ffi.Pointer<ffi.Char> app_get_shared_data_path() {
    return _app_get_shared_data_path();
  }

  late final _app_get_shared_data_pathPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function()>>(
          'app_get_shared_data_path');
  late final _app_get_shared_data_path = _app_get_shared_data_pathPtr
      .asFunction<ffi.Pointer<ffi.Char> Function()>();

  /// @brief Gets the absolute path to the application's shared resource directory which is used to share resources with other applications.
  /// @details	An application can read its own files in the application's shared resource directory, and others can only read the files.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks	The returned path should be released.
  /// @return The absolute path to the application's shared resource directory, @n
  /// otherwise a null pointer if the memory is insufficient
  ffi.Pointer<ffi.Char> app_get_shared_resource_path() {
    return _app_get_shared_resource_path();
  }

  late final _app_get_shared_resource_pathPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function()>>(
          'app_get_shared_resource_path');
  late final _app_get_shared_resource_path = _app_get_shared_resource_pathPtr
      .asFunction<ffi.Pointer<ffi.Char> Function()>();

  /// @brief Gets the absolute path to the application's shared trusted directory which is used to share data with a family of trusted applications.
  /// @details	An application can read and write its own files in the application's shared trusted directory
  /// and the family applications signed with the same certificate can read and write the files in the shared trusted directory.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks	The returned path should be released.
  /// @return The absolute path to the application's shared trusted directory, @n
  /// otherwise a null pointer if the memory is insufficient
  ffi.Pointer<ffi.Char> app_get_shared_trusted_path() {
    return _app_get_shared_trusted_path();
  }

  late final _app_get_shared_trusted_pathPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function()>>(
          'app_get_shared_trusted_path');
  late final _app_get_shared_trusted_path = _app_get_shared_trusted_pathPtr
      .asFunction<ffi.Pointer<ffi.Char> Function()>();

  /// @brief Gets the absolute path to the application's external data directory which is used to store data of the application.
  /// @details	An application can read and write its own files in the application's external data directory.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks	The returned path should be released. @n
  /// The important files stored in the application's external data directory should be encrypted because they can be exported via the external sdcard.
  /// To access the path returned by this function requires the privilege
  /// that is "http://tizen.org/privilege/externalstorage.appdata".
  /// @return The absolute path to the application's external data directory, @n
  /// otherwise a null pointer if the memory is insufficient
  ffi.Pointer<ffi.Char> app_get_external_data_path() {
    return _app_get_external_data_path();
  }

  late final _app_get_external_data_pathPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function()>>(
          'app_get_external_data_path');
  late final _app_get_external_data_path = _app_get_external_data_pathPtr
      .asFunction<ffi.Pointer<ffi.Char> Function()>();

  /// @brief Gets the absolute path to the application's external cache directory which is used to store temporary data of the application.
  /// @details	An application can read and write its own files in the application's external cache directory.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The returned path should be released. @n
  /// The files stored in the application's external cache directory can be removed by
  /// setting application while the application is running. @n
  /// The important files stored in the application's external cache directory should be
  /// encrypted because they can be exported via the external sdcard.
  /// To access the path returned by this function requires the privilege
  /// that is "http://tizen.org/privilege/externalstorage.appdata".
  /// @return The absolute path to the application's external cache directory, @n
  /// otherwise a null pointer if the memory is insufficient
  ffi.Pointer<ffi.Char> app_get_external_cache_path() {
    return _app_get_external_cache_path();
  }

  late final _app_get_external_cache_pathPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function()>>(
          'app_get_external_cache_path');
  late final _app_get_external_cache_path = _app_get_external_cache_pathPtr
      .asFunction<ffi.Pointer<ffi.Char> Function()>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif.
  /// @brief Gets the absolute path to the application's external shared data directory which is used to share data with other applications.
  /// @details	An application can read and write its own files in the application's external shared data directory, and others can only read the files.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks	The specified @a path should be released.
  /// To access the path returned by this function requires the privilege
  /// that is "http://tizen.org/privilege/externalstorage.appdata".
  /// The function may not work as intended in certain devices due to some implementation issues.
  /// @return The absolute path to the application's external shared data directory, @n
  /// otherwise a null pointer if the memory is insufficient
  ffi.Pointer<ffi.Char> app_get_external_shared_data_path() {
    return _app_get_external_shared_data_path();
  }

  late final _app_get_external_shared_data_pathPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function()>>(
          'app_get_external_shared_data_path');
  late final _app_get_external_shared_data_path =
      _app_get_external_shared_data_pathPtr
          .asFunction<ffi.Pointer<ffi.Char> Function()>();

  /// @brief Gets the absolute path to the application's TEP(Tizen Expansion Package) directory. The resource files are delivered with the expansion package.
  /// @details An application can only read its own files in the application's TEP(Tizen Expansion Package) directory.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks The returned path should be released.
  /// @return The absolute path to the application's TEP(Tizen Expansion Package) directory, @n
  /// otherwise a null pointer if the memory is insufficient
  ffi.Pointer<ffi.Char> app_get_tep_resource_path() {
    return _app_get_tep_resource_path();
  }

  late final _app_get_tep_resource_pathPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<ffi.Char> Function()>>(
          'app_get_tep_resource_path');
  late final _app_get_tep_resource_path = _app_get_tep_resource_pathPtr
      .asFunction<ffi.Pointer<ffi.Char> Function()>();

  /// @brief Gets the localized translation for the specified string.
  ///
  /// @details If a translation is not found in the localization file(.po file), @a message is returned.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Do not free the returned value.
  ///
  /// @param[in] message The string to be translated
  /// @return The localized translation for the given @a message on success,
  /// otherwise the given @a message
  ffi.Pointer<ffi.Char> i18n_get_text(
    ffi.Pointer<ffi.Char> message,
  ) {
    return _i18n_get_text(
      message,
    );
  }

  late final _i18n_get_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Pointer<ffi.Char> Function(
              ffi.Pointer<ffi.Char>)>>('i18n_get_text');
  late final _i18n_get_text = _i18n_get_textPtr
      .asFunction<ffi.Pointer<ffi.Char> Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the current device orientation.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @return The current device orientation
  int app_get_device_orientation() {
    return _app_get_device_orientation();
  }

  late final _app_get_device_orientationPtr =
      _lookup<ffi.NativeFunction<ffi.Int32 Function()>>(
          'app_get_device_orientation');
  late final _app_get_device_orientation =
      _app_get_device_orientationPtr.asFunction<int Function()>();

  /// @brief Runs the application's main loop until ui_app_exit() is called.
  /// @details This function is the main entry point of the Tizen application.
  /// The app_create_cb() callback function is called to initialize the application before the main loop of application starts up.
  /// After the app_create_cb() callback function returns true, the main loop starts up and the app_control_cb() callback function is subsequently called.
  /// If the app_create_cb() callback function returns false, the main loop doesn't start up and app_terminate_cb() callback function is called.
  /// This main loop supports event handling for the Ecore Main Loop.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] argc The argument count
  /// @param[in] argv The argument vector
  /// @param[in] callback The set of callback functions to handle application lifecycle events
  /// @param[in] user_data The user data to be passed to the callback functions
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT The application is launched illegally, not launched by the launch system
  /// @retval #APP_ERROR_ALREADY_RUNNING The main loop already started
  /// @see app_create_cb()
  /// @see app_terminate_cb()
  /// @see app_pause_cb()
  /// @see app_resume_cb()
  /// @see app_control_cb()
  /// @see ui_app_exit()
  /// @see #ui_app_lifecycle_callback_s
  int ui_app_main(
    int argc,
    ffi.Pointer<ffi.Pointer<ffi.Char>> argv,
    ffi.Pointer<ui_app_lifecycle_callback_s> callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ui_app_main(
      argc,
      argv,
      callback,
      user_data,
    );
  }

  late final _ui_app_mainPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ui_app_lifecycle_callback_s>,
              ffi.Pointer<ffi.Void>)>>('ui_app_main');
  late final _ui_app_main = _ui_app_mainPtr.asFunction<
      int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>,
          ffi.Pointer<ui_app_lifecycle_callback_s>, ffi.Pointer<ffi.Void>)>();

  /// @brief Exits the main loop of application.
  /// @details The main loop of application stops and app_terminate_cb() is invoked.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @see ui_app_main()
  /// @see app_terminate_cb()
  void ui_app_exit() {
    return _ui_app_exit();
  }

  late final _ui_app_exitPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function()>>('ui_app_exit');
  late final _ui_app_exit = _ui_app_exitPtr.asFunction<void Function()>();

  /// @brief Adds the system event handler.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out] event_handler The event handler
  /// @param[in] event_type The system event type
  /// @param[in] callback The callback function
  /// @param[in] user_data The user data to be passed to the callback functions
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_event_type_e
  /// @see app_event_cb
  /// @see ui_app_remove_event_handler
  int ui_app_add_event_handler(
    ffi.Pointer<app_event_handler_h> event_handler,
    int event_type,
    app_event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ui_app_add_event_handler(
      event_handler,
      event_type,
      callback,
      user_data,
    );
  }

  late final _ui_app_add_event_handlerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<app_event_handler_h>,
              ffi.Int32,
              app_event_cb,
              ffi.Pointer<ffi.Void>)>>('ui_app_add_event_handler');
  late final _ui_app_add_event_handler =
      _ui_app_add_event_handlerPtr.asFunction<
          int Function(ffi.Pointer<app_event_handler_h>, int, app_event_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Removes registered event handler.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] event_handler The event handler
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see ui_app_add_event_handler
  int ui_app_remove_event_handler(
    app_event_handler_h event_handler,
  ) {
    return _ui_app_remove_event_handler(
      event_handler,
    );
  }

  late final _ui_app_remove_event_handlerPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_event_handler_h)>>(
          'ui_app_remove_event_handler');
  late final _ui_app_remove_event_handler = _ui_app_remove_event_handlerPtr
      .asFunction<int Function(app_event_handler_h)>();

  /// @brief Creates a bundle object.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @return The bundle object
  /// @retval @c NULL - Failure
  /// @exception BUNDLE_ERROR_NONE Success
  /// @exception BUNDLE_ERROR_OUT_OF_MEMORY Out of memory
  /// @see bundle_free()
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_free(b); // Free the bundle
  /// @endcode
  ffi.Pointer<bundle> bundle_create() {
    return _bundle_create();
  }

  late final _bundle_createPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<bundle> Function()>>(
          'bundle_create');
  late final _bundle_create =
      _bundle_createPtr.asFunction<ffi.Pointer<bundle> Function()>();

  /// @brief Frees the given bundle object with key-value pairs in it.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] b The bundle object to be freed
  /// @return The operation result
  /// @retval BUNDLE_ERROR_NONE Success
  /// @retval BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre @a b must be a valid bundle object.
  /// @see bundle_create()
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_free(b); // Free the bundle
  /// @endcode
  int bundle_free(
    ffi.Pointer<bundle> b,
  ) {
    return _bundle_free(
      b,
    );
  }

  late final _bundle_freePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<bundle>)>>(
          'bundle_free');
  late final _bundle_free =
      _bundle_freePtr.asFunction<int Function(ffi.Pointer<bundle>)>();

  /// @brief Adds a strings array type key-value pair into a given bundle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] b The bundle object
  /// @param[in] key The key
  /// @param[in] str_array The string type value; if @c NULL, an empty array is created; you can change an item with
  /// @param[in] len The length of the array
  /// @return The operation result
  /// @retval BUNDLE_ERROR_NONE Success
  /// @retval BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BUNDLE_ERROR_KEY_EXISTS Key already exists
  /// @retval BUNDLE_ERROR_OUT_OF_MEMORY Out of memory
  /// @pre @a b must be a valid bundle object.
  /// @see bundle_get_str_array()
  ///
  /// @code
  /// #include <bundle.h>
  /// char *sa = {"aaa", "bbb", "ccc"}; // String array of length 3
  /// bundle *b = bundle_create();
  /// bundle_add_str_array(b, "foo", sa, 3); // Add a key-value pair
  /// bundle_free(b);
  /// @endcode
  int bundle_add_str_array(
    ffi.Pointer<bundle> b,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> str_array,
    int len,
  ) {
    return _bundle_add_str_array(
      b,
      key,
      str_array,
      len,
    );
  }

  late final _bundle_add_str_arrayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<bundle>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Int)>>('bundle_add_str_array');
  late final _bundle_add_str_array = _bundle_add_str_arrayPtr.asFunction<
      int Function(ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>, int)>();

  /// @brief Deletes a key-value object with the given key.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] b The bundle object
  /// @param[in] key The given key
  /// @return The operation result
  /// @retval BUNDLE_ERROR_NONE Success
  /// @retval BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BUNDLE_ERROR_KEY_NOT_AVAILABLE Key not available
  /// @pre @a b must be a valid bundle object.
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_add_str(b, "foo_key", "bar_val"); // Add a key-value pair
  /// bundle_del(b, "foo_key"); // Delete "foo_key" from b
  ///
  /// bundle_free(b);
  /// @endcode
  int bundle_del(
    ffi.Pointer<bundle> b,
    ffi.Pointer<ffi.Char> key,
  ) {
    return _bundle_del(
      b,
      key,
    );
  }

  late final _bundle_delPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>)>>('bundle_del');
  late final _bundle_del = _bundle_delPtr
      .asFunction<int Function(ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets a string array from a given key.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You MUST NOT free or modify the returned string. \n
  /// The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] b The bundle object
  /// @param[in] key The key
  /// @param[out] len The array length
  /// @return The pointer to the array of strings
  /// @retval @c NULL - Key not found
  /// @exception BUNDLE_ERROR_NONE Success
  /// @exception BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception BUNDLE_ERROR_KEY_NOT_AVAILABLE Key not available
  /// @pre @a b must be a valid bundle object.
  /// @see bundle_add_str_array()
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create();
  /// char *sa = {"aaa", "bbb", "ccc"}; // String array of length 3
  /// bundle_add_str_array(b, "foo", sa, 3); // Add a key-value pair
  ///
  /// char **str_array = NULL;
  /// int len_str_array = 0;
  ///
  /// str_array=bundle_get_str_array(b, "foo", &len_str_array);
  /// // str_array = {"aaa", "bbb", "ccc"}, and len_str_array = 3
  ///
  /// bundle_free(b);
  /// @endcode
  ffi.Pointer<ffi.Pointer<ffi.Char>> bundle_get_str_array(
    ffi.Pointer<bundle> b,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Int> len,
  ) {
    return _bundle_get_str_array(
      b,
      key,
      len,
    );
  }

  late final _bundle_get_str_arrayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Pointer<ffi.Pointer<ffi.Char>> Function(
              ffi.Pointer<bundle>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('bundle_get_str_array');
  late final _bundle_get_str_array = _bundle_get_str_arrayPtr.asFunction<
      ffi.Pointer<ffi.Pointer<ffi.Char>> Function(
          ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the number of bundle items.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] b The bundle object
  /// @return The number of bundle items
  /// @pre @a b must be a valid bundle object.
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_add_str(b, "key1", "val1"); // Add a key-value pair
  /// int count = bundle_get_count(b); // count = 1
  /// bundle_add_str(b, "key2", "val2"); // Add another key-value pair
  /// count = bundle_get_count(b); // count = 2
  ///
  /// bundle_free(b);
  /// @endcode
  int bundle_get_count(
    ffi.Pointer<bundle> b,
  ) {
    return _bundle_get_count(
      b,
    );
  }

  late final _bundle_get_countPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<bundle>)>>(
          'bundle_get_count');
  late final _bundle_get_count =
      _bundle_get_countPtr.asFunction<int Function(ffi.Pointer<bundle>)>();

  /// @brief Gets the type of the value with a given key.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] b A bundle
  /// @param[in] key A key in the bundle
  /// @return The type of a key in @a b
  /// @exception BUNDLE_ERROR_NONE Success
  /// @exception BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception BUNDLE_ERROR_KEY_NOT_AVAILABLE Key not available
  /// @pre @a b must be a valid bundle object.
  /// @see bundle_type_t
  int bundle_get_type(
    ffi.Pointer<bundle> b,
    ffi.Pointer<ffi.Char> key,
  ) {
    return _bundle_get_type(
      b,
      key,
    );
  }

  late final _bundle_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>)>>('bundle_get_type');
  late final _bundle_get_type = _bundle_get_typePtr
      .asFunction<int Function(ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>)>();

  /// @brief Duplicates a given bundle object.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] b_from The bundle object to be duplicated
  /// @return The new bundle object
  /// @retval @c NULL - Failure
  /// @exception BUNDLE_ERROR_NONE Success
  /// @exception BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre @a b must be a valid bundle object.
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_add_str(b, "foo_key", "bar_val"); // Add a key-value pair
  /// bundle *b_dup = bundle_dup(b); // Duplicate b
  ///
  /// bundle_free(b);
  /// bundle_free(b_dup);
  /// @endcode
  ffi.Pointer<bundle> bundle_dup(
    ffi.Pointer<bundle> b_from,
  ) {
    return _bundle_dup(
      b_from,
    );
  }

  late final _bundle_dupPtr = _lookup<
      ffi.NativeFunction<
          ffi.Pointer<bundle> Function(ffi.Pointer<bundle>)>>('bundle_dup');
  late final _bundle_dup = _bundle_dupPtr
      .asFunction<ffi.Pointer<bundle> Function(ffi.Pointer<bundle>)>();

  /// @brief Iterates a callback function for each key-value pair in a given bundle.
  /// @details Supports all types of values.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section. \n
  /// This function supports all types.
  /// @param[in] b The bundle object
  /// @param[in] iter The iteration callback function
  /// @param[in] user_data The data for the callback function
  /// @exception BUNDLE_ERROR_NONE Success
  /// @exception BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre @a b must be a valid bundle object.
  /// @see bundle_keyval_get_type()
  /// @see bundle_keyval_type_is_array()
  /// @see bundle_keyval_get_basic_val()
  /// @see bundle_keyval_get_array_val()
  ///
  /// @code
  /// #include <stdio.h>
  /// #include <bundle.h>
  /// void
  /// sample_cb(const char *key, const int type, const bundle_keyval_t *kv, void *user_data)
  /// {
  /// void *basic_val = NULL;
  /// size_t basic_size = 0;
  /// void **array_val = NULL;
  /// int array_len = 0;
  /// size_t *array_elem_size = NULL;
  ///
  /// printf("Key:%s, Type:%d\n", key, type);
  /// if (bundle_keyval_type_is_array(kv)) {
  /// bundle_keyval_get_array_val(kv, &array_val, &array_len, &array_elem_size);
  /// // Do something
  /// }
  /// else {
  /// bundle_keyval_get_basic_val(kv, &basic_val, &basic_size);
  /// // Do something
  /// }
  /// }
  ///
  /// int main(void)
  /// {
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_add_str(b, "k1", "v1"); // Add a key-value pair
  /// bundle_add_byte(b, "k2", "v2", 3); // Add a key-value pair
  /// char *s_arr[] = {"abc", "bcd", "cde"};
  /// bundle_add_str_array(b, "k3", s_arr, 3); // Add a key-value pair
  /// bundle_foreach(b, sample_cb, NULL); // Iterate sample_cb() for each key/value
  ///
  /// return 0;
  /// }
  /// @endcode
  void bundle_foreach(
    ffi.Pointer<bundle> b,
    bundle_iterator_t iter,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bundle_foreach(
      b,
      iter,
      user_data,
    );
  }

  late final _bundle_foreachPtr = _lookup<
      ffi.NativeFunction<
          ffi.Void Function(ffi.Pointer<bundle>, bundle_iterator_t,
              ffi.Pointer<ffi.Void>)>>('bundle_foreach');
  late final _bundle_foreach = _bundle_foreachPtr.asFunction<
      void Function(
          ffi.Pointer<bundle>, bundle_iterator_t, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the type of a key-value pair.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] kv A bundle_keyval_t object
  /// @return The type of @a kv
  /// @retval @c -1 - Failure
  /// @exception BUNDLE_ERROR_NONE Success
  /// @exception BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre @a kv must be a valid bundle_keyval_t object.
  /// @see bundle_foreach()
  int bundle_keyval_get_type(
    ffi.Pointer<bundle_keyval_t> kv,
  ) {
    return _bundle_keyval_get_type(
      kv,
    );
  }

  late final _bundle_keyval_get_typePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<bundle_keyval_t>)>>(
      'bundle_keyval_get_type');
  late final _bundle_keyval_get_type = _bundle_keyval_get_typePtr
      .asFunction<int Function(ffi.Pointer<bundle_keyval_t>)>();

  /// @brief Determines whether the type of a key-value pair is an array.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] kv A bundle_keyval_t object
  /// @return The operation result
  /// @retval @c 1 - @a kv is an array
  /// @retval @c 0 - @a kv is not an array
  /// @exception BUNDLE_ERROR_NONE Success
  /// @exception BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre @a kv must be a valid bundle_keyval_t object.
  /// @see bundle_foreach()
  int bundle_keyval_type_is_array(
    ffi.Pointer<bundle_keyval_t> kv,
  ) {
    return _bundle_keyval_type_is_array(
      kv,
    );
  }

  late final _bundle_keyval_type_is_arrayPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<bundle_keyval_t>)>>(
      'bundle_keyval_type_is_array');
  late final _bundle_keyval_type_is_array = _bundle_keyval_type_is_arrayPtr
      .asFunction<int Function(ffi.Pointer<bundle_keyval_t>)>();

  /// @brief Gets the value and size of the value from a key-value pair of basic type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must not free @a val.
  /// @param[in] kv A bundle_keyval_t object
  /// @param[out] val The value
  /// @param[out] size The size of @a val
  /// @return The operation result
  /// @retval BUNDLE_ERROR_NONE Success
  /// @retval BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre @a kv must be a valid bundle_keyval_t object.
  /// @post @a val and @a size are set.
  /// @see bundle_foreach()
  int bundle_keyval_get_basic_val(
    ffi.Pointer<bundle_keyval_t> kv,
    ffi.Pointer<ffi.Pointer<ffi.Void>> val,
    ffi.Pointer<ffi.Size> size,
  ) {
    return _bundle_keyval_get_basic_val(
      kv,
      val,
      size,
    );
  }

  late final _bundle_keyval_get_basic_valPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<bundle_keyval_t>,
              ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.Size>)>>('bundle_keyval_get_basic_val');
  late final _bundle_keyval_get_basic_val =
      _bundle_keyval_get_basic_valPtr.asFunction<
          int Function(ffi.Pointer<bundle_keyval_t>,
              ffi.Pointer<ffi.Pointer<ffi.Void>>, ffi.Pointer<ffi.Size>)>();

  /// @brief Gets the value array, length of the array, and size of each array item.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] kv A bundle_keyval_t object
  /// @param[out] array_val The array pointer of values
  /// @param[out] array_len The length of @a array_val
  /// @param[out] array_element_size The array of size of each array element
  /// @return The operation result
  /// @retval BUNDLE_ERROR_NONE Success
  /// @retval BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre @a kv must be a valid bundle_keyval_t object.
  /// @post @a array_val, @a array_len, @a array_item_size are set.
  /// @see bundle_foreach()
  int bundle_keyval_get_array_val(
    ffi.Pointer<bundle_keyval_t> kv,
    ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Void>>> array_val,
    ffi.Pointer<ffi.UnsignedInt> array_len,
    ffi.Pointer<ffi.Pointer<ffi.Size>> array_element_size,
  ) {
    return _bundle_keyval_get_array_val(
      kv,
      array_val,
      array_len,
      array_element_size,
    );
  }

  late final _bundle_keyval_get_array_valPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<bundle_keyval_t>,
                  ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Void>>>,
                  ffi.Pointer<ffi.UnsignedInt>,
                  ffi.Pointer<ffi.Pointer<ffi.Size>>)>>(
      'bundle_keyval_get_array_val');
  late final _bundle_keyval_get_array_val =
      _bundle_keyval_get_array_valPtr.asFunction<
          int Function(
              ffi.Pointer<bundle_keyval_t>,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Void>>>,
              ffi.Pointer<ffi.UnsignedInt>,
              ffi.Pointer<ffi.Pointer<ffi.Size>>)>();

  /// @brief Encodes a bundle to the bundle_raw format (uses base64 format).
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] b The bundle object
  /// @param[out] r The returned bundle_raw data(byte data)
  /// @a r MUST BE FREED by free(r)
  /// @param[out] len The size of @a r (in bytes)
  /// @return The size of the raw data
  /// @retval BUNDLE_ERROR_NONE Success
  /// @retval BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre @a b must be a valid bundle object.
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_add_str(b, "foo_key", "bar_val"); // Add a key-value pair
  /// bundle_raw *r;
  /// int len;
  /// bundle_encode(b, &r, &len); // Encode b
  ///
  /// bundle_free(b);
  /// @endcode
  int bundle_encode(
    ffi.Pointer<bundle> b,
    ffi.Pointer<ffi.Pointer<bundle_raw>> r,
    ffi.Pointer<ffi.Int> len,
  ) {
    return _bundle_encode(
      b,
      r,
      len,
    );
  }

  late final _bundle_encodePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<bundle>,
              ffi.Pointer<ffi.Pointer<bundle_raw>>,
              ffi.Pointer<ffi.Int>)>>('bundle_encode');
  late final _bundle_encode = _bundle_encodePtr.asFunction<
      int Function(ffi.Pointer<bundle>, ffi.Pointer<ffi.Pointer<bundle_raw>>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Deserializes bundle_raw and gets the bundle object.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] r The bundle_raw data to be converted to bundle object
  /// @param[in] len The size of @a r
  /// @return The bundle object
  /// @retval @c NULL - Failure
  /// @exception BUNDLE_ERROR_NONE Success
  /// @exception BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre @a b must be a valid bundle object.
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_add_str(b, "foo_key", "bar_val"); // Add a key-value pair
  ///
  /// bundle_raw *encoded_b;
  /// int len;
  /// bundle_encode(b, &encoded_b, &len); // Encode b
  ///
  /// bundle *b_dup;
  /// b_dup = bundle_decode(encoded_b, len); // Decoded bundle object
  ///
  /// bundle_free(b);
  /// free(encoded_b);
  /// bundle_free(b_dup);
  /// @endcode
  ffi.Pointer<bundle> bundle_decode(
    ffi.Pointer<bundle_raw> r,
    int len,
  ) {
    return _bundle_decode(
      r,
      len,
    );
  }

  late final _bundle_decodePtr = _lookup<
      ffi.NativeFunction<
          ffi.Pointer<bundle> Function(
              ffi.Pointer<bundle_raw>, ffi.Int)>>('bundle_decode');
  late final _bundle_decode = _bundle_decodePtr
      .asFunction<ffi.Pointer<bundle> Function(ffi.Pointer<bundle_raw>, int)>();

  /// @brief Adds a string type key-value pair into a bundle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] b The bundle object
  /// @param[in] key The key
  /// @param[in] str The string type value
  /// @return The operation result
  /// @retval BUNDLE_ERROR_NONE Success
  /// @retval BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BUNDLE_ERROR_KEY_EXISTS Key already exists
  /// @retval BUNDLE_ERROR_OUT_OF_MEMORY Out of memory
  /// @pre @a b must be a valid bundle object.
  /// @see bundle_get_str()
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_add_str(b, "foo", "bar"); // Add a key-value pair
  ///
  /// bundle_free(b);
  /// @endcode
  int bundle_add_str(
    ffi.Pointer<bundle> b,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> str,
  ) {
    return _bundle_add_str(
      b,
      key,
      str,
    );
  }

  late final _bundle_add_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('bundle_add_str');
  late final _bundle_add_str = _bundle_add_strPtr.asFunction<
      int Function(
          ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Adds a byte type key-value pair into a bundle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] b The bundle object
  /// @param[in] key The key
  /// @param[in] byte The string type value
  /// @param[in] size The size of @a byte
  /// @return The operation result
  /// @retval BUNDLE_ERROR_NONE Success
  /// @retval BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BUNDLE_ERROR_KEY_EXISTS Key already exists
  /// @retval BUNDLE_ERROR_OUT_OF_MEMORY Out of memory
  /// @pre @a b must be a valid bundle object.
  /// @see bundle_get_byte()
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_add_byte(b, "foo", "bar\0", 4); // Add a key-value pair
  ///
  /// int number = 12345;
  /// bundle_add_byte(b, "number", &number, sizeof(int));
  ///
  /// bundle_free(b);
  /// @endcode
  int bundle_add_byte(
    ffi.Pointer<bundle> b,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Void> byte,
    int size,
  ) {
    return _bundle_add_byte(
      b,
      key,
      byte,
      size,
    );
  }

  late final _bundle_add_bytePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Void>, ffi.Size)>>('bundle_add_byte');
  late final _bundle_add_byte = _bundle_add_bytePtr.asFunction<
      int Function(ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Void>, int)>();

  /// @brief Gets the string value with the given key.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must not free str.
  /// @param[in] b The bundle object
  /// @param[in] key The key
  /// @param[out] str The returned value
  /// @return The operation result
  /// @retval BUNDLE_ERROR_NONE Success
  /// @retval BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BUNDLE_ERROR_KEY_NOT_AVAILABLE Key not available
  /// @pre @a b must be a valid bundle object.
  /// @see bundle_add_str()
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_add_str(b, "foo_key", "bar_val"); // Add a key-value pair
  ///
  /// char *v = NULL;
  /// bundle_get_str(b, "foo_key", &v); // v = "bar_val"
  ///
  /// bundle_free(b); // After freeing b, v becomes a dangling pointer
  /// v = NULL;
  /// @endcode
  int bundle_get_str(
    ffi.Pointer<bundle> b,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> str,
  ) {
    return _bundle_get_str(
      b,
      key,
      str,
    );
  }

  late final _bundle_get_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('bundle_get_str');
  late final _bundle_get_str = _bundle_get_strPtr.asFunction<
      int Function(ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the byte value with the given key.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must not free @a byte.
  /// @param[in] b The bundle object
  /// @param[in] key The key
  /// @param[out] byte The returned value
  /// @param[out] size The size of the byte
  /// @return The operation result
  /// @retval BUNDLE_ERROR_NONE Success
  /// @retval BUNDLE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BUNDLE_ERROR_KEY_NOT_AVAILABLE Key not available
  /// @pre @a b must be a valid bundle object.
  /// @see bundle_add_byte()
  ///
  /// @code
  /// #include <bundle.h>
  /// bundle *b = bundle_create(); // Create a new bundle object
  /// bundle_add_byte(b, "foo", "bar\0", 4); // Add a string to the bundle
  /// int number = 12345;
  /// bundle_add_byte(b, "number", (const void**)&number, sizeof(int)); // Add an integer to the bundle
  ///
  /// unsigned char *v = NULL;
  /// size_t v_size;
  /// bundle_get_byte(b, "foo", (void**)&v, &v_size); // v = "bar\0"
  /// int *n = NULL;
  /// size_t n_size;
  /// bundle_get_byte(b, "number", (void**)&n, &n_size); // number = 12345
  ///
  /// bundle_free(b); // After freeing b, v and n become a dangling pointer
  /// @endcode
  int bundle_get_byte(
    ffi.Pointer<bundle> b,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Void>> byte,
    ffi.Pointer<ffi.Size> size,
  ) {
    return _bundle_get_byte(
      b,
      key,
      byte,
      size,
    );
  }

  late final _bundle_get_bytePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<bundle>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.Size>)>>('bundle_get_byte');
  late final _bundle_get_byte = _bundle_get_bytePtr.asFunction<
      int Function(ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ffi.Void>>, ffi.Pointer<ffi.Size>)>();

  /// @brief Shows a toast popup window with given message.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] message The messages to be posted
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #NOTIFICATION_ERROR_FROM_DBUS Error from DBus
  /// @see #notification_error_e
  int notification_status_message_post(
    ffi.Pointer<ffi.Char> message,
  ) {
    return _notification_status_message_post(
      message,
    );
  }

  late final _notification_status_message_postPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'notification_status_message_post');
  late final _notification_status_message_post =
      _notification_status_message_postPtr
          .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Sets an absolute path for an image file to display on the notification view.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] type The notification image type
  /// @param[in] image_path The image file full path
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Notification handle should be created by notification_create().
  /// @see #notification_image_type_e
  /// @see notification_create()
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// noti_err = notification_set_image(noti, NOTIFICATION_IMAGE_TYPE_ICON, APP_IMAGE_FULL_PATH);
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_set_image(
    notification_h noti,
    int type,
    ffi.Pointer<ffi.Char> image_path,
  ) {
    return _notification_set_image(
      noti,
      type,
      image_path,
    );
  }

  late final _notification_set_imagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('notification_set_image');
  late final _notification_set_image = _notification_set_imagePtr
      .asFunction<int Function(notification_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the absolute path of an image file.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @remarks Do not free @a image_path. It will be freed when notification_free() is called.
  /// @param[in] noti Notification handle
  /// @param[in] type Notification image type
  /// @param[out] image_path Image file full path
  /// @return NOTIFICATION_ERROR_NONE on success,
  /// other value on failure
  /// @retval NOTIFICATION_ERROR_NONE Success
  /// @retval NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Notification handle should be created by notification_create().
  /// @see #notification_image_type_e
  /// @see notification_create()
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// char *image_path = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti_err = notification_get_image(noti, NOTIFICATION_IMAGE_TYPE_ICON, &image_path);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int notification_get_image(
    notification_h noti,
    int type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> image_path,
  ) {
    return _notification_get_image(
      noti,
      type,
      image_path,
    );
  }

  late final _notification_get_imagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('notification_get_image');
  late final _notification_get_image = _notification_get_imagePtr.asFunction<
      int Function(notification_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets a timestamp.
  /// @details If input_time is @c 0, time information is taken from the current time.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] input_time The input time. If you want the time stamp to not be shown, set this as NOTIFICATION_DO_NOT_SHOW_TIME_STAMP
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Notification handle should be created by notification_create().
  /// @see notification_create()
  /// @see NOTIFICATION_DO_NOT_SHOW_TIME_STAMP
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// noti_err = notification_set_time(noti, time(NULL));
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_set_time(
    notification_h noti,
    int input_time,
  ) {
    return _notification_set_time(
      noti,
      input_time,
    );
  }

  late final _notification_set_timePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, time_t)>>(
          'notification_set_time');
  late final _notification_set_time =
      _notification_set_timePtr.asFunction<int Function(notification_h, int)>();

  /// @brief Gets a timestamp.
  /// @details If ret_time is @c 0, time information is not set before.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] ret_time The return time value
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Notification handle should be created by notification_create().
  /// @see notification_create()
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// time_t ret_time;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti_err = notification_get_time(noti, &ret_time);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int notification_get_time(
    notification_h noti,
    ffi.Pointer<time_t> ret_time,
  ) {
    return _notification_get_time(
      noti,
      ret_time,
    );
  }

  late final _notification_get_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              notification_h, ffi.Pointer<time_t>)>>('notification_get_time');
  late final _notification_get_time = _notification_get_timePtr
      .asFunction<int Function(notification_h, ffi.Pointer<time_t>)>();

  /// @brief Gets an insertion timestamp of the notification.
  /// @details If ret_time is @c 0, this notification data is not inserted before.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] ret_time The return time value
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// time_t ret_time;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti_err = notification_get_insert_time(noti, &ret_time);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int notification_get_insert_time(
    notification_h noti,
    ffi.Pointer<time_t> ret_time,
  ) {
    return _notification_get_insert_time(
      noti,
      ret_time,
    );
  }

  late final _notification_get_insert_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<time_t>)>>('notification_get_insert_time');
  late final _notification_get_insert_time = _notification_get_insert_timePtr
      .asFunction<int Function(notification_h, ffi.Pointer<time_t>)>();

  /// @brief Sets the text to display on the notification view.
  /// @details Sets title, content string. If the text is formatted data (only %d, %f, %s are supported), type - value pair should be set.
  /// If %d, the type #NOTIFICATION_VARIABLE_TYPE_INT and the value is an integer.
  /// If %f, the type #NOTIFICATION_VARIABLE_TYPE_DOUBLE and the value is a double.
  /// If %s, the type #NOTIFICATION_VARIABLE_TYPE_STRING and the value is a string.
  /// If the type is #NOTIFICATION_VARIABLE_TYPE_COUNT, notification count is displaying with text.
  /// If the value is #NOTIFICATION_COUNT_POS_LEFT, count is displayed at the left of the text.
  /// If the value is #NOTIFICATION_COUNT_POS_IN, count is displayed in the text when text has %d format.
  /// If the value is #NOTIFICATION_COUNT_POS_RIGHT, count is displayed at the right of the text.
  /// Variable parameters should be terminated #NOTIFICATION_VARIABLE_TYPE_NONE.
  ///
  /// Note that You can display the translated contents according to the language of the system.
  /// The application must supply a String KEY as the fourth argument to support localization.
  /// If the language on the system changes, the contents of the notification are also translated.
  ///
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] type The notification text type
  /// @param[in] text The basic text
  /// @param[in] key The text key for localization
  /// @param[in] args_type The variable parameter that type - value pair
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre notification handle should be created by notification_create().
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// noti_err = notification_set_text(noti, NOTIFICATION_TEXT_TYPE_TITLE,
  /// "I'm Title", "IDS_APP_BODY_IM_TITLE", NOTIFICATION_VARIABLE_TYPE_NONE);
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_set_text(
    notification_h noti,
    int type,
    ffi.Pointer<ffi.Char> text,
    ffi.Pointer<ffi.Char> key,
    int args_type,
  ) {
    return _notification_set_text(
      noti,
      type,
      text,
      key,
      args_type,
    );
  }

  late final _notification_set_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, ffi.Int)>>('notification_set_text');
  late final _notification_set_text = _notification_set_textPtr.asFunction<
      int Function(notification_h, int, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>, int)>();

  /// @brief Gets the text from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] type The notification text type
  /// @param[out] text The notification text
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// char *text = NULL;
  ///
  /// noti_err = notification_get_text(noti, NOTIFICATION_TEXT_TYPE_TITLE, &text);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_text(
    notification_h noti,
    int type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> text,
  ) {
    return _notification_get_text(
      noti,
      type,
      text,
    );
  }

  late final _notification_get_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('notification_get_text');
  late final _notification_get_text = _notification_get_textPtr.asFunction<
      int Function(notification_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the timestamp to display on the notification view.
  /// @details The timestamp will be converted to a formatted string and it will be displayed on the set text area.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] type The notification text type
  /// @param[in] time The timestamp
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Notification handle should be created by notification_create().
  int notification_set_time_to_text(
    notification_h noti,
    int type,
    int time,
  ) {
    return _notification_set_time_to_text(
      noti,
      type,
      time,
    );
  }

  late final _notification_set_time_to_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              time_t)>>('notification_set_time_to_text');
  late final _notification_set_time_to_text = _notification_set_time_to_textPtr
      .asFunction<int Function(notification_h, int, int)>();

  /// @brief Gets the timestamp from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] type The notification text type
  /// @param[in] time The pointer of time stamp
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Notification handle should be created by notification_create().
  int notification_get_time_from_text(
    notification_h noti,
    int type,
    ffi.Pointer<time_t> time,
  ) {
    return _notification_get_time_from_text(
      noti,
      type,
      time,
    );
  }

  late final _notification_get_time_from_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              ffi.Pointer<time_t>)>>('notification_get_time_from_text');
  late final _notification_get_time_from_text =
      _notification_get_time_from_textPtr
          .asFunction<int Function(notification_h, int, ffi.Pointer<time_t>)>();

  /// @brief Sets the sound type for the notification.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] type The notification sound type
  /// @param[in] path The user sound file path
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti_err = notification_set_sound(noti, NOTIFICATION_SOUND_TYPE_DEFAULT, NULL);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_set_sound(
    notification_h noti,
    int type,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _notification_set_sound(
      noti,
      type,
      path,
    );
  }

  late final _notification_set_soundPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('notification_set_sound');
  late final _notification_set_sound = _notification_set_soundPtr
      .asFunction<int Function(notification_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the sound type from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] type The notification sound type
  /// @param[out] path The user sound file path
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// notification_sound_type_e type = NOTIFICATION_SOUND_TYPE_NONE;
  ///
  /// noti_err = notification_get_sound(noti, &type, NULL);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_sound(
    notification_h noti,
    ffi.Pointer<ffi.Int32> type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _notification_get_sound(
      noti,
      type,
      path,
    );
  }

  late final _notification_get_soundPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('notification_get_sound');
  late final _notification_get_sound = _notification_get_soundPtr.asFunction<
      int Function(notification_h, ffi.Pointer<ffi.Int32>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the vibration type for the notification.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] type The notification vibration type
  /// @param[in] path The user vibration file path
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti_err = notification_set_vibration(noti, NOTIFICATION_VIBRATION_TYPE_DEFAULT, NULL);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_set_vibration(
    notification_h noti,
    int type,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _notification_set_vibration(
      noti,
      type,
      path,
    );
  }

  late final _notification_set_vibrationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('notification_set_vibration');
  late final _notification_set_vibration = _notification_set_vibrationPtr
      .asFunction<int Function(notification_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the vibrate type from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] type The notification sound type
  /// @param[out] path The user vibration file path
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// notification_vibration_type_e type = NOTIFICATION_VIBRATION_TYPE_NONE;
  ///
  /// noti_err = notification_get_vibration(noti, &type, NULL);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_vibration(
    notification_h noti,
    ffi.Pointer<ffi.Int32> type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _notification_get_vibration(
      noti,
      type,
      path,
    );
  }

  late final _notification_get_vibrationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(notification_h, ffi.Pointer<ffi.Int32>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'notification_get_vibration');
  late final _notification_get_vibration =
      _notification_get_vibrationPtr.asFunction<
          int Function(notification_h, ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the LED displaying option.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] operation The LED notification operation
  /// @param[in] led_argb The notification LED color
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti_err = notification_set_led(noti, NOTIFICATION_LED_OP_ON, NULL);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_set_led(
    notification_h noti,
    int operation,
    int led_argb,
  ) {
    return _notification_set_led(
      noti,
      operation,
      led_argb,
    );
  }

  late final _notification_set_ledPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              notification_h, ffi.Int32, ffi.Int)>>('notification_set_led');
  late final _notification_set_led = _notification_set_ledPtr
      .asFunction<int Function(notification_h, int, int)>();

  /// @brief Gets the LED displaying option from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] operation The LED notification operation
  /// @param[out] led_argb The notification LED color
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// notification_led_type_e type = NOTIFICATION_LED_OP_OFF;
  ///
  /// noti_err = notification_get_led(noti, &type, NULL);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_led(
    notification_h noti,
    ffi.Pointer<ffi.Int32> operation,
    ffi.Pointer<ffi.Int> led_argb,
  ) {
    return _notification_get_led(
      noti,
      operation,
      led_argb,
    );
  }

  late final _notification_get_ledPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Int>)>>('notification_get_led');
  late final _notification_get_led = _notification_get_ledPtr.asFunction<
      int Function(
          notification_h, ffi.Pointer<ffi.Int32>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the time period of flashing the LED.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] on_ms The time for turning on the LED
  /// @param[in] off_ms The time for turning off the LED
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti_err = notification_set_led_time_period(noti, 100, 100);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_set_led_time_period(
    notification_h noti,
    int on_ms,
    int off_ms,
  ) {
    return _notification_set_led_time_period(
      noti,
      on_ms,
      off_ms,
    );
  }

  late final _notification_set_led_time_periodPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int,
              ffi.Int)>>('notification_set_led_time_period');
  late final _notification_set_led_time_period =
      _notification_set_led_time_periodPtr
          .asFunction<int Function(notification_h, int, int)>();

  /// @brief Gets the time period of flashing the LED from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] on_ms The time for turning on the LED
  /// @param[out] off_ms The time for turning on the LED
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// int led_on_ms = 0;
  /// int led_off_ms = 0;
  ///
  /// noti_err = notification_get_led_time_period(noti, &led_on_ms, &led_off_ms);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_led_time_period(
    notification_h noti,
    ffi.Pointer<ffi.Int> on_ms,
    ffi.Pointer<ffi.Int> off_ms,
  ) {
    return _notification_get_led_time_period(
      noti,
      on_ms,
      off_ms,
    );
  }

  late final _notification_get_led_time_periodPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('notification_get_led_time_period');
  late final _notification_get_led_time_period =
      _notification_get_led_time_periodPtr.asFunction<
          int Function(
              notification_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the launch option for a notification.
  /// @details When notification data selected in display application, application launched by app_control_send_launch_request with app_control handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] type Launching option type
  /// @param[in] option App Control handler
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// app_control_h app_control = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// // Do something
  ///
  /// app_control_create(&app_control);
  /// app_control_set_app_id(app_control, "org.tizen.app");
  ///
  /// // Do something
  ///
  /// noti_err = notification_set_launch_option(noti, NOTIFICATION_LAUNCH_OPTION_APP_CONTROL, (void *)app_control);
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// app_control_destroy(app_control);
  /// notification_free(noti);
  /// return;
  /// }
  ///
  /// app_control_destroy(app_control);
  /// }
  /// @endcode
  int notification_set_launch_option(
    notification_h noti,
    int type,
    ffi.Pointer<ffi.Void> option,
  ) {
    return _notification_set_launch_option(
      noti,
      type,
      option,
    );
  }

  late final _notification_set_launch_optionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              ffi.Pointer<ffi.Void>)>>('notification_set_launch_option');
  late final _notification_set_launch_option =
      _notification_set_launch_optionPtr.asFunction<
          int Function(notification_h, int, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the launch option from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @remarks You must release @a app_control using app_control_destroy().
  /// @param[in] noti The notification handle
  /// @param[in] type Launching option type
  /// @param[out] option The pointer of App Control handler
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// app_control_h app_control = NULL;
  /// app_control_create(&app_control);
  ///
  /// // Do something
  ///
  /// noti_err = notification_get_launch_option(noti, NOTIFICATION_LAUNCH_OPTION_APP_CONTROL, (void *)&app_control);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int notification_get_launch_option(
    notification_h noti,
    int type,
    ffi.Pointer<ffi.Void> option,
  ) {
    return _notification_get_launch_option(
      noti,
      type,
      option,
    );
  }

  late final _notification_get_launch_optionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              ffi.Pointer<ffi.Void>)>>('notification_get_launch_option');
  late final _notification_get_launch_option =
      _notification_get_launch_optionPtr.asFunction<
          int Function(notification_h, int, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the handler for a specific event.
  /// @details When some event occurs on notification, application launched by app_control_send_launch_request with app_control handle. \n
  /// Setting event handler of a button means that the notification will show the button.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] noti The notification handle
  /// @param[in] event_type Event type
  /// @param[in] event_handler App control handle
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see #notification_event_type_e
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// app_control_h app_control = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// // Do something
  ///
  /// app_control_create(&app_control);
  /// app_control_set_app_id(app_control, "org.tizen.app");
  ///
  /// // Do something
  ///
  /// noti_err = notification_set_event_handler(noti, NOTIFICATION_EVENT_TYPE_CLICK_ON_BUTTON_1, app_control);
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// app_control_destroy(app_control);
  /// notification_free(noti);
  /// return;
  /// }
  ///
  /// app_control_destroy(app_control);
  /// }
  /// @endcode
  int notification_set_event_handler(
    notification_h noti,
    int event_type,
    app_control_h event_handler,
  ) {
    return _notification_set_event_handler(
      noti,
      event_type,
      event_handler,
    );
  }

  late final _notification_set_event_handlerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              app_control_h)>>('notification_set_event_handler');
  late final _notification_set_event_handler =
      _notification_set_event_handlerPtr
          .asFunction<int Function(notification_h, int, app_control_h)>();

  /// @brief Gets the event handler of a specific event.
  /// @remarks You must release @a app_control using app_control_destroy().
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] noti The notification handle
  /// @param[in] event_type Launching option type
  /// @param[out] event_handler The handler of App Control
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see #notification_event_type_e
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// app_control_h app_control = NULL;
  /// app_control_create(&app_control);
  ///
  /// // Do something
  ///
  /// noti_err = notification_get_event_handler(noti, NOTIFICATION_EVENT_TYPE_CLICK_ON_BUTTON_1, &app_control);
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_get_event_handler(
    notification_h noti,
    int event_type,
    ffi.Pointer<app_control_h> event_handler,
  ) {
    return _notification_get_event_handler(
      noti,
      event_type,
      event_handler,
    );
  }

  late final _notification_get_event_handlerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int32,
              ffi.Pointer<app_control_h>)>>('notification_get_event_handler');
  late final _notification_get_event_handler =
      _notification_get_event_handlerPtr.asFunction<
          int Function(notification_h, int, ffi.Pointer<app_control_h>)>();

  /// @brief Sets the property of the notification.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] flags The property with | operation
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// bundle *b = NULL;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// noti_err = notification_set_property(noti, NOTIFICATION_PROP_DISPLAY_ONLY_SIMMODE | NOTIFICATION_PROP_DISABLE_APP_LAUNCH);
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_set_property(
    notification_h noti,
    int flags,
  ) {
    return _notification_set_property(
      noti,
      flags,
    );
  }

  late final _notification_set_propertyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, ffi.Int)>>(
          'notification_set_property');
  late final _notification_set_property = _notification_set_propertyPtr
      .asFunction<int Function(notification_h, int)>();

  /// @brief Gets the property of the notification from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] flags The notification property
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// int flags = 0;
  ///
  /// noti_err = notification_get_property(noti, &flags);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_property(
    notification_h noti,
    ffi.Pointer<ffi.Int> flags,
  ) {
    return _notification_get_property(
      noti,
      flags,
    );
  }

  late final _notification_get_propertyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Int>)>>('notification_get_property');
  late final _notification_get_property = _notification_get_propertyPtr
      .asFunction<int Function(notification_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets applications to display the notification.
  /// @details All display application is enabled(NOTIFICATION_DISPLAY_APP_ALL) if you do not call this API.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] applist The with | operation
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// bundle *b = NULL;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// noti_err = notification_set_display_applist(noti, NOTIFICATION_DISPLAY_APP_NOTIFICATION_TRAY |
  /// NOTIFICATION_DISPLAY_APP_TICKER | NOTIFICATION_DISPLAY_APP_INDICATOR);
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_set_display_applist(
    notification_h noti,
    int applist,
  ) {
    return _notification_set_display_applist(
      noti,
      applist,
    );
  }

  late final _notification_set_display_applistPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, ffi.Int)>>(
          'notification_set_display_applist');
  late final _notification_set_display_applist =
      _notification_set_display_applistPtr
          .asFunction<int Function(notification_h, int)>();

  /// @brief Gets the application list displaying the notification from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] applist The display application list
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// int applist = 0;
  ///
  /// noti_err = notification_get_display_applist(noti, &applist);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_display_applist(
    notification_h noti,
    ffi.Pointer<ffi.Int> applist,
  ) {
    return _notification_get_display_applist(
      noti,
      applist,
    );
  }

  late final _notification_get_display_applistPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Int>)>>('notification_get_display_applist');
  late final _notification_get_display_applist =
      _notification_get_display_applistPtr
          .asFunction<int Function(notification_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the initial size for the ongoing type.
  /// @details After notification_post() call, the size is not updated.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] size The double type size
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// noti_err = notification_set_size(noti, 0.0);
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_set_size(
    notification_h noti,
    double size,
  ) {
    return _notification_set_size(
      noti,
      size,
    );
  }

  late final _notification_set_sizePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, ffi.Double)>>(
          'notification_set_size');
  late final _notification_set_size = _notification_set_sizePtr
      .asFunction<int Function(notification_h, double)>();

  /// @brief Gets the progress size.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] size The progress size
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// double size = 0.0;
  ///
  /// noti_err = notification_get_size(noti, &size);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int notification_get_size(
    notification_h noti,
    ffi.Pointer<ffi.Double> size,
  ) {
    return _notification_get_size(
      noti,
      size,
    );
  }

  late final _notification_get_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Double>)>>('notification_get_size');
  late final _notification_get_size = _notification_get_sizePtr
      .asFunction<int Function(notification_h, ffi.Pointer<ffi.Double>)>();

  /// @brief Sets the initial progress for the ongoing type.
  /// @details After the notification_post() call, the progress is not updated.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] percentage The progress percentage
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// noti_err = notification_set_progress(noti, 0.0);
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_set_progress(
    notification_h noti,
    double percentage,
  ) {
    return _notification_set_progress(
      noti,
      percentage,
    );
  }

  late final _notification_set_progressPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, ffi.Double)>>(
          'notification_set_progress');
  late final _notification_set_progress = _notification_set_progressPtr
      .asFunction<int Function(notification_h, double)>();

  /// @brief Gets the progress from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @remarks At the end of the operation, the progress should be @c 1.0.
  /// @param[in] noti The notification handle
  /// @param[out] percentage The progress percentage
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// double percentage = 0.0;
  ///
  /// noti_err = notification_get_progress(noti, &percentage);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_progress(
    notification_h noti,
    ffi.Pointer<ffi.Double> percentage,
  ) {
    return _notification_get_progress(
      noti,
      percentage,
    );
  }

  late final _notification_get_progressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Double>)>>('notification_get_progress');
  late final _notification_get_progress = _notification_get_progressPtr
      .asFunction<int Function(notification_h, ffi.Pointer<ffi.Double>)>();

  /// @brief Sets the layout of the notification view.
  /// @details Caller can set displaying layout of notification.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[in] layout The type of layout
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @see #notification_ly_type_e
  int notification_set_layout(
    notification_h noti,
    int layout,
  ) {
    return _notification_set_layout(
      noti,
      layout,
    );
  }

  late final _notification_set_layoutPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, ffi.Int32)>>(
          'notification_set_layout');
  late final _notification_set_layout = _notification_set_layoutPtr
      .asFunction<int Function(notification_h, int)>();

  /// @brief Gets the layout of the notification view from the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] layout The type of layout
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @see #notification_ly_type_e
  int notification_get_layout(
    notification_h noti,
    ffi.Pointer<ffi.Int32> layout,
  ) {
    return _notification_get_layout(
      noti,
      layout,
    );
  }

  late final _notification_get_layoutPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Int32>)>>('notification_get_layout');
  late final _notification_get_layout = _notification_get_layoutPtr
      .asFunction<int Function(notification_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the type of a notification.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @param[out] type The notification type
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// notification_type_e type;
  ///
  /// noti_err = notification_get_type(noti, &type);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int notification_get_type(
    notification_h noti,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _notification_get_type(
      noti,
      type,
    );
  }

  late final _notification_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Int32>)>>('notification_get_type');
  late final _notification_get_type = _notification_get_typePtr
      .asFunction<int Function(notification_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Updates notification data.
  /// @details The updated notification will appear in the notification area.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] noti The notification handle that is created by notification_create()
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @retval #NOTIFICATION_ERROR_NOT_EXIST_ID Priv ID does not exist
  /// @retval #NOTIFICATION_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti_err = notification_update(NULL);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int notification_update(
    notification_h noti,
  ) {
    return _notification_update(
      noti,
    );
  }

  late final _notification_updatePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h)>>(
          'notification_update');
  late final _notification_update =
      _notification_updatePtr.asFunction<int Function(notification_h)>();

  /// @brief Deletes a notification with the given handle.
  /// @details notification_delete() removes notification data from database and notification_free() releases memory of notification data.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] noti The notification handle
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @retval NOTIFICATION_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// // Do something
  ///
  /// noti_err = notification_delete(noti);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_delete(
    notification_h noti,
  ) {
    return _notification_delete(
      noti,
    );
  }

  late final _notification_deletePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h)>>(
          'notification_delete');
  late final _notification_delete =
      _notification_deletePtr.asFunction<int Function(notification_h)>();

  /// @brief Creates internal structure data and returns a notification handle.
  /// @details Available type is #NOTIFICATION_TYPE_NOTI and #NOTIFICATION_TYPE_ONGOING.
  /// #NOTIFICATION_TYPE_NOTI is remaining notification data even if device is restarted.
  /// #NOTIFICATION_TYPE_ONGOING can display progress on a notification with #NOTIFICATION_LY_ONGOING_PROGRESS layout.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] type The notification type
  /// @return Notification handle(notification_h) on success,
  /// otherwise @c NULL on failure
  /// @retval notification_h Success
  /// @retval NULL Failure
  /// @exception #NOTIFICATION_ERROR_NONE Success
  /// @exception #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @exception #NOTIFICATION_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception #NOTIFICATION_ERROR_IO_ERROR I/O error
  /// @see #notification_type_e
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// // Do something
  ///
  /// }
  /// @endcode
  notification_h notification_create(
    int type,
  ) {
    return _notification_create(
      type,
    );
  }

  late final _notification_createPtr =
      _lookup<ffi.NativeFunction<notification_h Function(ffi.Int32)>>(
          'notification_create');
  late final _notification_create =
      _notification_createPtr.asFunction<notification_h Function(int)>();

  /// @brief Creates a notification clone.
  /// @details Newly created notification handle is returned.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @remarks This cloned notification handle should be freed using notification_free().
  /// @param[in] noti The notification handle
  /// @param[out] clone The newly created notification handle that has same with input @a noti
  /// @return #NOTIFICATION_ERROR_NONE if success,
  /// otherwise any other value if failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see #notification_type_e
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// notification_h clone = NULL;
  ///
  /// notification_clone(noti, &clone);
  ///
  /// // Do something
  ///
  /// }
  /// @endcode
  int notification_clone(
    notification_h noti,
    ffi.Pointer<notification_h> clone,
  ) {
    return _notification_clone(
      noti,
      clone,
    );
  }

  late final _notification_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<notification_h>)>>('notification_clone');
  late final _notification_clone = _notification_clonePtr
      .asFunction<int Function(notification_h, ffi.Pointer<notification_h>)>();

  /// @brief Frees the internal structure data of a notification handle.
  /// @details Internal data of a notification handle is released. Data of the inserted notification is not deleted.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti The notification handle
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Notification handle should be created by notification_create().
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// // Do something
  ///
  /// noti_err = notification_free(noti);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_free(
    notification_h noti,
  ) {
    return _notification_free(
      noti,
    );
  }

  late final _notification_freePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h)>>(
          'notification_free');
  late final _notification_free =
      _notification_freePtr.asFunction<int Function(notification_h)>();

  /// @brief Sets the tag of the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti Notification handle
  /// @param[in] tag Tag for loading notification handle
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #NOTIFICATION_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @see notification_get_tag()
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// // Do something
  ///
  /// noti_err = notification_set_tag(noti, tag);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_set_tag(
    notification_h noti,
    ffi.Pointer<ffi.Char> tag,
  ) {
    return _notification_set_tag(
      noti,
      tag,
    );
  }

  late final _notification_set_tagPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              notification_h, ffi.Pointer<ffi.Char>)>>('notification_set_tag');
  late final _notification_set_tag = _notification_set_tagPtr
      .asFunction<int Function(notification_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the tag of the notification handle.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @param[in] noti Notification handle
  /// @param[out] tag Tag for loading notification handle
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #NOTIFICATION_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @see notification_set_tag()
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// const char *tag = NULL;
  ///
  /// // Do something
  ///
  /// noti_err = notification_get_tag(noti, &tag);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_tag(
    notification_h noti,
    ffi.Pointer<ffi.Pointer<ffi.Char>> tag,
  ) {
    return _notification_get_tag(
      noti,
      tag,
    );
  }

  late final _notification_get_tagPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('notification_get_tag');
  late final _notification_get_tag = _notification_get_tagPtr.asFunction<
      int Function(notification_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Loads a notification from the notification's database with the tag.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] tag Tag for loading notification handle
  /// @return Notification handle(notification_h) on success,
  /// NULL on failure
  /// @retval notification_h Success
  /// @retval NULL Failure
  /// @exception #NOTIFICATION_ERROR_NONE Success
  /// @exception #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @exception #NOTIFICATION_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception #NOTIFICATION_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @see #notification_type_e
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  ///
  /// noti = notification_load_by_tag(tag);
  /// if (noti == NULL)
  /// return;
  ///
  /// // Do something
  ///
  /// }
  /// @endcode
  notification_h notification_load_by_tag(
    ffi.Pointer<ffi.Char> tag,
  ) {
    return _notification_load_by_tag(
      tag,
    );
  }

  late final _notification_load_by_tagPtr = _lookup<
          ffi.NativeFunction<notification_h Function(ffi.Pointer<ffi.Char>)>>(
      'notification_load_by_tag');
  late final _notification_load_by_tag = _notification_load_by_tagPtr
      .asFunction<notification_h Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Deletes all notifications of the given type.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] type Notification type
  /// @return #NOTIFICATION_ERROR_NONE if success,
  /// other value if failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @retval #NOTIFICATION_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti_err = notification_delete_all(NOTIFICATION_TYPE_NOTI);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_delete_all(
    int type,
  ) {
    return _notification_delete_all(
      type,
    );
  }

  late final _notification_delete_allPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'notification_delete_all');
  late final _notification_delete_all =
      _notification_delete_allPtr.asFunction<int Function(int)>();

  /// @brief Posts a notification.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] noti Notification handle
  /// @return #NOTIFICATION_ERROR_NONE if success,
  /// other value if failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #NOTIFICATION_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @pre Notification handle should be created by notification_create().
  /// @post notification_free().
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti_err = notification_post(noti);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_post(
    notification_h noti,
  ) {
    return _notification_post(
      noti,
    );
  }

  late final _notification_postPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h)>>(
          'notification_post');
  late final _notification_post =
      _notification_postPtr.asFunction<int Function(notification_h)>();

  /// @brief Gets the package name of the notification.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] noti Notification handle
  /// @param[out] pkgname The package name of the notification
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval NOTIFICATION_ERROR_NONE Success
  /// @retval NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// char *pkgname = NULL;
  ///
  /// // Do something
  ///
  /// noti_err = notification_get_pkgname(noti, &pkgname);
  ///
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_get_pkgname(
    notification_h noti,
    ffi.Pointer<ffi.Pointer<ffi.Char>> pkgname,
  ) {
    return _notification_get_pkgname(
      noti,
      pkgname,
    );
  }

  late final _notification_get_pkgnamePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('notification_get_pkgname');
  late final _notification_get_pkgname =
      _notification_get_pkgnamePtr.asFunction<
          int Function(notification_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Adds a button on the notification.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] noti Notification handle
  /// @param[in] button_index Button index
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval NOTIFICATION_ERROR_NONE Success
  /// @retval NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// char *pkgname = NULL;
  ///
  /// // Do something
  ///
  /// noti_err = notification_add_button(noti, NOTIFICATION_BUTTON_1);
  ///
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_add_button(
    notification_h noti,
    int button_index,
  ) {
    return _notification_add_button(
      noti,
      button_index,
    );
  }

  late final _notification_add_buttonPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, ffi.Int32)>>(
          'notification_add_button');
  late final _notification_add_button = _notification_add_buttonPtr
      .asFunction<int Function(notification_h, int)>();

  /// @brief Removes a button on the notification.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] noti Notification handle
  /// @param[in] button_index Button index
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval NOTIFICATION_ERROR_NONE Success
  /// @retval NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// char *pkgname = NULL;
  ///
  /// // Do something
  ///
  /// noti_err = notification_remove_button(noti, NOTIFICATION_BUTTON_1);
  ///
  /// if (noti_err != NOTIFICATION_ERROR_NONE) {
  /// notification_free(noti);
  /// return;
  /// }
  /// }
  /// @endcode
  int notification_remove_button(
    notification_h noti,
    int button_index,
  ) {
    return _notification_remove_button(
      noti,
      button_index,
    );
  }

  late final _notification_remove_buttonPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, ffi.Int32)>>(
          'notification_remove_button');
  late final _notification_remove_button = _notification_remove_buttonPtr
      .asFunction<int Function(notification_h, int)>();

  /// @brief Sets the 'auto remove' option of the active notification.
  /// @details The 'auto remove' option lets the active notification be removed several seconds after it shows. Default value is true.
  /// @remarks When 'auto_remove' is set as false, the active notification will not be removed
  /// as long as the user removes the active notification or the app which posted the active notification removes the active notification.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] noti Notification handle
  /// @param[in] auto_remove Auto remove option
  /// @return #NOTIFICATION_ERROR_NONE On success,
  /// other value if failure
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see #notification_h
  /// @see #notification_get_auto_remove
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// // Do something
  ///
  /// noti_err = notification_set_auto_remove(noti, false);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_set_auto_remove(
    notification_h noti,
    bool auto_remove,
  ) {
    return _notification_set_auto_remove(
      noti,
      auto_remove,
    );
  }

  late final _notification_set_auto_removePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, ffi.Bool)>>(
          'notification_set_auto_remove');
  late final _notification_set_auto_remove = _notification_set_auto_removePtr
      .asFunction<int Function(notification_h, bool)>();

  /// @brief Gets the 'auto remove' option of the active notification.
  /// @details The 'auto remove' option lets the active notification be removed several seconds after it shows. Default value is true.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] noti Notification handle
  /// @param[out] auto_remove Auto remove option
  /// @return #NOTIFICATION_ERROR_NONE On success, other value on failure
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see #notification_h
  /// @see #notification_get_auto_remove
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// bool auto_remove;
  ///
  /// // Do something
  ///
  /// noti_err = notification_get_auto_remove(noti, &auto_remove);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_auto_remove(
    notification_h noti,
    ffi.Pointer<ffi.Bool> auto_remove,
  ) {
    return _notification_get_auto_remove(
      noti,
      auto_remove,
    );
  }

  late final _notification_get_auto_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Bool>)>>('notification_get_auto_remove');
  late final _notification_get_auto_remove = _notification_get_auto_removePtr
      .asFunction<int Function(notification_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Saves a notification template to the notification database.
  /// @details An application can save the created notification as a template for later reuse.
  /// If the template has the same name as a saved one, the saved template will be overwritten.
  /// A saved template can be loaded only by the application which saved it.
  /// All templates are removed when the application package is uninstalled.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @remarks The number of templates is limited to 10.
  /// When you try to add more than 10 templates, #NOTIFICATION_ERROR_MAX_EXCEEDED will be returned.
  /// @param[in] noti Notification handle
  /// @param[in] template_name Template name
  /// @return #NOTIFICATION_ERROR_NONE On success, other value on failure
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #NOTIFICATION_ERROR_IO_ERROR I/O error
  /// @retval #NOTIFICATION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #NOTIFICATION_ERROR_PERMISSION_DENIED The Permission denied
  /// @retval #NOTIFICATION_ERROR_MAX_EXCEEDED Max notification count exceeded
  /// @see #notification_h
  /// @see notification_create_from_template()
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// notification_h noti = NULL;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// // add the content you want to use for the template.
  ///
  /// noti_err = notification_save_as_template(noti, "CALL_ACCEPT");
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_free(noti);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int notification_save_as_template(
    notification_h noti,
    ffi.Pointer<ffi.Char> template_name,
  ) {
    return _notification_save_as_template(
      noti,
      template_name,
    );
  }

  late final _notification_save_as_templatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Char>)>>('notification_save_as_template');
  late final _notification_save_as_template = _notification_save_as_templatePtr
      .asFunction<int Function(notification_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Loads a notification template from the notification database.
  /// @details An application can load a saved template and post it.
  /// An application can load only templates that it has saved.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @remarks The returned handle should be destroyed using notification_free().
  /// The specific error code can be obtained using get_last_result().
  /// Error codes are described in the Exception section.
  /// If an invalid template name is given, the result will be set to #NOTIFICATION_ERROR_FROM_DB.
  /// @param[in] template_name Template name
  /// @return Notification handle on success, NULL on failure
  /// @exception #NOTIFICATION_ERROR_NONE Success
  /// @exception #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid input value
  /// @exception #NOTIFICATION_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception #NOTIFICATION_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @exception #NOTIFICATION_ERROR_FROM_DB Error from DB query
  /// @see #notification_h
  /// @see notification_save_as_template()
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  ///
  /// noti = notification_create_from_template("CALL_ACCEPT");
  /// if (noti == NULL)
  /// return;
  ///
  /// }
  /// @endcode
  notification_h notification_create_from_template(
    ffi.Pointer<ffi.Char> template_name,
  ) {
    return _notification_create_from_template(
      template_name,
    );
  }

  late final _notification_create_from_templatePtr = _lookup<
          ffi.NativeFunction<notification_h Function(ffi.Pointer<ffi.Char>)>>(
      'notification_create_from_template');
  late final _notification_create_from_template =
      _notification_create_from_templatePtr
          .asFunction<notification_h Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Gets notification block state.
  /// @details	The user can set the notification block state in settings.
  /// The block state indicates whether or not notifications can be posted.
  /// Additionally only notifications to the notification panel are
  /// allowed in "Do not disturb mode". Sound, Vibrate and
  /// Active/Instant notifications are blocked.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[out] state Notification block state
  /// @return #NOTIFICATION_ERROR_NONE On success, other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #NOTIFICATION_ERROR_OUT_OF_MEMORY out of memory
  /// @retval #NOTIFICATION_ERROR_IO_ERROR I/O Error
  /// @retval #NOTIFICATION_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #NOTIFICATION_ERROR_SERVICE_NOT_READY No response from notification service
  /// @see #notification_block_state_e
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// notification_block_state_e state;
  ///
  /// // Do something
  ///
  /// noti_err = notification_get_noti_block_state(&state);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int notification_get_noti_block_state(
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _notification_get_noti_block_state(
      state,
    );
  }

  late final _notification_get_noti_block_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'notification_get_noti_block_state');
  late final _notification_get_noti_block_state =
      _notification_get_noti_block_statePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets a text input box to reply directly on the notification.
  /// @details When you add a text input to the active notification, the notification UI will show a text input with a button.
  /// So, the user can enter any text and press the button to confirm the text as a input.
  /// You can edit some UI component that is related to the text input.
  /// First, you can add placeholder text to guide the user using notification_set_text() with #NOTIFICATION_TEXT_TYPE_TEXT_INPUT_PLACEHOLDER type.
  /// You also can edit button for the text input.
  /// For setting just a text to the button, you can set the text using notification_set_text() with #NOTIFICATION_TEXT_TYPE_TEXT_INPUT_BUTTON type.
  /// If you want to show image button, you can set an image for the button using notification_set_image() with #NOTIFICATION_IMAGE_TYPE_TEXT_INPUT_BUTTON type.
  ///
  /// Note that you should set an app_control for handling the event for user input using notification_set_event_handler().
  /// #NOTIFICATION_EVENT_TYPE_CLICK_ON_TEXT_INPUT_BUTTON is the event type for the text input.
  /// You can get the text the user enters in the app_control handle that is passed as a result of the event.
  /// The app_control will contain APP_CONTROL_DATA_TEXT key, so you can get the text using app_control_get_extra_data() using APP_CONTROL_DATA_TEXT key.
  /// The value will contain the text user enters.
  ///
  /// Note that you are able to make the switching button to the text input box.
  /// You have to set the app_control which you will set in a text input box to the switching button.
  /// Refer to the second sample code.
  /// @since_tizen 3.0
  /// @param[in] noti Notification handle
  /// @param[in] text_input_max_length The maximum value which can be inputted
  /// @return #NOTIFICATION_ERROR_NONE on success,
  /// otherwise any other value on failure
  /// @retval #NOTIFICATION_ERROR_NONE         Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// notification_h noti = NULL;
  /// app_control = NULL;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// noti_err = notification_set_text_input(noti, 160);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_text(noti,
  /// NOTIFICATION_TEXT_TYPE_TEXT_INPUT_PLACEHOLDER,
  /// "Text message",
  /// NULL,
  /// NOTIFICATION_VARIABLE_TYPE_NONE);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_text(noti,
  /// NOTIFICATION_TEXT_TYPE_TEXT_INPUT_BUTTON,
  /// "SEND",
  /// NULL,
  /// NOTIFICATION_VARIABLE_TYPE_NONE);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_display_applist(noti,
  /// NOTIFICATION_DISPLAY_APP_NOTIFICATION_TRAY | NOTIFICATION_DISPLAY_APP_ACTIVE);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// // Do something
  ///
  /// noti_err = app_control_create(&app_control);
  /// if (noti_err != APP_CONTROL_ERROR_NONE)
  /// return;
  ///
  /// noti_err = app_control_set_app_id(app_control, appid);
  /// if (noti_err != APP_CONTROL_ERROR_NONE)
  /// return;
  ///
  /// noti_err = app_control_set_operation(app_control, APP_CONTROL_OPERATION_DEFAULT);
  /// if (noti_err != APP_CONTROL_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_event_handler(noti,
  /// NOTIFICATION_EVENT_TYPE_CLICK_ON_TEXT_INPUT_BUTTON,
  /// app_control);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = app_control_destroy(app_control);
  /// if (noti_err != APP_CONTROL_ERROR_NONE)
  /// return;
  ///
  /// noti_err  = notification_post(noti);
  /// if(noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// }
  ///
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// notification_h noti = NULL;
  /// app_control = NULL;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL) {
  /// return;
  /// }
  ///
  /// noti_err = notification_set_text_input(noti, 160);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_text(noti,
  /// NOTIFICATION_TEXT_TYPE_TEXT_INPUT_PLACEHOLDER,
  /// "Text message",
  /// NULL,
  /// NOTIFICATION_VARIABLE_TYPE_NONE);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_text(noti,
  /// NOTIFICATION_TEXT_TYPE_TEXT_INPUT_BUTTON,
  /// "SEND",
  /// NULL,
  /// NOTIFICATION_VARIABLE_TYPE_NONE);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_add_button(notification, NOTIFICATION_BUTTON_1);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_text(notification,
  /// NOTIFICATION_TEXT_TYPE_BUTTON_1,
  /// "reply",
  /// NULL,
  /// NOTIFICATION_VARIABLE_TYPE_NONE);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_display_applist(noti,
  /// NOTIFICATION_DISPLAY_APP_NOTIFICATION_TRAY | NOTIFICATION_DISPLAY_APP_ACTIVE);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// // Do something
  ///
  /// noti_err = app_control_create(&app_control);
  /// if (noti_err != APP_CONTROL_ERROR_NONE)
  /// return;
  ///
  /// noti_err = app_control_set_app_id(app_control, appid);
  /// if (noti_err != APP_CONTROL_ERROR_NONE)
  /// return;
  ///
  /// noti_err = app_control_set_operation(app_control, APP_CONTROL_OPERATION_DEFAULT);
  /// if (noti_err != APP_CONTROL_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_event_handler(notification,
  /// NOTIFICATION_EVENT_TYPE_CLICK_ON_BUTTON_1,
  /// app_control);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_event_handler(noti,
  /// NOTIFICATION_EVENT_TYPE_CLICK_ON_TEXT_INPUT_BUTTON,
  /// app_control);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = app_control_destroy(app_control);
  /// if (noti_err != APP_CONTROL_ERROR_NONE)
  /// return;
  ///
  /// noti_err  = notification_post(noti);
  /// if(noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int notification_set_text_input(
    notification_h noti,
    int text_input_max_length,
  ) {
    return _notification_set_text_input(
      noti,
      text_input_max_length,
    );
  }

  late final _notification_set_text_inputPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, ffi.Int)>>(
          'notification_set_text_input');
  late final _notification_set_text_input = _notification_set_text_inputPtr
      .asFunction<int Function(notification_h, int)>();

  /// @brief Sets the image height for the extended notification.
  /// @details The image is shown under the notification's text. The application can set the image height.
  /// The image is modified to fit into the height set by this function.
  /// The image can be scaled down and/or cropped.
  /// If @a height is 0, the default value is used. The default height depends on the screen size.
  /// @since_tizen 4.0
  /// @param[in] noti   The notification handle
  /// @param[in] height The image height
  /// @return #NOTIFICATION_ERROR_NONE On success,
  /// otherwise a negative error value
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see notification_get_extension_image_size()
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// notification_h noti = NULL;
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  ///
  /// noti = notification_create(NOTIFICATION_TYPE_NOTI);
  /// if (noti == NULL)
  /// return;
  ///
  /// noti_err = notification_set_text(noti,
  /// NOTIFICATION_TEXT_TYPE_CONTENT_EXTENTION,
  /// "message",
  /// NULL,
  /// NOTIFICATION_VARIABLE_TYPE_NONE);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_image(noti,
  /// NOTIFICATION_IMAGE_TYPE_EXTENTION,
  /// image_path);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_layout(noti, NOTIFICATION_LY_EXTENTION);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// noti_err = notification_set_extension_image_size(noti, 20);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  ///
  /// // Do something
  /// }
  /// @endcode
  int notification_set_extension_image_size(
    notification_h noti,
    int height,
  ) {
    return _notification_set_extension_image_size(
      noti,
      height,
    );
  }

  late final _notification_set_extension_image_sizePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(notification_h, ffi.Int)>>(
          'notification_set_extension_image_size');
  late final _notification_set_extension_image_size =
      _notification_set_extension_image_sizePtr
          .asFunction<int Function(notification_h, int)>();

  /// @brief Gets the image height for the extended notification.
  /// @since_tizen 4.0
  /// @param[in] noti The notification handle
  /// @param[out] height The image height
  /// @return #NOTIFICATION_ERROR_NONE On success, otherwise a negative error value
  /// @retval #NOTIFICATION_ERROR_NONE Success
  /// @retval #NOTIFICATION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see notification_set_extension_image_size()
  /// @par Sample code:
  /// @code
  /// #include <notification.h>
  ///
  /// {
  /// int noti_err = NOTIFICATION_ERROR_NONE;
  /// int height;
  ///
  /// // Do something
  ///
  /// noti_err = notification_get_extension_image_size(noti, &height);
  /// if (noti_err != NOTIFICATION_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int notification_get_extension_image_size(
    notification_h noti,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _notification_get_extension_image_size(
      noti,
      height,
    );
  }

  late final _notification_get_extension_image_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h,
              ffi.Pointer<ffi.Int>)>>('notification_get_extension_image_size');
  late final _notification_get_extension_image_size =
      _notification_get_extension_image_sizePtr
          .asFunction<int Function(notification_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets an alarm to be triggered after a specific time.
  /// @details The alarm will first go off @a delay seconds later and then will go off every certain amount of time defined using @a period seconds. To cancel the alarm, call alarm_cancel() with @a alarm_id.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @remarks If the application is uninstalled after setting an alarm, the alarm is cancelled automatically.
  /// If the operation of @a app_control is not specified, #APP_CONTROL_OPERATION_DEFAULT is used for the launch request.
  /// If the operation of @a app_control is #APP_CONTROL_OPERATION_DEFAULT, the package information is mandatory to explicitly launch the application.
  /// Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, this api does not support exact period and delay for minimizing the wakeups of the device. The system can adjust when the alarm expires.
  /// If you want to trigger an alarm exactly, see @see alarm_schedule_once_after_delay()
  /// Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif If @a app_control is specified with service-application, the application is only allowed to run on which has Background Category.
  /// Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif If the appid of @a app_control is not specified, this api is not allowed. In other words, the explicit @a app_control is only allowed.
  ///
  /// @param[in] app_control The destination app_control to perform a specific task when the alarm is triggered
  /// @param[in] delay The amount of time before the first execution (in seconds). Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, Although this is inexact, the alarm will not fire before this time
  /// @param[in] period The amount of time between subsequent alarms (in seconds). Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, This value does not guarantee the accuracy. The actual interval is calculated by the OS. The minimum value is 600sec
  /// @param[out] alarm_id The alarm ID that uniquely identifies an alarm
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_INVALID_TIME Triggered time is invalid
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #ALARM_ERROR_NOT_PERMITTED_APP @a app_control is not permitted
  /// @see alarm_cancel()
  /// @see alarm_cancel_all()
  /// @see alarm_get_scheduled_date()
  /// @see alarm_get_scheduled_period()
  /// @see alarm_schedule_once_after_delay()
  int alarm_schedule_after_delay(
    app_control_h app_control,
    int delay,
    int period,
    ffi.Pointer<ffi.Int> alarm_id,
  ) {
    return _alarm_schedule_after_delay(
      app_control,
      delay,
      period,
      alarm_id,
    );
  }

  late final _alarm_schedule_after_delayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h, ffi.Int, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('alarm_schedule_after_delay');
  late final _alarm_schedule_after_delay =
      _alarm_schedule_after_delayPtr.asFunction<
          int Function(app_control_h, int, int, ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. [Use alarm_schedule_once_at_date() instead]
  /// @brief Sets an alarm to be triggered at a specific time.
  /// @details The @a date describes the time of the first occurrence.
  /// If @a period is bigger than @c 0, the alarm will be scheduled after the @a period time.
  /// If @a period is set to @c 0, the alarm will go off just once without repetition.
  /// To cancel the alarm, call alarm_cancel() with @a alarm_id.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @remarks If application is uninstalled after setting an alarm, the alarm is cancelled automatically.
  /// If the operation of @a app_control is not specified, #APP_CONTROL_OPERATION_DEFAULT is used for the launch request.
  /// If the operation of @a app_control is #APP_CONTROL_OPERATION_DEFAULT, the package information is mandatory to explicitly launch the application.
  ///
  /// @param[in] app_control The destination app_control to perform specific work when the alarm is triggered
  /// @param[in] date The first active alarm time
  /// @param[in] period The amount of time between subsequent alarms(in second)
  /// @param[out] alarm_id The alarm ID that uniquely identifies an alarm
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_INVALID_DATE Triggered date is invalid
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_cancel()
  /// @see alarm_cancel_all()
  /// @see alarm_get_scheduled_date()
  /// @see alarm_get_scheduled_period()
  int alarm_schedule_at_date(
    app_control_h app_control,
    ffi.Pointer<tm> date,
    int period,
    ffi.Pointer<ffi.Int> alarm_id,
  ) {
    return _alarm_schedule_at_date(
      app_control,
      date,
      period,
      alarm_id,
    );
  }

  late final _alarm_schedule_at_datePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h, ffi.Pointer<tm>, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('alarm_schedule_at_date');
  late final _alarm_schedule_at_date = _alarm_schedule_at_datePtr.asFunction<
      int Function(
          app_control_h, ffi.Pointer<tm>, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets an alarm to be triggered after a specific time.
  /// @details The alarm will go off @a delay seconds later. To cancel the alarm, call alarm_cancel() with @a alarm_id.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @remarks If the application is uninstalled after setting an alarm, the alarm is cancelled automatically.
  /// If the operation of @a app_control is not specified, #APP_CONTROL_OPERATION_DEFAULT is used for the launch request.
  /// If the operation of @a app_control is #APP_CONTROL_OPERATION_DEFAULT, the package information is mandatory to explicitly launch the application.
  /// If the appid of @a app_control is not specified, this api is not allowed. In other words, the explicit @a app_control is only allowed.
  /// The @a app_control only supports UI application with this api. If @a app_control is not UI application, #ALARM_ERROR_NOT_PERMITTED_APP returned.
  /// When the alarm is expired, Alarm Manager will turn on LCD to prohibit background jobs.
  ///
  /// @param[in] app_control The destination app_control to perform a specific task when the alarm is triggered
  /// @param[in] delay The amount of time before the execution (in seconds)
  /// @param[out] alarm_id The alarm ID that uniquely identifies an alarm
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_INVALID_TIME Triggered time is invalid
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #ALARM_ERROR_NOT_PERMITTED_APP @a app_control is not permitted. @a app_control for UI application is only permitted.
  /// @see alarm_cancel()
  /// @see alarm_cancel_all()
  /// @see alarm_get_scheduled_date()
  int alarm_schedule_once_after_delay(
    app_control_h app_control,
    int delay,
    ffi.Pointer<ffi.Int> alarm_id,
  ) {
    return _alarm_schedule_once_after_delay(
      app_control,
      delay,
      alarm_id,
    );
  }

  late final _alarm_schedule_once_after_delayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('alarm_schedule_once_after_delay');
  late final _alarm_schedule_once_after_delay =
      _alarm_schedule_once_after_delayPtr
          .asFunction<int Function(app_control_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets an alarm to be triggered at a specific time.
  /// @details The @a date describes the time of the first occurrence. To cancel the alarm, call alarm_cancel() with @a alarm_id.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @remarks If application is uninstalled after setting an alarm, the alarm is cancelled automatically.
  /// If the operation of @a app_control is not specified, #APP_CONTROL_OPERATION_DEFAULT is used for the launch request.
  /// If the operation of @a app_control is #APP_CONTROL_OPERATION_DEFAULT, the package information is mandatory to explicitly launch the application.
  /// If the appid of @a app_control is not specified, this api is not allowed. In other words, the explicit @a app_control is only allowed.
  /// The @a app_control only supports UI application with this api. If @a app_control is not UI application, #ALARM_ERROR_NOT_PERMITTED_APP returned.
  /// When the alarm is expired, Alarm Manager will turn on LCD to prohibit background jobs.
  ///
  /// @param[in] app_control The destination app_control to perform specific work when the alarm is triggered
  /// @param[in] date The first active alarm time
  /// @param[out] alarm_id The alarm ID that uniquely identifies an alarm
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE   Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #ALARM_ERROR_INVALID_DATE Triggered date is invalid
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #ALARM_ERROR_NOT_PERMITTED_APP @a app_control is not permitted. @a app_control for UI application is only permitted.
  /// @see alarm_cancel()
  /// @see alarm_cancel_all()
  /// @see alarm_get_scheduled_date()
  int alarm_schedule_once_at_date(
    app_control_h app_control,
    ffi.Pointer<tm> date,
    ffi.Pointer<ffi.Int> alarm_id,
  ) {
    return _alarm_schedule_once_at_date(
      app_control,
      date,
      alarm_id,
    );
  }

  late final _alarm_schedule_once_at_datePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_control_h, ffi.Pointer<tm>,
              ffi.Pointer<ffi.Int>)>>('alarm_schedule_once_at_date');
  late final _alarm_schedule_once_at_date =
      _alarm_schedule_once_at_datePtr.asFunction<
          int Function(app_control_h, ffi.Pointer<tm>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets an alarm to be triggered periodically, starting at a specific time.
  /// @details The @a date describes the time of the first occurrence.
  /// @a week_flag is the repeat value of the days of the week.
  /// If @a week_flag is #ALARM_WEEK_FLAG_TUESDAY, the alarm will repeat every Tuesday at a specific time.
  /// To cancel the alarm, call alarm_cancel() with @a alarm_id.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @remarks If the application is uninstalled after setting an alarm, the alarm is cancelled automatically.
  /// If the operation of @a app_control is not specified, #APP_CONTROL_OPERATION_DEFAULT is used for the launch request.
  /// If the operation of @a app_control is #APP_CONTROL_OPERATION_DEFAULT, the package information is mandatory to explicitly launch the application.
  /// Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, The @a app_control only supports UI application with this api. If @a app_control is not UI application, #ALARM_ERROR_NOT_PERMITTED_APP returned.
  /// When the alarm is expired, Alarm Manager will turn on LCD to prohibit background jobs.
  /// Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, If the appid of @a app_control is not specified, this api is not allowed. In other words, the explicit @a app_control is only allowed.
  ///
  /// @param[in] app_control The destination app_control to perform specific work when the alarm is triggered
  /// @param[in] date The first active alarm time
  /// @param[in] week_flag The day of the week, @a week_flag may be a combination of days, like #ALARM_WEEK_FLAG_TUESDAY | #ALARM_WEEK_FLAG_FRIDAY
  /// @param[out] alarm_id The alarm ID that uniquely identifies an alarm
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_INVALID_DATE Triggered date is invalid
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #ALARM_ERROR_NOT_PERMITTED_APP @a app_control is not permitted. @a app_control for UI application is only permitted.
  /// @see alarm_cancel()
  /// @see alarm_cancel_all()
  /// @see alarm_get_scheduled_recurrence_week_flag()
  /// @see alarm_get_scheduled_date()
  /// @see #alarm_week_flag_e
  int alarm_schedule_with_recurrence_week_flag(
    app_control_h app_control,
    ffi.Pointer<tm> date,
    int week_flag,
    ffi.Pointer<ffi.Int> alarm_id,
  ) {
    return _alarm_schedule_with_recurrence_week_flag(
      app_control,
      date,
      week_flag,
      alarm_id,
    );
  }

  late final _alarm_schedule_with_recurrence_week_flagPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(app_control_h, ffi.Pointer<tm>, ffi.Int,
                  ffi.Pointer<ffi.Int>)>>(
      'alarm_schedule_with_recurrence_week_flag');
  late final _alarm_schedule_with_recurrence_week_flag =
      _alarm_schedule_with_recurrence_week_flagPtr.asFunction<
          int Function(
              app_control_h, ffi.Pointer<tm>, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the recurrence days of the week.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.get
  /// @remarks If the given @a alarm_id is not obtained by using the alarm_schedule_with_recurrence_week_flag() function,
  /// an error (error code #ALARM_ERROR_INVALID_PARAMETER) will occur because this alarm is scheduled with no recurrence.
  /// If the operation of @a app_control is not specified, #APP_CONTROL_OPERATION_DEFAULT is used for the launch request.
  /// If the operation of @a app_control is #APP_CONTROL_OPERATION_DEFAULT, the package information is mandatory to explicitly launch the application.
  /// @param[in] alarm_id The alarm ID returned when the alarm is scheduled
  /// @param[out] week_flag The recurrence days of the week, @a week_flag may be a combination of days, like #ALARM_WEEK_FLAG_TUESDAY | #ALARM_WEEK_FLAG_FRIDAY
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_schedule_with_recurrence_week_flag()
  /// @see #alarm_week_flag_e
  int alarm_get_scheduled_recurrence_week_flag(
    int alarm_id,
    ffi.Pointer<ffi.Int> week_flag,
  ) {
    return _alarm_get_scheduled_recurrence_week_flag(
      alarm_id,
      week_flag,
    );
  }

  late final _alarm_get_scheduled_recurrence_week_flagPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'alarm_get_scheduled_recurrence_week_flag');
  late final _alarm_get_scheduled_recurrence_week_flag =
      _alarm_get_scheduled_recurrence_week_flagPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Cancels the alarm with the specific alarm ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @param[in] alarm_id The alarm ID that is cancelled
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_schedule_at_date()
  /// @see alarm_schedule_after_delay()
  /// @see alarm_schedule_with_recurrence_week_flag()
  /// @see alarm_cancel_all()
  int alarm_cancel(
    int alarm_id,
  ) {
    return _alarm_cancel(
      alarm_id,
    );
  }

  late final _alarm_cancelPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>('alarm_cancel');
  late final _alarm_cancel = _alarm_cancelPtr.asFunction<int Function(int)>();

  /// @brief Cancels all scheduled alarms that are registered by the application that calls this API.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_schedule_at_date()
  /// @see alarm_schedule_after_delay()
  /// @see alarm_schedule_with_recurrence_week_flag()
  /// @see alarm_cancel()
  int alarm_cancel_all() {
    return _alarm_cancel_all();
  }

  late final _alarm_cancel_allPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('alarm_cancel_all');
  late final _alarm_cancel_all =
      _alarm_cancel_allPtr.asFunction<int Function()>();

  /// @brief Retrieves the IDs of all registered alarms by invoking a callback once for each scheduled alarm.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.get
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @post This function invokes alarm_registered_alarm_cb() repeatedly for each registered alarm.
  /// @see alarm_registered_alarm_cb()
  int alarm_foreach_registered_alarm(
    alarm_registered_alarm_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _alarm_foreach_registered_alarm(
      callback,
      user_data,
    );
  }

  late final _alarm_foreach_registered_alarmPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(alarm_registered_alarm_cb,
              ffi.Pointer<ffi.Void>)>>('alarm_foreach_registered_alarm');
  late final _alarm_foreach_registered_alarm =
      _alarm_foreach_registered_alarmPtr.asFunction<
          int Function(alarm_registered_alarm_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the scheduled time from the given alarm ID in C standard time struct.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.get
  /// @remarks @a date is not needed by the function after the call.
  /// @param[in] alarm_id The alarm ID returned when the alarm is scheduled
  /// @param[out] date The time value of the next alarm event
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_schedule_at_date()
  /// @see alarm_schedule_after_delay()
  /// @see alarm_schedule_with_recurrence_week_flag()
  int alarm_get_scheduled_date(
    int alarm_id,
    ffi.Pointer<tm> date,
  ) {
    return _alarm_get_scheduled_date(
      alarm_id,
      date,
    );
  }

  late final _alarm_get_scheduled_datePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<tm>)>>(
          'alarm_get_scheduled_date');
  late final _alarm_get_scheduled_date = _alarm_get_scheduled_datePtr
      .asFunction<int Function(int, ffi.Pointer<tm>)>();

  /// @brief Gets the period of time between the recurrent alarms.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.get
  /// @remarks If the given @a alarm_id is not obtained by using the alarm_schedule_at_date() or alarm_schedule_after_delay() function,
  /// an error (error code #ALARM_ERROR_INVALID_PARAMETER) will occur.
  /// @param[in] alarm_id The alarm ID returned when the alarm is scheduled
  /// @param[out] period The period of time between recurrent alarms in seconds
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_schedule_at_date()
  /// @see alarm_schedule_after_delay()
  /// @see alarm_schedule_with_recurrence_week_flag()
  int alarm_get_scheduled_period(
    int alarm_id,
    ffi.Pointer<ffi.Int> period,
  ) {
    return _alarm_get_scheduled_period(
      alarm_id,
      period,
    );
  }

  late final _alarm_get_scheduled_periodPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'alarm_get_scheduled_period');
  late final _alarm_get_scheduled_period = _alarm_get_scheduled_periodPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the current system time using C standard time struct.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out] date The current system time
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  int alarm_get_current_time(
    ffi.Pointer<tm> date,
  ) {
    return _alarm_get_current_time(
      date,
    );
  }

  late final _alarm_get_current_timePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<tm>)>>(
          'alarm_get_current_time');
  late final _alarm_get_current_time =
      _alarm_get_current_timePtr.asFunction<int Function(ffi.Pointer<tm>)>();

  /// @brief Gets the app_control to be invoked when the alarm is triggered.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.get
  /// @remarks The @a app_control must be released using app_control_destroy().
  /// @param[in] alarm_id The alarm ID uniquely identifies an alarm
  /// @param[out] app_control The app_control handle to launch when the alarm is triggered
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_schedule_at_date()
  /// @see alarm_schedule_after_delay()
  /// @see alarm_schedule_with_recurrence_week_flag()
  int alarm_get_app_control(
    int alarm_id,
    ffi.Pointer<app_control_h> app_control,
  ) {
    return _alarm_get_app_control(
      alarm_id,
      app_control,
    );
  }

  late final _alarm_get_app_controlPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<app_control_h>)>>('alarm_get_app_control');
  late final _alarm_get_app_control = _alarm_get_app_controlPtr
      .asFunction<int Function(int, ffi.Pointer<app_control_h>)>();

  /// @brief Sets global flag in the alarm.
  /// @details Sets @a global flag to set/unset alarm globally.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @remarks The @a alarm_id must be id of alarm which will launch global application.
  /// The function returns an error (error code #ALARM_ERROR_NOT_PERMITTED_APP) if it is not.
  /// Note that the application which is launched by global alarm runs in the user session that is logged in currently.
  /// It doesn't run in the session for the user who registers the global alarm.
  /// So, if the application uses application's private data for each user to handling the app_control for the alarm, it might not show proper data to the user.
  /// Therefore, We recommend to contain all the data for the alarm to the app_control handle for the global alarm.
  /// Then, the launched application would be able to use the data to show proper alarm UX to the user.
  /// @param[in] alarm_id The alarm ID uniquely identifies an alarm
  /// @param[in] global The global flag to set/unset alarm globally
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_NOT_PERMITTED_APP @a alarm_id is not permitted
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_schedule_at_date()
  /// @see alarm_schedule_after_delay()
  /// @see alarm_schedule_with_recurrence_week_flag()
  int alarm_set_global(
    int alarm_id,
    bool global,
  ) {
    return _alarm_set_global(
      alarm_id,
      global,
    );
  }

  late final _alarm_set_globalPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Bool)>>(
          'alarm_set_global');
  late final _alarm_set_global =
      _alarm_set_globalPtr.asFunction<int Function(int, bool)>();

  /// @brief Gets whether the alarm will launch global application or not.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.get
  /// @param[in] alarm_id The alarm ID uniquely identifies an alarm
  /// @param[out] global Whether the alarm will launch global application or not
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_set_global()
  int alarm_get_global(
    int alarm_id,
    ffi.Pointer<ffi.Bool> global,
  ) {
    return _alarm_get_global(
      alarm_id,
      global,
    );
  }

  late final _alarm_get_globalPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Bool>)>>(
      'alarm_get_global');
  late final _alarm_get_global = _alarm_get_globalPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets a notification alarm to be triggered at a specific time.
  /// @details The @a date describes the time of the alarm occurrence.
  /// To cancel the alarm, call alarm_cancel() with @a alarm_id.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @privilege %http://tizen.org/privilege/notification
  /// @remarks If application is uninstalled after setting an alarm, the alarm is cancelled automatically.
  /// When the alarm goes off, Alarm Manager will turn on LCD to prohibit background jobs.
  ///
  /// @param[in] noti The notification to be posted when the alarm is triggered
  /// @param[in] date The active alarm time
  /// @param[out] alarm_id The ID which uniquely identifies the scheduled alarm
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #ALARM_ERROR_NONE   Successful
  /// @retval  #ALARM_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #ALARM_ERROR_INVALID_DATE Triggered date is invalid
  /// @retval  #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval  #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_cancel()
  /// @see alarm_cancel_all()
  /// @see alarm_get_scheduled_date()
  int alarm_schedule_noti_once_at_date(
    notification_h noti,
    ffi.Pointer<tm> date,
    ffi.Pointer<ffi.Int> alarm_id,
  ) {
    return _alarm_schedule_noti_once_at_date(
      noti,
      date,
      alarm_id,
    );
  }

  late final _alarm_schedule_noti_once_at_datePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Pointer<tm>,
              ffi.Pointer<ffi.Int>)>>('alarm_schedule_noti_once_at_date');
  late final _alarm_schedule_noti_once_at_date =
      _alarm_schedule_noti_once_at_datePtr.asFunction<
          int Function(
              notification_h, ffi.Pointer<tm>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets a notification alarm to be triggered after a specific delay.
  /// @details The alarm will first go off after @a delay seconds.
  /// The alarm will then go off every period seconds until canceled.
  /// To cancel the alarm, call alarm_cancel() with @a alarm_id.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @privilege %http://tizen.org/privilege/notification
  /// @remarks If the application is uninstalled after setting an alarm, the alarm is cancelled automatically.
  /// This function is a minimally intrusive way to trigger alarms when precision is not important.
  /// The system will adjust the @a delay and @a period requests to suit internal needs; the requests
  /// will be treated as minimum values. Note that @a period cannot be less than 600 seconds, if
  /// a smaller request is supplied it will be silently adjusted to a request of 600.
  /// When the alarm goes off, Alarm Manager will turn on LCD to prohibit background jobs.
  ///
  /// @param[in] noti The notification to be posted when the alarm is triggered
  /// @param[in] delay The amount of time before the first execution (in seconds).
  /// @param[in] period The amount of time between subsequent alarms (in seconds).
  /// @param[out] alarm_id The ID which uniquely identifies the scheduled alarm
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #ALARM_ERROR_NONE Successful
  /// @retval  #ALARM_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #ALARM_ERROR_INVALID_TIME Triggered time is invalid
  /// @retval  #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval  #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_cancel()
  /// @see alarm_cancel_all()
  /// @see alarm_get_scheduled_date()
  /// @see alarm_get_scheduled_period()
  /// @see alarm_schedule_noti_once_after_delay()
  int alarm_schedule_noti_after_delay(
    notification_h noti,
    int delay,
    int period,
    ffi.Pointer<ffi.Int> alarm_id,
  ) {
    return _alarm_schedule_noti_after_delay(
      noti,
      delay,
      period,
      alarm_id,
    );
  }

  late final _alarm_schedule_noti_after_delayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('alarm_schedule_noti_after_delay');
  late final _alarm_schedule_noti_after_delay =
      _alarm_schedule_noti_after_delayPtr.asFunction<
          int Function(notification_h, int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets a notification alarm to be triggered after a specific delay.
  /// @details The alarm will go off @a delay seconds later.
  /// To cancel the alarm, call alarm_cancel() with @a alarm_id.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @privilege %http://tizen.org/privilege/notification
  /// @remarks If the application is uninstalled after setting an alarm, the alarm is cancelled automatically.
  /// When the alarm goes off, Alarm Manager will turn on LCD to prohibit background jobs.
  ///
  /// @param[in] noti The notification to be posted when the alarm is triggered
  /// @param[in] delay The amount of time before the execution (in seconds)
  /// @param[out] alarm_id The ID which uniquely identifies the scheduled alarm
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #ALARM_ERROR_NONE Successful
  /// @retval  #ALARM_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #ALARM_ERROR_INVALID_TIME Triggered time is invalid
  /// @retval  #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval  #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_cancel()
  /// @see alarm_cancel_all()
  /// @see alarm_get_scheduled_date()
  int alarm_schedule_noti_once_after_delay(
    notification_h noti,
    int delay,
    ffi.Pointer<ffi.Int> alarm_id,
  ) {
    return _alarm_schedule_noti_once_after_delay(
      noti,
      delay,
      alarm_id,
    );
  }

  late final _alarm_schedule_noti_once_after_delayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(notification_h, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('alarm_schedule_noti_once_after_delay');
  late final _alarm_schedule_noti_once_after_delay =
      _alarm_schedule_noti_once_after_delayPtr.asFunction<
          int Function(notification_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets a notification to be triggered periodically, starting at a specific time.
  /// @details The @a date describes the time of the first occurrence.
  /// @a week_flag describes the day(s) of the week when the notification recurs.
  /// If @a week_flag is #ALARM_WEEK_FLAG_TUESDAY, the alarm will repeat every Tuesday at a specific time.
  /// If @a week_flag is less than or equal to zero, the alarm is not repeated.
  /// To cancel the alarm, call alarm_cancel() with @a alarm_id.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @privilege %http://tizen.org/privilege/notification
  /// @remarks If the application is uninstalled after setting an alarm, the alarm is cancelled automatically.
  ///
  /// @param[in] noti The notification to be posted when the alarm is triggered
  /// @param[in] date The first active alarm time
  /// @param[in] week_flag The day of the week the notification recurs. @a week_flag may be a combination of days, like #ALARM_WEEK_FLAG_TUESDAY | #ALARM_WEEK_FLAG_FRIDAY
  /// @param[out] alarm_id The ID which uniquely identifies the scheduled alarm
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_INVALID_DATE Triggered date is invalid
  /// @retval #ALARM_ERROR_CONNECTION_FAIL Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_cancel()
  /// @see alarm_cancel_all()
  /// @see alarm_get_scheduled_recurrence_week_flag()
  /// @see alarm_get_scheduled_date()
  /// @see #alarm_week_flag_e
  int alarm_schedule_noti_with_recurrence_week_flag(
    notification_h noti,
    ffi.Pointer<tm> date,
    int week_flag,
    ffi.Pointer<ffi.Int> alarm_id,
  ) {
    return _alarm_schedule_noti_with_recurrence_week_flag(
      noti,
      date,
      week_flag,
      alarm_id,
    );
  }

  late final _alarm_schedule_noti_with_recurrence_week_flagPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(notification_h, ffi.Pointer<tm>, ffi.Int,
                  ffi.Pointer<ffi.Int>)>>(
      'alarm_schedule_noti_with_recurrence_week_flag');
  late final _alarm_schedule_noti_with_recurrence_week_flag =
      _alarm_schedule_noti_with_recurrence_week_flagPtr.asFunction<
          int Function(
              notification_h, ffi.Pointer<tm>, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the notification to be posted when an alarm is triggered.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.get
  /// @remarks @a noti must be released using notification_free().
  ///
  /// @param[in] alarm_id The ID which uniquely identifies a scheduled alarm
  /// @param[out] noti The notification to be posted when the alarm is triggered
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #ALARM_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #ALARM_ERROR_PERMISSION_DENIED Permission denied
  /// @see alarm_schedule_noti_once_at_date()
  /// @see alarm_schedule_noti_after_delay()
  /// @see alarm_schedule_noti_once_after_delay()
  /// @see alarm_schedule_noti_with_recurrence_week_flag()
  int alarm_get_notification(
    int alarm_id,
    ffi.Pointer<notification_h> noti,
  ) {
    return _alarm_get_notification(
      alarm_id,
      noti,
    );
  }

  late final _alarm_get_notificationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<notification_h>)>>('alarm_get_notification');
  late final _alarm_get_notification = _alarm_get_notificationPtr
      .asFunction<int Function(int, ffi.Pointer<notification_h>)>();

  /// @brief Updates the delay of the registered alarm.
  /// @details The @a delay is the time (in seconds) before the alarm's first setting off.
  /// The delay is an exact value, see alarm_schedule_once_after_delay() for details.
  /// This function can be called for any alarm.
  /// If the delay was set before, it will be overwritten. If it was not, it will be set.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @remarks This function can be called only for alarms whose app control launches an UI application.
  /// If this condition is not met, #ALARM_ERROR_NOT_PERMITTED_APP is returned.
  /// @param[in] alarm_id  The ID which uniquely identifies the scheduled alarm
  /// @param[in] delay     The amount of time before the first execution (in seconds).
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE               Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #ALARM_ERROR_CONNECTION_FAIL    Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #ALARM_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #ALARM_ERROR_NOT_PERMITTED_APP  App control does not launch an UI application
  int alarm_update_delay(
    int alarm_id,
    int delay,
  ) {
    return _alarm_update_delay(
      alarm_id,
      delay,
    );
  }

  late final _alarm_update_delayPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'alarm_update_delay');
  late final _alarm_update_delay =
      _alarm_update_delayPtr.asFunction<int Function(int, int)>();

  /// @brief Updates the date of the registered alarm.
  /// @details The @a date describes the date on which the alarm is set off for the first time.
  /// This function can be called for any alarm.
  /// If the date was set before, it will be overwritten. If it was not, it will be set.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @remarks This function can be called only for alarms whose app control launches an UI application.
  /// If this condition is not met, #ALARM_ERROR_NOT_PERMITTED_APP is returned.
  /// @param[in] alarm_id  The ID which uniquely identifies the scheduled alarm
  /// @param[in] date      The time value of the next alarm event
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE               Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #ALARM_ERROR_INVALID_TIME       Triggered time is invalid
  /// @retval #ALARM_ERROR_INVALID_DATE       Triggered time is invalid
  /// @retval #ALARM_ERROR_CONNECTION_FAIL    Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #ALARM_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #ALARM_ERROR_NOT_PERMITTED_APP  App control does not launch an UI application
  int alarm_update_date(
    int alarm_id,
    ffi.Pointer<tm> date,
  ) {
    return _alarm_update_date(
      alarm_id,
      date,
    );
  }

  late final _alarm_update_datePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<tm>)>>(
          'alarm_update_date');
  late final _alarm_update_date =
      _alarm_update_datePtr.asFunction<int Function(int, ffi.Pointer<tm>)>();

  /// @brief Updates the period of the registered alarm.
  /// @details The alarm will then go off every @a period seconds until canceled.
  /// This function can be called for any alarm.
  /// If the week recurrence flag was set before, it will be removed and the period will be set.
  /// If the period was set before, it will be overwritten. If it was not, it will be set.
  /// If the @a period argument is 0 and the period was previously set,
  /// the period attribute will be cleared and the alarm will be changed to one-time.
  /// If the @a period argument is 0 and the period was not set,
  /// or the week recurrence flag was set, the alarm will be unchanged.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @param[in] alarm_id  The ID which uniquely identifies the scheduled alarm
  /// @param[in] period    The amount of time between subsequent alarms (in seconds).
  /// Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, this
  /// value does not guarantee the accuracy. The actual interval
  /// is calculated by the OS. The minimum value is 600sec.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE               Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #ALARM_ERROR_CONNECTION_FAIL    Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #ALARM_ERROR_PERMISSION_DENIED  Permission denied
  int alarm_update_period(
    int alarm_id,
    int period,
  ) {
    return _alarm_update_period(
      alarm_id,
      period,
    );
  }

  late final _alarm_update_periodPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'alarm_update_period');
  late final _alarm_update_period =
      _alarm_update_periodPtr.asFunction<int Function(int, int)>();

  /// @brief Updates the week recurrence flag of the registered alarm.
  /// @details @a week_flag is the repeat value of the days of the week.
  /// For example, if @a week_flag is #ALARM_WEEK_FLAG_TUESDAY, the alarm will repeat every
  /// Tuesday at a specific time.
  /// This function can be called for any alarm.
  /// If the period was set before, it will be removed and the week recurrence flag will be set.
  /// If the week recurrence flag was set before, it will be overwritten. If it was not, it will be set.
  /// If the @a week_flag argument is 0 and the flag was previously set,
  /// the flag attribute will be cleared and the alarm will be changed to one-time.
  /// If the @a week_flag argument is 0 and the flag was not set,
  /// or the period was set, the alarm will be unchanged.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/alarm.set
  /// @remarks This function can be called only for alarms whose app control launches an UI application.
  /// If this condition is not met, #ALARM_ERROR_NOT_PERMITTED_APP is returned.
  /// @param[in] alarm_id   The ID which uniquely identifies the scheduled alarm
  /// @param[in] week_flag  The day of the week, @a week_flag may be a combination
  /// of days, like #ALARM_WEEK_FLAG_TUESDAY | #ALARM_WEEK_FLAG_FRIDAY
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #ALARM_ERROR_NONE               Successful
  /// @retval #ALARM_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #ALARM_ERROR_CONNECTION_FAIL    Failed to connect to an alarm server
  /// @retval #ALARM_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #ALARM_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #ALARM_ERROR_NOT_PERMITTED_APP  App control does not launch an UI application
  int alarm_update_week_flag(
    int alarm_id,
    int week_flag,
  ) {
    return _alarm_update_week_flag(
      alarm_id,
      week_flag,
    );
  }

  late final _alarm_update_week_flagPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'alarm_update_week_flag');
  late final _alarm_update_week_flag =
      _alarm_update_week_flagPtr.asFunction<int Function(int, int)>();

  /// @brief Adds the event handler for receiving event-data of interested events.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks If you want to add the privileged event, you MUST declare right privilge first. Unless that, this function returns #EVENT_ERROR_PERMISSION_DENIED. The privileged events are commented on remarks of it's definitions.
  /// @param[in] event_name The interested event name
  /// @param[in] callback The event callback called when the event occurs
  /// @param[in] user_data The user data for passing to callback
  /// @param[out] event_handler The event handler
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EVENT_ERROR_NONE Successful
  /// @retval #EVENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EVENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #EVENT_ERROR_IO_ERROR Adding handler failed
  /// @retval #EVENT_ERROR_OUT_OF_MEMORY Out of memory
  int event_add_event_handler(
    ffi.Pointer<ffi.Char> event_name,
    event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<event_handler_h> event_handler,
  ) {
    return _event_add_event_handler(
      event_name,
      callback,
      user_data,
      event_handler,
    );
  }

  late final _event_add_event_handlerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              event_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<event_handler_h>)>>('event_add_event_handler');
  late final _event_add_event_handler = _event_add_event_handlerPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, event_cb, ffi.Pointer<ffi.Void>,
          ffi.Pointer<event_handler_h>)>();

  /// @brief Removes the registered event handler.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] event_handler The event handler
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EVENT_ERROR_NONE Successful
  /// @retval #EVENT_ERROR_INVALID_PARAMETER Invalid parameter
  int event_remove_event_handler(
    event_handler_h event_handler,
  ) {
    return _event_remove_event_handler(
      event_handler,
    );
  }

  late final _event_remove_event_handlerPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(event_handler_h)>>(
          'event_remove_event_handler');
  late final _event_remove_event_handler = _event_remove_event_handlerPtr
      .asFunction<int Function(event_handler_h)>();

  /// @brief Sends the User-Event to receiver applications.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks The format of User-Event's name MUST be "event.{sender's appid}.{user-defined name}", refer to 'The name-format of User-Event' section, If the event_name is invalid, the function returns #EVENT_ERROR_IO_ERROR.
  /// @param[in] event_name The event's name to send
  /// @param[in] event_data The event's data to send
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EVENT_ERROR_NONE Successful
  /// @retval #EVENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EVENT_ERROR_IO_ERROR Sending operation failed
  int event_publish_app_event(
    ffi.Pointer<ffi.Char> event_name,
    ffi.Pointer<bundle> event_data,
  ) {
    return _event_publish_app_event(
      event_name,
      event_data,
    );
  }

  late final _event_publish_app_eventPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>)>>('event_publish_app_event');
  late final _event_publish_app_event = _event_publish_app_eventPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<bundle>)>();

  /// @brief Sends the User-Event to trusted receiver-applications.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks The application which has same certification with sender can receive the event.
  /// @remarks The format of User-Event's name MUST be "event.{sender's appid}.{user-defined name}", refer to 'The name-format of User-Event' section,  If the event_name is invalid, the function returns #EVENT_ERROR_IO_ERROR.
  /// @param[in] event_name The event's name to send
  /// @param[in] event_data The event's data to send
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EVENT_ERROR_NONE Successful
  /// @retval #EVENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EVENT_ERROR_IO_ERROR Sending operation failed
  int event_publish_trusted_app_event(
    ffi.Pointer<ffi.Char> event_name,
    ffi.Pointer<bundle> event_data,
  ) {
    return _event_publish_trusted_app_event(
      event_name,
      event_data,
    );
  }

  late final _event_publish_trusted_app_eventPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>)>>('event_publish_trusted_app_event');
  late final _event_publish_trusted_app_event =
      _event_publish_trusted_app_eventPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<bundle>)>();

  /// @brief Keeps last User-Event data for receiver applications.
  ///
  /// @since_tizen 3.0
  /// @remarks The receiver applications will receive this last event data after adding their new handlers via event_add_event_handler() API since the sender application called this API.
  /// @remarks If a sender application sends same event via trusted API and non-trusted API, then a trusted receiver will get latest data regardless of trusted or non-trusted, but non-trusted receiver will get the last data only from non-trusted API.
  /// @remarks The effect of this API continues during runtime. That means when the sender application process restarts, the sender application needs to call this api again to make the event to keep the last event.
  /// @param[in] event_name The event's name to keep last event data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EVENT_ERROR_NONE Successful
  /// @retval #EVENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EVENT_ERROR_IO_ERROR Sending operation failed
  /// @retval #EVENT_ERROR_OUT_OF_MEMORY Out of memory
  int event_keep_last_event_data(
    ffi.Pointer<ffi.Char> event_name,
  ) {
    return _event_keep_last_event_data(
      event_name,
    );
  }

  late final _event_keep_last_event_dataPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'event_keep_last_event_data');
  late final _event_keep_last_event_data = _event_keep_last_event_dataPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Sets an integer value in the preference.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to modify
  /// @param[in] value  The new @c int value for the given key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY	Out of memory
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @see	preference_get_int()
  int preference_set_int(
    ffi.Pointer<ffi.Char> key,
    int value,
  ) {
    return _preference_set_int(
      key,
      value,
    );
  }

  late final _preference_set_intPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int)>>(
      'preference_set_int');
  late final _preference_set_int = _preference_set_intPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @brief Gets an integer value from the preference.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to retrieve
  /// @param[out] value The @c int value for the given key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_NO_KEY	Required key not available
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @see	preference_set_int()
  int preference_get_int(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _preference_get_int(
      key,
      value,
    );
  }

  late final _preference_get_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('preference_get_int');
  late final _preference_get_int = _preference_get_intPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets a double value in the preference.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to modify
  /// @param[in] value  The new @c double value associated with the given key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @see	preference_get_double()
  int preference_set_double(
    ffi.Pointer<ffi.Char> key,
    double value,
  ) {
    return _preference_set_double(
      key,
      value,
    );
  }

  late final _preference_set_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>, ffi.Double)>>('preference_set_double');
  late final _preference_set_double = _preference_set_doublePtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, double)>();

  /// @brief Gets a double value from the preference.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to retrieve
  /// @param[out] value The @c double value associated with the given key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_NO_KEY	Required key not available
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @see	preference_set_double()
  int preference_get_double(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Double> value,
  ) {
    return _preference_get_double(
      key,
      value,
    );
  }

  late final _preference_get_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Double>)>>('preference_get_double');
  late final _preference_get_double = _preference_get_doublePtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Double>)>();

  /// @brief Sets a string value in the preference.
  /// @details It makes a deep copy of the added string value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to modify
  /// @param[in] value The new @c string value associated with the given key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @see	preference_get_string()
  int preference_set_string(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _preference_set_string(
      key,
      value,
    );
  }

  late final _preference_set_stringPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('preference_set_string');
  late final _preference_set_string = _preference_set_stringPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets a string value from the preference.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks @a value must be released using free().
  /// @param[in] key The name of the key to retrieve
  /// @param[out] value The @c string value associated with the given key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_NO_KEY	Required key not available
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @see	preference_set_string()
  int preference_get_string(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _preference_get_string(
      key,
      value,
    );
  }

  late final _preference_get_stringPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('preference_get_string');
  late final _preference_get_string = _preference_get_stringPtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets a boolean value in the preference.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to modify
  /// @param[in] value The new @c boolean value associated with the given key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @see	preference_get_boolean()
  int preference_set_boolean(
    ffi.Pointer<ffi.Char> key,
    bool value,
  ) {
    return _preference_set_boolean(
      key,
      value,
    );
  }

  late final _preference_set_booleanPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>, ffi.Bool)>>('preference_set_boolean');
  late final _preference_set_boolean = _preference_set_booleanPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, bool)>();

  /// @brief Gets a boolean value from the preference.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to retrieve
  /// @param[out] value The @c boolean value associated with the given key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_NO_KEY	Required key not available
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @see	preference_set_boolean()
  int preference_get_boolean(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Bool> value,
  ) {
    return _preference_get_boolean(
      key,
      value,
    );
  }

  late final _preference_get_booleanPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('preference_get_boolean');
  late final _preference_get_boolean = _preference_get_booleanPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief Removes any value with the given @a key from the preference.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to remove
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_NO_KEY Required key not available
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  int preference_remove(
    ffi.Pointer<ffi.Char> key,
  ) {
    return _preference_remove(
      key,
    );
  }

  late final _preference_removePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'preference_remove');
  late final _preference_remove =
      _preference_removePtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Checks whether the given @a key exists in the preference.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to check
  /// @param[out] existing If @c true the @a key exists in the preference,
  /// otherwise @c false
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  int preference_is_existing(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Bool> existing,
  ) {
    return _preference_is_existing(
      key,
      existing,
    );
  }

  late final _preference_is_existingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('preference_is_existing');
  late final _preference_is_existing = _preference_is_existingPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief Removes all key-value pairs from the preference.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @see	preference_remove()
  int preference_remove_all() {
    return _preference_remove_all();
  }

  late final _preference_remove_allPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('preference_remove_all');
  late final _preference_remove_all =
      _preference_remove_allPtr.asFunction<int Function()>();

  /// @brief Registers a callback function to be invoked when value of the given key in the preference changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to monitor
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_NO_KEY Required key not available
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @post preference_changed_cb() will be invoked.
  /// @see	preference_unset_changed_cb()
  /// @see preference_changed_cb()
  int preference_set_changed_cb(
    ffi.Pointer<ffi.Char> key,
    preference_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _preference_set_changed_cb(
      key,
      callback,
      user_data,
    );
  }

  late final _preference_set_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, preference_changed_cb,
              ffi.Pointer<ffi.Void>)>>('preference_set_changed_cb');
  late final _preference_set_changed_cb =
      _preference_set_changed_cbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, preference_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] key The name of the key to monitor
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PREFERENCE_ERROR_NO_KEY Required key not available
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @see	preference_set_changed_cb()
  int preference_unset_changed_cb(
    ffi.Pointer<ffi.Char> key,
  ) {
    return _preference_unset_changed_cb(
      key,
    );
  }

  late final _preference_unset_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'preference_unset_changed_cb');
  late final _preference_unset_changed_cb = _preference_unset_changed_cbPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Retrieves all key-value pairs in the preference by invoking the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] callback The callback function to get key value once for each key-value pair in the preference
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PREFERENCE_ERROR_NONE Successful
  /// @retval #PREFERENCE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PREFERENCE_ERROR_IO_ERROR Internal I/O Error
  /// @post This function invokes preference_item_cb() repeatedly to get each key-value pair in the preference.
  /// @see preference_item_cb()
  int preference_foreach_item(
    preference_item_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _preference_foreach_item(
      callback,
      user_data,
    );
  }

  late final _preference_foreach_itemPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(preference_item_cb,
              ffi.Pointer<ffi.Void>)>>('preference_foreach_item');
  late final _preference_foreach_item = _preference_foreach_itemPtr
      .asFunction<int Function(preference_item_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Creates resource manager and get from db.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks If resource manager already exists,
  /// It will just return APP_RESOURCE_ERROR_NONE
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_RESOURCE_ERROR_NONE Successful
  /// @retval #APP_RESOURCE_ERROR_IO_ERROR IO Internal I/O Error
  /// @retval #APP_RESOURCE_ERROR_OUT_OF_MEMORY Out of memeory
  /// @see	app_resource_manager_release()
  int app_resource_manager_init() {
    return _app_resource_manager_init();
  }

  late final _app_resource_manager_initPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'app_resource_manager_init');
  late final _app_resource_manager_init =
      _app_resource_manager_initPtr.asFunction<int Function()>();

  /// @brief Converts resource ID to path name
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks If resource manager is not created yet,
  /// app_resource_manager_init() will be invoked automatically.
  /// Caller should free the returned pointer.
  /// @param[in] type Resource type @see app_resource_e
  /// @param[in] id Resource ID
  /// @param[out] path The name of requested resource on success, otherwise NULL
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_RESOURCE_ERROR_NONE Successful
  /// @retval #APP_RESOURCE_ERROR_INVALID_PARAMETER Invalid Parameter
  /// @retval #APP_RESOURCE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #APP_RESOURCE_ERROR_IO_ERROR Internal I/O Error or failed to find valid resource
  /// @see	app_resource_manager_init()
  int app_resource_manager_get(
    int type,
    ffi.Pointer<ffi.Char> id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _app_resource_manager_get(
      type,
      id,
      path,
    );
  }

  late final _app_resource_manager_getPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_resource_manager_get');
  late final _app_resource_manager_get =
      _app_resource_manager_getPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Destroys resource manager.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks Please note that the instance of resource manager should only be released when the application is closing.
  /// It is a highly recommended way to improve run-time performance.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_RESOURCE_ERROR_NONE Successful
  /// @see	app_resource_manager_init()
  int app_resource_manager_release() {
    return _app_resource_manager_release();
  }

  late final _app_resource_manager_releasePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'app_resource_manager_release');
  late final _app_resource_manager_release =
      _app_resource_manager_releasePtr.asFunction<int Function()>();

  /// @brief  Destroys the application context handle and releases all its resources.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   app_context  The application context handle
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @see app_manager_foreach_app_context()
  /// @see app_manager_get_app_context()
  int app_context_destroy(
    app_context_h app_context,
  ) {
    return _app_context_destroy(
      app_context,
    );
  }

  late final _app_context_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_context_h)>>(
          'app_context_destroy');
  late final _app_context_destroy =
      _app_context_destroyPtr.asFunction<int Function(app_context_h)>();

  /// @deprecated Deprecated since 2.3.1. Use app_context_get_app_id() instead.
  /// @brief    Gets the application ID with the given application context.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a package using free().
  /// @param[in]   app_context  The application context
  /// @param[out]  package      The application ID of the given application context
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_context_get_package(
    app_context_h app_context,
    ffi.Pointer<ffi.Pointer<ffi.Char>> package,
  ) {
    return _app_context_get_package(
      app_context,
      package,
    );
  }

  late final _app_context_get_packagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_context_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_context_get_package');
  late final _app_context_get_package = _app_context_get_packagePtr.asFunction<
      int Function(app_context_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief    Gets the application ID with the given application context.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     You must release @a app_id using free().
  /// @param[in]   app_context  The application context
  /// @param[out]  app_id       The application ID of the given application context
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_context_get_app_id(
    app_context_h app_context,
    ffi.Pointer<ffi.Pointer<ffi.Char>> app_id,
  ) {
    return _app_context_get_app_id(
      app_context,
      app_id,
    );
  }

  late final _app_context_get_app_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_context_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_context_get_app_id');
  late final _app_context_get_app_id = _app_context_get_app_idPtr.asFunction<
      int Function(app_context_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the process ID with the given application context.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   app_context  The application context
  /// @param[out]  pid          The process ID of the given application context
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_context_get_pid(
    app_context_h app_context,
    ffi.Pointer<pid_t> pid,
  ) {
    return _app_context_get_pid(
      app_context,
      pid,
    );
  }

  late final _app_context_get_pidPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_context_h, ffi.Pointer<pid_t>)>>('app_context_get_pid');
  late final _app_context_get_pid = _app_context_get_pidPtr
      .asFunction<int Function(app_context_h, ffi.Pointer<pid_t>)>();

  /// @brief  Gets the package id with the given application context.
  /// @since_tizen 3.0
  /// @remarks     You must release @a pkg_id using free().
  /// @param[in]   app_context  The application context
  /// @param[out]  pkg_id   The package ID of the given application context
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_context_get_package_id(
    app_context_h app_context,
    ffi.Pointer<ffi.Pointer<ffi.Char>> pkg_id,
  ) {
    return _app_context_get_package_id(
      app_context,
      pkg_id,
    );
  }

  late final _app_context_get_package_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  app_context_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'app_context_get_package_id');
  late final _app_context_get_package_id =
      _app_context_get_package_idPtr.asFunction<
          int Function(app_context_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the application state with the given application context.
  /// @since_tizen 3.0
  /// @remarks Note that application's state might be changed after you get app_context.
  /// This API just returns the state of application when you get the app_context.
  /// @param[in]   app_context  The application context
  /// @param[out]  state        The application state of the given application context
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_context_get_app_state(
    app_context_h app_context,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _app_context_get_app_state(
      app_context,
      state,
    );
  }

  late final _app_context_get_app_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_context_h,
              ffi.Pointer<ffi.Int32>)>>('app_context_get_app_state');
  late final _app_context_get_app_state = _app_context_get_app_statePtr
      .asFunction<int Function(app_context_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief  Checks whether the application with the given application context is terminated.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   app_context  The application context
  /// @param[out]  terminated   @c true if the application is terminated, \n
  /// otherwise @c false if the application is running
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_context_is_terminated(
    app_context_h app_context,
    ffi.Pointer<ffi.Bool> terminated,
  ) {
    return _app_context_is_terminated(
      app_context,
      terminated,
    );
  }

  late final _app_context_is_terminatedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_context_h,
              ffi.Pointer<ffi.Bool>)>>('app_context_is_terminated');
  late final _app_context_is_terminated = _app_context_is_terminatedPtr
      .asFunction<int Function(app_context_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief  Checks whether two application contexts are equal.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   lhs    The first application context to compare
  /// @param[in]   rhs    The second application context to compare
  /// @param[out]  equal  @c true if the application contexts are equal, \n
  /// otherwise @c false if they are not equal
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_context_is_equal(
    app_context_h lhs,
    app_context_h rhs,
    ffi.Pointer<ffi.Bool> equal,
  ) {
    return _app_context_is_equal(
      lhs,
      rhs,
      equal,
    );
  }

  late final _app_context_is_equalPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_context_h, app_context_h,
              ffi.Pointer<ffi.Bool>)>>('app_context_is_equal');
  late final _app_context_is_equal = _app_context_is_equalPtr.asFunction<
      int Function(app_context_h, app_context_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief  Checks whether the application is running as a sub application of the application group.
  /// @since_tizen 3.0
  /// @param[in]   app_context  The application context
  /// @param[out]  is_sub_app @c true if the sub application of the group, \n
  /// otherwise @c false if the main application of the group
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_context_is_sub_app(
    app_context_h app_context,
    ffi.Pointer<ffi.Bool> is_sub_app,
  ) {
    return _app_context_is_sub_app(
      app_context,
      is_sub_app,
    );
  }

  late final _app_context_is_sub_appPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_context_h, ffi.Pointer<ffi.Bool>)>>('app_context_is_sub_app');
  late final _app_context_is_sub_app = _app_context_is_sub_appPtr
      .asFunction<int Function(app_context_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief  Clones the application context handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out]  clone        The newly created application context handle, if cloning is successful
  /// @param[in]   app_context  The application context
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_context_clone(
    ffi.Pointer<app_context_h> clone,
    app_context_h app_context,
  ) {
    return _app_context_clone(
      clone,
      app_context,
    );
  }

  late final _app_context_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<app_context_h>, app_context_h)>>('app_context_clone');
  late final _app_context_clone = _app_context_clonePtr
      .asFunction<int Function(ffi.Pointer<app_context_h>, app_context_h)>();

  /// @brief  Creates the application information handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   app_id    The application ID
  /// @param[out]  app_info  The application information handle
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_NO_SUCH_APP        The app is not installed
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  /// @see app_manager_foreach_app_info()
  /// @see app_manager_get_app_info()
  int app_info_create(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<app_info_h> app_info,
  ) {
    return _app_info_create(
      app_id,
      app_info,
    );
  }

  late final _app_info_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<app_info_h>)>>('app_info_create');
  late final _app_info_create = _app_info_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<app_info_h>)>();

  /// @brief  Destroys the application information handle and releases all its resources.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   app_info  The application information handle
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @see app_manager_foreach_app_info()
  /// @see app_manager_get_app_info()
  int app_info_destroy(
    app_info_h app_info,
  ) {
    return _app_info_destroy(
      app_info,
    );
  }

  late final _app_info_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_info_h)>>(
          'app_info_destroy');
  late final _app_info_destroy =
      _app_info_destroyPtr.asFunction<int Function(app_info_h)>();

  /// @brief  Gets the application ID with the given application context.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     You must release @a app_id using free().
  /// @param[in]   app_info  The application information
  /// @param[out]  app_id    The application ID of the given application context
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_info_get_app_id(
    app_info_h app_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> app_id,
  ) {
    return _app_info_get_app_id(
      app_info,
      app_id,
    );
  }

  late final _app_info_get_app_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_info_get_app_id');
  late final _app_info_get_app_id = _app_info_get_app_idPtr.asFunction<
      int Function(app_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the executable path of the application
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     You must release @a exec path using free().
  /// @param[in]   app_info The application information
  /// @param[out]  exec     The executable path of the application
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_info_get_exec(
    app_info_h app_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> exec,
  ) {
    return _app_info_get_exec(
      app_info,
      exec,
    );
  }

  late final _app_info_get_execPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_info_get_exec');
  late final _app_info_get_exec = _app_info_get_execPtr.asFunction<
      int Function(app_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the label of the application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     You must release @a label using free().
  /// @param[in]   app_info  The application information
  /// @param[out]  label     The label of the application
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_info_get_label(
    app_info_h app_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> label,
  ) {
    return _app_info_get_label(
      app_info,
      label,
    );
  }

  late final _app_info_get_labelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_info_get_label');
  late final _app_info_get_label = _app_info_get_labelPtr.asFunction<
      int Function(app_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the localed name of the application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     You must release localed name using free().
  /// @param[in]   app_id  The application ID
  /// @param[in]   locale  The locale information
  /// @param[out]  label   The localed name of the application
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_info_get_localed_label(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Char> locale,
    ffi.Pointer<ffi.Pointer<ffi.Char>> label,
  ) {
    return _app_info_get_localed_label(
      app_id,
      locale,
      label,
    );
  }

  late final _app_info_get_localed_labelPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'app_info_get_localed_label');
  late final _app_info_get_localed_label =
      _app_info_get_localed_labelPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the absolute path to the icon image.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     You must release @a path using free().
  /// @param[in]   app_info  The application information
  /// @param[out]  path      The absolute path to the icon
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_info_get_icon(
    app_info_h app_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _app_info_get_icon(
      app_info,
      path,
    );
  }

  late final _app_info_get_iconPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_info_get_icon');
  late final _app_info_get_icon = _app_info_get_iconPtr.asFunction<
      int Function(app_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the package name.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     You must release @a package name using free().
  /// @param[in]   app_info  The application information
  /// @param[out]  package   The package name
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_info_get_package(
    app_info_h app_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> package,
  ) {
    return _app_info_get_package(
      app_info,
      package,
    );
  }

  late final _app_info_get_packagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_info_get_package');
  late final _app_info_get_package = _app_info_get_packagePtr.asFunction<
      int Function(app_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the package type name.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     You must release package @a type name using free().
  /// @param[in]   app_info The application information
  /// @param[out]  type     The package type
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_info_get_type(
    app_info_h app_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> type,
  ) {
    return _app_info_get_type(
      app_info,
      type,
    );
  }

  late final _app_info_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_info_get_type');
  late final _app_info_get_type = _app_info_get_typePtr.asFunction<
      int Function(app_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the application component type.
  /// @since_tizen 4.0
  /// @param[in]   app_info  The application information
  /// @param[out]  type      The application component type
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  /// @see #PACKAGE_INFO_PROP_APP_COMPONENT_TYPE
  /// @see #app_info_app_component_type_e
  int app_info_get_app_component_type(
    app_info_h app_info,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _app_info_get_app_component_type(
      app_info,
      type,
    );
  }

  late final _app_info_get_app_component_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_h,
              ffi.Pointer<ffi.Int32>)>>('app_info_get_app_component_type');
  late final _app_info_get_app_component_type =
      _app_info_get_app_component_typePtr
          .asFunction<int Function(app_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief  Gets the list of metadata for a particular application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  app_info   The application information
  /// @param[in]  callback   The callback function for list
  /// @param[in]  user_data  The user data to be passed to callback function
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_foreach_metadata(
    app_info_h app_info,
    app_info_metadata_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_info_foreach_metadata(
      app_info,
      callback,
      user_data,
    );
  }

  late final _app_info_foreach_metadataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_h, app_info_metadata_cb,
              ffi.Pointer<ffi.Void>)>>('app_info_foreach_metadata');
  late final _app_info_foreach_metadata =
      _app_info_foreach_metadataPtr.asFunction<
          int Function(
              app_info_h, app_info_metadata_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief  Checks whether application information is nodisplay.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   app_info   The application information
  /// @param[out]  nodisplay  @c true if the application is nodisplay, \n
  /// otherwise @c false
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_info_is_nodisplay(
    app_info_h app_info,
    ffi.Pointer<ffi.Bool> nodisplay,
  ) {
    return _app_info_is_nodisplay(
      app_info,
      nodisplay,
    );
  }

  late final _app_info_is_nodisplayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_info_h, ffi.Pointer<ffi.Bool>)>>('app_info_is_nodisplay');
  late final _app_info_is_nodisplay = _app_info_is_nodisplayPtr
      .asFunction<int Function(app_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief  Checks whether two application information are equal.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   lhs    The first application information to compare
  /// @param[in]   rhs    The second application information to compare
  /// @param[out]  equal  @c true if the application information are equal, \n
  /// otherwise @c false
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_info_is_equal(
    app_info_h lhs,
    app_info_h rhs,
    ffi.Pointer<ffi.Bool> equal,
  ) {
    return _app_info_is_equal(
      lhs,
      rhs,
      equal,
    );
  }

  late final _app_info_is_equalPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_h, app_info_h,
              ffi.Pointer<ffi.Bool>)>>('app_info_is_equal');
  late final _app_info_is_equal = _app_info_is_equalPtr.asFunction<
      int Function(app_info_h, app_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief  Checks whether application is enabled.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   app_info  The application information
  /// @param[out]  enabled   @c true if the application is enabled, \n
  /// otherwise @c false
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_info_is_enabled(
    app_info_h app_info,
    ffi.Pointer<ffi.Bool> enabled,
  ) {
    return _app_info_is_enabled(
      app_info,
      enabled,
    );
  }

  late final _app_info_is_enabledPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_info_h, ffi.Pointer<ffi.Bool>)>>('app_info_is_enabled');
  late final _app_info_is_enabled = _app_info_is_enabledPtr
      .asFunction<int Function(app_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief  Checks whether application is launched on booting time.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   app_info  The application information
  /// @param[out]  onboot    @c true if the application is launched on booting time, \n
  /// otherwise @c false
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_info_is_onboot(
    app_info_h app_info,
    ffi.Pointer<ffi.Bool> onboot,
  ) {
    return _app_info_is_onboot(
      app_info,
      onboot,
    );
  }

  late final _app_info_is_onbootPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_info_h, ffi.Pointer<ffi.Bool>)>>('app_info_is_onboot');
  late final _app_info_is_onboot = _app_info_is_onbootPtr
      .asFunction<int Function(app_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief  Checks whether application is preloaded.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   app_info  The application information
  /// @param[out]  preload   @c true if the application is preloaded, \n
  /// otherwise @c false
  /// @return        @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_info_is_preload(
    app_info_h app_info,
    ffi.Pointer<ffi.Bool> preload,
  ) {
    return _app_info_is_preload(
      app_info,
      preload,
    );
  }

  late final _app_info_is_preloadPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              app_info_h, ffi.Pointer<ffi.Bool>)>>('app_info_is_preload');
  late final _app_info_is_preload = _app_info_is_preloadPtr
      .asFunction<int Function(app_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief  Clones the application information handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out]  clone     A newly created application information handle, if successfully cloned
  /// @param[in]   app_info  The application information
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval  #APP_MANAGER_ERROR_NO_SUCH_APP        The app is not installed
  int app_info_clone(
    ffi.Pointer<app_info_h> clone,
    app_info_h app_info,
  ) {
    return _app_info_clone(
      clone,
      app_info,
    );
  }

  late final _app_info_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<app_info_h>, app_info_h)>>('app_info_clone');
  late final _app_info_clone = _app_info_clonePtr
      .asFunction<int Function(ffi.Pointer<app_info_h>, app_info_h)>();

  /// @platform
  /// @brief  Runs a callback for each category which the given application belongs to.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in]  app_info   The application information
  /// @param[in]  callback   The callback function
  /// @param[in]  user_data  The user data to be passed to the callback function
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  /// @retval  #APP_MANAGER_ERROR_PERMISSION_DENIED  Permission denied
  /// @see app_info_create()
  int app_info_foreach_category(
    app_info_h app_info,
    app_info_category_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_info_foreach_category(
      app_info,
      callback,
      user_data,
    );
  }

  late final _app_info_foreach_categoryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_h, app_info_category_cb,
              ffi.Pointer<ffi.Void>)>>('app_info_foreach_category');
  late final _app_info_foreach_category =
      _app_info_foreach_categoryPtr.asFunction<
          int Function(
              app_info_h, app_info_category_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief  Creates the application information filter handle from DB.
  /// All filter properties will be ANDed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out]  handle  The pointer to the application info filter handle
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_filter_create(
    ffi.Pointer<app_info_filter_h> handle,
  ) {
    return _app_info_filter_create(
      handle,
    );
  }

  late final _app_info_filter_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<app_info_filter_h>)>>(
      'app_info_filter_create');
  late final _app_info_filter_create = _app_info_filter_createPtr
      .asFunction<int Function(ffi.Pointer<app_info_filter_h>)>();

  /// @brief  Destroys the application information filter handle, freeing up all the resources.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  handle  The pointer to the application info filter handle
  /// @return     @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_filter_destroy(
    app_info_filter_h handle,
  ) {
    return _app_info_filter_destroy(
      handle,
    );
  }

  late final _app_info_filter_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_info_filter_h)>>(
          'app_info_filter_destroy');
  late final _app_info_filter_destroy =
      _app_info_filter_destroyPtr.asFunction<int Function(app_info_filter_h)>();

  /// @brief  Adds a boolean filter property to the filter handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  handle    The pointer to the application info filter handle
  /// @param[in]  property  The integer property name
  /// @param[in]  value     The value corresponding to the property
  /// @return     @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_filter_add_bool(
    app_info_filter_h handle,
    ffi.Pointer<ffi.Char> property,
    bool value,
  ) {
    return _app_info_filter_add_bool(
      handle,
      property,
      value,
    );
  }

  late final _app_info_filter_add_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_filter_h, ffi.Pointer<ffi.Char>,
              ffi.Bool)>>('app_info_filter_add_bool');
  late final _app_info_filter_add_bool =
      _app_info_filter_add_boolPtr.asFunction<
          int Function(app_info_filter_h, ffi.Pointer<ffi.Char>, bool)>();

  /// @brief  Adds a string filter property to the filter handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  handle    The pointer to the application info filter handle
  /// @param[in]  property  The integer property name
  /// @param[in]  value     The value corresponding to the property
  /// @return     @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_filter_add_string(
    app_info_filter_h handle,
    ffi.Pointer<ffi.Char> property,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _app_info_filter_add_string(
      handle,
      property,
      value,
    );
  }

  late final _app_info_filter_add_stringPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_filter_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('app_info_filter_add_string');
  late final _app_info_filter_add_string =
      _app_info_filter_add_stringPtr.asFunction<
          int Function(app_info_filter_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief  Gets the count of filtered apps.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   handle  The pointer to the application info filter handle
  /// @param[out]  count   The pointer to the variable for count
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_filter_count_appinfo(
    app_info_filter_h handle,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _app_info_filter_count_appinfo(
      handle,
      count,
    );
  }

  late final _app_info_filter_count_appinfoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_filter_h,
              ffi.Pointer<ffi.Int>)>>('app_info_filter_count_appinfo');
  late final _app_info_filter_count_appinfo = _app_info_filter_count_appinfoPtr
      .asFunction<int Function(app_info_filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief  Executes the user supplied callback function for each application that satisfy the filter conditions.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  handle     The pointer to the application info filter handle
  /// @param[in]  callback   The callback function
  /// @param[in]  user_data  The user data to be passed to the callback function
  /// @return     @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_filter_foreach_appinfo(
    app_info_filter_h handle,
    app_info_filter_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_info_filter_foreach_appinfo(
      handle,
      callback,
      user_data,
    );
  }

  late final _app_info_filter_foreach_appinfoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_filter_h, app_info_filter_cb,
              ffi.Pointer<ffi.Void>)>>('app_info_filter_foreach_appinfo');
  late final _app_info_filter_foreach_appinfo =
      _app_info_filter_foreach_appinfoPtr.asFunction<
          int Function(
              app_info_filter_h, app_info_filter_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief  Creates the application's metadata information filter handle from DB.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out]  handle  The pointer to the application metadata info filter handle
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_metadata_filter_create(
    ffi.Pointer<app_info_metadata_filter_h> handle,
  ) {
    return _app_info_metadata_filter_create(
      handle,
    );
  }

  late final _app_info_metadata_filter_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<app_info_metadata_filter_h>)>>(
      'app_info_metadata_filter_create');
  late final _app_info_metadata_filter_create =
      _app_info_metadata_filter_createPtr
          .asFunction<int Function(ffi.Pointer<app_info_metadata_filter_h>)>();

  /// @brief  Destroys the application's metadata information filter handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  handle  The pointer to the application info filter handle
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_metadata_filter_destroy(
    app_info_metadata_filter_h handle,
  ) {
    return _app_info_metadata_filter_destroy(
      handle,
    );
  }

  late final _app_info_metadata_filter_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_info_metadata_filter_h)>>(
          'app_info_metadata_filter_destroy');
  late final _app_info_metadata_filter_destroy =
      _app_info_metadata_filter_destroyPtr
          .asFunction<int Function(app_info_metadata_filter_h)>();

  /// @brief  Adds filter condition for the query API.
  /// @details  The query will search the entire application metadata information collected from
  /// the manifest file of all the installed packages. You can specify value as @c NULL to search based on key only.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  handle  The pointer to the application metadata info filter handle
  /// @param[in]  key     The pointer to metadata key
  /// @param[in]  value   The pointer to metadata value
  /// @return     @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_metadata_filter_add(
    app_info_metadata_filter_h handle,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _app_info_metadata_filter_add(
      handle,
      key,
      value,
    );
  }

  late final _app_info_metadata_filter_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_metadata_filter_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('app_info_metadata_filter_add');
  late final _app_info_metadata_filter_add =
      _app_info_metadata_filter_addPtr.asFunction<
          int Function(app_info_metadata_filter_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief  Executes the filter query.
  /// @details  The query will search the entire application metadata information collected from
  /// the manifest file of all the installed packages. For each application returned by the query, the callback will be called. If callback returns
  /// negative value, no more callbacks will be called and API will return.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  handle     The pointer to the application metadata info filter handle
  /// @param[in]  callback   The function pointer to callback
  /// @param[in]  user_data  The pointer to user data
  /// @return     @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           I/O error
  int app_info_metadata_filter_foreach(
    app_info_metadata_filter_h handle,
    app_info_filter_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_info_metadata_filter_foreach(
      handle,
      callback,
      user_data,
    );
  }

  late final _app_info_metadata_filter_foreachPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_info_metadata_filter_h, app_info_filter_cb,
              ffi.Pointer<ffi.Void>)>>('app_info_metadata_filter_foreach');
  late final _app_info_metadata_filter_foreach =
      _app_info_metadata_filter_foreachPtr.asFunction<
          int Function(app_info_metadata_filter_h, app_info_filter_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief  Registers a callback function to be invoked when the applications get launched or terminated.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in]   callback   The callback function to register
  /// @param[in]   user_data  The user data to be passed to the callback function
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           Internal I/O error
  /// @post It will invoke app_manager_app_context_event_cb() when the application is launched or terminated.
  /// @see app_manager_unset_app_context_event_cb()
  /// @see app_manager_app_context_event_cb()
  int app_manager_set_app_context_event_cb(
    app_manager_app_context_event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_manager_set_app_context_event_cb(
      callback,
      user_data,
    );
  }

  late final _app_manager_set_app_context_event_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_manager_app_context_event_cb,
              ffi.Pointer<ffi.Void>)>>('app_manager_set_app_context_event_cb');
  late final _app_manager_set_app_context_event_cb =
      _app_manager_set_app_context_event_cbPtr.asFunction<
          int Function(
              app_manager_app_context_event_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief   Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @see app_manager_app_context_event_cb()
  void app_manager_unset_app_context_event_cb() {
    return _app_manager_unset_app_context_event_cb();
  }

  late final _app_manager_unset_app_context_event_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function()>>(
          'app_manager_unset_app_context_event_cb');
  late final _app_manager_unset_app_context_event_cb =
      _app_manager_unset_app_context_event_cbPtr.asFunction<void Function()>();

  /// @brief  Retrieves all application contexts of running applications.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   callback   The callback function to invoke
  /// @param[in]   user_data  The user data to be passed to the callback function
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           Internal I/O error
  /// @post   This function invokes app_manager_app_context_cb() for each application context.
  /// @see app_manager_app_context_cb()
  /// @remarks  In case of ui applications, sub apps in application groups will not be shown.
  int app_manager_foreach_app_context(
    app_manager_app_context_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_manager_foreach_app_context(
      callback,
      user_data,
    );
  }

  late final _app_manager_foreach_app_contextPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_manager_app_context_cb,
              ffi.Pointer<ffi.Void>)>>('app_manager_foreach_app_context');
  late final _app_manager_foreach_app_context =
      _app_manager_foreach_app_contextPtr.asFunction<
          int Function(app_manager_app_context_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief  Retrieves all application contexts of running applications including sub apps.
  /// @details You can iterate all the running application contexts using this API.
  /// This API is similar to app_manager_foreach_app_context() except that this API iterates application contexts including sub apps in application groups.
  /// @since_tizen 3.0
  /// @param[in]   callback   The callback function to invoke
  /// @param[in]   user_data  The user data to be passed to the callback function
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_IO_ERROR           Internal I/O error
  /// @post   This function invokes app_manager_app_context_cb() for each application context.
  /// @see app_manager_app_context_cb()
  int app_manager_foreach_running_app_context(
    app_manager_app_context_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_manager_foreach_running_app_context(
      callback,
      user_data,
    );
  }

  late final _app_manager_foreach_running_app_contextPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  app_manager_app_context_cb, ffi.Pointer<ffi.Void>)>>(
      'app_manager_foreach_running_app_context');
  late final _app_manager_foreach_running_app_context =
      _app_manager_foreach_running_app_contextPtr.asFunction<
          int Function(app_manager_app_context_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief  Gets the application context for the given ID of the application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks  This function returns #APP_MANAGER_ERROR_NO_SUCH_APP if the application with the given application ID is not running. \n
  /// You must release @a app_context using app_context_destroy().
  /// @param[in]   app_id       The ID of the application
  /// @param[out]  app_context  The application context of the given application ID
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval  #APP_MANAGER_ERROR_NO_SUCH_APP        No such application
  int app_manager_get_app_context(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<app_context_h> app_context,
  ) {
    return _app_manager_get_app_context(
      app_id,
      app_context,
    );
  }

  late final _app_manager_get_app_contextPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<app_context_h>)>>('app_manager_get_app_context');
  late final _app_manager_get_app_context =
      _app_manager_get_app_contextPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<app_context_h>)>();

  /// @brief  Gets the ID of the application for the given process ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks  This function returns #APP_MANAGER_ERROR_NO_SUCH_APP if the application with the given process ID is not valid. \n
  /// You must release @a app_id using free().
  /// @param[in]   pid     The process ID of the application
  /// @param[out]  app_id  The ID of the application
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_manager_get_app_id(
    int pid,
    ffi.Pointer<ffi.Pointer<ffi.Char>> app_id,
  ) {
    return _app_manager_get_app_id(
      pid,
      app_id,
    );
  }

  late final _app_manager_get_app_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(pid_t,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('app_manager_get_app_id');
  late final _app_manager_get_app_id = _app_manager_get_app_idPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Checks whether the application with the given ID of the application is running.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   app_id   The ID of the application
  /// @param[out]  running  @c true if the application is running, \n
  /// otherwise @c false if not running
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  int app_manager_is_running(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Bool> running,
  ) {
    return _app_manager_is_running(
      app_id,
      running,
    );
  }

  late final _app_manager_is_runningPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('app_manager_is_running');
  late final _app_manager_is_running = _app_manager_is_runningPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief  Resumes the application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/appmanager.launch
  /// @param[in]   app_context  The application context
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_APP_NO_RUNNING     App is not running
  /// @retval  #APP_MANAGER_ERROR_REQUEST_FAILED     Internal resume error
  /// @retval  #APP_MANAGER_ERROR_PERMISSION_DENIED  Permission denied
  int app_manager_resume_app(
    app_context_h app_context,
  ) {
    return _app_manager_resume_app(
      app_context,
    );
  }

  late final _app_manager_resume_appPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_context_h)>>(
          'app_manager_resume_app');
  late final _app_manager_resume_app =
      _app_manager_resume_appPtr.asFunction<int Function(app_context_h)>();

  /// @brief  Terminates the back ground application.\n
  /// UI applications that are in paused state or some service applications could be required to terminate by this API.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/appmanager.kill.bgapp
  /// @remarks This function returns after it just sends a request for terminating a background application.\n
  /// Platform will decide if the target application could be terminated or not according to the state of the target application.
  /// @param[in]   app_context  The application context
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_REQUEST_FAILED  Failed to send terminate request
  /// @retval #APP_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int app_manager_request_terminate_bg_app(
    app_context_h app_context,
  ) {
    return _app_manager_request_terminate_bg_app(
      app_context,
    );
  }

  late final _app_manager_request_terminate_bg_appPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_context_h)>>(
          'app_manager_request_terminate_bg_app');
  late final _app_manager_request_terminate_bg_app =
      _app_manager_request_terminate_bg_appPtr
          .asFunction<int Function(app_context_h)>();

  /// @brief  Retrieves all installed applications information.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   callback   The callback function to invoke
  /// @param[in]   user_data  The user data to be passed to the callback function
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @post    This function invokes app_manager_app_info_cb() for each application information.
  /// @see app_manager_app_info_cb()
  int app_manager_foreach_app_info(
    app_manager_app_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_manager_foreach_app_info(
      callback,
      user_data,
    );
  }

  late final _app_manager_foreach_app_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_manager_app_info_cb,
              ffi.Pointer<ffi.Void>)>>('app_manager_foreach_app_info');
  late final _app_manager_foreach_app_info =
      _app_manager_foreach_app_infoPtr.asFunction<
          int Function(app_manager_app_info_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief  Gets the application information for the given application ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     You must release @a app_info using app_info_destroy().
  /// @param[in]   app_id    The ID of the application
  /// @param[out]  app_info  The application information for the given application ID
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval  #APP_MANAGER_ERROR_NO_SUCH_APP        No such application
  int app_manager_get_app_info(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<app_info_h> app_info,
  ) {
    return _app_manager_get_app_info(
      app_id,
      app_info,
    );
  }

  late final _app_manager_get_app_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<app_info_h>)>>('app_manager_get_app_info');
  late final _app_manager_get_app_info =
      _app_manager_get_app_infoPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<app_info_h>)>();

  /// @brief  Gets the absolute path to the shared data directory of the application specified
  /// with an application ID.
  /// @details     An application can only read the files of other application's shared data directory.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     The specified @a path should be released with free(). @n
  /// Since Tizen 3.0, the shared/data directory is supported only for the applications that declare the http://tizen.org/privilege/appdir.shareddata privilege.
  /// The function will fail with #APP_MANAGER_ERROR_NOT_SUPPORTED if the privilege is not declared.
  ///
  /// @param[in]      app_id  The ID of the application
  /// @param[in,out]  path    The absolute path to the shared data directory of the application
  /// specified with the @a app_id
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_NO_SUCH_APP        No such application
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval  #APP_MANAGER_ERROR_NOT_SUPPORTED	  Not supported
  int app_manager_get_shared_data_path(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _app_manager_get_shared_data_path(
      app_id,
      path,
    );
  }

  late final _app_manager_get_shared_data_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'app_manager_get_shared_data_path');
  late final _app_manager_get_shared_data_path =
      _app_manager_get_shared_data_pathPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the absolute path to the shared resource directory of the application specified
  /// with an application ID.
  /// @details     An application can only read the files of other application's shared resource directory.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     The specified @a path should be released with free().
  ///
  /// @param[in]      app_id  The ID of the application
  /// @param[in,out]  path    The absolute path to the shared resource directory of the application
  /// specified with the @a app_id
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_NO_SUCH_APP        No such application
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_manager_get_shared_resource_path(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _app_manager_get_shared_resource_path(
      app_id,
      path,
    );
  }

  late final _app_manager_get_shared_resource_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'app_manager_get_shared_resource_path');
  late final _app_manager_get_shared_resource_path =
      _app_manager_get_shared_resource_pathPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Gets the absolute path to the shared trusted directory of the application specified
  /// with an application ID.
  /// @details     An application signed with the same certificate can read and write the files of
  /// other application's shared trusted directory.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     The specified @a path should be released with free().
  ///
  /// @param[in]      app_id  The ID of the application
  /// @param[in,out]  path    The absolute path to the shared trusted directory of the application
  /// specified with the @a app_id
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_NO_SUCH_APP        No such application
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_manager_get_shared_trusted_path(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _app_manager_get_shared_trusted_path(
      app_id,
      path,
    );
  }

  late final _app_manager_get_shared_trusted_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'app_manager_get_shared_trusted_path');
  late final _app_manager_get_shared_trusted_path =
      _app_manager_get_shared_trusted_pathPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif.
  /// @brief  Gets the absolute path to the shared data directory of the application specified
  /// with an application ID.
  /// @details     An application can only read the files of other application's shared data directory.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks     The specified @a path should be released with free().
  /// @remarks     To access the path returned by this function may not work as intended in certain devices due to some implementation issues.
  ///
  /// @param[in]      app_id  The ID of the application
  /// @param[in,out]  path    The absolute path to the shared data directory of the application
  /// specified with the @a app_id
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #APP_MANAGER_ERROR_NONE               Successful
  /// @retval  #APP_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #APP_MANAGER_ERROR_NO_SUCH_APP        No such application
  /// @retval  #APP_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  int app_manager_get_external_shared_data_path(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _app_manager_get_external_shared_data_path(
      app_id,
      path,
    );
  }

  late final _app_manager_get_external_shared_data_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'app_manager_get_external_shared_data_path');
  late final _app_manager_get_external_shared_data_path =
      _app_manager_get_external_shared_data_pathPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Creates a app manager event handle.
  /// @since_tizen 3.0
  /// @remarks You must release @a handle using app_manager_event_destroy().
  ///
  /// @param[out] handle The app manager event handle that is newly created on success
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #APP_MANAGER_ERROR_NONE              Successful
  /// @retval #APP_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #APP_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see app_manager_event_destroy()
  int app_manager_event_create(
    ffi.Pointer<app_manager_event_h> handle,
  ) {
    return _app_manager_event_create(
      handle,
    );
  }

  late final _app_manager_event_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<app_manager_event_h>)>>('app_manager_event_create');
  late final _app_manager_event_create = _app_manager_event_createPtr
      .asFunction<int Function(ffi.Pointer<app_manager_event_h>)>();

  /// @brief Sets the event to handle to listen.
  /// You can combine multiple status using OR operation which you want to listen.
  /// @since_tizen 3.0
  ///
  /// @param [in] handle     The app manager event handle
  /// @param [in] status_type The status of the application
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #APP_MANAGER_ERROR_NONE              Successful
  /// @retval #APP_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_MANAGER_ERROR_REQUEST_FAILED          Internal error
  ///
  /// @see app_manager_event_status_type_e
  /// @see app_manager_set_event_cb()
  int app_manager_event_set_status(
    app_manager_event_h handle,
    int status_type,
  ) {
    return _app_manager_event_set_status(
      handle,
      status_type,
    );
  }

  late final _app_manager_event_set_statusPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(app_manager_event_h, ffi.Int)>>(
      'app_manager_event_set_status');
  late final _app_manager_event_set_status = _app_manager_event_set_statusPtr
      .asFunction<int Function(app_manager_event_h, int)>();

  /// @brief Registers a callback function to be invoked when the app is event has occurred
  /// @since_tizen 3.0
  /// @param[in] handle    The app manager event handle
  /// @param[in] callback   The callback function to be registered
  /// @param[in] user_data  The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #APP_MANAGER_ERROR_NONE              Successful
  /// @retval #APP_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_MANAGER_ERROR_REQUEST_FAILED          Internal error
  /// @post app_manager_event_cb() will be invoked.
  ///
  /// @see app_manager_event_set_status()
  /// @see app_manager_event_cb()
  /// @see app_manager_unset_event_cb()
  int app_manager_set_event_cb(
    app_manager_event_h handle,
    app_manager_event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _app_manager_set_event_cb(
      handle,
      callback,
      user_data,
    );
  }

  late final _app_manager_set_event_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_manager_event_h, app_manager_event_cb,
              ffi.Pointer<ffi.Void>)>>('app_manager_set_event_cb');
  late final _app_manager_set_event_cb =
      _app_manager_set_event_cbPtr.asFunction<
          int Function(app_manager_event_h, app_manager_event_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 3.0
  ///
  /// @param[in] handle The app manager event handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #APP_MANAGER_ERROR_NONE              Successful
  /// @retval #APP_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_MANAGER_ERROR_REQUEST_FAILED          Internal error
  ///
  /// @see app_manager_event_cb()
  /// @see app_manager_set_event_cb()
  int app_manager_unset_event_cb(
    app_manager_event_h handle,
  ) {
    return _app_manager_unset_event_cb(
      handle,
    );
  }

  late final _app_manager_unset_event_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_manager_event_h)>>(
          'app_manager_unset_event_cb');
  late final _app_manager_unset_event_cb = _app_manager_unset_event_cbPtr
      .asFunction<int Function(app_manager_event_h)>();

  /// @brief Destroys the app manager event handle.
  /// @since_tizen 3.0
  ///
  /// @param[in] handle The app manager event handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #APP_MANAGER_ERROR_NONE              Successful
  /// @retval #APP_MANAGER_ERROR_REQUEST_FAILED          Internal error
  /// @retval #APP_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see app_manager_event_create()
  int app_manager_event_destroy(
    app_manager_event_h handle,
  ) {
    return _app_manager_event_destroy(
      handle,
    );
  }

  late final _app_manager_event_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_manager_event_h)>>(
          'app_manager_event_destroy');
  late final _app_manager_event_destroy = _app_manager_event_destroyPtr
      .asFunction<int Function(app_manager_event_h)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif Use badge_add instead.
  /// @brief Creates a badge for the application itself.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @details Creates new badge to display.
  /// @param[in] writable_app_id The id of application which is authorized to change the badge
  /// @return #BADGE_ERROR_NONE if success, other value if failure
  /// @retval BADGE_ERROR_NONE Success
  /// @retval BADGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BADGE_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval BADGE_ERROR_IO_ERROR Error from I/O
  /// @retval BADGE_ERROR_SERVICE_NOT_READY Service is not ready
  /// @retval BADGE_ERROR_NOT_SUPPORTED Not supported
  /// @see #badge_error_e
  /// @par Sample code:
  /// @code
  /// #include <badge.h>
  ///
  /// {
  /// int err = BADGE_ERROR_NONE;
  ///
  /// err = badge_new(app_id);
  /// if (err != BADGE_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int badge_new(
    ffi.Pointer<ffi.Char> writable_app_id,
  ) {
    return _badge_new(
      writable_app_id,
    );
  }

  late final _badge_newPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'badge_new');
  late final _badge_new =
      _badge_newPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Creates a badge for the application specified by the badge_app_id.
  /// @remarks Creating and updating a badge of the other application is allowed only when both applications are signed with the same certificate.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] badge_app_id The id of the application for which the badge will be created. This parameter can be null when creating a badge for itself.
  /// @return #BADGE_ERROR_NONE If success, other value if failure
  /// @retval #BADGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #BADGE_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #BADGE_ERROR_IO_ERROR Error from I/O
  /// @retval #BADGE_ERROR_SERVICE_NOT_READY Service is not ready
  /// @retval #BADGE_ERROR_INVALID_PACKAGE The caller application is not signed with the certificate of the badge_app_id
  /// @retval BADGE_ERROR_NOT_SUPPORTED Not supported
  /// @see #badge_error_e
  /// @par Sample code:
  /// @code
  /// #include <badge.h>
  ///
  /// {
  /// int err = BADGE_ERROR_NONE;
  ///
  /// err = badge_add("org.tizen.email");
  /// if (err != BADGE_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int badge_add(
    ffi.Pointer<ffi.Char> badge_app_id,
  ) {
    return _badge_add(
      badge_app_id,
    );
  }

  late final _badge_addPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'badge_add');
  late final _badge_add =
      _badge_addPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Removes the badge for the designated application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] app_id The name of the designated application
  /// @return #BADGE_ERROR_NONE if success, other value if failure
  /// @retval BADGE_ERROR_NONE Success
  /// @retval BADGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BADGE_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval BADGE_ERROR_IO_ERROR Error from I/O
  /// @retval BADGE_ERROR_SERVICE_NOT_READY Service is not ready
  /// @retval BADGE_ERROR_NOT_SUPPORTED Not supported
  /// @see #badge_error_e
  /// @par Sample code:
  /// @code
  /// #include <badge.h>
  ///
  /// {
  /// int err = BADGE_ERROR_NONE;
  ///
  /// err = badge_remove(app_id);
  /// if (err != BADGE_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int badge_remove(
    ffi.Pointer<ffi.Char> app_id,
  ) {
    return _badge_remove(
      app_id,
    );
  }

  late final _badge_removePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'badge_remove');
  late final _badge_remove =
      _badge_removePtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Sets badge count for the designated application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] app_id The name of the designated application
  /// @param[in] count The count of the badge
  /// @return #BADGE_ERROR_NONE if success, other value if failure
  /// @retval BADGE_ERROR_NONE Success
  /// @retval BADGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BADGE_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval BADGE_ERROR_IO_ERROR Error from I/O
  /// @retval BADGE_ERROR_SERVICE_NOT_READY Service is not ready
  /// @retval BADGE_ERROR_NOT_SUPPORTED Not supported
  /// @see #badge_error_e
  /// @see badge_new()
  /// @par Sample code:
  /// @code
  /// #include <badge.h>
  ///
  /// {
  /// int err = BADGE_ERROR_NONE;
  ///
  /// err = badge_set_count(app_id, 1);
  /// if (err != BADGE_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int badge_set_count(
    ffi.Pointer<ffi.Char> app_id,
    int count,
  ) {
    return _badge_set_count(
      app_id,
      count,
    );
  }

  late final _badge_set_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>, ffi.UnsignedInt)>>('badge_set_count');
  late final _badge_set_count = _badge_set_countPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @brief Gets badge count for the designated application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] app_id The name of the designated application
  /// @param[out] count The count of the badge
  /// @return #BADGE_ERROR_NONE if success, other value if failure
  /// @retval BADGE_ERROR_NONE Success
  /// @retval BADGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BADGE_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval BADGE_ERROR_FROM_DB Error from DB
  /// @retval BADGE_ERROR_ALREADY_EXIST Already exist
  /// @retval BADGE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval BADGE_ERROR_NOT_SUPPORTED Not supported
  /// @see #badge_error_e
  /// @see badge_new()
  /// @see badge_set_count()
  /// @par Sample code:
  /// @code
  /// #include <badge.h>
  ///
  /// {
  /// int err = BADGE_ERROR_NONE;
  /// int count = 0;
  ///
  /// err = badge_get_count(app_id, &count);
  /// if (err != BADGE_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int badge_get_count(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.UnsignedInt> count,
  ) {
    return _badge_get_count(
      app_id,
      count,
    );
  }

  late final _badge_get_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.UnsignedInt>)>>('badge_get_count');
  late final _badge_get_count = _badge_get_countPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Sets the display option for the designated application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] app_id The name of the designated application
  /// @param[in] is_display The display option (1 = display, 0 = not display)
  /// @return #BADGE_ERROR_NONE if success, other value if failure
  /// @retval BADGE_ERROR_NONE Success
  /// @retval BADGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BADGE_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval BADGE_ERROR_IO_ERROR Error from I/O
  /// @retval BADGE_ERROR_SERVICE_NOT_READY Service is not ready
  /// @retval BADGE_ERROR_NOT_SUPPORTED Not supported
  /// @see #badge_error_e
  /// @see badge_new()
  /// @par Sample code:
  /// @code
  /// #include <badge.h>
  ///
  /// {
  /// int err = BADGE_ERROR_NONE;
  ///
  /// err = badge_set_display(app_id, 1);
  /// if (err != BADGE_ERROR_NONE)
  /// return;
  ///
  /// }
  /// @endcode
  int badge_set_display(
    ffi.Pointer<ffi.Char> app_id,
    int is_display,
  ) {
    return _badge_set_display(
      app_id,
      is_display,
    );
  }

  late final _badge_set_displayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>, ffi.UnsignedInt)>>('badge_set_display');
  late final _badge_set_display = _badge_set_displayPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @brief Gets the display option for the designated application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] app_id The name of the designated application
  /// @param[out]  is_display The display option (1 = display, 0 = not display)
  /// @return #BADGE_ERROR_NONE if success, other value if failure
  /// @retval BADGE_ERROR_NONE Success
  /// @retval BADGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BADGE_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval BADGE_ERROR_FROM_DB Error from DB
  /// @retval BADGE_ERROR_NOT_EXIST Not exist
  /// @retval BADGE_ERROR_SERVICE_NOT_READY Service is not ready
  /// @retval BADGE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval BADGE_ERROR_NOT_SUPPORTED Not supported
  /// @see #badge_error_e
  /// @see badge_new()
  /// @see badge_set_count()
  /// @par Sample code:
  /// @code
  /// #include <badge.h>
  ///
  /// {
  /// int is_display = 0;
  /// int err = BADGE_ERROR_NONE;
  ///
  /// err = badge_get_display(app_id, &is_display);
  /// if (err != BADGE_ERROR_NONE)
  /// return;
  /// }
  /// @endcode
  int badge_get_display(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.UnsignedInt> is_display,
  ) {
    return _badge_get_display(
      app_id,
      is_display,
    );
  }

  late final _badge_get_displayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.UnsignedInt>)>>('badge_get_display');
  late final _badge_get_display = _badge_get_displayPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Retrieves all existing badges.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] callback The callback function
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return #BADGE_ERROR_NONE if success, other value if failure
  /// @retval BADGE_ERROR_NONE Success
  /// @retval BADGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BADGE_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval BADGE_ERROR_FROM_DB Error form DB
  /// @retval BADGE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval BADGE_ERROR_NOT_EXIST Not exist
  /// @retval BADGE_ERROR_NOT_SUPPORTED Not supported
  /// @see #badge_error_e
  /// @see badge_foreach_cb()
  int badge_foreach(
    badge_foreach_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _badge_foreach(
      callback,
      user_data,
    );
  }

  late final _badge_foreachPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              badge_foreach_cb, ffi.Pointer<ffi.Void>)>>('badge_foreach');
  late final _badge_foreach = _badge_foreachPtr
      .asFunction<int Function(badge_foreach_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Registers a callback function to receive badge change event.
  /// @remarks Should be used in the homescreen.\n
  /// Prospective Clients : Homescreen.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] callback The callback function
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return #BADGE_ERROR_NONE if success, other value if failure
  /// @retval BADGE_ERROR_NONE Success
  /// @retval BADGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BADGE_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval BADGE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval BADGE_ERROR_NOT_SUPPORTED Not supported
  /// @see #badge_error_e
  /// @see badge_new()
  /// @see badge_remove()
  /// @see badge_set_count()
  int badge_register_changed_cb(
    badge_change_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _badge_register_changed_cb(
      callback,
      user_data,
    );
  }

  late final _badge_register_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(badge_change_cb,
              ffi.Pointer<ffi.Void>)>>('badge_register_changed_cb');
  late final _badge_register_changed_cb = _badge_register_changed_cbPtr
      .asFunction<int Function(badge_change_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters a callback function to receive badge change event.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/notification
  /// @param[in] callback The callback function
  /// @return #BADGE_ERROR_NONE if success, other value if failure
  /// @retval BADGE_ERROR_NONE Success
  /// @retval BADGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval BADGE_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval BADGE_ERROR_NOT_EXIST Not exist
  /// @retval BADGE_ERROR_NOT_SUPPORTED Not supported
  /// @see #badge_error_e
  /// @see badge_register_changed_cb()
  int badge_unregister_changed_cb(
    badge_change_cb callback,
  ) {
    return _badge_unregister_changed_cb(
      callback,
    );
  }

  late final _badge_unregister_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(badge_change_cb)>>(
          'badge_unregister_changed_cb');
  late final _badge_unregister_changed_cb = _badge_unregister_changed_cbPtr
      .asFunction<int Function(badge_change_cb)>();

  /// @brief Moves the cursor to the first position.
  /// @since_tizen 2.3
  /// @remarks The following example demonstrates how to use the %data_control_sql_step_first() method:
  ///
  /// @code
  ///
  /// void
  /// sql_select_response_cb(int request_id, data_control_h provider, result_set_cursor cursor,
  /// bool provider_result, const char *error)
  /// {
  /// char person_name[32] = {0,};
  /// long long person_number = -1;
  ///
  /// data_control_sql_step_first(cursor);
  /// data_control_sql_get_text_data(cursor, 0, person_name);
  /// data_control_sql_get_int64_data(cursor, 1, &person_number);
  /// printf("The person %s has the number %l", person_name, person_number);
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_step_first(
    result_set_cursor cursor,
  ) {
    return _data_control_sql_step_first(
      cursor,
    );
  }

  late final _data_control_sql_step_firstPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(result_set_cursor)>>(
          'data_control_sql_step_first');
  late final _data_control_sql_step_first = _data_control_sql_step_firstPtr
      .asFunction<int Function(result_set_cursor)>();

  /// @brief Moves the cursor to the last position.
  /// @since_tizen 2.3
  /// @remarks The following example demonstrates how to use the %data_control_sql_step_last() method:
  ///
  /// @code
  ///
  /// void
  /// sql_select_response_cb(int request_id, data_control_h provider, result_set_cursor cursor,
  /// bool provider_result, const char *error)
  /// {
  /// char person_name[32] = {0,};
  /// long long person_number = -1;
  ///
  /// data_control_sql_step_last(cursor);
  /// data_control_sql_get_text_data(cursor, 0, person_name);
  /// data_control_sql_get_int64_data(cursor, 1, &person_number);
  /// printf("The person %s has the number %l", person_name, person_number);
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] cursor The cursor that navigates the result of data control select request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_step_last(
    result_set_cursor cursor,
  ) {
    return _data_control_sql_step_last(
      cursor,
    );
  }

  late final _data_control_sql_step_lastPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(result_set_cursor)>>(
          'data_control_sql_step_last');
  late final _data_control_sql_step_last = _data_control_sql_step_lastPtr
      .asFunction<int Function(result_set_cursor)>();

  /// @brief Moves the cursor to the next position.
  /// @since_tizen 2.3
  /// @remarks The following example demonstrates how to use the %data_control_sql_step_next() method:
  ///
  /// @code
  ///
  /// void
  /// sql_select_response_cb(int request_id, data_control_h provider, result_set_cursor cursor,
  /// bool provider_result, const char *error)
  /// {
  /// char person_name[32] = {0,};
  /// long long person_number = -1;
  /// while (data_control_sql_step_next(cursor) == DATA_CONTROL_ERROR_NONE) {
  /// data_control_sql_get_text_data(cursor, 0, person_name);
  /// data_control_sql_get_int64_data(cursor, 1, &person_number);
  /// printf("The person %s has the number %l", person_name, person_number);
  /// }
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_step_next(
    result_set_cursor cursor,
  ) {
    return _data_control_sql_step_next(
      cursor,
    );
  }

  late final _data_control_sql_step_nextPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(result_set_cursor)>>(
          'data_control_sql_step_next');
  late final _data_control_sql_step_next = _data_control_sql_step_nextPtr
      .asFunction<int Function(result_set_cursor)>();

  /// @brief Moves the cursor to the previous position.
  /// @since_tizen 2.3
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_step_previous(
    result_set_cursor cursor,
  ) {
    return _data_control_sql_step_previous(
      cursor,
    );
  }

  late final _data_control_sql_step_previousPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(result_set_cursor)>>(
          'data_control_sql_step_previous');
  late final _data_control_sql_step_previous =
      _data_control_sql_step_previousPtr
          .asFunction<int Function(result_set_cursor)>();

  /// @brief Gets the number of columns for this cursor.
  /// @since_tizen 2.3
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @return The number of columns in the calling cursor
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_get_column_count(
    result_set_cursor cursor,
  ) {
    return _data_control_sql_get_column_count(
      cursor,
    );
  }

  late final _data_control_sql_get_column_countPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(result_set_cursor)>>(
          'data_control_sql_get_column_count');
  late final _data_control_sql_get_column_count =
      _data_control_sql_get_column_countPtr
          .asFunction<int Function(result_set_cursor)>();

  /// @brief Gets the name of the column indicated by the specified index.
  /// @since_tizen 2.3
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @param[in] column_index The index of the destination column
  /// @param[out] name The name of the destination column. You should provide a buffer for the column name. The limit of column name length is 4096 bytes
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_get_column_name(
    result_set_cursor cursor,
    int column_index,
    ffi.Pointer<ffi.Char> name,
  ) {
    return _data_control_sql_get_column_name(
      cursor,
      column_index,
      name,
    );
  }

  late final _data_control_sql_get_column_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(result_set_cursor, ffi.Int,
              ffi.Pointer<ffi.Char>)>>('data_control_sql_get_column_name');
  late final _data_control_sql_get_column_name =
      _data_control_sql_get_column_namePtr.asFunction<
          int Function(result_set_cursor, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the size of the data in the column indicated by the specified index.
  /// @since_tizen 2.3
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @param[in] column_index The index of the destination column
  /// @return The size of data in the column indicated by the specified index \n
  /// If an error is occurred, then a negative value is returned
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_get_column_item_size(
    result_set_cursor cursor,
    int column_index,
  ) {
    return _data_control_sql_get_column_item_size(
      cursor,
      column_index,
    );
  }

  late final _data_control_sql_get_column_item_sizePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(result_set_cursor, ffi.Int)>>(
          'data_control_sql_get_column_item_size');
  late final _data_control_sql_get_column_item_size =
      _data_control_sql_get_column_item_sizePtr
          .asFunction<int Function(result_set_cursor, int)>();

  /// @brief Gets the type of the column indicated by the specified index.
  /// @since_tizen 2.3
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @param[in] column_index The index of the destination column
  /// @param[out] type The type of the destination column
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_get_column_item_type(
    result_set_cursor cursor,
    int column_index,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _data_control_sql_get_column_item_type(
      cursor,
      column_index,
      type,
    );
  }

  late final _data_control_sql_get_column_item_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  result_set_cursor, ffi.Int, ffi.Pointer<ffi.Int32>)>>(
      'data_control_sql_get_column_item_type');
  late final _data_control_sql_get_column_item_type =
      _data_control_sql_get_column_item_typePtr.asFunction<
          int Function(result_set_cursor, int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets a blob data from the column indicated by the specified index.
  /// @since_tizen 2.3
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @param[in] column_index The index of the destination column
  /// @param[out] data The blob value obtained from the column
  /// @param[out] size The size of the data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_MAX_EXCEEDED Too long argument
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_get_blob_data(
    result_set_cursor cursor,
    int column_index,
    ffi.Pointer<ffi.Void> data,
    int size,
  ) {
    return _data_control_sql_get_blob_data(
      cursor,
      column_index,
      data,
      size,
    );
  }

  late final _data_control_sql_get_blob_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(result_set_cursor, ffi.Int, ffi.Pointer<ffi.Void>,
              ffi.Int)>>('data_control_sql_get_blob_data');
  late final _data_control_sql_get_blob_data =
      _data_control_sql_get_blob_dataPtr.asFunction<
          int Function(result_set_cursor, int, ffi.Pointer<ffi.Void>, int)>();

  /// @brief Gets an int value from the column indicated by the specified index.
  /// @since_tizen 2.3
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @param[in] column_index The index of the destination column
  /// @param[out] data The integer value obtained from the column
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_get_int_data(
    result_set_cursor cursor,
    int column_index,
    ffi.Pointer<ffi.Int> data,
  ) {
    return _data_control_sql_get_int_data(
      cursor,
      column_index,
      data,
    );
  }

  late final _data_control_sql_get_int_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(result_set_cursor, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('data_control_sql_get_int_data');
  late final _data_control_sql_get_int_data = _data_control_sql_get_int_dataPtr
      .asFunction<int Function(result_set_cursor, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets a long long value from the column indicated by the specified index.
  /// @since_tizen 2.3
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @param[in] column_index The index of the destination column
  /// @param[out] data The 64-bit integer value obtained from the column
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_get_int64_data(
    result_set_cursor cursor,
    int column_index,
    ffi.Pointer<ffi.LongLong> data,
  ) {
    return _data_control_sql_get_int64_data(
      cursor,
      column_index,
      data,
    );
  }

  late final _data_control_sql_get_int64_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(result_set_cursor, ffi.Int,
              ffi.Pointer<ffi.LongLong>)>>('data_control_sql_get_int64_data');
  late final _data_control_sql_get_int64_data =
      _data_control_sql_get_int64_dataPtr.asFunction<
          int Function(result_set_cursor, int, ffi.Pointer<ffi.LongLong>)>();

  /// @brief Gets a double value from the column indicated by the specified index.
  /// @since_tizen 2.3
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @param[in] column_index The index of the destination column
  /// @param[out] data The value obtained from the column as double
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_get_double_data(
    result_set_cursor cursor,
    int column_index,
    ffi.Pointer<ffi.Double> data,
  ) {
    return _data_control_sql_get_double_data(
      cursor,
      column_index,
      data,
    );
  }

  late final _data_control_sql_get_double_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(result_set_cursor, ffi.Int,
              ffi.Pointer<ffi.Double>)>>('data_control_sql_get_double_data');
  late final _data_control_sql_get_double_data =
      _data_control_sql_get_double_dataPtr.asFunction<
          int Function(result_set_cursor, int, ffi.Pointer<ffi.Double>)>();

  /// @brief Gets a text value from the column indicated by the specified index.
  /// @since_tizen 2.3
  /// @param[in] cursor The cursor that navigates the result of the request for the select operation
  /// @param[in] column_index The index of the destination column
  /// @param[out] data The value obtained from the column as text. You should provide a buffer for the data. You can get the size of data via data_control_sql_get_column_item_size()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  int data_control_sql_get_text_data(
    result_set_cursor cursor,
    int column_index,
    ffi.Pointer<ffi.Char> data,
  ) {
    return _data_control_sql_get_text_data(
      cursor,
      column_index,
      data,
    );
  }

  late final _data_control_sql_get_text_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(result_set_cursor, ffi.Int,
              ffi.Pointer<ffi.Char>)>>('data_control_sql_get_text_data');
  late final _data_control_sql_get_text_data =
      _data_control_sql_get_text_dataPtr.asFunction<
          int Function(result_set_cursor, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the n-th bundle from bulk data.
  /// @since_tizen 3.0
  /// @remarks The @a data should not be released. \n
  /// It will be released when data_control_bulk_data_destroy() is called.
  /// @param[in] bulk_data The bulk data handle
  /// @param[in] idx The bundle index. Index starts at 0
  /// @param[out] data The n-th bundle.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_bulk_data_add()
  /// @see data_control_bulk_data_destroy()
  int data_control_bulk_data_get_data(
    data_control_bulk_data_h bulk_data,
    int idx,
    ffi.Pointer<ffi.Pointer<bundle>> data,
  ) {
    return _data_control_bulk_data_get_data(
      bulk_data,
      idx,
      data,
    );
  }

  late final _data_control_bulk_data_get_dataPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(data_control_bulk_data_h, ffi.Int,
                  ffi.Pointer<ffi.Pointer<bundle>>)>>(
      'data_control_bulk_data_get_data');
  late final _data_control_bulk_data_get_data =
      _data_control_bulk_data_get_dataPtr.asFunction<
          int Function(data_control_bulk_data_h, int,
              ffi.Pointer<ffi.Pointer<bundle>>)>();

  /// @brief Gets the bulk data bundle count.
  /// @since_tizen 3.0
  /// @param[in] bulk_data The bulk data handle
  /// @param[out] count The bundle count
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_bulk_data_get_count(
    data_control_bulk_data_h bulk_data,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _data_control_bulk_data_get_count(
      bulk_data,
      count,
    );
  }

  late final _data_control_bulk_data_get_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_bulk_data_h,
              ffi.Pointer<ffi.Int>)>>('data_control_bulk_data_get_count');
  late final _data_control_bulk_data_get_count =
      _data_control_bulk_data_get_countPtr.asFunction<
          int Function(data_control_bulk_data_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Adds a bundle to bulk data.
  /// @since_tizen 3.0
  /// @remarks The order in which bundles are added is preserved. Bundle indexes start from 0.
  /// @param[in] bulk_data The bulk data handle
  /// @param[in] data The bundle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_bulk_data_add(
    data_control_bulk_data_h bulk_data,
    ffi.Pointer<bundle> data,
  ) {
    return _data_control_bulk_data_add(
      bulk_data,
      data,
    );
  }

  late final _data_control_bulk_data_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_bulk_data_h,
              ffi.Pointer<bundle>)>>('data_control_bulk_data_add');
  late final _data_control_bulk_data_add =
      _data_control_bulk_data_addPtr.asFunction<
          int Function(data_control_bulk_data_h, ffi.Pointer<bundle>)>();

  /// @brief Creates bulk data.
  /// @since_tizen 3.0
  /// @remarks The @a bulk_data should be released using data_control_bulk_data_destroy().
  /// @param[out] bulk_data The bulk data handle
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_bulk_data_create(
    ffi.Pointer<data_control_bulk_data_h> bulk_data,
  ) {
    return _data_control_bulk_data_create(
      bulk_data,
    );
  }

  late final _data_control_bulk_data_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<data_control_bulk_data_h>)>>(
      'data_control_bulk_data_create');
  late final _data_control_bulk_data_create = _data_control_bulk_data_createPtr
      .asFunction<int Function(ffi.Pointer<data_control_bulk_data_h>)>();

  /// @brief Destroys bulk data.
  /// @since_tizen 3.0
  /// @param[in] bulk_data The bulk data handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_bulk_data_destroy(
    data_control_bulk_data_h bulk_data,
  ) {
    return _data_control_bulk_data_destroy(
      bulk_data,
    );
  }

  late final _data_control_bulk_data_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_bulk_data_h)>>(
          'data_control_bulk_data_destroy');
  late final _data_control_bulk_data_destroy =
      _data_control_bulk_data_destroyPtr
          .asFunction<int Function(data_control_bulk_data_h)>();

  /// @brief Gets the n-th bundle from bulk result data.
  /// @since_tizen 3.0
  /// @remarks The @a data should not be released. \n
  /// It will be released when data_control_bulk_result_data_destroy() is called.
  /// @param[in] result_data The bulk result data handle
  /// @param[in] idx The bundle index. Index starts at 0
  /// @param[out] data The n-th bundle
  /// @param[out] result Bulk operation result. Possible values and their meaning are defined by the developer.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_bulk_result_data_add()
  /// @see data_control_bulk_result_data_destroy()
  int data_control_bulk_result_data_get_result_data(
    data_control_bulk_result_data_h result_data,
    int idx,
    ffi.Pointer<ffi.Pointer<bundle>> data,
    ffi.Pointer<ffi.Int> result,
  ) {
    return _data_control_bulk_result_data_get_result_data(
      result_data,
      idx,
      data,
      result,
    );
  }

  late final _data_control_bulk_result_data_get_result_dataPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(data_control_bulk_result_data_h, ffi.Int,
                  ffi.Pointer<ffi.Pointer<bundle>>, ffi.Pointer<ffi.Int>)>>(
      'data_control_bulk_result_data_get_result_data');
  late final _data_control_bulk_result_data_get_result_data =
      _data_control_bulk_result_data_get_result_dataPtr.asFunction<
          int Function(data_control_bulk_result_data_h, int,
              ffi.Pointer<ffi.Pointer<bundle>>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the bulk result data bundle count.
  /// @since_tizen 3.0
  /// @param[in] result_data The bulk result data handle
  /// @param[out] count The bundle count
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_bulk_result_data_get_count(
    data_control_bulk_result_data_h result_data,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _data_control_bulk_result_data_get_count(
      result_data,
      count,
    );
  }

  late final _data_control_bulk_result_data_get_countPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  data_control_bulk_result_data_h, ffi.Pointer<ffi.Int>)>>(
      'data_control_bulk_result_data_get_count');
  late final _data_control_bulk_result_data_get_count =
      _data_control_bulk_result_data_get_countPtr.asFunction<
          int Function(
              data_control_bulk_result_data_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Adds bulk data
  /// @since_tizen 3.0
  /// @remarks The order in which bundles are added is preserved. Bundle indexes start from 0.
  /// @param[in] result_data The bulk result data handle
  /// @param[in] data The bundle
  /// @param[in] result Bulk operation result. Possible values and their meaning are defined by the developer.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_bulk_result_data_get_result_data()
  int data_control_bulk_result_data_add(
    data_control_bulk_result_data_h result_data,
    ffi.Pointer<bundle> data,
    int result,
  ) {
    return _data_control_bulk_result_data_add(
      result_data,
      data,
      result,
    );
  }

  late final _data_control_bulk_result_data_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_bulk_result_data_h, ffi.Pointer<bundle>,
              ffi.Int)>>('data_control_bulk_result_data_add');
  late final _data_control_bulk_result_data_add =
      _data_control_bulk_result_data_addPtr.asFunction<
          int Function(
              data_control_bulk_result_data_h, ffi.Pointer<bundle>, int)>();

  /// @brief Creates bulk result data.
  /// @since_tizen 3.0
  /// @remarks The @a result_data should be released using data_control_bulk_result_data_destroy().
  /// @param[out] result_data The bulk result data handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_bulk_result_data_create(
    ffi.Pointer<data_control_bulk_result_data_h> result_data,
  ) {
    return _data_control_bulk_result_data_create(
      result_data,
    );
  }

  late final _data_control_bulk_result_data_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<data_control_bulk_result_data_h>)>>(
      'data_control_bulk_result_data_create');
  late final _data_control_bulk_result_data_create =
      _data_control_bulk_result_data_createPtr.asFunction<
          int Function(ffi.Pointer<data_control_bulk_result_data_h>)>();

  /// @brief Destroys bulk result data.
  /// @since_tizen 3.0
  /// @param[in] result_data The bulk result data handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_bulk_result_data_destroy(
    data_control_bulk_result_data_h result_data,
  ) {
    return _data_control_bulk_result_data_destroy(
      result_data,
    );
  }

  late final _data_control_bulk_result_data_destroyPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(data_control_bulk_result_data_h)>>(
      'data_control_bulk_result_data_destroy');
  late final _data_control_bulk_result_data_destroy =
      _data_control_bulk_result_data_destroyPtr
          .asFunction<int Function(data_control_bulk_result_data_h)>();

  /// @brief Creates a provider handle.
  /// @since_tizen 2.3
  ///
  /// @remarks @a provider should be destroyed with data_control_sql_destroy().
  /// The following example demonstrates how to use the %data_control_sql_create() method:
  ///
  /// @code
  ///
  /// {
  /// const char *provider_id = "http://tizen.org/datacontrol/provider/example";
  /// const char *data_id = "table";
  /// data_control_h provider;
  /// int result = 0;
  ///
  /// result = data_control_sql_create(&provider);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Creating data control provider is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// result = data_control_sql_set_provider_id(provider, provider_id);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Setting providerID is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// result = data_control_sql_set_data_id(provider, data_id);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Setting dataID is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// // Executes some operations
  ///
  /// result = data_control_sql_destroy(provider);
  /// if (result != DATA_CONTROL_ERROR_NONE)
  /// LOGE("Destroying data control provider is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  /// @param[out] provider The provider handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @see data_control_sql_destroy()
  int data_control_sql_create(
    ffi.Pointer<data_control_h> provider,
  ) {
    return _data_control_sql_create(
      provider,
    );
  }

  late final _data_control_sql_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<data_control_h>)>>(
      'data_control_sql_create');
  late final _data_control_sql_create = _data_control_sql_createPtr
      .asFunction<int Function(ffi.Pointer<data_control_h>)>();

  /// @brief Destroys the provider handle and releases all its resources.
  /// @since_tizen 2.3
  ///
  /// @remarks When operations of data control are finished, this function must be called to prevent the memory leak.
  ///
  /// @param[in] provider The provider handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_sql_create()
  int data_control_sql_destroy(
    data_control_h provider,
  ) {
    return _data_control_sql_destroy(
      provider,
    );
  }

  late final _data_control_sql_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h)>>(
          'data_control_sql_destroy');
  late final _data_control_sql_destroy =
      _data_control_sql_destroyPtr.asFunction<int Function(data_control_h)>();

  /// @brief Sets the Provider ID.
  /// @since_tizen 2.3
  ///
  /// @param[in] provider The provider handle
  /// @param[in] provider_id The data control provider ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @see data_control_sql_get_provider_id()
  int data_control_sql_set_provider_id(
    data_control_h provider,
    ffi.Pointer<ffi.Char> provider_id,
  ) {
    return _data_control_sql_set_provider_id(
      provider,
      provider_id,
    );
  }

  late final _data_control_sql_set_provider_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h,
              ffi.Pointer<ffi.Char>)>>('data_control_sql_set_provider_id');
  late final _data_control_sql_set_provider_id =
      _data_control_sql_set_provider_idPtr
          .asFunction<int Function(data_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the Provider ID.
  /// @since_tizen 2.3
  ///
  /// @remarks You must release @a provider_id using free() after it is used.
  ///
  /// @param[in] provider The provider handle
  /// @param[out] provider_id The data control provider ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @see data_control_sql_set_provider_id()
  int data_control_sql_get_provider_id(
    data_control_h provider,
    ffi.Pointer<ffi.Pointer<ffi.Char>> provider_id,
  ) {
    return _data_control_sql_get_provider_id(
      provider,
      provider_id,
    );
  }

  late final _data_control_sql_get_provider_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  data_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'data_control_sql_get_provider_id');
  late final _data_control_sql_get_provider_id =
      _data_control_sql_get_provider_idPtr.asFunction<
          int Function(data_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the data ID.
  /// @since_tizen 2.3
  ///
  /// @param[in] provider The provider handle
  /// @param[in] data_id A string for identifying a specific table to operate \n
  /// The string consists of one or more components separated by a slash('/')
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @see data_control_sql_get_data_id()
  ///
  /// @code
  ///
  /// {
  /// bundle *b;
  /// int ret;
  ///
  /// // Insert data to Note table
  /// ret = data_control_sql_set_data_id(ad->provider_h, "Note");
  /// if (ret != DATA_CONTROL_ERROR_NONE)
  /// dlog_print(DLOG_ERROR, LOG_TAG, "setting data id failed with error: %d", ret);
  ///
  /// b = bundle_create();
  /// bundle_add_str(b, ""TITLE"", "test");
  /// bundle_add_str(b, "CONTENTS", "test contents");
  /// data_control_sql_insert(ad->provider_h, b, &req_id);
  /// bundle_free(b);
  ///
  /// // Insert data to Dictionary table
  /// ret = data_control_sql_set_data_id(ad->provider_h, "Dictionary");
  /// if (ret != DATA_CONTROL_ERROR_NONE)
  /// dlog_print(DLOG_ERROR, LOG_TAG, "setting data id failed with error: %d", ret);
  ///
  /// b = bundle_create();
  /// bundle_add_str(b, "WORD", "test");
  /// bundle_add_str(b, "WORD_DESC", "test desc");
  /// data_control_sql_insert(ad->provider_h, b, &req_id);
  /// bundle_free(b);
  /// }
  ///
  /// @endcode
  int data_control_sql_set_data_id(
    data_control_h provider,
    ffi.Pointer<ffi.Char> data_id,
  ) {
    return _data_control_sql_set_data_id(
      provider,
      data_id,
    );
  }

  late final _data_control_sql_set_data_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h,
              ffi.Pointer<ffi.Char>)>>('data_control_sql_set_data_id');
  late final _data_control_sql_set_data_id = _data_control_sql_set_data_idPtr
      .asFunction<int Function(data_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the data ID.
  /// @since_tizen 2.3
  ///
  /// @remarks You must release @a data_id using free() after it is used.
  ///
  /// @param[in] provider The provider handle
  /// @param[out] data_id A string for identifying a specific table to operate \n
  /// The string consists of one or more components separated by a slash('/')
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @see data_control_sql_set_data_id()
  int data_control_sql_get_data_id(
    data_control_h provider,
    ffi.Pointer<ffi.Pointer<ffi.Char>> data_id,
  ) {
    return _data_control_sql_get_data_id(
      provider,
      data_id,
    );
  }

  late final _data_control_sql_get_data_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  data_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'data_control_sql_get_data_id');
  late final _data_control_sql_get_data_id =
      _data_control_sql_get_data_idPtr.asFunction<
          int Function(data_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Registers a callback function for the SQL data control response.
  /// @since_tizen 2.3
  ///
  /// @remarks The application is notified when a data control response is received from the @a provider.
  /// @remarks Only one callback can be registered for each provider id with this API.
  /// @remarks If you register multiple callback for same provider id, it will be overwritten by latest one.
  ///
  ///
  /// @param[in] provider The provider handle
  /// @param[in] callback The callback function to be called when a response is received
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @see data_control_sql_unregister_response_cb()
  /// @see data_control_sql_bind_response_cb()
  int data_control_sql_register_response_cb(
    data_control_h provider,
    ffi.Pointer<data_control_sql_response_cb> callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_sql_register_response_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _data_control_sql_register_response_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<data_control_sql_response_cb>,
              ffi.Pointer<ffi.Void>)>>('data_control_sql_register_response_cb');
  late final _data_control_sql_register_response_cb =
      _data_control_sql_register_response_cbPtr.asFunction<
          int Function(
              data_control_h,
              ffi.Pointer<data_control_sql_response_cb>,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function in the @a provider.
  /// @since_tizen 2.3
  ///
  /// @param[in] provider The provider handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see data_control_sql_register_response_cb()
  int data_control_sql_unregister_response_cb(
    data_control_h provider,
  ) {
    return _data_control_sql_unregister_response_cb(
      provider,
    );
  }

  late final _data_control_sql_unregister_response_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h)>>(
          'data_control_sql_unregister_response_cb');
  late final _data_control_sql_unregister_response_cb =
      _data_control_sql_unregister_response_cbPtr
          .asFunction<int Function(data_control_h)>();

  /// @brief Deletes rows of a table owned by the SQL-type data control provider.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  ///
  /// @remarks If you want to use this api, you must add privileges.
  /// @remarks If the value is a string, then the value must be wrapped in single quotes, else it does not need to be wrapped in single quotes.
  /// @remarks The following example demonstrates how to use the %data_control_sql_delete() method:
  ///
  /// @code
  ///
  /// void
  /// sql_delete_response_cb(int request_id, data_control_h provider, bool provider_result, const char *error, void *user_data)
  /// {
  /// if (provider_result)
  /// LOGI(The delete operation is successful");
  /// else
  /// LOGI("The delete operation for the request %d is failed. error message: %s", request_id, error);
  /// }
  ///
  /// data_control_sql_response_cb sql_callback;
  ///
  /// {
  /// const char *where = "group = 'friend'";
  /// int result = 0;
  /// int req_id = 0;
  ///
  /// sql_callback.delete_cb = sql_delete_response_cb;
  /// result = data_control_sql_register_response_cb(provider, &sql_callback, void *user_data);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Registering the callback function is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// result = data_control_sql_delete(provider, where, &req_id);
  /// if (result != DATA_CONTROL_ERROR_NONE)
  /// LOGE("Deleting is failed with error: %d", result);
  /// else
  /// LOGI("req_id is %d", req_id);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] provider The provider handle
  /// @param[in] where A filter to select the desired rows to delete \n
  /// It is an SQL 'WHERE' clause excluding the 'WHERE' itself such as column1 = 'stringValue' and column2 = numericValue
  /// @param[out] request_id The request ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_sql_delete(
    data_control_h provider,
    ffi.Pointer<ffi.Char> where,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_sql_delete(
      provider,
      where,
      request_id,
    );
  }

  late final _data_control_sql_deletePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('data_control_sql_delete');
  late final _data_control_sql_delete = _data_control_sql_deletePtr.asFunction<
      int Function(
          data_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @brief Inserts new rows in a table owned by the SQL-type data control provider.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  ///
  /// @remarks If you want to use this api, you must add privileges.
  /// @remarks The following example demonstrates how to use the %data_control_sql_insert() method:
  ///
  /// @code
  ///
  /// void
  /// sql_insert_response_cb(int request_id, data_control_h provider, long long inserted_row_id,
  /// bool provider_result, const char *error, void *user_data)
  /// {
  /// if (provider_result)
  /// LOGI("The insert operation is successful");
  /// else
  /// LOGI("The insert operation for the request %d is failed. error message: %s", request_id, error);
  /// }
  ///
  /// data_control_sql_response_cb sql_callback;
  ///
  /// {
  /// int result = 0;
  /// int req_id = 0;
  /// bundle *b = NULL;
  ///
  /// sql_callback.insert_cb = sql_insert_response_cb;
  /// result = data_control_sql_register_response_cb(provider, &sql_callback, void *user_data);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Registering the callback function is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// b = bundle_create();
  /// bundle_add(b, "WORD", "test");
  /// bundle_add(b, "WORD_DESC", "test description");
  ///
  /// result = data_control_sql_insert(provider, b, &req_id);
  /// if (result != DATA_CONTROL_ERROR_NONE)
  /// LOGE("Inserting is failed with error: %d", result);
  /// else
  /// LOGI("req_id is %d", req_id);
  ///
  /// bundle_free(b);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] provider The provider handle
  /// @param[in] insert_data The column-value pairs to insert \n
  /// If the value is a string, then the value must be wrapped in single quotes,
  /// else it does not need to be wrapped in single quotes
  /// @param[out] request_id The request ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DATA_CONTROL_ERROR_MAX_EXCEEDED Too long argument
  int data_control_sql_insert(
    data_control_h provider,
    ffi.Pointer<bundle> insert_data,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_sql_insert(
      provider,
      insert_data,
      request_id,
    );
  }

  late final _data_control_sql_insertPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h, ffi.Pointer<bundle>,
              ffi.Pointer<ffi.Int>)>>('data_control_sql_insert');
  late final _data_control_sql_insert = _data_control_sql_insertPtr.asFunction<
      int Function(
          data_control_h, ffi.Pointer<bundle>, ffi.Pointer<ffi.Int>)>();

  /// @brief Selects the specified columns to be queried.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  ///
  /// @remarks If you want to use this api, you must add privileges.
  /// @remarks The following example demonstrates how to use the %data_control_sql_select() method:
  ///
  /// @code
  ///
  /// void
  /// sql_select_response_cb(int request_id, data_control_h provider, result_set_cursor *enumerator,
  /// bool provider_result, const char *error, void *user_data)
  /// {
  /// if (provider_result)
  /// LOGI("The select operation is successful");
  /// else
  /// LOGI("The select operation for the request %d is failed. error message: %s", request_id, error);
  /// }
  ///
  /// data_control_sql_response_cb sql_callback;
  ///
  /// {
  /// int result = 0;
  /// int req_id = 0;
  /// char *column_list[2];
  /// column_list[0] = "WORD";
  /// column_list[1] = "WORD_DESC";
  /// const char *where = "WORD = 'test'";
  /// const char *order = "WORD ASC";
  ///
  /// sql_callback.select_cb = sql_select_response_cb;
  /// result = data_control_sql_register_response_cb(provider, &sql_callback, void *user_data);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Registering the callback function is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// result = data_control_sql_select(provider, column_list, 2, where, order, &req_id);
  /// if (result != DATA_CONTROL_ERROR_NONE)
  /// LOGE("Selecting is failed with error: %d", result);
  /// else
  /// LOGI("req_id is %d", req_id);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  ///
  /// @param[in] provider The provider handle
  /// @param[in] column_list The column list to query
  /// @param[in] column_count The total number of columns to be queried
  /// @param[in] where A filter to select the desired rows \n
  /// It is an SQL 'WHERE' clause excluding the 'WHERE' itself such as column1 = 'stringValue' and column2 = numericValue
  /// @param[in] order The sorting order of the rows to query \n
  /// It is an SQL 'ORDER BY' clause excluding the 'ORDER BY' itself.
  /// @param[out] request_id The request ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_sql_select(
    data_control_h provider,
    ffi.Pointer<ffi.Pointer<ffi.Char>> column_list,
    int column_count,
    ffi.Pointer<ffi.Char> where,
    ffi.Pointer<ffi.Char> order,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_sql_select(
      provider,
      column_list,
      column_count,
      where,
      order,
      request_id,
    );
  }

  late final _data_control_sql_selectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Int,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('data_control_sql_select');
  late final _data_control_sql_select = _data_control_sql_selectPtr.asFunction<
      int Function(
          data_control_h,
          ffi.Pointer<ffi.Pointer<ffi.Char>>,
          int,
          ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Selects the specified columns to be queried, with partition into pages.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  ///
  /// @remarks If you want to use this api, you must add privileges.
  ///
  /// @param[in] provider The provider handle
  /// @param[in] column_list The column list to query
  /// @param[in] column_count The total number of columns to be queried
  /// @param[in] where A filter to select the desired rows \n
  /// It is an SQL 'WHERE' clause excluding the 'WHERE' itself such as column1 = 'stringValue' and column2 = numericValue
  /// @param[in] order The sorting order of the rows to query \n
  /// It is an SQL 'ORDER BY' clause excluding the 'ORDER BY' itself
  /// @param[in] page_number The page number of the result set \n
  /// It starts from @c 1
  /// @param[in] count_per_page The desired maximum count of rows on a page
  /// @param[out] request_id The request ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  /// @see data_control_sql_select()
  int data_control_sql_select_with_page(
    data_control_h provider,
    ffi.Pointer<ffi.Pointer<ffi.Char>> column_list,
    int column_count,
    ffi.Pointer<ffi.Char> where,
    ffi.Pointer<ffi.Char> order,
    int page_number,
    int count_per_page,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_sql_select_with_page(
      provider,
      column_list,
      column_count,
      where,
      order,
      page_number,
      count_per_page,
      request_id,
    );
  }

  late final _data_control_sql_select_with_pagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Int,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Int,
              ffi.Pointer<ffi.Int>)>>('data_control_sql_select_with_page');
  late final _data_control_sql_select_with_page =
      _data_control_sql_select_with_pagePtr.asFunction<
          int Function(
              data_control_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              int,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              int,
              int,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Updates values of a table owned by the SQL-type data control provider.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  ///
  /// @remarks If you want to use this api, you must add privileges.
  /// @remarks The following example demonstrates how to use the %data_control_sql_update() method:
  ///
  /// @code
  ///
  /// void
  /// sql_update_response_cb(int request_id, data_control_h provider, bool provider_result, const char *error, void *user_data)
  /// {
  /// if (provider_result)
  /// LOGI("The update operation is successful");
  /// else
  /// LOGI("The update operation for the request %d is failed. error message: %s", request_id, error);
  /// }
  ///
  /// data_control_sql_response_cb sql_callback;
  ///
  /// {
  /// int result = 0;
  /// int req_id = 0;
  /// const char *where = "WORD = 'test'";
  /// bundle *b = NULL;
  ///
  /// sql_callback.update_cb = sql_update_response_cb;
  /// result = data_control_sql_register_response_cb(provider, &sql_callback, void *user_data);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Registering the callback function is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// b = bundle_create();
  /// bundle_add(b, "WORD", "test_new");
  ///
  /// result = data_control_sql_update(provider, b, where, &req_id);
  /// if (result != DATA_CONTROL_ERROR_NONE)
  /// LOGE("Updating is failed with error: %d", result);
  /// else
  /// LOGI("req_id is %d", req_id);
  ///
  /// bundle_free(b);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  ///
  /// @param[in] provider The provider handle
  /// @param[in] update_data The column-value pairs to update \n
  /// If the value is a string, the value must be wrapped in single quotes,
  /// else it does not need to be wrapped in single quotes
  /// @param[in] where A filter to select the desired rows to update \n
  /// It is an SQL 'WHERE' clause excluding the 'WHERE' itself such as column1 = 'stringValue' and column2 = numericValue
  /// @param[out] request_id The request ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DATA_CONTROL_ERROR_MAX_EXCEEDED Too long argument
  int data_control_sql_update(
    data_control_h provider,
    ffi.Pointer<bundle> update_data,
    ffi.Pointer<ffi.Char> where,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_sql_update(
      provider,
      update_data,
      where,
      request_id,
    );
  }

  late final _data_control_sql_updatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<bundle>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('data_control_sql_update');
  late final _data_control_sql_update = _data_control_sql_updatePtr.asFunction<
      int Function(data_control_h, ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Inserts multiple rows in one request.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  ///
  /// @remarks If you want to use this function, you must add privileges.
  /// @remarks The following example demonstrates how to use the %data_control_sql_insert_bulk_data() method:
  ///
  /// @code
  ///
  /// void
  /// sql_bulk_insert_response_cb(int request_id, data_control_h provider, data_control_bulk_result_data_h bulk_results,
  /// bool provider_result, const char *error, void *user_data)
  /// {
  /// if (provider_result)
  /// LOGI("The bulk insert operation is successful");
  /// else
  /// LOGI("The bulk insert operation for the request %d is failed. error message: %s", request_id, error);
  /// }
  ///
  /// data_control_sql_response_cb sql_callback;
  ///
  /// {
  /// data_control_bulk_data_h bulk_data;
  /// int req_id;
  /// bundle *b1;
  /// bundle *b2;
  /// int result = 0;
  /// int req_id = 0;
  /// int bulk_count = 0;
  ///
  /// result = data_control_sql_register_insert_bulk_data_response_cb(provider, sql_bulk_insert_response_cb, user_data);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Registering the callback function is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// b1 = bundle_create();
  /// bundle_add_str(b1, "WORD", "'test'");
  /// bundle_add_str(b1, "WORD_DESC", "'test description'");
  /// b2 = bundle_create();
  /// bundle_add_str(b2, "WORD", "'test2'");
  /// bundle_add_str(b2, "WORD_DESC", "'test2 description'");
  ///
  /// data_control_bulk_data_create(&bulk_data);
  /// data_control_bulk_data_add(bulk_data, b1);
  /// data_control_bulk_data_add(bulk_data, b2);
  /// data_control_bulk_data_get_count(bulk_data, &bulk_count);
  ///
  /// dlog_print(DLOG_INFO, LOG_TAG, "bulk insert count %d ", bulk_count);
  ///
  /// data_control_sql_insert_bulk_data(provider, bulk_data, &req_id);
  /// data_control_bulk_data_destroy(bulk_data);
  ///
  /// bundle_free(b1);
  /// bundle_free(b2);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] provider The provider handle
  /// @param[in] bulk_data The bulk data handle
  /// @param[out] request_id The request ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DATA_CONTROL_ERROR_MAX_EXCEEDED Too long argument
  int data_control_sql_insert_bulk_data(
    data_control_h provider,
    data_control_bulk_data_h bulk_data,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_sql_insert_bulk_data(
      provider,
      bulk_data,
      request_id,
    );
  }

  late final _data_control_sql_insert_bulk_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h, data_control_bulk_data_h,
              ffi.Pointer<ffi.Int>)>>('data_control_sql_insert_bulk_data');
  late final _data_control_sql_insert_bulk_data =
      _data_control_sql_insert_bulk_dataPtr.asFunction<
          int Function(data_control_h, data_control_bulk_data_h,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Registers an insert bulk data callback for the SQL data control response.
  /// The application is notified when a data control response is
  /// received from the @a provider.
  /// @since_tizen 3.0
  ///
  /// @remarks Only one callback can be registered for each provider id with this
  /// function. If you call this function multiple times for the same
  /// provider id, any previously set callback will be overwritten.
  ///
  /// @param[in] provider The provider handle
  /// @param[in] callback The callback function to be called when a response is received
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see  data_control_sql_unregister_insert_bulk_data_response_cb()
  /// @see  data_control_sql_bind_insert_bulk_data_response_cb()
  int data_control_sql_register_insert_bulk_data_response_cb(
    data_control_h provider,
    data_control_bulk_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_sql_register_insert_bulk_data_response_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _data_control_sql_register_insert_bulk_data_response_cbPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(data_control_h, data_control_bulk_cb,
                      ffi.Pointer<ffi.Void>)>>(
          'data_control_sql_register_insert_bulk_data_response_cb');
  late final _data_control_sql_register_insert_bulk_data_response_cb =
      _data_control_sql_register_insert_bulk_data_response_cbPtr.asFunction<
          int Function(
              data_control_h, data_control_bulk_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the insert bulk data callback.
  /// @since_tizen 3.0
  ///
  /// @param[in] provider The provider handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see  data_control_sql_register_insert_bulk_data_response_cb()
  int data_control_sql_unregister_insert_bulk_data_response_cb(
    data_control_h provider,
  ) {
    return _data_control_sql_unregister_insert_bulk_data_response_cb(
      provider,
    );
  }

  late final _data_control_sql_unregister_insert_bulk_data_response_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h)>>(
          'data_control_sql_unregister_insert_bulk_data_response_cb');
  late final _data_control_sql_unregister_insert_bulk_data_response_cb =
      _data_control_sql_unregister_insert_bulk_data_response_cbPtr
          .asFunction<int Function(data_control_h)>();

  /// @brief Binds a callback function to the SQL data control response.
  /// @details This function is very similar to
  /// data_control_sql_register_response_cb(), which can register a
  /// callback for a given provider id. Calling
  /// data_control_sql_register_response_cb() again overwrites the
  /// callback previously set for the provider id, which means that only
  /// one callback can be set for a given id.
  /// data_control_sql_bind_response_cb() binds a callback to the handle
  /// of a provider, which allows registering multiple callbacks for a
  /// given provider id. To do that, you can create new #data_control_h
  /// for the same provider id and register callback for the
  /// #data_control_h.
  ///
  /// @since_tizen 4.0
  /// @remarks You can bind a callback function to @a provider. If you call this
  /// function multiple times for the same handle, any previously set
  /// callback will be overwritten.
  ///
  /// @param[in] provider  The provider handle
  /// @param[in] callback  The callback function to be called
  /// when a response is received
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_sql_register_response_cb()
  /// @see data_control_sql_unbind_response_cb()
  int data_control_sql_bind_response_cb(
    data_control_h provider,
    ffi.Pointer<data_control_sql_response_cb> callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_sql_bind_response_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _data_control_sql_bind_response_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<data_control_sql_response_cb>,
              ffi.Pointer<ffi.Void>)>>('data_control_sql_bind_response_cb');
  late final _data_control_sql_bind_response_cb =
      _data_control_sql_bind_response_cbPtr.asFunction<
          int Function(
              data_control_h,
              ffi.Pointer<data_control_sql_response_cb>,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unbinds the callback function in the @a provider.
  /// @since_tizen 4.0
  ///
  /// @param[in] provider The provider handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_sql_bind_response_cb()
  int data_control_sql_unbind_response_cb(
    data_control_h provider,
  ) {
    return _data_control_sql_unbind_response_cb(
      provider,
    );
  }

  late final _data_control_sql_unbind_response_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h)>>(
          'data_control_sql_unbind_response_cb');
  late final _data_control_sql_unbind_response_cb =
      _data_control_sql_unbind_response_cbPtr
          .asFunction<int Function(data_control_h)>();

  /// @brief Binds the insert bulk data callback to the SQL data control response.
  /// @details This function is very similar to
  /// data_control_sql_register_insert_bulk_data_response_cb(), which can
  /// register a callback for a given provider id. Calling
  /// data_control_sql_register_insert_bulk_data_response_cb() again
  /// overwrites the callback previously set for the provider id, which
  /// means that only one callback can be set for a given id.
  /// data_control_sql_bind_insert_bulk_data_response_cb() binds a
  /// callback to the handle of a provider, which allows registering
  /// multiple callbacks for a given provider id. To do that, you can
  /// create new #data_control_h for the same provider id and register
  /// callback for the #data_control_h.
  ///
  /// @since_tizen 4.0
  /// @remarks You can bind a callback function to @a provider. If you call this
  /// function multiple times for the same handle, any previously set
  /// callback will be overwritten.
  ///
  /// @param[in] provider  The provider handle
  /// @param[in] callback  The callback function to be called
  /// when a response is received
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see  data_control_sql_register_insert_bulk_data_response_cb()
  /// @see  data_control_sql_unbind_insert_bulk_data_response_cb()
  int data_control_sql_bind_insert_bulk_data_response_cb(
    data_control_h provider,
    data_control_bulk_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_sql_bind_insert_bulk_data_response_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _data_control_sql_bind_insert_bulk_data_response_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(data_control_h, data_control_bulk_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'data_control_sql_bind_insert_bulk_data_response_cb');
  late final _data_control_sql_bind_insert_bulk_data_response_cb =
      _data_control_sql_bind_insert_bulk_data_response_cbPtr.asFunction<
          int Function(
              data_control_h, data_control_bulk_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unbinds the insert bulk data callback in the @a provider.
  /// @since_tizen 4.0
  ///
  /// @param[in] provider The provider handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see  data_control_sql_unbind_insert_bulk_data_response_cb()
  int data_control_sql_unbind_insert_bulk_data_response_cb(
    data_control_h provider,
  ) {
    return _data_control_sql_unbind_insert_bulk_data_response_cb(
      provider,
    );
  }

  late final _data_control_sql_unbind_insert_bulk_data_response_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h)>>(
          'data_control_sql_unbind_insert_bulk_data_response_cb');
  late final _data_control_sql_unbind_insert_bulk_data_response_cb =
      _data_control_sql_unbind_insert_bulk_data_response_cbPtr
          .asFunction<int Function(data_control_h)>();

  /// @brief Gets the handle ID for @a provider.
  /// @since_tizen 4.0
  ///
  /// @remarks @a handle_id is generated internally and it is unique for each
  /// handle. This function can be used in callbacks to know for which
  /// handle the callback was called.
  ///
  /// @param[in]  provider  The provider handle
  /// @param[out] handle_id The handle ID for @a provider
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_sql_get_handle_id(
    data_control_h provider,
    ffi.Pointer<ffi.Int> handle_id,
  ) {
    return _data_control_sql_get_handle_id(
      provider,
      handle_id,
    );
  }

  late final _data_control_sql_get_handle_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h,
              ffi.Pointer<ffi.Int>)>>('data_control_sql_get_handle_id');
  late final _data_control_sql_get_handle_id =
      _data_control_sql_get_handle_idPtr
          .asFunction<int Function(data_control_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Creates a provider handle.
  /// @since_tizen 2.3
  /// @remarks @a provider should be destroyed with data_control_map_destroy().
  /// The following example demonstrates how to use the %data_control_map_create() method.
  ///
  /// @code
  ///
  /// {
  /// const char *provider_id = "http://tizen.org/datacontrol/provider/example";
  /// const char *data_id = "table";
  /// data_control_h provider;
  /// int result = 0;
  ///
  /// result = data_control_map_create(&provider);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Creating data control provider is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// result = data_control_map_set_provider_id(provider, provider_id);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Setting providerID is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// result = data_control_map_set_data_id(provider, data_id);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Setting dataID is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// // Executes some operations
  ///
  /// result = data_control_map_destroy(provider);
  /// if (result != DATA_CONTROL_ERROR_NONE)
  /// LOGE("Destorying data control provider is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  /// @param[out] provider The provider handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see data_control_map_destroy()
  int data_control_map_create(
    ffi.Pointer<data_control_h> provider,
  ) {
    return _data_control_map_create(
      provider,
    );
  }

  late final _data_control_map_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<data_control_h>)>>(
      'data_control_map_create');
  late final _data_control_map_create = _data_control_map_createPtr
      .asFunction<int Function(ffi.Pointer<data_control_h>)>();

  /// @brief Destroys the provider handle and releases all its resources.
  /// @since_tizen 2.3
  /// @remarks When operations of data control are finished, this function must be called to prevent memory leak.
  /// @param[in] provider The provider handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_map_create()
  int data_control_map_destroy(
    data_control_h provider,
  ) {
    return _data_control_map_destroy(
      provider,
    );
  }

  late final _data_control_map_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h)>>(
          'data_control_map_destroy');
  late final _data_control_map_destroy =
      _data_control_map_destroyPtr.asFunction<int Function(data_control_h)>();

  /// @brief Sets the Provider ID.
  /// @since_tizen 2.3
  /// @param[in] provider The provider handle
  /// @param[in] provider_id The data control provider ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see data_control_map_get_provider_id()
  int data_control_map_set_provider_id(
    data_control_h provider,
    ffi.Pointer<ffi.Char> provider_id,
  ) {
    return _data_control_map_set_provider_id(
      provider,
      provider_id,
    );
  }

  late final _data_control_map_set_provider_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h,
              ffi.Pointer<ffi.Char>)>>('data_control_map_set_provider_id');
  late final _data_control_map_set_provider_id =
      _data_control_map_set_provider_idPtr
          .asFunction<int Function(data_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the Provider ID.
  /// @since_tizen 2.3
  /// @remarks You must release @a provider_id using free() after it is used.
  /// @param[in] provider The provider handle
  /// @param[out] provider_id The data control provider ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see data_control_map_set_provider_id()
  int data_control_map_get_provider_id(
    data_control_h provider,
    ffi.Pointer<ffi.Pointer<ffi.Char>> provider_id,
  ) {
    return _data_control_map_get_provider_id(
      provider,
      provider_id,
    );
  }

  late final _data_control_map_get_provider_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  data_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'data_control_map_get_provider_id');
  late final _data_control_map_get_provider_id =
      _data_control_map_get_provider_idPtr.asFunction<
          int Function(data_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the Data ID.
  /// @since_tizen 2.3
  /// @param[in] provider The provider handle
  /// @param[in] data_id A string for identifying a specific table to operate \n
  /// The string consists of one or more components separated by a slash('/').
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see data_control_map_get_data_id()
  int data_control_map_set_data_id(
    data_control_h provider,
    ffi.Pointer<ffi.Char> data_id,
  ) {
    return _data_control_map_set_data_id(
      provider,
      data_id,
    );
  }

  late final _data_control_map_set_data_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h,
              ffi.Pointer<ffi.Char>)>>('data_control_map_set_data_id');
  late final _data_control_map_set_data_id = _data_control_map_set_data_idPtr
      .asFunction<int Function(data_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the data ID.
  /// @since_tizen 2.3
  /// @remarks You must release @a data_id using free() after it is used.
  /// @param[in] provider The provider handle
  /// @param[out] data_id A string for identifying a specific table to operate \n
  /// The string consists of one or more components separated by a slash('/').
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see data_control_map_set_data_id()
  int data_control_map_get_data_id(
    data_control_h provider,
    ffi.Pointer<ffi.Pointer<ffi.Char>> data_id,
  ) {
    return _data_control_map_get_data_id(
      provider,
      data_id,
    );
  }

  late final _data_control_map_get_data_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  data_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'data_control_map_get_data_id');
  late final _data_control_map_get_data_id =
      _data_control_map_get_data_idPtr.asFunction<
          int Function(data_control_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Registers a callback function for the key-value structured data control response.
  /// The application is notified when a data control response is received from the @a provider.
  /// @since_tizen 2.3
  ///
  /// @remarks The application is notified when a data control response is received from the @a provider.
  /// @remarks Only one callback can be registered for each provider id with this API.
  /// @remarks If you register multiple callback for same provider id, it will be overwritten by latest one.
  ///
  /// @param[in] provider The provider handle
  /// @param[in] callback The callback function to be called when a response is received
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @see data_control_map_unregister_response_cb()
  /// @see data_control_map_bind_response_cb()
  int data_control_map_register_response_cb(
    data_control_h provider,
    ffi.Pointer<data_control_map_response_cb> callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_map_register_response_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _data_control_map_register_response_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<data_control_map_response_cb>,
              ffi.Pointer<ffi.Void>)>>('data_control_map_register_response_cb');
  late final _data_control_map_register_response_cb =
      _data_control_map_register_response_cbPtr.asFunction<
          int Function(
              data_control_h,
              ffi.Pointer<data_control_map_response_cb>,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function in the @a provider.
  /// @since_tizen 2.3
  /// @param[in] provider The provider handle
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_map_register_response_cb()
  int data_control_map_unregister_response_cb(
    data_control_h provider,
  ) {
    return _data_control_map_unregister_response_cb(
      provider,
    );
  }

  late final _data_control_map_unregister_response_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h)>>(
          'data_control_map_unregister_response_cb');
  late final _data_control_map_unregister_response_cb =
      _data_control_map_unregister_response_cbPtr
          .asFunction<int Function(data_control_h)>();

  /// @brief Gets the value list associated with the specified @a key from the key-values map owned by the key-value structured data control provider.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  /// @remarks If you want to use this api, you must add privileges.
  /// @remarks If the length of value list associated with the @a key is larger than 20, this API only returns the first 20 values.
  /// @remarks The following example demonstrates how to use the %data_control_map_get() method.
  ///
  /// @code
  ///
  /// void
  /// map_get_response_cb(int request_id, data_control_h provider, char **result_value_list,
  /// int ret_value_count, bool provider_result, const char *error, void *user_data)
  /// {
  /// if (provider_result)
  /// LOGI("The get operation is successful");
  /// else
  /// LOGI("The get operation for the request %d is failed. error message: %s", request_id, error);
  /// }
  ///
  /// data_control_map_response_cb map_callback;
  ///
  /// {
  /// int result = 0;
  /// int req_id = 0;
  /// char *key = "key";
  ///
  /// map_callback.get_cb = map_get_response_cb;
  /// result = data_control_map_register_response_cb(provider, &map_callback, NULL);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Registering the callback function is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// result = data_control_map_get(provider, key, &req_id);
  /// if (result != DATA_CONTROL_ERROR_NONE)
  /// LOGE("Getting the value list of the key(%s) is failed with error: %d", key, result);
  /// else
  /// LOGI("req_id is %d", req_id);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] provider The provider handle
  /// @param[in] key The key of the value list to obtain
  /// @param[out] request_id The request ID
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_MAX_EXCEEDED Too long argument
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  /// @see data_control_map_get_with_page()
  int data_control_map_get(
    data_control_h provider,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_map_get(
      provider,
      key,
      request_id,
    );
  }

  late final _data_control_map_getPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('data_control_map_get');
  late final _data_control_map_get = _data_control_map_getPtr.asFunction<
      int Function(
          data_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the value list associated with the specified @a key from the key-values map owned by the key-value structured data control provider, with partition into pages.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  ///
  /// @remarks If you want to use this api, you must add privileges.
  /// @param[in] provider The provider handle
  /// @param[in] key The key of the value list to obtain
  /// @param[out] request_id The request ID
  /// @param[in] page_number The page number of the value set \n
  /// It starts from @c 1.
  /// @param[in] count_per_page The desired maximum count of the data items per page
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_MAX_EXCEEDED Too long argument
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  /// @see data_control_map_get()
  int data_control_map_get_with_page(
    data_control_h provider,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Int> request_id,
    int page_number,
    int count_per_page,
  ) {
    return _data_control_map_get_with_page(
      provider,
      key,
      request_id,
      page_number,
      count_per_page,
    );
  }

  late final _data_control_map_get_with_pagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>,
              ffi.Int,
              ffi.Int)>>('data_control_map_get_with_page');
  late final _data_control_map_get_with_page =
      _data_control_map_get_with_pagePtr.asFunction<
          int Function(data_control_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>, int, int)>();

  /// @brief Sets the value associated with the specified @a key to a new value.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  /// @remarks If you want to use this api, you must add privileges.
  /// @remarks The following example demonstrates how to use the %data_control_map_set() method.
  ///
  /// @code
  ///
  /// void
  /// map_set_response_cb(int request_id, data_control_h provider, bool provider_result, const char *error, void *user_data)
  /// {
  /// if (provider_result)
  /// LOGI("The set operation is successful");
  /// else
  /// LOGI("The set operation for the request %d is failed. error message: %s", request_id, error);
  /// }
  ///
  /// data_control_map_response_cb map_callback;
  ///
  /// {
  /// int result = 0;
  /// int req_id = 0;
  /// char *key = "key";
  /// char *old_value = "old value";
  /// char *new_value = "new value";
  ///
  /// map_callback.set_cb = map_set_response_cb;
  /// result = data_control_map_register_response_cb(provider, &map_callback, NULL);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Registering the callback function is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// result = data_control_map_set(provider, key, old_value, new_value, &req_id);
  /// if (result != DATA_CONTROL_ERROR_NONE)
  /// LOGE("Replacing old_value(%s) with new_value(%s) is failed with error: %d", old_value, new_value, result);
  /// else
  /// LOGI("req_id is %d", req_id);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] provider The provider handle
  /// @param[in] key The key of the value to replace
  /// @param[in] old_value The value to replace
  /// @param[in] new_value The new value that replaces the existing value
  /// @param[out] request_id The request ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_MAX_EXCEEDED Too long argument
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_map_set(
    data_control_h provider,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> old_value,
    ffi.Pointer<ffi.Char> new_value,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_map_set(
      provider,
      key,
      old_value,
      new_value,
      request_id,
    );
  }

  late final _data_control_map_setPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('data_control_map_set');
  late final _data_control_map_set = _data_control_map_setPtr.asFunction<
      int Function(data_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @brief Adds the @a value associated with the specified @a key to the key-values map owned by the key-value structured data control provider.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  /// @remarks If you want to use this api, you must add privileges.
  /// @remarks The following example demonstrates how to use the %data_control_map_add() method.
  ///
  /// @code
  ///
  /// void
  /// map_add_response_cb(int request_id, data_control_h provider, bool provider_result, const char *error, void *user_data)
  /// {
  /// if (provider_result)
  /// LOGI("The add operation is successful");
  /// else
  /// LOGI("The add operation for the request %d is failed. error message: %s", request_id, error);
  /// }
  ///
  /// data_control_map_response_cb map_callback;
  ///
  /// {
  /// int result = 0;
  /// int req_id = 0;
  /// const char *key = "key";
  /// const char *value = "value";
  ///
  /// map_callback.add_cb = map_add_response_cb;
  /// result = data_control_map_register_response_cb(provider, &map_callback, NULL);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Registering the callback function is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// result = data_control_map_add(provider, key, value, &req_id);
  /// if (result != DATA_CONTROL_ERROR_NONE)
  /// LOGE("Adding %s-%s pair is failed with error: %d", key, value, result);
  /// else
  /// LOGI("req_id is %d", req_id);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] provider The provider handle
  /// @param[in] key The key of the value to add
  /// @param[in] value The value to add
  /// @param[out] request_id The request ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_MAX_EXCEEDED Too long argument
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_map_add(
    data_control_h provider,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> value,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_map_add(
      provider,
      key,
      value,
      request_id,
    );
  }

  late final _data_control_map_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('data_control_map_add');
  late final _data_control_map_add = _data_control_map_addPtr.asFunction<
      int Function(data_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Removes the @a value associated with the specified @a key from the key-values map owned by the key-value structured data control provider.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  /// @remarks If you want to use this api, you must add privileges.
  /// @remarks The following example demonstrates how to use the %data_control_map_remove() method.
  ///
  /// @code
  ///
  /// void
  /// map_remove_response_cb(int request_id, data_control_h provider, bool provider_result, const char *error, void *user_data)
  /// {
  /// if (provider_result)
  /// LOGI("The remove operation is successful");
  /// else
  /// LOGI("The remove operation for the request %d is failed. error message: %s", request_id, error);
  /// }
  ///
  /// data_control_map_response_cb map_callback;
  ///
  /// {
  /// int result = 0;
  /// int req_id = 0;
  /// const char *key = "key";
  /// const char *value = "value";
  ///
  /// map_callback.remove_cb = map_remove_response_cb;
  /// result = data_control_map_register_response_cb(provider, &map_callback, NULL);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Registering the callback function is failed with error: %d", result);
  ///
  /// return result;
  /// }
  ///
  /// result = data_control_map_remove(provider, key, value, &req_id);
  /// if (result != DATA_CONTROL_ERROR_NONE)
  /// LOGE("Removing %s-%s pair is failed with error: %d", key, value, result);
  /// else
  /// LOGI("req_id is %d", req_id);
  ///
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] provider The provider handle
  /// @param[in] key The key of the value to remove
  /// @param[in] value The value to remove
  /// @param[out] request_id The request ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_MAX_EXCEEDED Too long argument
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_map_remove(
    data_control_h provider,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> value,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_map_remove(
      provider,
      key,
      value,
      request_id,
    );
  }

  late final _data_control_map_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('data_control_map_remove');
  late final _data_control_map_remove = _data_control_map_removePtr.asFunction<
      int Function(data_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Adds multiple key-value pairs in one request.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  /// @remarks If you want to use this function, you must add privileges.
  /// @remarks The following example demonstrates how to use the %data_control_map_add_bulk_data() method.
  ///
  /// @code
  ///
  /// void
  /// map_bulk_add_response_cb(int request_id, data_control_h provider, data_control_bulk_result_data_h bulk_results,
  /// bool provider_result, const char *error, void *user_data)
  /// {
  /// if (provider_result)
  /// LOGI("The add operation is successful");
  /// else
  /// LOGI("The add operation for the request %d is failed. error message: %s", request_id, error);
  /// }
  ///
  /// data_control_map_response_cb map_callback;
  /// {
  /// data_control_bulk_data_h bulk_data;
  /// int req_id;
  /// bundle *b1;
  /// bundle *b2;
  /// int result = 0;
  /// int req_id = 0;
  /// int count;
  ///
  /// result = data_control_map_register_add_bulk_data_response_cb(provider, map_bulk_add_response_cb, user_data);
  /// if (result != DATA_CONTROL_ERROR_NONE) {
  /// LOGE("Registering the callback function is failed with error: %d", result);
  /// return result;
  /// }
  ///
  /// b1 = bundle_create();
  /// bundle_add_str(b1, "key", "test key");
  /// bundle_add_str(b1, "value", "test value");
  /// b2 = bundle_create();
  /// bundle_add_str(b2, "key", "test key2");
  /// bundle_add_str(b2, "value", "test value2");
  ///
  /// data_control_bulk_data_create(&bulk_data);
  /// data_control_bulk_data_add(bulk_data, b1);
  /// data_control_bulk_data_add(bulk_data, b2);
  ///
  /// data_control_bulk_data_get_count(bulk_data, &count);
  /// dlog_print(DLOG_INFO, LOG_TAG, "bulk add count %d ", count);
  ///
  /// data_control_map_add_bulk_data(provider, bulk_data, &req_id);
  /// data_control_bulk_data_destroy(bulk_data);
  ///
  /// bundle_free(b1);
  /// bundle_free(b2);
  /// return result;
  /// }
  ///
  /// @endcode
  ///
  /// @param[in] provider The provider handle
  /// @param[in] bulk_data The bulk data handle
  /// @param[out] request_id The request ID
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_MAX_EXCEEDED Too long argument. Bulk data total length cannot exceed 1MB
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_map_add_bulk_data(
    data_control_h provider,
    data_control_bulk_data_h bulk_data,
    ffi.Pointer<ffi.Int> request_id,
  ) {
    return _data_control_map_add_bulk_data(
      provider,
      bulk_data,
      request_id,
    );
  }

  late final _data_control_map_add_bulk_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h, data_control_bulk_data_h,
              ffi.Pointer<ffi.Int>)>>('data_control_map_add_bulk_data');
  late final _data_control_map_add_bulk_data =
      _data_control_map_add_bulk_dataPtr.asFunction<
          int Function(data_control_h, data_control_bulk_data_h,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Registers an add bulk data callback for the MAP data control response.
  /// The application is notified when a data control response is received
  /// from the @a provider.
  /// @since_tizen 3.0
  ///
  /// @remarks Only one callback can be registered for each provider id with this
  /// function. If you call this function multiple times for the same
  /// provider id, any previously set callback will be overwritten.
  /// @param[in] provider The provider handle
  /// @param[in] callback The callback function to be called when a response is received
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_map_unregister_add_bulk_data_response_cb()
  /// @see data_control_map_bind_add_bulk_data_response_cb()
  int data_control_map_register_add_bulk_data_response_cb(
    data_control_h provider,
    data_control_bulk_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_map_register_add_bulk_data_response_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _data_control_map_register_add_bulk_data_response_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(data_control_h, data_control_bulk_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'data_control_map_register_add_bulk_data_response_cb');
  late final _data_control_map_register_add_bulk_data_response_cb =
      _data_control_map_register_add_bulk_data_response_cbPtr.asFunction<
          int Function(
              data_control_h, data_control_bulk_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the add bulk data callback.
  /// @since_tizen 3.0
  /// @param[in] provider The provider handle
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_map_register_add_bulk_data_response_cb()
  int data_control_map_unregister_add_bulk_data_response_cb(
    data_control_h provider,
  ) {
    return _data_control_map_unregister_add_bulk_data_response_cb(
      provider,
    );
  }

  late final _data_control_map_unregister_add_bulk_data_response_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h)>>(
          'data_control_map_unregister_add_bulk_data_response_cb');
  late final _data_control_map_unregister_add_bulk_data_response_cb =
      _data_control_map_unregister_add_bulk_data_response_cbPtr
          .asFunction<int Function(data_control_h)>();

  /// @brief Binds a response callback function to a data control provider handle.
  /// The application is notified when a data control response is received
  /// from the @a provider.
  /// @details This function is very similar to
  /// data_control_map_register_response_cb(), which can register a
  /// callback for a given provider id. Calling
  /// data_control_map_register_response_cb() again overwrites the
  /// callback previously set for the provider id, which means that only
  /// one callback can be set for a given id.
  /// data_control_map_bind_response_cb() binds a callback to the handle
  /// of a provider, which allows registering multiple callbacks for a
  /// given provider id. To do that, you can create new #data_control_h
  /// for the same provider id and register callback for the
  /// #data_control_h.
  ///
  /// @since_tizen 4.0
  ///
  /// @remarks If you call this function multiple times for the same handle, any
  /// previously set callback will be overwritten.
  ///
  /// @param[in] provider  The provider handle
  /// @param[in] callback  The callback function to be called
  /// when a response is received
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_map_register_response_cb()
  /// @see data_control_map_unbind_response_cb()
  int data_control_map_bind_response_cb(
    data_control_h provider,
    ffi.Pointer<data_control_map_response_cb> callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_map_bind_response_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _data_control_map_bind_response_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              ffi.Pointer<data_control_map_response_cb>,
              ffi.Pointer<ffi.Void>)>>('data_control_map_bind_response_cb');
  late final _data_control_map_bind_response_cb =
      _data_control_map_bind_response_cbPtr.asFunction<
          int Function(
              data_control_h,
              ffi.Pointer<data_control_map_response_cb>,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unbinds the callback function in the @a provider.
  /// @since_tizen 4.0
  ///
  /// @param[in] provider The provider handle
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_bind_map_response_cb()
  int data_control_map_unbind_response_cb(
    data_control_h provider,
  ) {
    return _data_control_map_unbind_response_cb(
      provider,
    );
  }

  late final _data_control_map_unbind_response_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h)>>(
          'data_control_map_unbind_response_cb');
  late final _data_control_map_unbind_response_cb =
      _data_control_map_unbind_response_cbPtr
          .asFunction<int Function(data_control_h)>();

  /// @brief Binds the add bulk data callback to the map data control response.
  /// @details This function is very similar to
  /// data_control_map_register_add_bulk_data_response_cb(), which can
  /// register a callback for a given provider id. Calling
  /// data_control_map_register_add_bulk_data_response_cb() again
  /// overwrites the callback previously set for the provider id, which
  /// means that only one callback can be set for a given id.
  /// data_control_map_bind_add_bulk_data_response_cb() binds a
  /// callback to the handle of a provider, which allows registering
  /// multiple callbacks for a given provider id. To do that, you can
  /// create new #data_control_h for the same provider id and register
  /// callback for the #data_control_h.
  ///
  /// @since_tizen 4.0
  /// @remarks If you call this function multiple times for the same handle,
  /// any previously set callback will be overwritten.
  ///
  /// @param[in] provider  The provider handle
  /// @param[in] callback  The callback function to be called
  /// when a response is received
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_map_register_add_bulk_data_response_cb()
  /// @see data_control_map_unbind_add_bulk_data_response_cb()
  int data_control_map_bind_add_bulk_data_response_cb(
    data_control_h provider,
    data_control_bulk_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_map_bind_add_bulk_data_response_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _data_control_map_bind_add_bulk_data_response_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(data_control_h, data_control_bulk_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'data_control_map_bind_add_bulk_data_response_cb');
  late final _data_control_map_bind_add_bulk_data_response_cb =
      _data_control_map_bind_add_bulk_data_response_cbPtr.asFunction<
          int Function(
              data_control_h, data_control_bulk_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unbinds the add bulk data callback in the @a provider.
  /// @since_tizen 4.0
  ///
  /// @param[in] provider The provider handle
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_map_bind_add_bulk_data_response_cb()
  int data_control_map_unbind_add_bulk_data_response_cb(
    data_control_h provider,
  ) {
    return _data_control_map_unbind_add_bulk_data_response_cb(
      provider,
    );
  }

  late final _data_control_map_unbind_add_bulk_data_response_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h)>>(
          'data_control_map_unbind_add_bulk_data_response_cb');
  late final _data_control_map_unbind_add_bulk_data_response_cb =
      _data_control_map_unbind_add_bulk_data_response_cbPtr
          .asFunction<int Function(data_control_h)>();

  /// @brief Gets the handle ID for @a provider.
  /// @since_tizen 4.0
  ///
  /// @remarks @a handle_id is generated internally and it is unique for each
  /// handle. This function can be used in callbacks to know for which
  /// handle the callback was called.
  ///
  /// @param[in]  provider  The provider handle
  /// @param[out] handle_id The handle ID for @a provider
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_map_get_handle_id(
    data_control_h provider,
    ffi.Pointer<ffi.Int> handle_id,
  ) {
    return _data_control_map_get_handle_id(
      provider,
      handle_id,
    );
  }

  late final _data_control_map_get_handle_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(data_control_h,
              ffi.Pointer<ffi.Int>)>>('data_control_map_get_handle_id');
  late final _data_control_map_get_handle_id =
      _data_control_map_get_handle_idPtr
          .asFunction<int Function(data_control_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Registers a callback function for the SQL data control request.
  /// The provider is notified when a data control request is received from the client applications.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing
  ///
  /// @param[in] callback The callback function to be called when a data control request is received
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_provider_sql_register_cb(
    ffi.Pointer<data_control_provider_sql_cb> callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_provider_sql_register_cb(
      callback,
      user_data,
    );
  }

  late final _data_control_provider_sql_register_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<data_control_provider_sql_cb>,
              ffi.Pointer<ffi.Void>)>>('data_control_provider_sql_register_cb');
  late final _data_control_provider_sql_register_cb =
      _data_control_provider_sql_register_cbPtr.asFunction<
          int Function(ffi.Pointer<data_control_provider_sql_cb>,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the SQL data control request callback functions.
  /// @since_tizen 2.3
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  int data_control_provider_sql_unregister_cb() {
    return _data_control_provider_sql_unregister_cb();
  }

  late final _data_control_provider_sql_unregister_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'data_control_provider_sql_unregister_cb');
  late final _data_control_provider_sql_unregister_cb =
      _data_control_provider_sql_unregister_cbPtr.asFunction<int Function()>();

  /// @brief Registers a callback function for the map data control request.
  /// The provider is notified when a data control request is received from the client applications.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing
  ///
  /// @param[in] callback The callback function to be called when a data control request is received
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_provider_map_register_cb(
    ffi.Pointer<data_control_provider_map_cb> callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_provider_map_register_cb(
      callback,
      user_data,
    );
  }

  late final _data_control_provider_map_register_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<data_control_provider_map_cb>,
              ffi.Pointer<ffi.Void>)>>('data_control_provider_map_register_cb');
  late final _data_control_provider_map_register_cb =
      _data_control_provider_map_register_cbPtr.asFunction<
          int Function(ffi.Pointer<data_control_provider_map_cb>,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the map data control request callback functions.
  /// @since_tizen 2.3
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  int data_control_provider_map_unregister_cb() {
    return _data_control_provider_map_unregister_cb();
  }

  late final _data_control_provider_map_unregister_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'data_control_provider_map_unregister_cb');
  late final _data_control_provider_map_unregister_cb =
      _data_control_provider_map_unregister_cbPtr.asFunction<int Function()>();

  /// @brief Gets the application ID which sends the data control request.
  /// @since_tizen 2.3
  ///
  /// @remarks You must release @a appid using free() after it is used.
  ///
  /// @param[in] request_id The request ID
  /// @param[out] appid The application ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_get_client_appid(
    int request_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> appid,
  ) {
    return _data_control_provider_get_client_appid(
      request_id,
      appid,
    );
  }

  late final _data_control_provider_get_client_appidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'data_control_provider_get_client_appid');
  late final _data_control_provider_get_client_appid =
      _data_control_provider_get_client_appidPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sends the success result and the result set of the select request to the client application.
  /// @since_tizen 2.3
  ///
  /// @param[in] request_id The request ID
  /// @param[in] db_handle The result DB handle for the result set
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_send_select_result(
    int request_id,
    ffi.Pointer<ffi.Void> db_handle,
  ) {
    return _data_control_provider_send_select_result(
      request_id,
      db_handle,
    );
  }

  late final _data_control_provider_send_select_resultPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Void>)>>(
      'data_control_provider_send_select_result');
  late final _data_control_provider_send_select_result =
      _data_control_provider_send_select_resultPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Void>)>();

  /// @brief Sends the success result of the insert request and the last inserted row ID to the client application.
  /// @since_tizen 2.3
  ///
  /// @param[in] request_id The request ID
  /// @param[in] row_id The row ID of the database changed by the insert request
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_send_insert_result(
    int request_id,
    int row_id,
  ) {
    return _data_control_provider_send_insert_result(
      request_id,
      row_id,
    );
  }

  late final _data_control_provider_send_insert_resultPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.LongLong)>>(
          'data_control_provider_send_insert_result');
  late final _data_control_provider_send_insert_result =
      _data_control_provider_send_insert_resultPtr
          .asFunction<int Function(int, int)>();

  /// @brief Sends the success result of the update request to the client application.
  /// @since_tizen 2.3
  ///
  /// @param[in] request_id The request ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_send_update_result(
    int request_id,
  ) {
    return _data_control_provider_send_update_result(
      request_id,
    );
  }

  late final _data_control_provider_send_update_resultPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'data_control_provider_send_update_result');
  late final _data_control_provider_send_update_result =
      _data_control_provider_send_update_resultPtr
          .asFunction<int Function(int)>();

  /// @brief Sends the success result of the delete request to the client application.
  /// @since_tizen 2.3
  ///
  /// @param[in] request_id The request ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_send_delete_result(
    int request_id,
  ) {
    return _data_control_provider_send_delete_result(
      request_id,
    );
  }

  late final _data_control_provider_send_delete_resultPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'data_control_provider_send_delete_result');
  late final _data_control_provider_send_delete_result =
      _data_control_provider_send_delete_resultPtr
          .asFunction<int Function(int)>();

  /// @brief Sends the provider error message to the client application.
  /// @since_tizen 2.3
  ///
  /// @param[in] request_id The request ID
  /// @param[in] error The provider-defined error message
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_send_error(
    int request_id,
    ffi.Pointer<ffi.Char> error,
  ) {
    return _data_control_provider_send_error(
      request_id,
      error,
    );
  }

  late final _data_control_provider_send_errorPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Char>)>>(
      'data_control_provider_send_error');
  late final _data_control_provider_send_error =
      _data_control_provider_send_errorPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sends the success result of the request for setting, adding, and removing the key-value structured data to the client application.
  /// @since_tizen 2.3
  ///
  /// @param[in] request_id The request ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_send_map_result(
    int request_id,
  ) {
    return _data_control_provider_send_map_result(
      request_id,
    );
  }

  late final _data_control_provider_send_map_resultPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'data_control_provider_send_map_result');
  late final _data_control_provider_send_map_result =
      _data_control_provider_send_map_resultPtr.asFunction<int Function(int)>();

  /// @brief Sends the success result of the request for getting the value list to the client application.
  /// @since_tizen 2.3
  ///
  /// @param[in] request_id The request ID
  /// @param[in] value_list The result value list
  /// @param[in] value_count The number of the values
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_send_map_get_value_result(
    int request_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value_list,
    int value_count,
  ) {
    return _data_control_provider_send_map_get_value_result(
      request_id,
      value_list,
      value_count,
    );
  }

  late final _data_control_provider_send_map_get_value_resultPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Int)>>('data_control_provider_send_map_get_value_result');
  late final _data_control_provider_send_map_get_value_result =
      _data_control_provider_send_map_get_value_resultPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>, int)>();

  /// @brief Creates SQL INSERT statement.
  ///
  /// @since_tizen 2.3
  ///
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] provider The provider handle
  /// @param[in] insert_map The column-value pairs to insert
  ///
  /// @return The SQL INSERT statement on success,
  /// otherwise NULL
  /// @exception DATA_CONTROL_ERROR_NONE Success
  /// @exception DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  ffi.Pointer<ffi.Char> data_control_provider_create_insert_statement(
    data_control_h provider,
    ffi.Pointer<bundle> insert_map,
  ) {
    return _data_control_provider_create_insert_statement(
      provider,
      insert_map,
    );
  }

  late final _data_control_provider_create_insert_statementPtr = _lookup<
          ffi.NativeFunction<
              ffi.Pointer<ffi.Char> Function(
                  data_control_h, ffi.Pointer<bundle>)>>(
      'data_control_provider_create_insert_statement');
  late final _data_control_provider_create_insert_statement =
      _data_control_provider_create_insert_statementPtr.asFunction<
          ffi.Pointer<ffi.Char> Function(
              data_control_h, ffi.Pointer<bundle>)>();

  /// @brief Creates SQL DELETE statement.
  ///
  /// @since_tizen 2.3
  ///
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] provider The provider handle
  /// @param[in] where A filter to select the desired rows to delete \n
  /// Pass @c NULL if all rows need to be deleted
  ///
  /// @return The SQL DELETE statement on success,
  /// otherwise NULL
  /// @exception DATA_CONTROL_ERROR_NONE Success
  /// @exception DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  ffi.Pointer<ffi.Char> data_control_provider_create_delete_statement(
    data_control_h provider,
    ffi.Pointer<ffi.Char> where,
  ) {
    return _data_control_provider_create_delete_statement(
      provider,
      where,
    );
  }

  late final _data_control_provider_create_delete_statementPtr = _lookup<
          ffi.NativeFunction<
              ffi.Pointer<ffi.Char> Function(
                  data_control_h, ffi.Pointer<ffi.Char>)>>(
      'data_control_provider_create_delete_statement');
  late final _data_control_provider_create_delete_statement =
      _data_control_provider_create_delete_statementPtr.asFunction<
          ffi.Pointer<ffi.Char> Function(
              data_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Creates SQL UPDATE statement.
  ///
  /// @since_tizen 2.3
  ///
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] provider The provider handle
  /// @param[in] update_map The column-value pairs to update
  /// @param[in] where A filter to select the desired rows to update
  ///
  /// @return The SQL UPDATE statement on success,
  /// otherwise NULL
  /// @exception DATA_CONTROL_ERROR_NONE Success
  /// @exception DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  ffi.Pointer<ffi.Char> data_control_provider_create_update_statement(
    data_control_h provider,
    ffi.Pointer<bundle> update_map,
    ffi.Pointer<ffi.Char> where,
  ) {
    return _data_control_provider_create_update_statement(
      provider,
      update_map,
      where,
    );
  }

  late final _data_control_provider_create_update_statementPtr = _lookup<
          ffi.NativeFunction<
              ffi.Pointer<ffi.Char> Function(
                  data_control_h, ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>)>>(
      'data_control_provider_create_update_statement');
  late final _data_control_provider_create_update_statement =
      _data_control_provider_create_update_statementPtr.asFunction<
          ffi.Pointer<ffi.Char> Function(
              data_control_h, ffi.Pointer<bundle>, ffi.Pointer<ffi.Char>)>();

  /// @brief Creates SQL SELECT statement.
  ///
  /// @since_tizen 2.3
  ///
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] provider The provider handle
  /// @param[in] column_list The column names to query \n
  /// Pass @c NULL if all columns need to be selected
  /// @param[in] column_count The total number of columns to be queried
  /// @param[in] where A filter to select the desired rows
  /// @param[in] order The sorting order of rows to query
  ///
  /// @return The SQL SELECT statement on success,
  /// otherwise NULL
  /// @exception DATA_CONTROL_ERROR_NONE Success
  /// @exception DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  ffi.Pointer<ffi.Char> data_control_provider_create_select_statement(
    data_control_h provider,
    ffi.Pointer<ffi.Pointer<ffi.Char>> column_list,
    int column_count,
    ffi.Pointer<ffi.Char> where,
    ffi.Pointer<ffi.Char> order,
  ) {
    return _data_control_provider_create_select_statement(
      provider,
      column_list,
      column_count,
      where,
      order,
    );
  }

  late final _data_control_provider_create_select_statementPtr = _lookup<
          ffi.NativeFunction<
              ffi.Pointer<ffi.Char> Function(
                  data_control_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>,
                  ffi.Int,
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>)>>(
      'data_control_provider_create_select_statement');
  late final _data_control_provider_create_select_statement =
      _data_control_provider_create_select_statementPtr.asFunction<
          ffi.Pointer<ffi.Char> Function(
              data_control_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              int,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief Checks whether the given provider ID matches the provider handle's provider ID.
  ///
  /// @since_tizen 2.3
  ///
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] provider The provider handle
  /// @param[in] provider_id The provider ID to be compared with handle's provider ID
  ///
  /// @return @c true if the provider_id matches,
  /// otherwise @c false if it does not match
  /// @exception DATA_CONTROL_ERROR_NONE Success
  /// @exception DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  bool data_control_provider_match_provider_id(
    data_control_h provider,
    ffi.Pointer<ffi.Char> provider_id,
  ) {
    return _data_control_provider_match_provider_id(
      provider,
      provider_id,
    );
  }

  late final _data_control_provider_match_provider_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Bool Function(data_control_h, ffi.Pointer<ffi.Char>)>>(
      'data_control_provider_match_provider_id');
  late final _data_control_provider_match_provider_id =
      _data_control_provider_match_provider_idPtr
          .asFunction<bool Function(data_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Checks whether the given data ID matches the provider handle's data ID.
  ///
  /// @since_tizen 2.3
  ///
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] provider The provider handle
  /// @param[in] data_id The data ID to be compared with handle's data ID
  ///
  /// @return @c true if the @a data_id matches,
  /// otherwise @c false if it does not match
  /// @exception DATA_CONTROL_ERROR_NONE Success
  /// @exception DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  bool data_control_provider_match_data_id(
    data_control_h provider,
    ffi.Pointer<ffi.Char> data_id,
  ) {
    return _data_control_provider_match_data_id(
      provider,
      data_id,
    );
  }

  late final _data_control_provider_match_data_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Bool Function(data_control_h,
              ffi.Pointer<ffi.Char>)>>('data_control_provider_match_data_id');
  late final _data_control_provider_match_data_id =
      _data_control_provider_match_data_idPtr
          .asFunction<bool Function(data_control_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sends a data change notification to consumer applications which have successfully added a data change callback.
  /// @details If the function is successful, data_control_data_change_cb() callback will be called under certain conditions.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing
  ///
  /// @param[in] provider Target provider handle
  /// @param[in] type Changed data type
  /// @param[in] data Customized information about changed data
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre The consumer should call data_control_add_data_change_cb() to receive data change notifications
  /// @see data_control_data_change_cb()
  /// @see data_control_add_data_change_cb()
  int data_control_provider_send_data_change_noti(
    data_control_h provider,
    int type,
    ffi.Pointer<bundle> data,
  ) {
    return _data_control_provider_send_data_change_noti(
      provider,
      type,
      data,
    );
  }

  late final _data_control_provider_send_data_change_notiPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  data_control_h, ffi.Int32, ffi.Pointer<bundle>)>>(
      'data_control_provider_send_data_change_noti');
  late final _data_control_provider_send_data_change_noti =
      _data_control_provider_send_data_change_notiPtr
          .asFunction<int Function(data_control_h, int, ffi.Pointer<bundle>)>();

  /// @brief Adds a consumer filter for the data changed callback addition process.
  /// @since_tizen 3.0
  /// @remarks If the provider does not add any filters by calling this function, all requests to add a data change callback will be granted. \n
  /// If filters are added, and at least one filter returns false for a consumer application, the application will not be able to add data change callbacks.
  ///
  /// @param[in] callback Consumer filter callback, filtering consumers which try to add data changed callback
  /// @param[in] user_data The user data to be passed to the list_cb function
  /// @param[out] callback_id Added callback ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see data_control_provider_data_change_consumer_filter_cb()
  int data_control_provider_add_data_change_consumer_filter_cb(
    data_control_provider_data_change_consumer_filter_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> callback_id,
  ) {
    return _data_control_provider_add_data_change_consumer_filter_cb(
      callback,
      user_data,
      callback_id,
    );
  }

  late final _data_control_provider_add_data_change_consumer_filter_cbPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      data_control_provider_data_change_consumer_filter_cb,
                      ffi.Pointer<ffi.Void>,
                      ffi.Pointer<ffi.Int>)>>(
          'data_control_provider_add_data_change_consumer_filter_cb');
  late final _data_control_provider_add_data_change_consumer_filter_cb =
      _data_control_provider_add_data_change_consumer_filter_cbPtr.asFunction<
          int Function(data_control_provider_data_change_consumer_filter_cb,
              ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Int>)>();

  /// @brief Removes a consumer filter for the data changed callback addition process.
  /// @since_tizen 3.0
  ///
  /// @param[in] callback_id Target callback ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_remove_data_change_consumer_filter_cb(
    int callback_id,
  ) {
    return _data_control_provider_remove_data_change_consumer_filter_cb(
      callback_id,
    );
  }

  late final _data_control_provider_remove_data_change_consumer_filter_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'data_control_provider_remove_data_change_consumer_filter_cb');
  late final _data_control_provider_remove_data_change_consumer_filter_cb =
      _data_control_provider_remove_data_change_consumer_filter_cbPtr
          .asFunction<int Function(int)>();

  /// @brief Retrieves ids of all applications which receive data change notifications from a given provider.
  /// @details This function calls data_control_provider_data_change_consumer_cb() once for each provider's notification target consumer id. \n
  /// If the data_control_provider_data_change_consumer_cb() callback function returns @c false, then iteration will be finished.
  /// @since_tizen 3.0
  ///
  /// @param[in] provider Target provider handle
  /// @param[in] list_cb The iteration callback function
  /// @param[in] user_data The user data to be passed to the list_cb function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post This function invokes data_control_provider_data_change_consumer_cb().
  /// @see data_control_provider_data_change_consumer_cb()
  int data_control_provider_foreach_data_change_consumer(
    data_control_h provider,
    data_control_provider_data_change_consumer_cb list_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_provider_foreach_data_change_consumer(
      provider,
      list_cb,
      user_data,
    );
  }

  late final _data_control_provider_foreach_data_change_consumerPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  data_control_h,
                  data_control_provider_data_change_consumer_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'data_control_provider_foreach_data_change_consumer');
  late final _data_control_provider_foreach_data_change_consumer =
      _data_control_provider_foreach_data_change_consumerPtr.asFunction<
          int Function(
              data_control_h,
              data_control_provider_data_change_consumer_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sends the result of the bulk insert request to the client application.
  /// @since_tizen 3.0
  ///
  /// @param[in] request_id The request ID
  /// @param[in] bulk_results The bulk add result for each data
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_send_bulk_insert_result(
    int request_id,
    data_control_bulk_result_data_h bulk_results,
  ) {
    return _data_control_provider_send_bulk_insert_result(
      request_id,
      bulk_results,
    );
  }

  late final _data_control_provider_send_bulk_insert_resultPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, data_control_bulk_result_data_h)>>(
      'data_control_provider_send_bulk_insert_result');
  late final _data_control_provider_send_bulk_insert_result =
      _data_control_provider_send_bulk_insert_resultPtr
          .asFunction<int Function(int, data_control_bulk_result_data_h)>();

  /// @brief Sends the result of the bulk add request to the client application.
  /// @since_tizen 3.0
  ///
  /// @param[in] request_id The request ID
  /// @param[in] bulk_results The bulk add result for each data
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  int data_control_provider_send_map_bulk_add_result(
    int request_id,
    data_control_bulk_result_data_h bulk_results,
  ) {
    return _data_control_provider_send_map_bulk_add_result(
      request_id,
      bulk_results,
    );
  }

  late final _data_control_provider_send_map_bulk_add_resultPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, data_control_bulk_result_data_h)>>(
      'data_control_provider_send_map_bulk_add_result');
  late final _data_control_provider_send_map_bulk_add_result =
      _data_control_provider_send_map_bulk_add_resultPtr
          .asFunction<int Function(int, data_control_bulk_result_data_h)>();

  /// @brief Registers a callback for the SQL bulk data request.
  /// @details The provider is notified when a data control request is received from the client applications.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing
  ///
  /// @param[in] callback  The callback function to be called when a data control request is received
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_provider_sql_register_insert_bulk_data_request_cb(
    data_control_provider_bulk_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_provider_sql_register_insert_bulk_data_request_cb(
      callback,
      user_data,
    );
  }

  late final _data_control_provider_sql_register_insert_bulk_data_request_cbPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      data_control_provider_bulk_cb, ffi.Pointer<ffi.Void>)>>(
          'data_control_provider_sql_register_insert_bulk_data_request_cb');
  late final _data_control_provider_sql_register_insert_bulk_data_request_cb =
      _data_control_provider_sql_register_insert_bulk_data_request_cbPtr
          .asFunction<
              int Function(
                  data_control_provider_bulk_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief  Unregisters the callback for the SQL bulk data request.
  /// @since_tizen 3.0
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @see data_control_provider_sql_register_insert_bulk_data_request_cb()
  int data_control_provider_sql_unregister_insert_bulk_data_request_cb() {
    return _data_control_provider_sql_unregister_insert_bulk_data_request_cb();
  }

  late final _data_control_provider_sql_unregister_insert_bulk_data_request_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'data_control_provider_sql_unregister_insert_bulk_data_request_cb');
  late final _data_control_provider_sql_unregister_insert_bulk_data_request_cb =
      _data_control_provider_sql_unregister_insert_bulk_data_request_cbPtr
          .asFunction<int Function()>();

  /// @brief  Registers a callback for the MAP bulk data request.
  /// @details	The provider is notified when a data control request is received from the client applications.
  /// @since_tizen 3.0
  /// @privlevel   public
  /// @privilege   %http://tizen.org/privilege/datasharing
  ///
  /// @param[in]  callback  The callback function to be called when a data control request is received
  /// @param[in]  user_data The user data to be passed to the callback function
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE              Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_provider_map_register_add_bulk_data_request_cb(
    data_control_provider_bulk_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _data_control_provider_map_register_add_bulk_data_request_cb(
      callback,
      user_data,
    );
  }

  late final _data_control_provider_map_register_add_bulk_data_request_cbPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      data_control_provider_bulk_cb, ffi.Pointer<ffi.Void>)>>(
          'data_control_provider_map_register_add_bulk_data_request_cb');
  late final _data_control_provider_map_register_add_bulk_data_request_cb =
      _data_control_provider_map_register_add_bulk_data_request_cbPtr
          .asFunction<
              int Function(
                  data_control_provider_bulk_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief  Unregisters the callback for the MAP bulk data request.
  /// @since_tizen 3.0
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @see data_control_provider_map_register_add_bulk_data_request_cb()
  int data_control_provider_map_unregister_add_bulk_data_request_cb() {
    return _data_control_provider_map_unregister_add_bulk_data_request_cb();
  }

  late final _data_control_provider_map_unregister_add_bulk_data_request_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'data_control_provider_map_unregister_add_bulk_data_request_cb');
  late final _data_control_provider_map_unregister_add_bulk_data_request_cb =
      _data_control_provider_map_unregister_add_bulk_data_request_cbPtr
          .asFunction<int Function()>();

  /// @brief Asynchronously adds a data changed callback, which is called whenever the provider's data is changed.
  /// @details The function attempts to add the callback asynchronously and calls result_callback to inform about the result of the attempt. \n
  /// If the function is successful, result_callback will be called. \n
  /// The provider will call any filters which were added for the callback addition process.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  /// @remarks If you want to use this function, you must add privileges.
  /// @param[in] provider  Target provider handle
  /// @param[in] callback  The callback function to be called when consumer receives data change notification
  /// @param[in] user_data The user data to be passed to the callback function
  /// @param[in] result_callback The callback function to be called when consumer receives add data change callback process result
  /// @param[in] result_cb_user_data The user data to be passed to the result_callback function
  /// @param[out] callback_id Added callback ID, it can be used to remove the callback
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  /// @see data_control_data_change_cb()
  /// @see data_control_add_callback_result_cb()
  /// @see data_control_provider_add_data_change_consumer_filter_cb()
  int data_control_add_data_change_cb(
    data_control_h provider,
    data_control_data_change_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    data_control_add_callback_result_cb result_callback,
    ffi.Pointer<ffi.Void> result_cb_user_data,
    ffi.Pointer<ffi.Int> callback_id,
  ) {
    return _data_control_add_data_change_cb(
      provider,
      callback,
      user_data,
      result_callback,
      result_cb_user_data,
      callback_id,
    );
  }

  late final _data_control_add_data_change_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              data_control_h,
              data_control_data_change_cb,
              ffi.Pointer<ffi.Void>,
              data_control_add_callback_result_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('data_control_add_data_change_cb');
  late final _data_control_add_data_change_cb =
      _data_control_add_data_change_cbPtr.asFunction<
          int Function(
              data_control_h,
              data_control_data_change_cb,
              ffi.Pointer<ffi.Void>,
              data_control_add_callback_result_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Removes data change callback function.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/datasharing \n
  /// %http://tizen.org/privilege/appmanager.launch
  /// @remarks If you want to use this function, you must add privileges.
  /// @param[in] provider Target provider handle
  /// @param[in] callback_id Target callback ID
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DATA_CONTROL_ERROR_NONE Successful
  /// @retval #DATA_CONTROL_ERROR_IO_ERROR I/O error
  /// @retval #DATA_CONTROL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DATA_CONTROL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DATA_CONTROL_ERROR_PERMISSION_DENIED Permission denied
  int data_control_remove_data_change_cb(
    data_control_h provider,
    int callback_id,
  ) {
    return _data_control_remove_data_change_cb(
      provider,
      callback_id,
    );
  }

  late final _data_control_remove_data_change_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(data_control_h, ffi.Int)>>(
          'data_control_remove_data_change_cb');
  late final _data_control_remove_data_change_cb =
      _data_control_remove_data_change_cbPtr
          .asFunction<int Function(data_control_h, int)>();

  /// @brief Registers the local message port.
  /// @details If the message port name is already registered, the previous local message port ID returns and the callback function is changed. \n
  /// Multiple message ports can be registered.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specified callback is called only in the main thread.
  /// @param[in] local_port The name of the local message port
  /// @param[in] callback The callback function to be called when a message is received
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return A local message port ID on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER The specified @a local_port or @a callback is NULL
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval MESSAGE_PORT_ERROR_IO_ERROR Internal I/O error
  /// @see message_port_unregister_local_port()
  int message_port_register_local_port(
    ffi.Pointer<ffi.Char> local_port,
    message_port_message_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _message_port_register_local_port(
      local_port,
      callback,
      user_data,
    );
  }

  late final _message_port_register_local_portPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, message_port_message_cb,
              ffi.Pointer<ffi.Void>)>>('message_port_register_local_port');
  late final _message_port_register_local_port =
      _message_port_register_local_portPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, message_port_message_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Registers the trusted local message port.
  /// @details If the message port name is already registered, the previous local message port ID returns and the callback function is changed. @n
  /// It allows communications only if the applications are signed with the same certificate, which is uniquely assigned to the developer. @n
  /// Multiple message ports can be registered.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specified callback is called only in the main thread.
  /// @param[in] trusted_local_port The name of the trusted local message port
  /// @param[in] callback The callback function to be called when a trusted message is received
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return A trusted local message port ID on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER The specified @a trusted_local_port or @a callback is NULL
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR	Internal I/O error
  /// @see message_port_unregister_trusted_local_port()
  int message_port_register_trusted_local_port(
    ffi.Pointer<ffi.Char> trusted_local_port,
    message_port_trusted_message_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _message_port_register_trusted_local_port(
      trusted_local_port,
      callback,
      user_data,
    );
  }

  late final _message_port_register_trusted_local_portPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>,
                  message_port_trusted_message_cb, ffi.Pointer<ffi.Void>)>>(
      'message_port_register_trusted_local_port');
  late final _message_port_register_trusted_local_port =
      _message_port_register_trusted_local_portPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, message_port_trusted_message_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the local message port.
  /// @details This method unregisters the callback function with the specified local port ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] local_port_id	The local message port ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_NONE	Successful
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER The specified @a local_port_id is not positive
  /// @retval #MESSAGE_PORT_ERROR_PORT_NOT_FOUND The specified @a local_port_id cannot be found
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR	Internal I/O error
  /// @see message_port_register_local_port()
  int message_port_unregister_local_port(
    int local_port_id,
  ) {
    return _message_port_unregister_local_port(
      local_port_id,
    );
  }

  late final _message_port_unregister_local_portPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'message_port_unregister_local_port');
  late final _message_port_unregister_local_port =
      _message_port_unregister_local_portPtr.asFunction<int Function(int)>();

  /// @brief Registers the trusted local message port.
  /// @details This method unregisters the callback function with the specified local port ID. @n
  /// It allows communications only if the applications are signed with the same certificate, which is uniquely assigned to the developer.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] trusted_local_port_id	The trusted local message port ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_NONE	Successful
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER The specified @a trusted_local_port_id is not positive
  /// @retval #MESSAGE_PORT_ERROR_PORT_NOT_FOUND The specified @a trusted_local_port_id cannot be found
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR Internal I/O error
  /// @see message_port_register_trusted_local_port()
  int message_port_unregister_trusted_local_port(
    int trusted_local_port_id,
  ) {
    return _message_port_unregister_trusted_local_port(
      trusted_local_port_id,
    );
  }

  late final _message_port_unregister_trusted_local_portPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'message_port_unregister_trusted_local_port');
  late final _message_port_unregister_trusted_local_port =
      _message_port_unregister_trusted_local_portPtr
          .asFunction<int Function(int)>();

  /// @brief Checks whether the message port of a remote application is registered.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If this function returns a negative error value, the out parameter @a exist will not be changed.
  /// @param[in] remote_app_id The ID of the remote application
  /// @param[in] remote_port The name of the remote message port
  /// @param[out] exist If @c true, the message port of the remote application exists;
  /// otherwise @c false
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_NONE	Successful
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER The specified @a remote_app_id or @a remote_port is NULL
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR Internal I/O error
  int message_port_check_remote_port(
    ffi.Pointer<ffi.Char> remote_app_id,
    ffi.Pointer<ffi.Char> remote_port,
    ffi.Pointer<ffi.Bool> exist,
  ) {
    return _message_port_check_remote_port(
      remote_app_id,
      remote_port,
      exist,
    );
  }

  late final _message_port_check_remote_portPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('message_port_check_remote_port');
  late final _message_port_check_remote_port =
      _message_port_check_remote_portPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the trusted message port of a remote application is registered.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks	If this function returns a negative error value, the out parameter @a exist will not be changed.
  /// @param[in] remote_app_id The ID of the remote application
  /// @param[in] remote_port The name of the remote message port
  /// @param[out] exist If @c true, the message port of the remote application exists;
  /// otherwise @c false
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_NONE Successful
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER The specified @a remote_app_id or @a remote_port is @c NULL
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGE_PORT_ERROR_CERTIFICATE_NOT_MATCH The remote application is not signed with the same certificate
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR Internal I/O error
  int message_port_check_trusted_remote_port(
    ffi.Pointer<ffi.Char> remote_app_id,
    ffi.Pointer<ffi.Char> remote_port,
    ffi.Pointer<ffi.Bool> exist,
  ) {
    return _message_port_check_trusted_remote_port(
      remote_app_id,
      remote_port,
      exist,
    );
  }

  late final _message_port_check_trusted_remote_portPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Bool>)>>(
      'message_port_check_trusted_remote_port');
  late final _message_port_check_trusted_remote_port =
      _message_port_check_trusted_remote_portPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>();

  /// @brief Sends a message to the message port of a remote application.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks @a message must be released with bundle_free() after sending the message.
  /// @param[in] remote_app_id The ID of the remote application
  /// @param[in] remote_port The name of the remote message port
  /// @param[in] message The message to be passed to the remote application, the recommended message size is under 4KB
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_NONE Successful
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER The specified @a remote_app_id, @a remote_port or @a message is NULL
  /// @retval #MESSAGE_PORT_ERROR_PORT_NOT_FOUND The message port of the remote application cannot be found
  /// @retval #MESSAGE_PORT_ERROR_MAX_EXCEEDED The size of message has exceeded the maximum limit
  /// @retval #MESSAGE_PORT_ERROR_RESOURCE_UNAVAILABLE Resource temporarily unavailable
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR Internal I/O error
  /// @post It invokes message_port_message_cb() on the remote application.
  /// @see message_port_message_cb()
  /// @see message_port_register_local_port()
  /// @see message_port_unregister_local_port()
  ///
  /// @code
  /// #include <message_port.h>
  /// bundle *b = bundle_create();
  /// bundle_add(b, "key1", "value1");
  /// bundle_add(b, "key2", "value2");
  /// int ret = message_port_send_message("0123456789.BasicApp", "BasicAppPort", b);
  /// bundle_free(b);
  /// @endcode
  int message_port_send_message(
    ffi.Pointer<ffi.Char> remote_app_id,
    ffi.Pointer<ffi.Char> remote_port,
    ffi.Pointer<bundle> message,
  ) {
    return _message_port_send_message(
      remote_app_id,
      remote_port,
      message,
    );
  }

  late final _message_port_send_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>)>>('message_port_send_message');
  late final _message_port_send_message =
      _message_port_send_messagePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>)>();

  /// @brief Sends a trusted message to the message port of a remote application.
  /// @details This method allows communication only if the applications are signed with the same certificate, which is uniquely assigned to the developer.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a message using bundle_free() after sending the message.
  /// @param[in] remote_app_id The ID of the remote application
  /// @param[in] remote_port The name of the remote message port
  /// @param[in] message The message to be passed to the remote application, the recommended message size is under 4KB
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_NONE Successful
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER The specified @a remote_app_id, @a remote_port or @a message is @c NULL
  /// @retval #MESSAGE_PORT_ERROR_PORT_NOT_FOUND The message port of the remote application cannot be found
  /// @retval #MESSAGE_PORT_ERROR_CERTIFICATE_NOT_MATCH The remote application is not signed with the same certificate
  /// @retval #MESSAGE_PORT_ERROR_MAX_EXCEEDED The size of the message has exceeded the maximum limit
  /// @retval #MESSAGE_PORT_ERROR_RESOURCE_UNAVAILABLE Resource is temporarily unavailable
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR Internal I/O error
  /// @post It invokes message_port_trusted_message_cb() on the remote application.
  /// @see message_port_trusted_message_cb()
  /// @see message_port_register_trusted_local_port()
  /// @see message_port_unregister_trusted_local_port()
  int message_port_send_trusted_message(
    ffi.Pointer<ffi.Char> remote_app_id,
    ffi.Pointer<ffi.Char> remote_port,
    ffi.Pointer<bundle> message,
  ) {
    return _message_port_send_trusted_message(
      remote_app_id,
      remote_port,
      message,
    );
  }

  late final _message_port_send_trusted_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>)>>('message_port_send_trusted_message');
  late final _message_port_send_trusted_message =
      _message_port_send_trusted_messagePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>)>();

  /// @brief Sends a message with local port information to the message port of a remote application.
  /// @details This method is used for bidirectional communication.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a message using bundle_free() after sending the message.
  /// @param[in] remote_app_id The ID of the remote application
  /// @param[in] remote_port The name of the remote message port
  /// @param[in] message The message to be passed to the remote application, the recommended message size is under 4KB
  /// @param[in] local_port_id The message port ID returned by message_port_register_local_port() or message_port_register_trusted_local_port()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_NONE Successful
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER The specified @a remote_app_id, @a remote_port or @a message is @c NULL and
  /// The specified @a local_port_id is not positive
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGE_PORT_ERROR_PORT_NOT_FOUND The port of the local or remote application cannot be found
  /// @retval #MESSAGE_PORT_ERROR_MAX_EXCEEDED The size of the message has exceeded the maximum limit
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR Internal I/O error
  /// @post It invokes message_port_message_cb() on the remote application.
  /// @see message_port_message_cb()
  /// @see message_port_register_local_port()
  /// @see message_port_unregister_local_port()
  ///
  /// @code
  /// #include <message_port.h>
  ///
  /// static void message_port_receive_cb(int local_port_id, const char *remote_app_id, const char *remote_port, bundle *message) {}
  ///
  /// int
  /// main(int argc, char *argv[])
  /// {
  /// bundle *b = bundle_create();
  /// bundle_add(b, "key1", "value1");
  /// bundle_add(b, "key2", "value2");
  ///
  /// int local_port_id = message_port_register_local_port("HelloPort", message_port_receive_cb);
  ///
  /// int ret = message_port_send_message_with_local_port("0123456789.BasicApp", "BasicAppPort", b, local_port_id);
  ///
  /// bundle_free(b);
  /// }
  /// @endcode
  int message_port_send_message_with_local_port(
    ffi.Pointer<ffi.Char> remote_app_id,
    ffi.Pointer<ffi.Char> remote_port,
    ffi.Pointer<bundle> message,
    int local_port_id,
  ) {
    return _message_port_send_message_with_local_port(
      remote_app_id,
      remote_port,
      message,
      local_port_id,
    );
  }

  late final _message_port_send_message_with_local_portPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>,
              ffi.Int)>>('message_port_send_message_with_local_port');
  late final _message_port_send_message_with_local_port =
      _message_port_send_message_with_local_portPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>, int)>();

  /// @brief Sends a trusted message with local port information to the message port of a remote application.
  /// @details This method is used for bidirectional communication. @n
  /// It allows communications only if the applications are signed with the same certificate, which is uniquely assigned to the developer.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You muse release @a message using bundle_free() after sending the message.
  /// @param[in] remote_app_id The ID of the remote application
  /// @param[in] remote_port The name of the remote message port
  /// @param[in] message The message to be passed to the remote application, the recommended message size is under 4KB
  /// @param[in] local_port_id	The message port ID returned by message_port_register_local_port() or message_port_register_trusted_local_port()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_NONE	Successful
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER The specified @a remote_app_id, @a remote_port or @a message is @c NULL and
  /// specified @a local_port_id is not positive
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGE_PORT_ERROR_PORT_NOT_FOUND The port of the local or remote application cannot be found
  /// @retval #MESSAGE_PORT_ERROR_CERTIFICATE_NOT_MATCH The remote application is not signed with the same certificate
  /// @retval #MESSAGE_PORT_ERROR_MAX_EXCEEDED The size of the message has exceeded the maximum limit
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR Internal I/O error
  /// @post It invokes message_port_trusted_message_cb() on the remote application.
  /// @see message_port_trusted_message_cb()
  /// @see message_port_register_trusted_local_port()
  /// @see message_port_unregister_trusted_local_port()
  int message_port_send_trusted_message_with_local_port(
    ffi.Pointer<ffi.Char> remote_app_id,
    ffi.Pointer<ffi.Char> remote_port,
    ffi.Pointer<bundle> message,
    int local_port_id,
  ) {
    return _message_port_send_trusted_message_with_local_port(
      remote_app_id,
      remote_port,
      message,
      local_port_id,
    );
  }

  late final _message_port_send_trusted_message_with_local_portPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>,
              ffi.Int)>>('message_port_send_trusted_message_with_local_port');
  late final _message_port_send_trusted_message_with_local_port =
      _message_port_send_trusted_message_with_local_portPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>, int)>();

  /// @brief Adds a callback called when a remote port is registered.
  /// @details When remote port is registered, @a registered_cb function is called.
  /// Each added callback has its own separate watcher.
  /// @since_tizen 4.0
  /// @remarks The specified callback is called only in the main thread.
  /// @param[in] remote_app_id        The ID of the remote application
  /// @param[in] remote_port          The name of the remote message port
  /// @param[in] trusted_remote_port  Indicates whether remote port is trusted
  /// @param[in] registered_cb        The callback function to be called
  /// when remote port is registered
  /// @param[in] user_data            The user data to be passed to the callback function
  /// @param[out] watcher_id          The ID of the watcher which is monitoring the remote port
  /// registration events
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER  The specified @a remote_app_id or @a remote_port
  /// or @a registered_cb is NULL
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR          Internal I/O error
  /// @see message_port_registration_event_cb()
  /// @see message_port_add_unregistered_cb()
  /// @see message_port_remove_registration_event_cb()
  int message_port_add_registered_cb(
    ffi.Pointer<ffi.Char> remote_app_id,
    ffi.Pointer<ffi.Char> remote_port,
    bool trusted_remote_port,
    message_port_registration_event_cb registered_cb,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> watcher_id,
  ) {
    return _message_port_add_registered_cb(
      remote_app_id,
      remote_port,
      trusted_remote_port,
      registered_cb,
      user_data,
      watcher_id,
    );
  }

  late final _message_port_add_registered_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Bool,
              message_port_registration_event_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('message_port_add_registered_cb');
  late final _message_port_add_registered_cb =
      _message_port_add_registered_cbPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              bool,
              message_port_registration_event_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Adds a callback called when a remote port is unregistered.
  /// @details When the remote port is unregistered, @a unregistered_cb function is called.
  /// Each added callback has its own separate watcher.
  /// @remarks The specified callback is called only in the main thread.
  /// @since_tizen 4.0
  /// @param[in] remote_app_id        The ID of the remote application
  /// @param[in] remote_port          The name of the remote message port
  /// @param[in] trusted_remote_port  Indicates whether remote port is trusted
  /// @param[in] unregistered_cb      The callback function to be called
  /// when remote port is unregistered
  /// @param[in] user_data            The user data to be passed to the callback function
  /// @param[out] watcher_id          The ID of the watcher which is monitoring the remote port
  /// unregistration events
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER  The specified @a remote_app_id or @a remote_port
  /// or @a unregistered_cb is NULL
  /// @retval #MESSAGE_PORT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR          Internal I/O error
  /// @see message_port_registration_event_cb()
  /// @see message_port_add_registered_cb()
  /// @see message_port_remove_registration_event_cb()
  int message_port_add_unregistered_cb(
    ffi.Pointer<ffi.Char> remote_app_id,
    ffi.Pointer<ffi.Char> remote_port,
    bool trusted_remote_port,
    message_port_registration_event_cb unregistered_cb,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> watcher_id,
  ) {
    return _message_port_add_unregistered_cb(
      remote_app_id,
      remote_port,
      trusted_remote_port,
      unregistered_cb,
      user_data,
      watcher_id,
    );
  }

  late final _message_port_add_unregistered_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Bool,
              message_port_registration_event_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('message_port_add_unregistered_cb');
  late final _message_port_add_unregistered_cb =
      _message_port_add_unregistered_cbPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              bool,
              message_port_registration_event_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Removes the registration/unregistration callback associated with the given watcher.
  /// @since_tizen 4.0
  /// @param[in] watcher_id  The ID of watcher which is monitoring remote port
  /// registration/unregistration events
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGE_PORT_ERROR_INVALID_PARAMETER  The specified @a watcher_id is not correct
  /// @retval #MESSAGE_PORT_ERROR_IO_ERROR           Internal I/O error
  /// @see message_port_registration_event_cb()
  /// @see message_port_add_registered_cb()
  /// @see message_port_add_unregistered_cb()
  int message_port_remove_registration_event_cb(
    int watcher_id,
  ) {
    return _message_port_remove_registration_event_cb(
      watcher_id,
    );
  }

  late final _message_port_remove_registration_event_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'message_port_remove_registration_event_cb');
  late final _message_port_remove_registration_event_cb =
      _message_port_remove_registration_event_cbPtr
          .asFunction<int Function(int)>();

  /// @brief Retrieves all application IDs of each package.
  /// @since_tizen 2.3
  /// @param[in] package_info  The package info handle
  /// @param[in] comp_type     The application component type
  /// @param[in] callback      The callback function to invoke
  /// @param[in] user_data     The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_NO_SUCH_PACKAGE   No such package
  /// @post This function invokes package_info_app_cb() repeatedly for each package.
  /// @see package_info_app_cb()
  int package_info_foreach_app_from_package(
    package_info_h package_info,
    int comp_type,
    package_info_app_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _package_info_foreach_app_from_package(
      package_info,
      comp_type,
      callback,
      user_data,
    );
  }

  late final _package_info_foreach_app_from_packagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h, ffi.Int32, package_info_app_cb,
              ffi.Pointer<ffi.Void>)>>('package_info_foreach_app_from_package');
  late final _package_info_foreach_app_from_package =
      _package_info_foreach_app_from_packagePtr.asFunction<
          int Function(package_info_h, int, package_info_app_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Destroys the package information handle and releases all its resources.
  /// @since_tizen 2.3
  /// @param[in] package_info The package information handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_manager_foreach_package_info()
  /// @see package_manager_get_package_info()
  int package_info_destroy(
    package_info_h package_info,
  ) {
    return _package_info_destroy(
      package_info,
    );
  }

  late final _package_info_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(package_info_h)>>(
          'package_info_destroy');
  late final _package_info_destroy =
      _package_info_destroyPtr.asFunction<int Function(package_info_h)>();

  /// @brief Gets the package name.
  /// @since_tizen 2.3
  /// @remarks You must release @a package using free().
  /// @param[in]  package_info The package information
  /// @param[out] package      The package name
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  int package_info_get_package(
    package_info_h package_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> package,
  ) {
    return _package_info_get_package(
      package_info,
      package,
    );
  }

  late final _package_info_get_packagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('package_info_get_package');
  late final _package_info_get_package =
      _package_info_get_packagePtr.asFunction<
          int Function(package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the main application ID of the package.
  /// @since_tizen 4.0
  /// @remarks You must release @a main_app_id using free().
  /// @param[in]  package_info     The package information
  /// @param[out] main_app_id      The main application ID of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_get_main_app_id(
    package_info_h package_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> main_app_id,
  ) {
    return _package_info_get_main_app_id(
      package_info,
      main_app_id,
    );
  }

  late final _package_info_get_main_app_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_info_get_main_app_id');
  late final _package_info_get_main_app_id =
      _package_info_get_main_app_idPtr.asFunction<
          int Function(package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the label of the package.
  /// @since_tizen 2.3
  /// @remarks You must release @a label using free().
  /// @param[in]  package_info The package information
  /// @param[out] label        The label of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_get_label(
    package_info_h package_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> label,
  ) {
    return _package_info_get_label(
      package_info,
      label,
    );
  }

  late final _package_info_get_labelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('package_info_get_label');
  late final _package_info_get_label = _package_info_get_labelPtr.asFunction<
      int Function(package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the absolute path to the icon image.
  /// @since_tizen 2.3
  /// @remarks You must release @a path using free().
  /// @param[in]  package_info The package information
  /// @param[out] path         The path of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_get_icon(
    package_info_h package_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _package_info_get_icon(
      package_info,
      path,
    );
  }

  late final _package_info_get_iconPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('package_info_get_icon');
  late final _package_info_get_icon = _package_info_get_iconPtr.asFunction<
      int Function(package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the version of the package.
  /// @since_tizen 2.3
  /// @remarks You must release @a version using free().
  /// @param[in]  package_info The package information
  /// @param[out] version      The version of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_get_version(
    package_info_h package_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> version,
  ) {
    return _package_info_get_version(
      package_info,
      version,
    );
  }

  late final _package_info_get_versionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('package_info_get_version');
  late final _package_info_get_version =
      _package_info_get_versionPtr.asFunction<
          int Function(package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the type of the package.
  /// @since_tizen 2.3
  /// @remarks You must release @a type using free().
  /// @param[in]  package_info The package information
  /// @param[out] type         The type of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_get_type(
    package_info_h package_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> type,
  ) {
    return _package_info_get_type(
      package_info,
      type,
    );
  }

  late final _package_info_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('package_info_get_type');
  late final _package_info_get_type = _package_info_get_typePtr.asFunction<
      int Function(package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the installed storage for the given package.
  /// @since_tizen 2.3
  /// @param[in]  package_info The package information
  /// @param[out] storage      The installed storage
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  int package_info_get_installed_storage(
    package_info_h package_info,
    ffi.Pointer<ffi.Int32> storage,
  ) {
    return _package_info_get_installed_storage(
      package_info,
      storage,
    );
  }

  late final _package_info_get_installed_storagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Int32>)>>('package_info_get_installed_storage');
  late final _package_info_get_installed_storage =
      _package_info_get_installed_storagePtr
          .asFunction<int Function(package_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the root path of the package.
  /// @since_tizen 2.3
  /// @remarks You must release @a path using free().
  /// @param[in]  package_info The package information
  /// @param[out] path         The root path of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_get_root_path(
    package_info_h package_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _package_info_get_root_path(
      package_info,
      path,
    );
  }

  late final _package_info_get_root_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_info_get_root_path');
  late final _package_info_get_root_path =
      _package_info_get_root_pathPtr.asFunction<
          int Function(package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @platform
  /// @brief Gets the name of the TEP(Tizen Expansion Package).
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @remarks Name must be released using free().
  /// @param[in] package_info The package information
  /// @param[out] name The name of the tep
  /// @return 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_SYSTEM_ERROR		 Severe system error
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_info_get_tep_name(
    package_info_h package_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _package_info_get_tep_name(
      package_info,
      name,
    );
  }

  late final _package_info_get_tep_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_info_get_tep_name');
  late final _package_info_get_tep_name =
      _package_info_get_tep_namePtr.asFunction<
          int Function(package_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Checks whether the package is system package.
  /// @since_tizen 2.3
  /// @param[in]  package_info The package information
  /// @param[out] system       @c true if the package is system package,
  /// otherwise @c false if the package is not system package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_is_system_package(
    package_info_h package_info,
    ffi.Pointer<ffi.Bool> system,
  ) {
    return _package_info_is_system_package(
      package_info,
      system,
    );
  }

  late final _package_info_is_system_packagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Bool>)>>('package_info_is_system_package');
  late final _package_info_is_system_package =
      _package_info_is_system_packagePtr
          .asFunction<int Function(package_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the package is removable.
  /// @since_tizen 2.3
  /// @param[in]  package_info The package information
  /// @param[out] removable    The removable info of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR IO error
  int package_info_is_removable_package(
    package_info_h package_info,
    ffi.Pointer<ffi.Bool> removable,
  ) {
    return _package_info_is_removable_package(
      package_info,
      removable,
    );
  }

  late final _package_info_is_removable_packagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Bool>)>>('package_info_is_removable_package');
  late final _package_info_is_removable_package =
      _package_info_is_removable_packagePtr
          .asFunction<int Function(package_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the package is preloaded.
  /// @since_tizen 2.3
  /// @param[in]  package_info The package information
  /// @param[out] preload      The preload info of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_is_preload_package(
    package_info_h package_info,
    ffi.Pointer<ffi.Bool> preload,
  ) {
    return _package_info_is_preload_package(
      package_info,
      preload,
    );
  }

  late final _package_info_is_preload_packagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Bool>)>>('package_info_is_preload_package');
  late final _package_info_is_preload_package =
      _package_info_is_preload_packagePtr
          .asFunction<int Function(package_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether two package information is equal.
  /// @since_tizen 2.3
  /// @param[in]  lhs    The first package information to be compared
  /// @param[in]  rhs    The second package information to be compared
  /// @param[out] equal  @c true if the package information are equal,
  /// otherwise @c false if package information are not equal
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Database error occurred
  int package_info_is_equal(
    package_info_h lhs,
    package_info_h rhs,
    ffi.Pointer<ffi.Bool> equal,
  ) {
    return _package_info_is_equal(
      lhs,
      rhs,
      equal,
    );
  }

  late final _package_info_is_equalPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h, package_info_h,
              ffi.Pointer<ffi.Bool>)>>('package_info_is_equal');
  late final _package_info_is_equal = _package_info_is_equalPtr.asFunction<
      int Function(package_info_h, package_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the package info is accessible for the given package.
  /// @since_tizen 2.3
  /// @param[in]  package_info The package information
  /// @param[out] accessible   @c true if the package info is accessible,
  /// otherwise @c false if the package info is not accessible
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  int package_info_is_accessible(
    package_info_h package_info,
    ffi.Pointer<ffi.Bool> accessible,
  ) {
    return _package_info_is_accessible(
      package_info,
      accessible,
    );
  }

  late final _package_info_is_accessiblePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Bool>)>>('package_info_is_accessible');
  late final _package_info_is_accessible = _package_info_is_accessiblePtr
      .asFunction<int Function(package_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the installed time for the given package.
  /// @details If the package was updated, the @a installed_time represents updated time.
  /// So, the meaning of 'installed time' corresponds with 'last modified time'.
  /// @since_tizen 4.0
  /// @param[in]  package_info   The package information
  /// @param[out] installed_time The integer value of time_t type for installed time
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Database error occurred
  int package_info_get_installed_time(
    package_info_h package_info,
    ffi.Pointer<ffi.Int> installed_time,
  ) {
    return _package_info_get_installed_time(
      package_info,
      installed_time,
    );
  }

  late final _package_info_get_installed_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h,
              ffi.Pointer<ffi.Int>)>>('package_info_get_installed_time');
  late final _package_info_get_installed_time =
      _package_info_get_installed_timePtr
          .asFunction<int Function(package_info_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Clones the package information handle.
  /// @since_tizen 2.3
  /// @param[out] clone          The newly created package information handle
  /// @param[in]  package_info   The package information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_NO_SUCH_PACKAGE   The package is not installed
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  int package_info_clone(
    ffi.Pointer<package_info_h> clone,
    package_info_h package_info,
  ) {
    return _package_info_clone(
      clone,
      package_info,
    );
  }

  late final _package_info_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<package_info_h>,
              package_info_h)>>('package_info_clone');
  late final _package_info_clone = _package_info_clonePtr
      .asFunction<int Function(ffi.Pointer<package_info_h>, package_info_h)>();

  /// @brief Gets the package information for the given package
  /// @since_tizen 2.3
  /// @remarks You must release @a package_info using package_info_destroy().
  /// @param[in]  package      The ID of the package
  /// @param[out] package_info The package information for the given package ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_NO_SUCH_PACKAGE   The package is not installed
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  int package_info_create(
    ffi.Pointer<ffi.Char> package,
    ffi.Pointer<package_info_h> package_info,
  ) {
    return _package_info_create(
      package,
      package_info,
    );
  }

  late final _package_info_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<package_info_h>)>>('package_info_create');
  late final _package_info_create = _package_info_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<package_info_h>)>();

  /// @brief Retrieves certification information of the package.
  /// @since_tizen 2.3
  /// @param[in] package_info The package information
  /// @param[in] callback     The iteration callback function
  /// @param[in] user_data    The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_foreach_cert_info(
    package_info_h package_info,
    package_info_cert_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _package_info_foreach_cert_info(
      package_info,
      callback,
      user_data,
    );
  }

  late final _package_info_foreach_cert_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h, package_info_cert_info_cb,
              ffi.Pointer<ffi.Void>)>>('package_info_foreach_cert_info');
  late final _package_info_foreach_cert_info =
      _package_info_foreach_cert_infoPtr.asFunction<
          int Function(package_info_h, package_info_cert_info_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves privilege information of the package.
  /// @since_tizen 2.3
  /// @param[in] package_info The package information
  /// @param[in] callback     The iteration callback function
  /// @param[in] user_data    The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_foreach_privilege_info(
    package_info_h package_info,
    package_info_privilege_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _package_info_foreach_privilege_info(
      package_info,
      callback,
      user_data,
    );
  }

  late final _package_info_foreach_privilege_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_h, package_info_privilege_info_cb,
              ffi.Pointer<ffi.Void>)>>('package_info_foreach_privilege_info');
  late final _package_info_foreach_privilege_info =
      _package_info_foreach_privilege_infoPtr.asFunction<
          int Function(package_info_h, package_info_privilege_info_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the package update information for the given package.
  /// @since_tizen 4.0
  /// @remarks You must release @a info using package_info_updateinfo_destroy().
  /// @param[in]  pkgid       The ID of the package
  /// @param[out] info        The package update information for the given package ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_NO_SUCH_PACKAGE   The package is not installed
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Database error occurred
  /// @see package_info_updateinfo_destroy()
  int package_info_updateinfo_create(
    ffi.Pointer<ffi.Char> pkgid,
    ffi.Pointer<package_updateinfo_h> info,
  ) {
    return _package_info_updateinfo_create(
      pkgid,
      info,
    );
  }

  late final _package_info_updateinfo_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<package_updateinfo_h>)>>(
      'package_info_updateinfo_create');
  late final _package_info_updateinfo_create =
      _package_info_updateinfo_createPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<package_updateinfo_h>)>();

  /// @brief Gets the package name.
  /// @since_tizen 4.0
  /// @remarks You must release @a package using free().
  /// @param[in]  info        The package update information
  /// @param[out] package     The package name
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Internal I/O error occured
  int package_info_updateinfo_get_pkgid(
    package_updateinfo_h info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> package,
  ) {
    return _package_info_updateinfo_get_pkgid(
      info,
      package,
    );
  }

  late final _package_info_updateinfo_get_pkgidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_updateinfo_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_info_updateinfo_get_pkgid');
  late final _package_info_updateinfo_get_pkgid =
      _package_info_updateinfo_get_pkgidPtr.asFunction<
          int Function(
              package_updateinfo_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the update version of package.
  /// @since_tizen 4.0
  /// @remarks You must release @a version using free().
  /// @param[in]  info        The package update information
  /// @param[out] version     The package update version
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Internal I/O error occured
  int package_info_updateinfo_get_version(
    package_updateinfo_h info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> version,
  ) {
    return _package_info_updateinfo_get_version(
      info,
      version,
    );
  }

  late final _package_info_updateinfo_get_versionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_updateinfo_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_info_updateinfo_get_version');
  late final _package_info_updateinfo_get_version =
      _package_info_updateinfo_get_versionPtr.asFunction<
          int Function(
              package_updateinfo_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the update type of package.
  /// @since_tizen 4.0
  /// @param[in]  info        The package update information
  /// @param[out] type        The package update type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Internal I/O error occured
  int package_info_updateinfo_get_type(
    package_updateinfo_h info,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _package_info_updateinfo_get_type(
      info,
      type,
    );
  }

  late final _package_info_updateinfo_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_updateinfo_h,
              ffi.Pointer<ffi.Int32>)>>('package_info_updateinfo_get_type');
  late final _package_info_updateinfo_get_type =
      _package_info_updateinfo_get_typePtr.asFunction<
          int Function(package_updateinfo_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Destroys the package update information handle and releases all its resources.
  /// @since_tizen 4.0
  /// @param[in] info         The package update information handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_info_updateinfo_create()
  int package_info_updateinfo_destroy(
    package_updateinfo_h info,
  ) {
    return _package_info_updateinfo_destroy(
      info,
    );
  }

  late final _package_info_updateinfo_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(package_updateinfo_h)>>(
          'package_info_updateinfo_destroy');
  late final _package_info_updateinfo_destroy =
      _package_info_updateinfo_destroyPtr
          .asFunction<int Function(package_updateinfo_h)>();

  /// @brief Retrieve update information of all packages and invoke callback for each of it.
  /// @since_tizen 4.0
  /// @param[in] callback     The iteration callback function
  /// @param[in] user_data    The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_info_updateinfo_foreach_info(
    package_info_updateinfo_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _package_info_updateinfo_foreach_info(
      callback,
      user_data,
    );
  }

  late final _package_info_updateinfo_foreach_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_info_updateinfo_cb,
              ffi.Pointer<ffi.Void>)>>('package_info_updateinfo_foreach_info');
  late final _package_info_updateinfo_foreach_info =
      _package_info_updateinfo_foreach_infoPtr.asFunction<
          int Function(package_info_updateinfo_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Creates a package manager handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @remarks You must release @a manager using package_manager_destroy().
  /// @param[out] manager The package manager handle that is newly created on success
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Internal I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @see package_manager_destroy()
  int package_manager_create(
    ffi.Pointer<package_manager_h> manager,
  ) {
    return _package_manager_create(
      manager,
    );
  }

  late final _package_manager_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<package_manager_h>)>>(
      'package_manager_create');
  late final _package_manager_create = _package_manager_createPtr
      .asFunction<int Function(ffi.Pointer<package_manager_h>)>();

  /// @brief Destroys the package manager handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] manager The package manager handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_manager_create()
  int package_manager_destroy(
    package_manager_h manager,
  ) {
    return _package_manager_destroy(
      manager,
    );
  }

  late final _package_manager_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(package_manager_h)>>(
          'package_manager_destroy');
  late final _package_manager_destroy =
      _package_manager_destroyPtr.asFunction<int Function(package_manager_h)>();

  /// @brief Sets the event status of the package when the package is installed, uninstalled, or updated.
  /// @details You can combine multiple status using OR operation which you want to listen.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param [in] manager     The package manager handle
  /// @param [in] status_type The status of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Internal I/O error
  /// @see package_manager_status_type_e
  /// @see package_manager_set_event_cb()
  int package_manager_set_event_status(
    package_manager_h manager,
    int status_type,
  ) {
    return _package_manager_set_event_status(
      manager,
      status_type,
    );
  }

  late final _package_manager_set_event_statusPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(package_manager_h, ffi.Int)>>(
          'package_manager_set_event_status');
  late final _package_manager_set_event_status =
      _package_manager_set_event_statusPtr
          .asFunction<int Function(package_manager_h, int)>();

  /// @brief Registers a callback function to be invoked when the package is installed, uninstalled, or updated.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[in] manager    The package manager handle
  /// @param[in] callback   The callback function to be registered
  /// @param[in] user_data  The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @post package_manager_event_cb() will be invoked.
  /// @see package_manager_set_event_status()
  /// @see package_manager_event_cb()
  /// @see package_manager_unset_event_cb()
  int package_manager_set_event_cb(
    package_manager_h manager,
    package_manager_event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _package_manager_set_event_cb(
      manager,
      callback,
      user_data,
    );
  }

  late final _package_manager_set_event_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_manager_h, package_manager_event_cb,
              ffi.Pointer<ffi.Void>)>>('package_manager_set_event_cb');
  late final _package_manager_set_event_cb =
      _package_manager_set_event_cbPtr.asFunction<
          int Function(package_manager_h, package_manager_event_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] manager The package manager handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_manager_event_cb()
  /// @see package_manager_set_event_cb()
  int package_manager_unset_event_cb(
    package_manager_h manager,
  ) {
    return _package_manager_unset_event_cb(
      manager,
    );
  }

  late final _package_manager_unset_event_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(package_manager_h)>>(
          'package_manager_unset_event_cb');
  late final _package_manager_unset_event_cb =
      _package_manager_unset_event_cbPtr
          .asFunction<int Function(package_manager_h)>();

  /// @brief Retrieves all package information of installed packages.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @post This function invokes package_manager_package_info_cb() repeatedly for each package information.
  /// @see package_manager_package_info_cb()
  int package_manager_foreach_package_info(
    package_manager_package_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _package_manager_foreach_package_info(
      callback,
      user_data,
    );
  }

  late final _package_manager_foreach_package_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_manager_package_info_cb,
              ffi.Pointer<ffi.Void>)>>('package_manager_foreach_package_info');
  late final _package_manager_foreach_package_info =
      _package_manager_foreach_package_infoPtr.asFunction<
          int Function(
              package_manager_package_info_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the package ID for the given app ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[in]  app_id     The ID of the application
  /// @param[out] package_id The ID of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_manager_get_package_id_by_app_id(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> package_id,
  ) {
    return _package_manager_get_package_id_by_app_id(
      app_id,
      package_id,
    );
  }

  late final _package_manager_get_package_id_by_app_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_manager_get_package_id_by_app_id');
  late final _package_manager_get_package_id_by_app_id =
      _package_manager_get_package_id_by_app_idPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the package information for the given package.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @remarks You must release @a package_info using package_info_destroy().
  /// @param[in]  package_id   The ID of the package
  /// @param[out] package_info The package information for the given package ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR Database error occurred
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_manager_get_package_info(
    ffi.Pointer<ffi.Char> package_id,
    ffi.Pointer<package_info_h> package_info,
  ) {
    return _package_manager_get_package_info(
      package_id,
      package_info,
    );
  }

  late final _package_manager_get_package_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<package_info_h>)>>(
      'package_manager_get_package_info');
  late final _package_manager_get_package_info =
      _package_manager_get_package_infoPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<package_info_h>)>();

  /// @brief Compares whether two package certifications are matched.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  lhs_package_id The first package ID to compare
  /// @param[in]  rhs_package_id The second package ID to compare
  /// @param[out] compare_result @c 0 if the certification information are matched,
  /// otherwise the compared result
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Database error occurred
  int package_manager_compare_package_cert_info(
    ffi.Pointer<ffi.Char> lhs_package_id,
    ffi.Pointer<ffi.Char> rhs_package_id,
    ffi.Pointer<ffi.Int32> compare_result,
  ) {
    return _package_manager_compare_package_cert_info(
      lhs_package_id,
      rhs_package_id,
      compare_result,
    );
  }

  late final _package_manager_compare_package_cert_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Int32>)>>(
      'package_manager_compare_package_cert_info');
  late final _package_manager_compare_package_cert_info =
      _package_manager_compare_package_cert_infoPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>();

  /// @brief Compares whether two app certifications are matched.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  lhs_app_id     The first app ID to compare
  /// @param[in]  rhs_app_id     The second app ID to compare
  /// @param[out] compare_result @c 0 if the certification information are matched,
  /// otherwise the compared result
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Database error occurred
  int package_manager_compare_app_cert_info(
    ffi.Pointer<ffi.Char> lhs_app_id,
    ffi.Pointer<ffi.Char> rhs_app_id,
    ffi.Pointer<ffi.Int32> compare_result,
  ) {
    return _package_manager_compare_app_cert_info(
      lhs_app_id,
      rhs_app_id,
      compare_result,
    );
  }

  late final _package_manager_compare_app_cert_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Int32>)>>(
      'package_manager_compare_app_cert_info');
  late final _package_manager_compare_app_cert_info =
      _package_manager_compare_app_cert_infoPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>();

  /// @brief Checks whether the package is preloaded by @a app_id.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[in]  app_id   The ID of the application
  /// @param[out] preload  The preload info of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_manager_is_preload_package_by_app_id(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Bool> preload,
  ) {
    return _package_manager_is_preload_package_by_app_id(
      app_id,
      preload,
    );
  }

  late final _package_manager_is_preload_package_by_app_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>>(
      'package_manager_is_preload_package_by_app_id');
  late final _package_manager_is_preload_package_by_app_id =
      _package_manager_is_preload_package_by_app_idPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the package permission type by @a app_id.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[in]  app_id          The ID of the application
  /// @param[out] permission_type The package permission type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_manager_get_permission_type(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Int32> permission_type,
  ) {
    return _package_manager_get_permission_type(
      app_id,
      permission_type,
    );
  }

  late final _package_manager_get_permission_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>>('package_manager_get_permission_type');
  late final _package_manager_get_permission_type =
      _package_manager_get_permission_typePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int32>)>();

  /// @brief Clears the application's internal and external cache directory, asynchronously.
  /// @details All files stored in the cache directory of the application specified with the package ID are removed.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.clearcache
  /// @param[in] package_id  The package ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_NO_SUCH_PACKAGE   No such package
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_SYSTEM_ERROR      Severe system error
  int package_manager_clear_cache_dir(
    ffi.Pointer<ffi.Char> package_id,
  ) {
    return _package_manager_clear_cache_dir(
      package_id,
    );
  }

  late final _package_manager_clear_cache_dirPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'package_manager_clear_cache_dir');
  late final _package_manager_clear_cache_dir =
      _package_manager_clear_cache_dirPtr
          .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @platform
  /// @brief  Clears all applications' internal and external cache directory, asynchronously.
  /// @details All files stored in the cache directory of each application are removed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_NO_SUCH_PACKAGE   No such package
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_SYSTEM_ERROR      Severe system error
  int package_manager_clear_all_cache_dir() {
    return _package_manager_clear_all_cache_dir();
  }

  late final _package_manager_clear_all_cache_dirPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'package_manager_clear_all_cache_dir');
  late final _package_manager_clear_all_cache_dir =
      _package_manager_clear_all_cache_dirPtr.asFunction<int Function()>();

  /// @platform
  /// @brief Clears internal and external data directories used by applications in the given package.
  /// @details All files stored in data directories used by applications in the package specified with the @a package_id are removed.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in] package_id  The package ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_NO_SUCH_PACKAGE   No such package
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_SYSTEM_ERROR      Severe system error
  int package_manager_clear_data_dir(
    ffi.Pointer<ffi.Char> package_id,
  ) {
    return _package_manager_clear_data_dir(
      package_id,
    );
  }

  late final _package_manager_clear_data_dirPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'package_manager_clear_data_dir');
  late final _package_manager_clear_data_dir =
      _package_manager_clear_data_dirPtr
          .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the package size information, asynchronously.
  /// @details The package size info is asynchronously obtained by the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[in] package_id  The package ID
  /// @param[in] callback    The asynchronous callback function to get the package size information
  /// @param[in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_NO_SUCH_PACKAGE   No such package
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_SYSTEM_ERROR      Severe system error
  int package_manager_get_package_size_info(
    ffi.Pointer<ffi.Char> package_id,
    package_manager_size_info_receive_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _package_manager_get_package_size_info(
      package_id,
      callback,
      user_data,
    );
  }

  late final _package_manager_get_package_size_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              package_manager_size_info_receive_cb,
              ffi.Pointer<ffi.Void>)>>('package_manager_get_package_size_info');
  late final _package_manager_get_package_size_info =
      _package_manager_get_package_size_infoPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>,
              package_manager_size_info_receive_cb, ffi.Pointer<ffi.Void>)>();

  /// @platform
  /// @brief Gets the total package size information, asynchronously.
  /// @details The total package size info is asynchronously obtained by the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[in] callback  The asynchronous callback function to get the total package size information
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_NO_SUCH_PACKAGE   No such package
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_SYSTEM_ERROR      Severe system error
  int package_manager_get_total_package_size_info(
    package_manager_total_size_info_receive_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _package_manager_get_total_package_size_info(
      callback,
      user_data,
    );
  }

  late final _package_manager_get_total_package_size_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(package_manager_total_size_info_receive_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'package_manager_get_total_package_size_info');
  late final _package_manager_get_total_package_size_info =
      _package_manager_get_total_package_size_infoPtr.asFunction<
          int Function(package_manager_total_size_info_receive_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Creates the package information filter handle from db.
  /// @details The filtered result will be based on AND operation of all added filter properties.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[out] handle Pointer to the package info filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR I/O error
  /// @post package_manager_filter_destroy()
  /// @see package_manager_filter_add_bool()
  /// @see package_manager_filter_foreach_pkginfo()
  int package_manager_filter_create(
    ffi.Pointer<package_manager_filter_h> handle,
  ) {
    return _package_manager_filter_create(
      handle,
    );
  }

  late final _package_manager_filter_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<package_manager_filter_h>)>>(
      'package_manager_filter_create');
  late final _package_manager_filter_create = _package_manager_filter_createPtr
      .asFunction<int Function(ffi.Pointer<package_manager_filter_h>)>();

  /// @brief This API destroys the package information filter handle freeing up all the resources
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] handle Pointer to the package info filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR I/O error
  /// @pre package_manager_filter_create()
  /// @see package_manager_filter_count()
  /// @see package_manager_filter_foreach_package_info()
  int package_manager_filter_destroy(
    package_manager_filter_h handle,
  ) {
    return _package_manager_filter_destroy(
      handle,
    );
  }

  late final _package_manager_filter_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(package_manager_filter_h)>>(
          'package_manager_filter_destroy');
  late final _package_manager_filter_destroy =
      _package_manager_filter_destroyPtr
          .asFunction<int Function(package_manager_filter_h)>();

  /// @brief This API adds a boolean filter property to the filter handle
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] handle Pointer to the package info filter handle
  /// @param[in] property boolean property name
  /// @param[in] value value corresponding to the property
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR I/O error
  /// @pre package_manager_filter_create()
  /// @post package_manager_filter_destroy()
  /// @see package_manager_filter_count()
  /// @see package_manager_filter_foreach_package_info()
  int package_manager_filter_add_bool(
    package_manager_filter_h handle,
    ffi.Pointer<ffi.Char> property,
    bool value,
  ) {
    return _package_manager_filter_add_bool(
      handle,
      property,
      value,
    );
  }

  late final _package_manager_filter_add_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_manager_filter_h, ffi.Pointer<ffi.Char>,
              ffi.Bool)>>('package_manager_filter_add_bool');
  late final _package_manager_filter_add_bool =
      _package_manager_filter_add_boolPtr.asFunction<
          int Function(
              package_manager_filter_h, ffi.Pointer<ffi.Char>, bool)>();

  /// @brief This API counts the package that satisfy the filter conditions
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[in] handle Pointer to the package info filter handle
  /// @param[out] count Pointer to store the count value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR I/O error
  /// @pre package_manager_filter_create()
  /// @post package_manager_filter_destroy()
  /// @see package_manager_filter_foreach_package_info()
  int package_manager_filter_count(
    package_manager_filter_h handle,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _package_manager_filter_count(
      handle,
      count,
    );
  }

  late final _package_manager_filter_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_manager_filter_h,
              ffi.Pointer<ffi.Int>)>>('package_manager_filter_count');
  late final _package_manager_filter_count =
      _package_manager_filter_countPtr.asFunction<
          int Function(package_manager_filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief This API executes the user supplied callback function for each package that satisfy the filter conditions
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[in] handle Pointer to the package info filter handle
  /// @param[in] callback callback function
  /// @param[in] user_data user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR I/O error
  /// @pre package_manager_filter_create()
  /// @post package_manager_filter_destroy()
  /// @post This function invokes package_manager_package_info_cb() repeatedly for each package information.
  /// @see package_manager_package_info_cb()
  /// @see package_manager_filter_count()
  int package_manager_filter_foreach_package_info(
    package_manager_filter_h handle,
    package_manager_package_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _package_manager_filter_foreach_package_info(
      handle,
      callback,
      user_data,
    );
  }

  late final _package_manager_filter_foreach_package_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(package_manager_filter_h,
                  package_manager_package_info_cb, ffi.Pointer<ffi.Void>)>>(
      'package_manager_filter_foreach_package_info');
  late final _package_manager_filter_foreach_package_info =
      _package_manager_filter_foreach_package_infoPtr.asFunction<
          int Function(package_manager_filter_h,
              package_manager_package_info_cb, ffi.Pointer<ffi.Void>)>();

  /// @platform
  /// @brief Generates request for getting License, asynchronously.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @remarks You must release @a req_data and @a license_url by yourself.
  /// @param[in] resp_data The response data string of the purchase request
  /// @param[out] req_data	License request data
  /// @param[out] license_url License acquisition url data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR Internal I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @post package_manager_drm_register_license
  int package_manager_drm_generate_license_request(
    ffi.Pointer<ffi.Char> resp_data,
    ffi.Pointer<ffi.Pointer<ffi.Char>> req_data,
    ffi.Pointer<ffi.Pointer<ffi.Char>> license_url,
  ) {
    return _package_manager_drm_generate_license_request(
      resp_data,
      req_data,
      license_url,
    );
  }

  late final _package_manager_drm_generate_license_requestPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_manager_drm_generate_license_request');
  late final _package_manager_drm_generate_license_request =
      _package_manager_drm_generate_license_requestPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @platform
  /// @brief Registers encrypted license, asynchronously.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in] resp_data The response data string of the rights request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR Internal I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre package_manager_drm_generate_license_request
  int package_manager_drm_register_license(
    ffi.Pointer<ffi.Char> resp_data,
  ) {
    return _package_manager_drm_register_license(
      resp_data,
    );
  }

  late final _package_manager_drm_register_licensePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'package_manager_drm_register_license');
  late final _package_manager_drm_register_license =
      _package_manager_drm_register_licensePtr
          .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @platform
  /// @brief Decrypts contents which is encrypted, asynchronously.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in] drm_file_path DRM file path
  /// @param[in] decrypted_file_path Decrypted file path
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR Internal I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_manager_drm_decrypt_package(
    ffi.Pointer<ffi.Char> drm_file_path,
    ffi.Pointer<ffi.Char> decrypted_file_path,
  ) {
    return _package_manager_drm_decrypt_package(
      drm_file_path,
      decrypted_file_path,
    );
  }

  late final _package_manager_drm_decrypt_packagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('package_manager_drm_decrypt_package');
  late final _package_manager_drm_decrypt_package =
      _package_manager_drm_decrypt_packagePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Retrieves data size from given handle
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] handle Package size info handle
  /// @param[out] data_size Data size will be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  int package_size_info_get_data_size(
    package_size_info_h handle,
    ffi.Pointer<ffi.LongLong> data_size,
  ) {
    return _package_size_info_get_data_size(
      handle,
      data_size,
    );
  }

  late final _package_size_info_get_data_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_size_info_h,
              ffi.Pointer<ffi.LongLong>)>>('package_size_info_get_data_size');
  late final _package_size_info_get_data_size =
      _package_size_info_get_data_sizePtr.asFunction<
          int Function(package_size_info_h, ffi.Pointer<ffi.LongLong>)>();

  /// @brief Retrieves cache size from given handle
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] handle  Package size info handle
  /// @param[out] cache_size Cache size will be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  int package_size_info_get_cache_size(
    package_size_info_h handle,
    ffi.Pointer<ffi.LongLong> cache_size,
  ) {
    return _package_size_info_get_cache_size(
      handle,
      cache_size,
    );
  }

  late final _package_size_info_get_cache_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_size_info_h,
              ffi.Pointer<ffi.LongLong>)>>('package_size_info_get_cache_size');
  late final _package_size_info_get_cache_size =
      _package_size_info_get_cache_sizePtr.asFunction<
          int Function(package_size_info_h, ffi.Pointer<ffi.LongLong>)>();

  /// @brief Retrieves application size from given handle
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] handle Package size info handle
  /// @param[out] app_size App size will be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  int package_size_info_get_app_size(
    package_size_info_h handle,
    ffi.Pointer<ffi.LongLong> app_size,
  ) {
    return _package_size_info_get_app_size(
      handle,
      app_size,
    );
  }

  late final _package_size_info_get_app_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_size_info_h,
              ffi.Pointer<ffi.LongLong>)>>('package_size_info_get_app_size');
  late final _package_size_info_get_app_size =
      _package_size_info_get_app_sizePtr.asFunction<
          int Function(package_size_info_h, ffi.Pointer<ffi.LongLong>)>();

  /// @brief Retrieves external data size from given handle
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] handle  Package size info handle
  /// @param[out] ext_data_size External data size will be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  int package_size_info_get_external_data_size(
    package_size_info_h handle,
    ffi.Pointer<ffi.LongLong> ext_data_size,
  ) {
    return _package_size_info_get_external_data_size(
      handle,
      ext_data_size,
    );
  }

  late final _package_size_info_get_external_data_sizePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_size_info_h, ffi.Pointer<ffi.LongLong>)>>(
      'package_size_info_get_external_data_size');
  late final _package_size_info_get_external_data_size =
      _package_size_info_get_external_data_sizePtr.asFunction<
          int Function(package_size_info_h, ffi.Pointer<ffi.LongLong>)>();

  /// @brief Retrieves external cache size from given handle
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] handle Package size info handle
  /// @param[out] ext_cache_size External cache size will be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  int package_size_info_get_external_cache_size(
    package_size_info_h handle,
    ffi.Pointer<ffi.LongLong> ext_cache_size,
  ) {
    return _package_size_info_get_external_cache_size(
      handle,
      ext_cache_size,
    );
  }

  late final _package_size_info_get_external_cache_sizePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_size_info_h, ffi.Pointer<ffi.LongLong>)>>(
      'package_size_info_get_external_cache_size');
  late final _package_size_info_get_external_cache_size =
      _package_size_info_get_external_cache_sizePtr.asFunction<
          int Function(package_size_info_h, ffi.Pointer<ffi.LongLong>)>();

  /// @brief Retrieves external application size from given handle
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] handle Package size info handle
  /// @param[out] ext_app_size External app size will be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  int package_size_info_get_external_app_size(
    package_size_info_h handle,
    ffi.Pointer<ffi.LongLong> ext_app_size,
  ) {
    return _package_size_info_get_external_app_size(
      handle,
      ext_app_size,
    );
  }

  late final _package_size_info_get_external_app_sizePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_size_info_h, ffi.Pointer<ffi.LongLong>)>>(
      'package_size_info_get_external_app_size');
  late final _package_size_info_get_external_app_size =
      _package_size_info_get_external_app_sizePtr.asFunction<
          int Function(package_size_info_h, ffi.Pointer<ffi.LongLong>)>();

  /// @platform
  /// @brief Creates a request handle to the package manager.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a request using package_manager_request_destroy().
  /// @param[out] request The request handle that is newly created on success
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Internal I/O error
  /// @see package_manager_request_destroy()
  int package_manager_request_create(
    ffi.Pointer<package_manager_request_h> request,
  ) {
    return _package_manager_request_create(
      request,
    );
  }

  late final _package_manager_request_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<package_manager_request_h>)>>(
      'package_manager_request_create');
  late final _package_manager_request_create =
      _package_manager_request_createPtr
          .asFunction<int Function(ffi.Pointer<package_manager_request_h>)>();

  /// @platform
  /// @brief Destroys the request handle to the package manager.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] request The request handle to the package manager
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_manager_request_create()
  int package_manager_request_destroy(
    package_manager_request_h request,
  ) {
    return _package_manager_request_destroy(
      request,
    );
  }

  late final _package_manager_request_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(package_manager_request_h)>>(
          'package_manager_request_destroy');
  late final _package_manager_request_destroy =
      _package_manager_request_destroyPtr
          .asFunction<int Function(package_manager_request_h)>();

  /// @platform
  /// @brief Registers a callback function to be invoked when the progress of the request changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/packagemanager.info
  /// @param[in] request The request handle
  /// @param[in] callback The callback function to be registered
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @post package_manager_request_event_cb() will be invoked.
  /// @see package_manager_request_event_cb()
  /// @see package_manager_request_unset_event_cb()
  int package_manager_request_set_event_cb(
    package_manager_request_h request,
    package_manager_request_event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _package_manager_request_set_event_cb(
      request,
      callback,
      user_data,
    );
  }

  late final _package_manager_request_set_event_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              package_manager_request_h,
              package_manager_request_event_cb,
              ffi.Pointer<ffi.Void>)>>('package_manager_request_set_event_cb');
  late final _package_manager_request_set_event_cb =
      _package_manager_request_set_event_cbPtr.asFunction<
          int Function(package_manager_request_h,
              package_manager_request_event_cb, ffi.Pointer<ffi.Void>)>();

  /// @platform
  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] request The request handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_manager_request_event_cb()
  /// @see package_manager_request_set_event_cb()
  int package_manager_request_unset_event_cb(
    package_manager_request_h request,
  ) {
    return _package_manager_request_unset_event_cb(
      request,
    );
  }

  late final _package_manager_request_unset_event_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(package_manager_request_h)>>(
          'package_manager_request_unset_event_cb');
  late final _package_manager_request_unset_event_cb =
      _package_manager_request_unset_event_cbPtr
          .asFunction<int Function(package_manager_request_h)>();

  /// @platform
  /// @brief Sets the type of the package to install, uninstall, or update.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] request The request handle
  /// @param[in] type    The type of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  int package_manager_request_set_type(
    package_manager_request_h request,
    ffi.Pointer<ffi.Char> type,
  ) {
    return _package_manager_request_set_type(
      request,
      type,
    );
  }

  late final _package_manager_request_set_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_manager_request_h,
              ffi.Pointer<ffi.Char>)>>('package_manager_request_set_type');
  late final _package_manager_request_set_type =
      _package_manager_request_set_typePtr.asFunction<
          int Function(package_manager_request_h, ffi.Pointer<ffi.Char>)>();

  /// @platform
  /// @brief Sets the mode of the request.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] request The request handle
  /// @param[in] mode    The mode of the request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  int package_manager_request_set_mode(
    package_manager_request_h request,
    int mode,
  ) {
    return _package_manager_request_set_mode(
      request,
      mode,
    );
  }

  late final _package_manager_request_set_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_manager_request_h,
              ffi.Int32)>>('package_manager_request_set_mode');
  late final _package_manager_request_set_mode =
      _package_manager_request_set_modePtr
          .asFunction<int Function(package_manager_request_h, int)>();

  /// @platform
  /// @brief Sets the path of TEP file to the request. The TEP file that is set will be installed when the package is installed.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in] request The request handle
  /// @param[in] tep_path The TEP path to set. If this is NULL on update, installed TEP will be removed.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PACKAGE_MANAGER_ERROR_SYSTEM_ERROR		 Severe system error
  int package_manager_request_set_tep(
    package_manager_request_h request,
    ffi.Pointer<ffi.Char> tep_path,
  ) {
    return _package_manager_request_set_tep(
      request,
      tep_path,
    );
  }

  late final _package_manager_request_set_tepPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_manager_request_h,
              ffi.Pointer<ffi.Char>)>>('package_manager_request_set_tep');
  late final _package_manager_request_set_tep =
      _package_manager_request_set_tepPtr.asFunction<
          int Function(package_manager_request_h, ffi.Pointer<ffi.Char>)>();

  /// @platform
  /// @brief Installs the package located at the given path, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in]  request The request handle
  /// @param[in]  path    The absolute path to the package to be installed
  /// @param[out] id      The ID of the request to the package manager
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @see package_manager_request_uninstall()
  int package_manager_request_install(
    package_manager_request_h request,
    ffi.Pointer<ffi.Char> path,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _package_manager_request_install(
      request,
      path,
      id,
    );
  }

  late final _package_manager_request_installPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_manager_request_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('package_manager_request_install');
  late final _package_manager_request_install =
      _package_manager_request_installPtr.asFunction<
          int Function(package_manager_request_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>();

  /// @platform
  /// @brief Installs the package located at the given path, asynchronously.
  /// @details The progress of the request is asynchronously received by the callback function.
  /// The @a callback is the individual callback only called for the current API call.
  /// The @a callback is the only callback called, even if another callback was set for this request
  /// with package_manager_request_set_event_cb().
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in]  request   The request handle
  /// @param[in]  path      The absolute path to the package to be installed
  /// @param[in]  callback  The callback function to be invoked
  /// @param[in]  user_data The user data to be passed to the callback function
  /// @param[out] id        The ID of the request to the package manager
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_manager_request_install_with_cb(
    package_manager_request_h request,
    ffi.Pointer<ffi.Char> path,
    package_manager_request_event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _package_manager_request_install_with_cb(
      request,
      path,
      callback,
      user_data,
      id,
    );
  }

  late final _package_manager_request_install_with_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_manager_request_h,
                  ffi.Pointer<ffi.Char>,
                  package_manager_request_event_cb,
                  ffi.Pointer<ffi.Void>,
                  ffi.Pointer<ffi.Int>)>>(
      'package_manager_request_install_with_cb');
  late final _package_manager_request_install_with_cb =
      _package_manager_request_install_with_cbPtr.asFunction<
          int Function(
              package_manager_request_h,
              ffi.Pointer<ffi.Char>,
              package_manager_request_event_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>();

  /// @platform
  /// @brief Uninstalls the package with the given name, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in]  request The request handle
  /// @param[in]  name    The name of the package to be uninstalled
  /// @param[out] id      The ID of the request to the package manager
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_manager_request_uninstall(
    package_manager_request_h request,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _package_manager_request_uninstall(
      request,
      name,
      id,
    );
  }

  late final _package_manager_request_uninstallPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_manager_request_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('package_manager_request_uninstall');
  late final _package_manager_request_uninstall =
      _package_manager_request_uninstallPtr.asFunction<
          int Function(package_manager_request_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>();

  /// @platform
  /// @brief Uninstalls the package with the given name, asynchronously.
  /// @details The progress of the request is asynchronously received by the callback function.
  /// The @a callback is the individual callback only called for the current API call.
  /// The @a callback is the only callback called, even if another callback was set for this request
  /// with package_manager_request_set_event_cb().
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in]  request   The request handle
  /// @param[in]  name      The name of the package to be uninstalled
  /// @param[in]  callback  The callback function to be invoked
  /// @param[in]  user_data The user data to be passed to the callback function
  /// @param[out] id        The ID of the request to the package manager
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_manager_request_uninstall_with_cb(
    package_manager_request_h request,
    ffi.Pointer<ffi.Char> name,
    package_manager_request_event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _package_manager_request_uninstall_with_cb(
      request,
      name,
      callback,
      user_data,
      id,
    );
  }

  late final _package_manager_request_uninstall_with_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_manager_request_h,
                  ffi.Pointer<ffi.Char>,
                  package_manager_request_event_cb,
                  ffi.Pointer<ffi.Void>,
                  ffi.Pointer<ffi.Int>)>>(
      'package_manager_request_uninstall_with_cb');
  late final _package_manager_request_uninstall_with_cb =
      _package_manager_request_uninstall_with_cbPtr.asFunction<
          int Function(
              package_manager_request_h,
              ffi.Pointer<ffi.Char>,
              package_manager_request_event_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>();

  /// @platform
  /// @brief Moves the package from SD card to the internal memory and vice versa, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in] request   The request handle
  /// @param[in] name      The name of the package to be moved
  /// @param[in] move_type The move type [enum package_manager_move_type_e], [external to internal/internal to external]
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_manager_request_move(
    package_manager_request_h request,
    ffi.Pointer<ffi.Char> name,
    int move_type,
  ) {
    return _package_manager_request_move(
      request,
      name,
      move_type,
    );
  }

  late final _package_manager_request_movePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_manager_request_h, ffi.Pointer<ffi.Char>,
              ffi.Int32)>>('package_manager_request_move');
  late final _package_manager_request_move =
      _package_manager_request_movePtr.asFunction<
          int Function(
              package_manager_request_h, ffi.Pointer<ffi.Char>, int)>();

  /// @platform
  /// @brief Moves the package from SD card to the internal memory and vice versa, asynchronously.
  /// @details The progress of the request is asynchronously received by the callback function.
  /// The @a callback is the individual callback only called for the current API call.
  /// The @a callback is the only callback called, even if another callback was set for this request
  /// with package_manager_request_set_event_cb().
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @param[in]  request   The request handle
  /// @param[in]  name      The name of the package to be moved
  /// @param[in]  move_type The move type [enum package_manager_move_type_e], [external to internal/internal to external]
  /// @param[in]  callback  The callback function to be invoked
  /// @param[in]  user_data The user data to be passed to the callback function
  /// @param[out] id        The ID of the request to the package manager
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  int package_manager_request_move_with_cb(
    package_manager_request_h request,
    ffi.Pointer<ffi.Char> name,
    int move_type,
    package_manager_request_event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _package_manager_request_move_with_cb(
      request,
      name,
      move_type,
      callback,
      user_data,
      id,
    );
  }

  late final _package_manager_request_move_with_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              package_manager_request_h,
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              package_manager_request_event_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('package_manager_request_move_with_cb');
  late final _package_manager_request_move_with_cb =
      _package_manager_request_move_with_cbPtr.asFunction<
          int Function(
              package_manager_request_h,
              ffi.Pointer<ffi.Char>,
              int,
              package_manager_request_event_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>();

  /// @platform
  /// @brief Creates a package update info request.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/packagemanager.admin
  /// @remarks You must release @a pkg_updateinfo_req using package_manager_updateinfo_request_destroy().
  /// @param[out] pkg_updateinfo_req The package update info request handle that is newly created on success
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @see package_manager_updateinfo_request_destroy()
  int package_manager_updateinfo_request_create(
    ffi.Pointer<package_updateinfo_request_h> pkg_updateinfo_req,
  ) {
    return _package_manager_updateinfo_request_create(
      pkg_updateinfo_req,
    );
  }

  late final _package_manager_updateinfo_request_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<package_updateinfo_request_h>)>>(
      'package_manager_updateinfo_request_create');
  late final _package_manager_updateinfo_request_create =
      _package_manager_updateinfo_request_createPtr.asFunction<
          int Function(ffi.Pointer<package_updateinfo_request_h>)>();

  /// @brief Sets the package ID to the package update info request.
  /// @since_tizen 4.0
  /// @param[in] pkg_updateinfo_req   The update info request handle
  /// @param[in] pkgid                The package ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_manager_updateinfo_request_create()
  int package_manager_updateinfo_set_pkgid(
    package_updateinfo_request_h pkg_updateinfo_req,
    ffi.Pointer<ffi.Char> pkgid,
  ) {
    return _package_manager_updateinfo_set_pkgid(
      pkg_updateinfo_req,
      pkgid,
    );
  }

  late final _package_manager_updateinfo_set_pkgidPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_updateinfo_request_h,
              ffi.Pointer<ffi.Char>)>>('package_manager_updateinfo_set_pkgid');
  late final _package_manager_updateinfo_set_pkgid =
      _package_manager_updateinfo_set_pkgidPtr.asFunction<
          int Function(package_updateinfo_request_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the package version to the package update info request.
  /// @since_tizen 4.0
  /// @param[in] pkg_updateinfo_req   The update info request handle
  /// @param[in] version              The package version
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_manager_updateinfo_request_create()
  int package_manager_updateinfo_set_version(
    package_updateinfo_request_h pkg_updateinfo_req,
    ffi.Pointer<ffi.Char> version,
  ) {
    return _package_manager_updateinfo_set_version(
      pkg_updateinfo_req,
      version,
    );
  }

  late final _package_manager_updateinfo_set_versionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_updateinfo_request_h, ffi.Pointer<ffi.Char>)>>(
      'package_manager_updateinfo_set_version');
  late final _package_manager_updateinfo_set_version =
      _package_manager_updateinfo_set_versionPtr.asFunction<
          int Function(package_updateinfo_request_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the package update type to the package update info request.
  /// @since_tizen 4.0
  /// @param[in] pkg_updateinfo_req   The update info request handle
  /// @param[in] type                 The package update type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_manager_updateinfo_request_create()
  /// @see package_updateinfo_type_e
  int package_manager_updateinfo_set_type(
    package_updateinfo_request_h pkg_updateinfo_req,
    int type,
  ) {
    return _package_manager_updateinfo_set_type(
      pkg_updateinfo_req,
      type,
    );
  }

  late final _package_manager_updateinfo_set_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(package_updateinfo_request_h,
              ffi.Int32)>>('package_manager_updateinfo_set_type');
  late final _package_manager_updateinfo_set_type =
      _package_manager_updateinfo_set_typePtr
          .asFunction<int Function(package_updateinfo_request_h, int)>();

  /// @brief Request to register package update info in platform.
  /// @since_tizen 4.0
  /// @param[in] pkg_updateinfo_req    The update info request handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_SYSTEM_ERROR      Severe system error
  /// @see package_manager_updateinfo_request_create()
  /// @see package_manager_updateinfo_request_destroy()
  int package_manager_updateinfo_request_register(
    package_updateinfo_request_h pkg_updateinfo_req,
  ) {
    return _package_manager_updateinfo_request_register(
      pkg_updateinfo_req,
    );
  }

  late final _package_manager_updateinfo_request_registerPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(package_updateinfo_request_h)>>(
      'package_manager_updateinfo_request_register');
  late final _package_manager_updateinfo_request_register =
      _package_manager_updateinfo_request_registerPtr
          .asFunction<int Function(package_updateinfo_request_h)>();

  /// @brief Destroys the package update info request.
  /// @since_tizen 4.0
  /// @param[in] pkg_updateinfo_req    The update info request handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_manager_updateinfo_request_create()
  int package_manager_updateinfo_request_destroy(
    package_updateinfo_request_h pkg_updateinfo_req,
  ) {
    return _package_manager_updateinfo_request_destroy(
      pkg_updateinfo_req,
    );
  }

  late final _package_manager_updateinfo_request_destroyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(package_updateinfo_request_h)>>(
      'package_manager_updateinfo_request_destroy');
  late final _package_manager_updateinfo_request_destroy =
      _package_manager_updateinfo_request_destroyPtr
          .asFunction<int Function(package_updateinfo_request_h)>();

  /// @brief Request to unregister update info in platform for given package id.
  /// @since_tizen 4.0
  /// @param[in] pkg_updateinfo_req   The update info request handle
  /// @param[in] pkgid                The package id to request unregister update info
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_SYSTEM_ERROR      Severe system error
  int package_manager_updateinfo_request_unregister(
    package_updateinfo_request_h pkg_updateinfo_req,
    ffi.Pointer<ffi.Char> pkgid,
  ) {
    return _package_manager_updateinfo_request_unregister(
      pkg_updateinfo_req,
      pkgid,
    );
  }

  late final _package_manager_updateinfo_request_unregisterPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_updateinfo_request_h, ffi.Pointer<ffi.Char>)>>(
      'package_manager_updateinfo_request_unregister');
  late final _package_manager_updateinfo_request_unregister =
      _package_manager_updateinfo_request_unregisterPtr.asFunction<
          int Function(package_updateinfo_request_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Request to unregister update info of all packages in platform.
  /// @since_tizen 4.0
  /// @param[in] pkg_updateinfo_req    The update info request handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  /// @retval #PACKAGE_MANAGER_ERROR_SYSTEM_ERROR      Severe system error
  int package_manager_updateinfo_request_unregister_all(
    package_updateinfo_request_h pkg_updateinfo_req,
  ) {
    return _package_manager_updateinfo_request_unregister_all(
      pkg_updateinfo_req,
    );
  }

  late final _package_manager_updateinfo_request_unregister_allPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(package_updateinfo_request_h)>>(
      'package_manager_updateinfo_request_unregister_all');
  late final _package_manager_updateinfo_request_unregister_all =
      _package_manager_updateinfo_request_unregister_allPtr
          .asFunction<int Function(package_updateinfo_request_h)>();

  /// @brief Creates the package archive information for the given package.
  /// @since_tizen 4.0
  /// @remarks If the given path is relevant to media storage, the privilege
  /// http://tizen.org/privilege/mediastorage is needed.
  /// @remarks If the given path is relevant to external storage, the privilege
  /// http://tizen.org/privilege/externalstorage is needed.
  /// @remarks You must release @a archive_info
  /// using package_archive_info_destroy().
  /// @param[in]  path         The path of the package
  /// @param[out] archive_info The package archive information for
  /// the given package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          Internal I/O error
  /// @see package_archive_info_destroy()
  int package_archive_info_create(
    ffi.Pointer<ffi.Char> path,
    ffi.Pointer<package_archive_info_h> archive_info,
  ) {
    return _package_archive_info_create(
      path,
      archive_info,
    );
  }

  late final _package_archive_info_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<package_archive_info_h>)>>(
      'package_archive_info_create');
  late final _package_archive_info_create =
      _package_archive_info_createPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<package_archive_info_h>)>();

  /// @brief Destroys the package archive information handle.
  /// @since_tizen 4.0
  /// @param[in] archive_info The package archive information handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see package_archive_info_create()
  int package_archive_info_destroy(
    package_archive_info_h archive_info,
  ) {
    return _package_archive_info_destroy(
      archive_info,
    );
  }

  late final _package_archive_info_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(package_archive_info_h)>>(
          'package_archive_info_destroy');
  late final _package_archive_info_destroy = _package_archive_info_destroyPtr
      .asFunction<int Function(package_archive_info_h)>();

  /// @brief Gets the package name.
  /// @since_tizen 4.0
  /// @remarks You must release @a package using free().
  /// @param[in]  archive_info The package archive information
  /// @param[out] package      The package name
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  int package_archive_info_get_package(
    package_archive_info_h archive_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> package,
  ) {
    return _package_archive_info_get_package(
      archive_info,
      package,
    );
  }

  late final _package_archive_info_get_packagePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_archive_info_get_package');
  late final _package_archive_info_get_package =
      _package_archive_info_get_packagePtr.asFunction<
          int Function(
              package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the type of the package.
  /// @since_tizen 4.0
  /// @remarks You must release @a type using free().
  /// @param[in]  archive_info The package archive information
  /// @param[out] type         The type of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  int package_archive_info_get_type(
    package_archive_info_h archive_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> type,
  ) {
    return _package_archive_info_get_type(
      archive_info,
      type,
    );
  }

  late final _package_archive_info_get_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_archive_info_get_type');
  late final _package_archive_info_get_type =
      _package_archive_info_get_typePtr.asFunction<
          int Function(
              package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the version of the package.
  /// @since_tizen 4.0
  /// @remarks You must release @a version using free().
  /// @param[in]  archive_info The package archive information
  /// @param[out] version      The version of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  int package_archive_info_get_version(
    package_archive_info_h archive_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> version,
  ) {
    return _package_archive_info_get_version(
      archive_info,
      version,
    );
  }

  late final _package_archive_info_get_versionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_archive_info_get_version');
  late final _package_archive_info_get_version =
      _package_archive_info_get_versionPtr.asFunction<
          int Function(
              package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the API version of the package.
  /// @since_tizen 4.0
  /// @remarks You must release @a api_version using free().
  /// @param[in]  archive_info The package archive information
  /// @param[out] api_version  The API version of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  int package_archive_info_get_api_version(
    package_archive_info_h archive_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> api_version,
  ) {
    return _package_archive_info_get_api_version(
      archive_info,
      api_version,
    );
  }

  late final _package_archive_info_get_api_versionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_archive_info_get_api_version');
  late final _package_archive_info_get_api_version =
      _package_archive_info_get_api_versionPtr.asFunction<
          int Function(
              package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the description of the package.
  /// @since_tizen 4.0
  /// @remarks You must release @a description using free().
  /// @param[in]  archive_info The package archive information
  /// @param[out] description  The description of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_archive_info_get_description(
    package_archive_info_h archive_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> description,
  ) {
    return _package_archive_info_get_description(
      archive_info,
      description,
    );
  }

  late final _package_archive_info_get_descriptionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_archive_info_get_description');
  late final _package_archive_info_get_description =
      _package_archive_info_get_descriptionPtr.asFunction<
          int Function(
              package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the label of the package.
  /// @since_tizen 4.0
  /// @remarks You must release @a label using free().
  /// @param[in]  archive_info The package archive information
  /// @param[out] label        The label of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_archive_info_get_label(
    package_archive_info_h archive_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> label,
  ) {
    return _package_archive_info_get_label(
      archive_info,
      label,
    );
  }

  late final _package_archive_info_get_labelPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_archive_info_get_label');
  late final _package_archive_info_get_label =
      _package_archive_info_get_labelPtr.asFunction<
          int Function(
              package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the author of the package.
  /// @since_tizen 4.0
  /// @remarks You must release @a author using free().
  /// @param[in]  archive_info The package archive information
  /// @param[out] author       The author of the package
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_archive_info_get_author(
    package_archive_info_h archive_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> author,
  ) {
    return _package_archive_info_get_author(
      archive_info,
      author,
    );
  }

  late final _package_archive_info_get_authorPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'package_archive_info_get_author');
  late final _package_archive_info_get_author =
      _package_archive_info_get_authorPtr.asFunction<
          int Function(
              package_archive_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the raw icon of the package.
  /// @since_tizen 4.0
  /// @remarks You must release @a icon using free().
  /// @param[in]  archive_info The package archive information
  /// @param[out] icon         The raw icon of the package
  /// @param[out] icon_size    The size of the icon
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PACKAGE_MANAGER_ERROR_NONE              Successful
  /// @retval #PACKAGE_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #PACKAGE_MANAGER_ERROR_IO_ERROR          I/O error
  int package_archive_info_get_icon(
    package_archive_info_h archive_info,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> icon,
    ffi.Pointer<ffi.Size> icon_size,
  ) {
    return _package_archive_info_get_icon(
      archive_info,
      icon,
      icon_size,
    );
  }

  late final _package_archive_info_get_iconPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              package_archive_info_h,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Size>)>>('package_archive_info_get_icon');
  late final _package_archive_info_get_icon =
      _package_archive_info_get_iconPtr.asFunction<
          int Function(
              package_archive_info_h,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Size>)>();

  /// @brief Adds the system event handler
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The service application can handle low memory event, low battery event, language setting changed event and region format changed event.
  /// @param[out] handler The event handler
  /// @param[in] event_type The system event type
  /// @param[in] callback The callback function
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_OUT_OF_MEMORY Out of memory
  /// @see app_event_type_e
  /// @see app_event_cb
  /// @see service_app_remove_event_handler
  int service_app_add_event_handler(
    ffi.Pointer<app_event_handler_h> handler,
    int event_type,
    app_event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _service_app_add_event_handler(
      handler,
      event_type,
      callback,
      user_data,
    );
  }

  late final _service_app_add_event_handlerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<app_event_handler_h>,
              ffi.Int32,
              app_event_cb,
              ffi.Pointer<ffi.Void>)>>('service_app_add_event_handler');
  late final _service_app_add_event_handler =
      _service_app_add_event_handlerPtr.asFunction<
          int Function(ffi.Pointer<app_event_handler_h>, int, app_event_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Removes registered event handler
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] event_handler The event handler
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see service_app_add_event_handler
  int service_app_remove_event_handler(
    app_event_handler_h event_handler,
  ) {
    return _service_app_remove_event_handler(
      event_handler,
    );
  }

  late final _service_app_remove_event_handlerPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_event_handler_h)>>(
          'service_app_remove_event_handler');
  late final _service_app_remove_event_handler =
      _service_app_remove_event_handlerPtr
          .asFunction<int Function(app_event_handler_h)>();

  /// @brief Runs the main loop of the application until service_app_exit() is called.
  /// @details This function is the main entry point of the Tizen service application.
  /// This main loop supports event handling for the GMainLoop and the Ecore Main Loop.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] argc The argument count
  /// @param[in] argv The argument vector
  /// @param[in] callback The set of callback functions to handle application events
  /// @param[in] user_data The user data to be passed to the callback functions
  /// @return @c 0 on success,
  /// otherwise a negative error value.
  /// @retval #APP_ERROR_NONE Successful
  /// @retval #APP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #APP_ERROR_INVALID_CONTEXT The application is launched illegally, not launched by the launch system.
  /// @retval #APP_ERROR_ALREADY_RUNNING The main loop has already started
  /// @see service_app_create_cb()
  /// @see service_app_terminate_cb()
  /// @see service_app_control_cb()
  /// @see service_app_exit()
  /// @see #service_app_lifecycle_callback_s
  int service_app_main(
    int argc,
    ffi.Pointer<ffi.Pointer<ffi.Char>> argv,
    ffi.Pointer<service_app_lifecycle_callback_s> callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _service_app_main(
      argc,
      argv,
      callback,
      user_data,
    );
  }

  late final _service_app_mainPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<service_app_lifecycle_callback_s>,
              ffi.Pointer<ffi.Void>)>>('service_app_main');
  late final _service_app_main = _service_app_mainPtr.asFunction<
      int Function(
          int,
          ffi.Pointer<ffi.Pointer<ffi.Char>>,
          ffi.Pointer<service_app_lifecycle_callback_s>,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Exits the main loop of the application.
  /// @details The main loop of the application stops and service_app_terminate_cb() is invoked.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @see service_app_main()
  /// @see service_app_terminate_cb()
  void service_app_exit() {
    return _service_app_exit();
  }

  late final _service_app_exitPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function()>>('service_app_exit');
  late final _service_app_exit =
      _service_app_exitPtr.asFunction<void Function()>();

  /// @brief Adds a shortcut to home, asynchronously.
  /// @since_tizen 2.3
  /// @remarks If a homescreen does not support this feature, you will get a proper error code.\n
  /// Application must check the return value of this function.\n
  /// Application must check the return status from the callback function.\n
  /// Application should set the callback function to get the result of this request.
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/shortcut
  /// @param[in] name The name of the created shortcut icon
  /// @param[in] type The type of shortcuts
  /// @param[in] uri The specific information for delivering to the viewer for creating a shortcut
  /// @param[in] icon The absolute path of an icon file
  /// @param[in] allow_duplicate @c 1 if it accepts the duplicated shortcut,
  /// otherwise @c 0
  /// @param[in] result_cb The address of the callback function that is called when the result comes back from the viewer
  /// @param[in] data The callback data that is used in the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SHORTCUT_ERROR_NONE Successful
  /// @retval #SHORTCUT_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SHORTCUT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SHORTCUT_ERROR_IO_ERROR I/O Error
  /// @retval #SHORTCUT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #SHORTCUT_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SHORTCUT_ERROR_RESOURCE_BUSY Device or resource busy
  /// @retval #SHORTCUT_ERROR_NO_SPACE There is no space to add a new shortcut
  /// @retval #SHORTCUT_ERROR_EXIST Shortcut is already exist
  /// @retval #SHORTCUT_ERROR_FAULT Unrecoverable error
  /// @retval #SHORTCUT_ERROR_COMM Connection not established or communication problem
  /// @pre You have to prepare the callback function.
  /// @post You have to check the return status from the callback function which is passed by the argument.
  /// @see result_cb_t
  /// @par Example
  /// @code
  /// #include <stdio.h>
  /// #include <shortcut_manager.h>
  /// static int result_cb(int ret, int pid, void *data)
  /// {
  /// if (ret < 0)
  /// dlog_print("Failed to add a shortcut: %s\n", perror(ret));
  ///
  /// dlog_print("Processed by the %d\n", pid);
  /// return 0;
  /// }
  ///
  /// static int app_create(void *data)
  /// {
  /// char* data_path = app_get_data_path();
  /// int path_len = strlen(data_path)+10;
  /// char * path = malloc(path_len);
  /// memset(path, 0, path_len);
  /// strncat(path, data_path, path_len);
  /// strncat(path, "Friend.jpg", path_len);
  ///
  /// shortcut_add_to_home("With friends", LAUNCH_BY_URI, "gallery:0000-0000", path, 0, result_cb, NULL);
  /// free(path);
  ///
  /// return 0;
  /// }
  /// @endcode
  int shortcut_add_to_home(
    ffi.Pointer<ffi.Char> name,
    int type,
    ffi.Pointer<ffi.Char> uri,
    ffi.Pointer<ffi.Char> icon,
    int allow_duplicate,
    result_cb_t result_cb,
    ffi.Pointer<ffi.Void> data,
  ) {
    return _shortcut_add_to_home(
      name,
      type,
      uri,
      icon,
      allow_duplicate,
      result_cb,
      data,
    );
  }

  late final _shortcut_add_to_homePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              result_cb_t,
              ffi.Pointer<ffi.Void>)>>('shortcut_add_to_home');
  late final _shortcut_add_to_home = _shortcut_add_to_homePtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, int, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>, int, result_cb_t, ffi.Pointer<ffi.Void>)>();

  /// @brief Adds a widget to home, asynchronously.
  /// @since_tizen 2.4
  /// @remarks If a homescreen does not support this feature, you will get a proper error code.\n
  /// Application must check the return value of this function.\n
  /// Application must check the return status from the callback function.\n
  /// Application should set the callback function to get the result of this request.
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/shortcut
  /// @param[in] name The name of the created widget which will be shown when the widget is not prepared
  /// @param[in] size The size of widget
  /// @param[in] widget_id Widget ID
  /// @param[in] icon The absolute path of an icon file which will be shown when the widget is not prepared
  /// @param[in] period The Update period in seconds
  /// @param[in] allow_duplicate @c 1 if it accepts the duplicated widget,
  /// otherwise @c 0
  /// @param[in] result_cb The address of the callback function that is called when the result comes back from the viewer
  /// @param[in] data The callback data that is used in the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SHORTCUT_ERROR_NONE Successful
  /// @retval #SHORTCUT_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SHORTCUT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SHORTCUT_ERROR_IO_ERROR I/O Error
  /// @retval #SHORTCUT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #SHORTCUT_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SHORTCUT_ERROR_FAULT Unrecoverable error
  /// @retval #SHORTCUT_ERROR_COMM Connection not established or communication problem
  /// @pre You have to prepare the callback function.
  /// @post You have to check the return status from the callback function which is passed by the argument.
  /// @see result_cb_t
  /// @see shortcut_widget_size_e
  /// @par Example
  /// @code
  /// #include <stdio.h>
  /// #include <shortcut.h>
  /// #include <storage.h>
  ///
  /// #define TIZEN_PATH_MAX 1024
  /// static int result_cb(int ret, int pid, void *data)
  /// {
  /// if (ret < 0)
  /// dlog_print("Failed to add a widget: %s\n", perror(ret));
  ///
  /// dlog_print("Processed by the %d\n", pid);
  ///
  /// return 0;
  /// }
  ///
  /// static int app_create(void *data)
  /// {
  /// char *image_root = NULL;
  /// char image_path[TIZEN_PATH_MAX] = {0,};
  ///
  /// storage_get_directory(STORAGE_TYPE_INTERNAL, STORAGE_DIRECTORY_IMAGES, &image_root);
  /// snprintf(image_path, TIZEN_PATH_MAX, "%s/alter_icon.png", image_root);
  ///
  /// shortcut_add_to_home_widget("alter_name", WIDGET_SIZE_1x1, "org.tizen.testwidget",
  /// image_path, -1.0f, 0, result_cb, NULL);
  ///
  /// return 0;
  /// }
  /// @endcode
  int shortcut_add_to_home_widget(
    ffi.Pointer<ffi.Char> name,
    int size,
    ffi.Pointer<ffi.Char> widget_id,
    ffi.Pointer<ffi.Char> icon,
    double period,
    int allow_duplicate,
    result_cb_t result_cb,
    ffi.Pointer<ffi.Void> data,
  ) {
    return _shortcut_add_to_home_widget(
      name,
      size,
      widget_id,
      icon,
      period,
      allow_duplicate,
      result_cb,
      data,
    );
  }

  late final _shortcut_add_to_home_widgetPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Double,
              ffi.Int,
              result_cb_t,
              ffi.Pointer<ffi.Void>)>>('shortcut_add_to_home_widget');
  late final _shortcut_add_to_home_widget =
      _shortcut_add_to_home_widgetPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              int,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              double,
              int,
              result_cb_t,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Removes a shortcut from home, asynchronously.
  /// @details If the callback function registered for a widget, the shortcut deletion is possible.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/shortcut
  /// @param[in] name The name of the created shortcut icon
  /// @param[in] result_cb The address of the callback function that is called when the result comes back from the viewer
  /// @param[in] user_data The callback data that is used in the callback function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #SHORTCUT_ERROR_NONE Successful
  /// @retval #SHORTCUT_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SHORTCUT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SHORTCUT_ERROR_IO_ERROR I/O Error
  /// @retval #SHORTCUT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #SHORTCUT_ERROR_COMM Connection not established or communication problem
  /// @retval #SHORTCUT_ERROR_NOT_SUPPORTED Not supported
  /// @pre You have to prepare the callback function.
  /// @post You have to check the return status from the callback function which is passed by the argument.
  /// @see result_cb_t
  /// @par Example
  /// @code
  /// #include <shortcut_manager.h>
  ///
  /// int result_cb(int ret, void *data)
  /// {
  /// if (ret < 0)
  /// dlog_print("Failed to remove a shortcut: %d\n", ret);
  ///
  /// return 0;
  /// }
  ///
  /// {
  /// int result;
  ///
  /// result = shortcut_remove_from_home("shortcut_name", result_cb, NULL);
  /// if (result != SHORTCUT_ERROR_NONE) {
  /// dlog_print("Failed to remove a shortcut: %d\n", result);
  /// return result;
  /// }
  /// }
  ///
  /// @endcode
  int shortcut_remove_from_home(
    ffi.Pointer<ffi.Char> name,
    result_cb_t result_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _shortcut_remove_from_home(
      name,
      result_cb,
      user_data,
    );
  }

  late final _shortcut_remove_from_homePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, result_cb_t,
              ffi.Pointer<ffi.Void>)>>('shortcut_remove_from_home');
  late final _shortcut_remove_from_home =
      _shortcut_remove_from_homePtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, result_cb_t, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the preset list of shortcut template from the installed package, synchronously.
  /// @since_tizen 2.4
  /// @remarks If a homescreen does not support this feature, you will get a proper error code.\n
  /// Application must check the return value of this function.\n
  /// Application must check the return status from the callback function.\n
  /// Application should set the callback function to get the result of this request.
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/shortcut
  /// @param[in] package_name The package name
  /// @param[in] list_cb The callback function to get the shortcut item information
  /// @param[in] data The callback data that is used in the callback function
  /// @return The return type (int)
  /// @retval @c N Number of items (call count of the callback function)
  /// @retval #SHORTCUT_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SHORTCUT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SHORTCUT_ERROR_IO_ERROR I/O Error
  /// @retval #SHORTCUT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #SHORTCUT_ERROR_FAULT Unrecoverable error
  /// @retval #SHORTCUT_ERROR_COMM Connection not established or communication problem
  /// @retval #SHORTCUT_ERROR_NOT_SUPPORTED Not supported
  /// @pre You have to prepare the callback function.
  /// @post You have to check the return status from the callback function which is passed by the argument.
  int shortcut_get_list(
    ffi.Pointer<ffi.Char> package_name,
    shortcut_list_cb list_cb,
    ffi.Pointer<ffi.Void> data,
  ) {
    return _shortcut_get_list(
      package_name,
      list_cb,
      data,
    );
  }

  late final _shortcut_get_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, shortcut_list_cb,
              ffi.Pointer<ffi.Void>)>>('shortcut_get_list');
  late final _shortcut_get_list = _shortcut_get_listPtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>, shortcut_list_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Registers a callback function to listen requests from applications.
  /// @since_tizen 2.4
  /// @remarks Should be used in the homescreen.\n
  /// Should check the return value of this function.
  /// Prospective Clients: Homescreen.
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/shortcut
  ///
  /// @param[in] request_cb The callback function pointer that is invoked when add_to_home is requested
  /// @param[in] data The callback data to deliver to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SHORTCUT_ERROR_NONE Successful
  /// @retval #SHORTCUT_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SHORTCUT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SHORTCUT_ERROR_IO_ERROR I/O Error
  /// @retval #SHORTCUT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #SHORTCUT_ERROR_COMM Connection not established or communication problem
  /// @retval #SHORTCUT_ERROR_NOT_SUPPORTED Not supported
  /// @pre You have to prepare a callback function.
  /// @post If a request is sent from the application, the registered callback will be invoked.
  /// @see request_cb_t
  /// @see shortcut_error_e
  int shortcut_set_request_cb(
    shortcut_request_cb request_cb,
    ffi.Pointer<ffi.Void> data,
  ) {
    return _shortcut_set_request_cb(
      request_cb,
      data,
    );
  }

  late final _shortcut_set_request_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(shortcut_request_cb,
              ffi.Pointer<ffi.Void>)>>('shortcut_set_request_cb');
  late final _shortcut_set_request_cb = _shortcut_set_request_cbPtr
      .asFunction<int Function(shortcut_request_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters a callback for the shortcut request.
  /// @since_tizen 3.0
  /// @remarks The specific error code can be obtained using the gat_last_result() method. Error codes are described in Exception section.
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/shortcut
  /// @return None
  /// @exception #SHORTCUT_ERROR_NONE Successful
  /// @exception #SHORTCUT_ERROR_NOT_SUPPORTED Not supported
  /// @exception #SHORTCUT_ERROR_PERMISSION_DENIED Permission denied
  /// @see shortcut_set_request_cb
  /// @see get_last_result()
  void shortcut_unset_request_cb() {
    return _shortcut_unset_request_cb();
  }

  late final _shortcut_unset_request_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function()>>(
          'shortcut_unset_request_cb');
  late final _shortcut_unset_request_cb =
      _shortcut_unset_request_cbPtr.asFunction<void Function()>();

  /// @brief Registers the callback function to listen the remove requests from applications.
  /// @remarks Should be used in the homescreen.\n
  /// Should check the return value of this function.
  /// Prospective Clients: Homescreen.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/shortcut
  /// @param[in] remove_cb The callback function pointer that is invoked when remove_from_home is requested
  /// @param[in] data The callback data to deliver to the callback function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #SHORTCUT_ERROR_NONE Successful
  /// @retval #SHORTCUT_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SHORTCUT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SHORTCUT_ERROR_IO_ERROR I/O Error
  /// @retval #SHORTCUT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #SHORTCUT_ERROR_COMM Connection not established or communication problem
  /// @retval #SHORTCUT_ERROR_NOT_SUPPORTED Not supported
  /// @pre You have to prepare a callback function.
  /// @post If a request is sent from the application, the registered callback will be invoked.
  /// @see remove_cb_t
  /// @see shortcut_error_e
  int shortcut_set_remove_cb(
    shortcut_remove_cb remove_cb,
    ffi.Pointer<ffi.Void> data,
  ) {
    return _shortcut_set_remove_cb(
      remove_cb,
      data,
    );
  }

  late final _shortcut_set_remove_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(shortcut_remove_cb,
              ffi.Pointer<ffi.Void>)>>('shortcut_set_remove_cb');
  late final _shortcut_set_remove_cb = _shortcut_set_remove_cbPtr
      .asFunction<int Function(shortcut_remove_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters a callback for the shortcut remove.
  /// @since_tizen 3.0
  /// @remarks The specific error code can be obtained using the gat_last_result() method. Error codes are described in Exception section.
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/shortcut
  /// @return None
  /// @exception #SHORTCUT_ERROR_NONE Successful
  /// @exception #SHORTCUT_ERROR_NOT_SUPPORTED Not supported
  /// @exception #SHORTCUT_ERROR_PERMISSION_DENIED Permission denied
  /// @see shortcut_set_remove_cb
  /// @see get_last_result()
  void shortcut_unset_remove_cb() {
    return _shortcut_unset_remove_cb();
  }

  late final _shortcut_unset_remove_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function()>>(
          'shortcut_unset_remove_cb');
  late final _shortcut_unset_remove_cb =
      _shortcut_unset_remove_cbPtr.asFunction<void Function()>();

  /// @brief Creates a new download request and return its download ID.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks The @a download_id is released with download_destroy() by client.
  ///
  /// @param[out] download_id The download ID that is newly created on success
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_IO_ERROR          Internal I/O error
  /// @retval #DOWNLOAD_ERROR_QUEUE_FULL        Download server queue is full
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @post The download state will be #DOWNLOAD_STATE_READY.
  ///
  /// @see download_destroy()
  int download_create(
    ffi.Pointer<ffi.Int> download_id,
  ) {
    return _download_create(
      download_id,
    );
  }

  late final _download_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'download_create');
  late final _download_create =
      _download_createPtr.asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Unloads all data concerning a download ID from memory.
  ///
  /// @details After calling this API, a download ID is existed at DB in certain time.
  /// Within that time, it is able to use the other API with the download ID.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  ///
  /// @remarks If #DOWNLOAD_ERROR_ID_NOT_FOUND is returned, it means that the download ID is completely removed from DB.
  ///
  /// @param[in] download_id The download ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_create()
  int download_destroy(
    int download_id,
  ) {
    return _download_destroy(
      download_id,
    );
  }

  late final _download_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'download_destroy');
  late final _download_destroy =
      _download_destroyPtr.asFunction<int Function(int)>();

  /// @brief Sets the URL to download.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function should be called before downloading (see download_start()).
  ///
  /// @param[in] download_id  The download ID
  /// @param[in] url          The URL to download \n
  /// If @a url is @c NULL, it clears the previous value.
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_FAILED, or #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_get_url()
  int download_set_url(
    int download_id,
    ffi.Pointer<ffi.Char> url,
  ) {
    return _download_set_url(
      download_id,
      url,
    );
  }

  late final _download_set_urlPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Char>)>>(
      'download_set_url');
  late final _download_set_url = _download_set_urlPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the URL to download.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks You must release @a url using free().
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] url          The URL to download
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_url()
  int download_get_url(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> url,
  ) {
    return _download_get_url(
      download_id,
      url,
    );
  }

  late final _download_get_urlPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('download_get_url');
  late final _download_get_url = _download_get_urlPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the allowed network type for the downloaded file.
  ///
  /// @details The file can be downloaded only under the allowed network.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function should be called before downloading (see download_start()).
  ///
  /// @param[in] download_id  The download ID
  /// @param[in] net_type     The network type that the client prefers
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_FAILED, or #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_get_network_type()
  /// @see #download_network_type_e
  int download_set_network_type(
    int download_id,
    int net_type,
  ) {
    return _download_set_network_type(
      download_id,
      net_type,
    );
  }

  late final _download_set_network_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int32)>>(
          'download_set_network_type');
  late final _download_set_network_type =
      _download_set_network_typePtr.asFunction<int Function(int, int)>();

  /// @brief Gets the network type for the downloaded file.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in] download_id  The download ID
  /// @param[out] net_type    The network type that is defined by client
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_network_type()
  /// @see #download_network_type_e
  int download_get_network_type(
    int download_id,
    ffi.Pointer<ffi.Int32> net_type,
  ) {
    return _download_get_network_type(
      download_id,
      net_type,
    );
  }

  late final _download_get_network_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<ffi.Int32>)>>('download_get_network_type');
  late final _download_get_network_type = _download_get_network_typePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the destination for the downloaded file.
  ///
  /// @details The file will be downloaded to the specified destination.
  /// The downloaded file is saved to an auto-generated file name in the destination.
  /// If the destination is not specified, the file will be downloaded to default storage (see the @ref CAPI_SYSTEM_STORAGE_MODULE API).
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function should be called before downloading (see download_start()).
  ///
  /// @param[in] download_id  The download ID
  /// @param[in] path         The absolute path to the downloaded file \n
  /// If @a path is @c NULL, it clears the previous value.
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_FAILED, or #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_get_destination()
  int download_set_destination(
    int download_id,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _download_set_destination(
      download_id,
      path,
    );
  }

  late final _download_set_destinationPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Char>)>>(
      'download_set_destination');
  late final _download_set_destination = _download_set_destinationPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the destination path for the downloaded file.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks You must release @a path using free().
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] path         The absolute path to the downloaded file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_destination()
  int download_get_destination(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _download_get_destination(
      download_id,
      path,
    );
  }

  late final _download_get_destinationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('download_get_destination');
  late final _download_get_destination = _download_get_destinationPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the name for the downloaded file.
  ///
  /// @details The file will be saved in the specified destination with the given file name.
  /// If the file name is not specified, the downloaded file will be saved with an auto-generated file name in the destination.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function should be called before downloading (see download_start()).
  ///
  /// @param[in] download_id  The download ID
  /// @param[in] file_name    The file name for the downloaded file \n
  /// If @a name is @c NULL it clears the previous value.
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_FAILED, or #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_get_file_name()
  int download_set_file_name(
    int download_id,
    ffi.Pointer<ffi.Char> file_name,
  ) {
    return _download_set_file_name(
      download_id,
      file_name,
    );
  }

  late final _download_set_file_namePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Char>)>>(
      'download_set_file_name');
  late final _download_set_file_name = _download_set_file_namePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the name of the downloaded file set previously by download_set_file_name().
  ///
  /// @details If the name is not set, @c NULL is returned.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks You must release @a file_name using free().
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] file_name    The file name which is set by user
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_file_name()
  int download_get_file_name(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> file_name,
  ) {
    return _download_get_file_name(
      download_id,
      file_name,
    );
  }

  late final _download_get_file_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('download_get_file_name');
  late final _download_get_file_name = _download_get_file_namePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the absolute path to save the downloaded file.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function returns #DOWNLOAD_ERROR_INVALID_STATE if the download is not completed.
  /// You must release @a path using free().
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] path         The absolute path to the downloaded file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE               Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND       No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The download state must be #DOWNLOAD_STATE_COMPLETED.
  ///
  /// @see download_set_file_name()
  /// @see download_set_destination()
  int download_get_downloaded_file_path(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _download_get_downloaded_file_path(
      download_id,
      path,
    );
  }

  late final _download_get_downloaded_file_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'download_get_downloaded_file_path');
  late final _download_get_downloaded_file_path =
      _download_get_downloaded_file_pathPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the MIME type of the downloaded content.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function returns #DOWNLOAD_ERROR_INVALID_STATE if the download has not been started.
  /// You must release @a mime_type using free().
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] mime_type    The MIME type of the downloaded file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_file_name()
  /// @see download_set_destination()
  /// @see download_get_downloaded_file_path()
  int download_get_mime_type(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mime_type,
  ) {
    return _download_get_mime_type(
      download_id,
      mime_type,
    );
  }

  late final _download_get_mime_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('download_get_mime_type');
  late final _download_get_mime_type = _download_get_mime_typePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Enables or disables auto download.
  /// @details If this option is enabled,
  /// the previous downloading item is restarted automatically as soon as the download daemon is restarted.
  /// The download progress continues after the client process is terminated.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks The client should call download_set_notification() and download_set_notification_extra_param() after calling this API.
  /// If it is not done, the user will not receive the download result in case the client process is not alive. \n
  /// The default value is @c false.
  ///
  /// @param[in] download_id The download ID
  /// @param[in] enable      Set @c true to enable auto download,
  /// otherwise set @c false to disable auto download
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_FAILED, or #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_get_auto_download()
  /// @see download_set_notification()
  /// @see download_set_notification_extra_param()
  int download_set_auto_download(
    int download_id,
    bool enable,
  ) {
    return _download_set_auto_download(
      download_id,
      enable,
    );
  }

  late final _download_set_auto_downloadPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Bool)>>(
          'download_set_auto_download');
  late final _download_set_auto_download =
      _download_set_auto_downloadPtr.asFunction<int Function(int, bool)>();

  /// @brief Checks whether auto download is enabled.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in]  download_id The download ID
  /// @param[out] enable      @c true if auto download is enabled,
  /// otherwise @c false if auto download is disabled
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_auto_download()
  int download_get_auto_download(
    int download_id,
    ffi.Pointer<ffi.Bool> enable,
  ) {
    return _download_get_auto_download(
      download_id,
      enable,
    );
  }

  late final _download_get_auto_downloadPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Bool>)>>(
      'download_get_auto_download');
  late final _download_get_auto_download = _download_get_auto_downloadPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Adds a HTTP header field to the download request.
  ///
  /// @details The given HTTP header field will be included with the HTTP request of the download request.
  /// For more information, see <a href="HTTP://www.w3.org/Protocols/rfc2616/rfc2616-sec4.html#sec4.2">HTTP/1.1: HTTP Message Headers</a>.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function should be called before downloading (see download_start()).
  /// This function replaces any existing value for the given key.
  /// This function returns #DOWNLOAD_ERROR_INVALID_PARAMETER if @a field or @a value is a zero-length string.
  ///
  /// @param[in] download_id  The download ID
  /// @param[in] field        The name of the HTTP header field
  /// @param[in] value        The value associated with given field
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_IO_ERROR Internal I/O error
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_FAILED, or #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_get_http_header_field()
  /// @see download_remove_http_header_field()
  int download_add_http_header_field(
    int download_id,
    ffi.Pointer<ffi.Char> field,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _download_add_http_header_field(
      download_id,
      field,
      value,
    );
  }

  late final _download_add_http_header_fieldPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('download_add_http_header_field');
  late final _download_add_http_header_field =
      _download_add_http_header_fieldPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets a value associated with a given HTTP header field from the download.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function returns #DOWNLOAD_ERROR_INVALID_PARAMETER if @a field is zero-length string.
  /// You must release @a value using free().
  ///
  /// @param[in]  download_id  The download ID
  /// @param[in]  field        The name of the HTTP header field
  /// @param[out] value        The value associated with given field
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_FIELD_NOT_FOUND   Specified field not found
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_add_http_header_field()
  /// @see download_remove_http_header_field()
  int download_get_http_header_field(
    int download_id,
    ffi.Pointer<ffi.Char> field,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _download_get_http_header_field(
      download_id,
      field,
      value,
    );
  }

  late final _download_get_http_header_fieldPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'download_get_http_header_field');
  late final _download_get_http_header_field =
      _download_get_http_header_fieldPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets all the HTTP header fields added to the download request.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks You must release @a value using free().
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] fields       The array of the HTTP header fields
  /// @param[out] length       The number of the HTTP header fields
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_add_http_header_field()
  /// @see download_remove_http_header_field()
  int download_get_http_header_field_list(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>> fields,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _download_get_http_header_field_list(
      download_id,
      fields,
      length,
    );
  }

  late final _download_get_http_header_field_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>)>>('download_get_http_header_field_list');
  late final _download_get_http_header_field_list =
      _download_get_http_header_field_listPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Removes a given HTTP header field from the download.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function should be called before downloading (see download_start()).
  /// This function returns #DOWNLOAD_ERROR_INVALID_PARAMETER if field is zero-length string.
  ///
  /// @param[in] download_id  The download ID
  /// @param[in] field        The name of the HTTP header field
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_FIELD_NOT_FOUND   Specified field not found
  /// @retval #DOWNLOAD_ERROR_IO_ERROR          Internal I/O error
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_FAILED, or #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_add_http_header_field()
  /// @see download_get_http_header_field()
  int download_remove_http_header_field(
    int download_id,
    ffi.Pointer<ffi.Char> field,
  ) {
    return _download_remove_http_header_field(
      download_id,
      field,
    );
  }

  late final _download_remove_http_header_fieldPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Char>)>>(
      'download_remove_http_header_field');
  late final _download_remove_http_header_field =
      _download_remove_http_header_fieldPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Registers a callback function to be invoked when a download state is changed.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function should be called before downloading (see download_start()).
  ///
  /// @param[in] download_id  The download ID
  /// @param[in] callback     The callback function to register
  /// @param[in] user_data    The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @post download_state_changed_cb() will be invoked.
  ///
  /// @see download_unset_state_changed_cb()
  /// @see download_state_changed_cb()
  int download_set_state_changed_cb(
    int download_id,
    download_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _download_set_state_changed_cb(
      download_id,
      callback,
      user_data,
    );
  }

  late final _download_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, download_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('download_set_state_changed_cb');
  late final _download_set_state_changed_cb =
      _download_set_state_changed_cbPtr.asFunction<
          int Function(
              int, download_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the download state change callback function.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function should be called before downloading (see download_start()).
  ///
  /// @param[in] download_id The download ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_state_changed_cb()
  /// @see download_state_changed_cb()
  int download_unset_state_changed_cb(
    int download_id,
  ) {
    return _download_unset_state_changed_cb(
      download_id,
    );
  }

  late final _download_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'download_unset_state_changed_cb');
  late final _download_unset_state_changed_cb =
      _download_unset_state_changed_cbPtr.asFunction<int Function(int)>();

  /// @brief Registers a callback function to be invoked when progress of the download changes.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function should be called before downloading (see download_start()).
  ///
  /// @param[in] download_id  The download ID
  /// @param[in] callback     The callback function to register
  /// @param[in] user_data    The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @post download_progress_cb() will be invoked.
  ///
  /// @see download_unset_progress_cb()
  /// @see download_progress_cb()
  int download_set_progress_cb(
    int download_id,
    download_progress_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _download_set_progress_cb(
      download_id,
      callback,
      user_data,
    );
  }

  late final _download_set_progress_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, download_progress_cb,
              ffi.Pointer<ffi.Void>)>>('download_set_progress_cb');
  late final _download_set_progress_cb =
      _download_set_progress_cbPtr.asFunction<
          int Function(int, download_progress_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the download progress change callback function.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks This function should be called before downloading (see download_start()).
  ///
  /// @param[in] download_id The download ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_progress_cb()
  /// @see download_progress_cb()
  int download_unset_progress_cb(
    int download_id,
  ) {
    return _download_unset_progress_cb(
      download_id,
    );
  }

  late final _download_unset_progress_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'download_unset_progress_cb');
  late final _download_unset_progress_cb =
      _download_unset_progress_cbPtr.asFunction<int Function(int)>();

  /// @brief Starts or resumes the download, asynchronously.
  ///
  /// @details This function starts to download the current URL, or resumes the download if paused.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks The URL is the mandatory information to start the download.
  /// @remarks It should call download_set_progress_cb() and download_set_state_changed_cb() again
  /// after the client process is restarted or download_destroy() is called.
  ///
  /// @param[in] download_id The download ID
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_IO_ERROR          Internal I/O error
  /// @retval #DOWNLOAD_ERROR_INVALID_URL       Invalid URL
  /// @retval #DOWNLOAD_ERROR_INVALID_DESTINATION Invalid destination
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_QUEUE_FULL        Download server queue is full
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre  The download state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_PAUSED, #DOWNLOAD_STATE_CANCELED, or #DOWNLOAD_STATE_FAILED.
  /// @post The download state will be #DOWNLOAD_STATE_QUEUED or #DOWNLOAD_STATE_DOWNLOADING.
  ///
  /// @see download_set_url()
  /// @see download_pause()
  /// @see download_cancel()
  int download_start(
    int download_id,
  ) {
    return _download_start(
      download_id,
    );
  }

  late final _download_startPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>('download_start');
  late final _download_start =
      _download_startPtr.asFunction<int Function(int)>();

  /// @brief Pauses the download, asynchronously.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks The paused download can be restarted with download_start() or cancelled with download_cancel().
  ///
  /// @param[in] download_id The download ID
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_IO_ERROR          Internal I/O error
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre  The download state must be #DOWNLOAD_STATE_DOWNLOADING.
  /// @post The download state will be #DOWNLOAD_STATE_PAUSED.
  ///
  /// @see download_start()
  /// @see download_cancel()
  int download_pause(
    int download_id,
  ) {
    return _download_pause(
      download_id,
    );
  }

  late final _download_pausePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>('download_pause');
  late final _download_pause =
      _download_pausePtr.asFunction<int Function(int)>();

  /// @brief Cancels the download, asynchronously.
  ///
  /// @details This function cancels the running download and its state will be #DOWNLOAD_STATE_READY.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks The canceled download can be restarted with download_start().
  ///
  /// @param[in] download_id The download ID
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #DOWNLOAD_ERROR_INVALID_STATE     Invalid state
  /// @retval #DOWNLOAD_ERROR_IO_ERROR          Internal I/O error
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre  The download state must be #DOWNLOAD_STATE_QUEUED, #DOWNLOAD_STATE_DOWNLOADING, or #DOWNLOAD_STATE_PAUSED.
  /// @post The download state will be #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_start()
  int download_cancel(
    int download_id,
  ) {
    return _download_cancel(
      download_id,
    );
  }

  late final _download_cancelPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>('download_cancel');
  late final _download_cancel =
      _download_cancelPtr.asFunction<int Function(int)>();

  /// @brief Gets the current state of the download.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] state        The current state of the download
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see #download_state_e
  int download_get_state(
    int download_id,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _download_get_state(
      download_id,
      state,
    );
  }

  late final _download_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<ffi.Int32>)>>('download_get_state');
  late final _download_get_state = _download_get_statePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the full path of the temporary file to store downloaded content.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] temp_path    The full path of temporary file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The download state must be one of the states after #DOWNLOAD_STATE_DOWNLOADING.
  ///
  /// @see download_set_state_changed_cb()
  /// @see download_unset_state_changed_cb()
  /// @see download_start()
  int download_get_temp_path(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> temp_path,
  ) {
    return _download_get_temp_path(
      download_id,
      temp_path,
    );
  }

  late final _download_get_temp_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('download_get_temp_path');
  late final _download_get_temp_path = _download_get_temp_pathPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the directory path of the temporary file used in the previous download request.
  /// @details This is only useful when resuming download to make HTTP request header at the client side.
  /// Otherwise, the path should be ignored internally.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks If the etag value is not present in the download database, it is useless to set the temporary path. \n
  /// When resuming download, the data is attached at the end of this temporary file.
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] path         The full path of temporary file
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_FAILED, or #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_get_etag()
  int download_set_temp_file_path(
    int download_id,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _download_set_temp_file_path(
      download_id,
      path,
    );
  }

  late final _download_set_temp_file_pathPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Char>)>>(
      'download_set_temp_file_path');
  late final _download_set_temp_file_path = _download_set_temp_file_pathPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the content name of downloaded file.
  ///
  /// @details This can be defined with reference of HTTP response header data.
  /// The content name can be received when HTTP response header is received.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in]  download_id   The download ID
  /// @param[out] content_name  The content name for displaying to user
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The download state must be one of the states after #DOWNLOAD_STATE_DOWNLOADING.
  ///
  /// @see download_set_state_changed_cb()
  /// @see download_unset_state_changed_cb()
  /// @see download_start()
  int download_get_content_name(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> content_name,
  ) {
    return _download_get_content_name(
      download_id,
      content_name,
    );
  }

  late final _download_get_content_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'download_get_content_name');
  late final _download_get_content_name = _download_get_content_namePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the total size of downloaded content.
  ///
  /// @details This information is received from the server. If the server does not send the total size of the content, @a content_size is set to zero.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] content_size The content size for displaying to user
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The download state must be one of the states after #DOWNLOAD_STATE_DOWNLOADING.
  ///
  /// @see download_set_state_changed_cb()
  /// @see download_unset_state_changed_cb()
  /// @see download_start()
  int download_get_content_size(
    int download_id,
    ffi.Pointer<ffi.UnsignedLongLong> content_size,
  ) {
    return _download_get_content_size(
      download_id,
      content_size,
    );
  }

  late final _download_get_content_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<ffi.UnsignedLongLong>)>>('download_get_content_size');
  late final _download_get_content_size = _download_get_content_sizePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.UnsignedLongLong>)>();

  /// @brief Gets an error value when the download fails.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in]  download_id The download ID
  /// @param[out] error       The error value
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The download state must be #DOWNLOAD_STATE_FAILED.
  /// @pre The download state must be #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_set_state_changed_cb()
  /// @see download_unset_state_changed_cb()
  /// @see download_start()
  /// @see download_error_e
  int download_get_error(
    int download_id,
    ffi.Pointer<ffi.Int32> error,
  ) {
    return _download_get_error(
      download_id,
      error,
    );
  }

  late final _download_get_errorPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<ffi.Int32>)>>('download_get_error');
  late final _download_get_error = _download_get_errorPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets a HTTP status code when a download error occurs.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] HTTP_status  The HTTP status code defined in RFC 2616
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The download state must be #DOWNLOAD_STATE_FAILED.
  ///
  /// @see download_set_download_status_cb()
  /// @see download_unset_download_status_cb()
  /// @see download_start()
  int download_get_http_status(
    int download_id,
    ffi.Pointer<ffi.Int> HTTP_status,
  ) {
    return _download_get_http_status(
      download_id,
      HTTP_status,
    );
  }

  late final _download_get_http_statusPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'download_get_http_status');
  late final _download_get_http_status = _download_get_http_statusPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets an app control handle to register notification messages.
  /// @details Three types of notification message can be posted: completion, failed and ongoing type.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks When the notification message is clicked, the action to take is decided by the app control handle. \n
  /// If the app control handle is not set, the following default operation is executed when the notification message is clicked: \n
  /// 1) download completed state - the viewer application is executed according to extension name of downloaded content, \n
  /// 2) download failed state and ongoing state - the client application is executed. \n
  /// This function should be called before starting the download. \n
  /// The app control handle MUST BE FREED by the client when it is not used any more.
  ///
  /// @param[in] download_id The download ID
  /// @param[in] type        The enumeration type \n
  /// See #download_notification_app_control_type_e.
  /// @param[in] handle      The app control handle pointer value
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_FAILED, or #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_set_notification_type()
  /// @see download_get_notification_app_control()
  int download_set_notification_app_control(
    int download_id,
    int type,
    app_control_h handle,
  ) {
    return _download_set_notification_app_control(
      download_id,
      type,
      handle,
    );
  }

  late final _download_set_notification_app_controlPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int32,
              app_control_h)>>('download_set_notification_app_control');
  late final _download_set_notification_app_control =
      _download_set_notification_app_controlPtr
          .asFunction<int Function(int, int, app_control_h)>();

  /// @brief Gets the app control handle (used previously to register notification messages) which is set by download_set_notification_app_control().
  ///
  /// @details When the notification message is clicked, the action is decided by the app control handle.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks The app control handle MUST BE FREED by the client when it is not used any more.
  ///
  /// @param[in]  download_id The download ID
  /// @param[in]  type        The enumeration type \n
  /// See #download_notification_app_control_type_e.
  /// @param[out] handle      The app control handle pointer value
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_NO_DATA           The app control handle has not been set
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_notification_app_control()
  int download_get_notification_app_control(
    int download_id,
    int type,
    ffi.Pointer<app_control_h> handle,
  ) {
    return _download_get_notification_app_control(
      download_id,
      type,
      handle,
    );
  }

  late final _download_get_notification_app_controlPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Int, ffi.Int32, ffi.Pointer<app_control_h>)>>(
      'download_get_notification_app_control');
  late final _download_get_notification_app_control =
      _download_get_notification_app_controlPtr
          .asFunction<int Function(int, int, ffi.Pointer<app_control_h>)>();

  /// @brief Sets the title of a notification.
  ///
  /// @details When registering a notification, the title is displayed in the title area of the notification message.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in] download_id The download ID
  /// @param[in] title       The title for displaying to user
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre If a notification option is not enabled, this title is not shown to user.
  ///
  /// @see download_set_notification_type()
  /// @see download_get_notification_title()
  int download_set_notification_title(
    int download_id,
    ffi.Pointer<ffi.Char> title,
  ) {
    return _download_set_notification_title(
      download_id,
      title,
    );
  }

  late final _download_set_notification_titlePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Char>)>>(
      'download_set_notification_title');
  late final _download_set_notification_title =
      _download_set_notification_titlePtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the title of the notification set by download_set_notification_title().
  ///
  /// @details When registering a notification, the title is displayed in the title area of the notification message.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] title        The title for displaying to user
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_NO_DATA           The title has not been set
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre It can get the title value before calling this API.
  ///
  /// @see download_set_notification_title()
  int download_get_notification_title(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> title,
  ) {
    return _download_get_notification_title(
      download_id,
      title,
    );
  }

  late final _download_get_notification_titlePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'download_get_notification_title');
  late final _download_get_notification_title =
      _download_get_notification_titlePtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the description of a notification.
  ///
  /// @details When registering a notification, the description is displayed in the description area of the notification message.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in] download_id  The download ID
  /// @param[in] description  The description for displaying to user
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre If the notification option is not enabled, this description is not shown to user.
  ///
  /// @see download_set_notification_type()
  /// @see download_get_notification_description()
  int download_set_notification_description(
    int download_id,
    ffi.Pointer<ffi.Char> description,
  ) {
    return _download_set_notification_description(
      download_id,
      description,
    );
  }

  late final _download_set_notification_descriptionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Char>)>>(
      'download_set_notification_description');
  late final _download_set_notification_description =
      _download_set_notification_descriptionPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the description of a notification set by download_set_notification_description().
  ///
  /// @details When registering a notification, the description is displayed in the description area of the notification message.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] description  The description for displaying to user
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_NO_DATA           The description has not been set
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre It can get the title value before calling this API.
  ///
  /// @see download_set_notification_description()
  int download_get_notification_description(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> description,
  ) {
    return _download_get_notification_description(
      download_id,
      description,
    );
  }

  late final _download_get_notification_descriptionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'download_get_notification_description');
  late final _download_get_notification_description =
      _download_get_notification_descriptionPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets an option value to register notification messages.
  /// @details Three types of notification message can be posted: completion, failed and ongoing type.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks When the notification message is clicked, the action to take is decided by the app control handle (set by download_set_notification_app_control()). \n
  /// If the app control is not set, the following default operation is executed when the notification message is clicked: \n
  /// 1) download completed state - the viewer application is executed according to extension name of downloaded content, \n
  /// 2) download failed state and ongoing state - the client application is executed. \n
  /// The default type is #DOWNLOAD_NOTIFICATION_TYPE_NONE. \n
  /// This function should be called before starting the download.
  ///
  /// @param[in] download_id  The download ID
  /// @param[in] type         The enumeration type \n
  /// See #download_notification_type_e.
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The state must be #DOWNLOAD_STATE_READY, #DOWNLOAD_STATE_FAILED, or #DOWNLOAD_STATE_CANCELED.
  ///
  /// @see download_set_notification_app_control()
  /// @see download_get_notification_type()
  int download_set_notification_type(
    int download_id,
    int type,
  ) {
    return _download_set_notification_type(
      download_id,
      type,
    );
  }

  late final _download_set_notification_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int32)>>(
          'download_set_notification_type');
  late final _download_set_notification_type =
      _download_set_notification_typePtr.asFunction<int Function(int, int)>();

  /// @brief Gets an option value to register notification messages set by download_set_notification_type().
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks When the notification message is clicked, the action is decided by the app control from download_set_notification_app_control(). \n
  /// The default type is #DOWNLOAD_NOTIFICATION_TYPE_NONE.
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] type         The enumeration type \n
  /// See #download_notification_type_e.
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_notification_type()
  int download_get_notification_type(
    int download_id,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _download_get_notification_type(
      download_id,
      type,
    );
  }

  late final _download_get_notification_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<ffi.Int32>)>>('download_get_notification_type');
  late final _download_get_notification_type =
      _download_get_notification_typePtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets an etag value from the HTTP response header when making a HTTP request for resume.
  ///
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/download
  ///
  /// @remarks The etag value is available or not depending on the web server. \n
  /// After download is started, it can get the etag value.
  ///
  /// @param[in]  download_id  The download ID
  /// @param[out] etag         The etag value
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #DOWNLOAD_ERROR_NONE              Successful
  /// @retval #DOWNLOAD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DOWNLOAD_ERROR_ID_NOT_FOUND      No download ID
  /// @retval #DOWNLOAD_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DOWNLOAD_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @see download_set_temp_file_path()
  int download_get_etag(
    int download_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> etag,
  ) {
    return _download_get_etag(
      download_id,
      etag,
    );
  }

  late final _download_get_etagPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('download_get_etag');
  late final _download_get_etag = _download_get_etagPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the MIME type for the given file extension.
  ///
  /// @remarks The @a mime_type must be released with free() by you.
  /// @param[in] file_extension The file extension without the leading dot ('.')
  /// @param[out] mime_type The MIME type for the given file extension \n
  /// The MIME type is 'application/octet-stream' if the given file extension is not associated with specific file formats
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MIME_TYPE_ERROR_NONE Successful
  /// @retval #MIME_TYPE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MIME_TYPE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MIME_TYPE_ERROR_IO_ERROR Internal I/O error
  /// @see mime_type_get_file_extension()
  int mime_type_get_mime_type(
    ffi.Pointer<ffi.Char> file_extension,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mime_type,
  ) {
    return _mime_type_get_mime_type(
      file_extension,
      mime_type,
    );
  }

  late final _mime_type_get_mime_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('mime_type_get_mime_type');
  late final _mime_type_get_mime_type = _mime_type_get_mime_typePtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the file extensions for the given MIME type.
  ///
  /// @remarks The @a file_extension must be released with free() by you.
  /// @param[in] mime_type The MIME type
  /// @param[out] file_extension The array of file extension without the leading dot ('.')
  /// @param[out] length The length of the array of file extension or zero if there is none
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MIME_TYPE_ERROR_NONE Successful
  /// @retval #MIME_TYPE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MIME_TYPE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MIME_TYPE_ERROR_IO_ERROR Internal I/O error
  /// @see mime_type_get_mime_type()
  int mime_type_get_file_extension(
    ffi.Pointer<ffi.Char> mime_type,
    ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>> file_extension,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _mime_type_get_file_extension(
      mime_type,
      file_extension,
      length,
    );
  }

  late final _mime_type_get_file_extensionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>)>>('mime_type_get_file_extension');
  late final _mime_type_get_file_extension =
      _mime_type_get_file_extensionPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the MIME type for the given data.
  ///
  /// @since_tizen 4.0
  /// @remarks The @a mime_type must be released with free() by you.
  /// @param[in] data The stream of file data
  /// @param[in] len The length of data
  /// @param[out] mime_type The MIME type for the given file extension \n
  /// The MIME type is 'application/octet-stream' if the given file extension is not associated with specific file formats
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MIME_TYPE_ERROR_NONE Successful
  /// @retval #MIME_TYPE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MIME_TYPE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MIME_TYPE_ERROR_IO_ERROR Internal I/O error
  int mime_type_get_mime_type_for_data(
    ffi.Pointer<ffi.Void> data,
    int len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mime_type,
  ) {
    return _mime_type_get_mime_type_for_data(
      data,
      len,
      mime_type,
    );
  }

  late final _mime_type_get_mime_type_for_dataPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Void>, ffi.Size,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mime_type_get_mime_type_for_data');
  late final _mime_type_get_mime_type_for_data =
      _mime_type_get_mime_type_for_dataPtr.asFunction<
          int Function(ffi.Pointer<ffi.Void>, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the MIME type for the given file path.
  ///
  /// @since_tizen 4.0
  /// @remarks The @a mime_type must be released with free() by you.
  /// @remarks http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.
  /// @remarks http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  /// @param[in] file_path The path of target file
  /// @param[out] mime_type The MIME type for the given file extension \n
  /// The MIME type is 'application/octet-stream' if the given file extension is not associated with specific file formats
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MIME_TYPE_ERROR_NONE Successful
  /// @retval #MIME_TYPE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MIME_TYPE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MIME_TYPE_ERROR_IO_ERROR Internal I/O error
  /// @retval #MIME_TYPE_ERROR_PERMISSION_DENIED Permission denined
  int mime_type_get_mime_type_for_file(
    ffi.Pointer<ffi.Char> file_path,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mime_type,
  ) {
    return _mime_type_get_mime_type_for_file(
      file_path,
      mime_type,
    );
  }

  late final _mime_type_get_mime_type_for_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mime_type_get_mime_type_for_file');
  late final _mime_type_get_mime_type_for_file =
      _mime_type_get_mime_type_for_filePtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the icon name for the given MIME type.
  ///
  /// @since_tizen 4.0
  /// @remarks The @a icon must be released with free() by you.
  /// @param[in] mime_type The MIME type
  /// @param[out] icon The icon name for the given MIME type
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MIME_TYPE_ERROR_NONE Successful
  /// @retval #MIME_TYPE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MIME_TYPE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MIME_TYPE_ERROR_IO_ERROR Internal I/O error
  /// @see mime_type_get_mime_type()
  int mime_type_get_icon(
    ffi.Pointer<ffi.Char> mime_type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> icon,
  ) {
    return _mime_type_get_icon(
      mime_type,
      icon,
    );
  }

  late final _mime_type_get_iconPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('mime_type_get_icon');
  late final _mime_type_get_icon = _mime_type_get_iconPtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the generic icon name for the given MIME type.
  ///
  /// @since_tizen 4.0
  /// @remarks The @a generic_icon must be released with free() by you.
  /// @param[in] mime_type The MIME type
  /// @param[out] generic_icon The generic icon name for the given MIME type
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MIME_TYPE_ERROR_NONE Successful
  /// @retval #MIME_TYPE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MIME_TYPE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MIME_TYPE_ERROR_IO_ERROR Internal I/O error
  /// @see mime_type_get_mime_type()
  int mime_type_get_generic_icon(
    ffi.Pointer<ffi.Char> mime_type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> generic_icon,
  ) {
    return _mime_type_get_generic_icon(
      mime_type,
      generic_icon,
    );
  }

  late final _mime_type_get_generic_iconPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mime_type_get_generic_icon');
  late final _mime_type_get_generic_icon =
      _mime_type_get_generic_iconPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Clones the audio metadata.
  /// @details This function copies the audio metadata handle from a source to destination.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release the destination handle using audio_meta_destroy().
  ///
  /// @param[out] dst The destination handle to the audio metadata
  /// @param[in]  src The source handle to the audio metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @see audio_meta_destroy()
  int audio_meta_clone(
    ffi.Pointer<audio_meta_h> dst,
    audio_meta_h src,
  ) {
    return _audio_meta_clone(
      dst,
      src,
    );
  }

  late final _audio_meta_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<audio_meta_h>, audio_meta_h)>>('audio_meta_clone');
  late final _audio_meta_clone = _audio_meta_clonePtr
      .asFunction<int Function(ffi.Pointer<audio_meta_h>, audio_meta_h)>();

  /// @brief Destroys the audio metadata.
  /// @details This function frees all resources related to the audio metadata handle. This handle
  /// no longer can be used to perform any operation. A new handle has to
  /// be created before the next use.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] audio The audio metadata handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre Get a copy of audio metadata handle handle by calling audio_meta_clone().
  ///
  /// @see audio_meta_clone()
  int audio_meta_destroy(
    audio_meta_h audio,
  ) {
    return _audio_meta_destroy(
      audio,
    );
  }

  late final _audio_meta_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_meta_h)>>(
          'audio_meta_destroy');
  late final _audio_meta_destroy =
      _audio_meta_destroyPtr.asFunction<int Function(audio_meta_h)>();

  /// @brief Gets the ID of the media of the given audio metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a media_id using free().
  ///
  /// @param[in]  audio    The audio metadata handle
  /// @param[out] media_id The ID of the audio
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int audio_meta_get_media_id(
    audio_meta_h audio,
    ffi.Pointer<ffi.Pointer<ffi.Char>> media_id,
  ) {
    return _audio_meta_get_media_id(
      audio,
      media_id,
    );
  }

  late final _audio_meta_get_media_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('audio_meta_get_media_id');
  late final _audio_meta_get_media_id = _audio_meta_get_media_idPtr.asFunction<
      int Function(audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the album of the given audio metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no album info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a album using free().
  ///
  /// @param[in]  audio The audio metadata handle
  /// @param[out] album The album of the audio metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int audio_meta_get_album(
    audio_meta_h audio,
    ffi.Pointer<ffi.Pointer<ffi.Char>> album,
  ) {
    return _audio_meta_get_album(
      audio,
      album,
    );
  }

  late final _audio_meta_get_albumPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('audio_meta_get_album');
  late final _audio_meta_get_album = _audio_meta_get_albumPtr.asFunction<
      int Function(audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the artist of the given audio metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no artist info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a artist using free().
  ///
  /// @param[in]  audio  The audio metadata handle
  /// @param[out] artist The artist of the audio metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int audio_meta_get_artist(
    audio_meta_h audio,
    ffi.Pointer<ffi.Pointer<ffi.Char>> artist,
  ) {
    return _audio_meta_get_artist(
      audio,
      artist,
    );
  }

  late final _audio_meta_get_artistPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('audio_meta_get_artist');
  late final _audio_meta_get_artist = _audio_meta_get_artistPtr.asFunction<
      int Function(audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the album artist of the given audio metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no album artist info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a album_artist using free().
  ///
  /// @param[in]  audio        The audio metadata handle
  /// @param[out] album_artist The album artist of the audio metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int audio_meta_get_album_artist(
    audio_meta_h audio,
    ffi.Pointer<ffi.Pointer<ffi.Char>> album_artist,
  ) {
    return _audio_meta_get_album_artist(
      audio,
      album_artist,
    );
  }

  late final _audio_meta_get_album_artistPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'audio_meta_get_album_artist');
  late final _audio_meta_get_album_artist =
      _audio_meta_get_album_artistPtr.asFunction<
          int Function(audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the genre of the given audio metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no genre info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a genre using free().
  ///
  /// @param[in]  audio The audio metadata handle
  /// @param[out] genre The genre of the audio metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int audio_meta_get_genre(
    audio_meta_h audio,
    ffi.Pointer<ffi.Pointer<ffi.Char>> genre,
  ) {
    return _audio_meta_get_genre(
      audio,
      genre,
    );
  }

  late final _audio_meta_get_genrePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('audio_meta_get_genre');
  late final _audio_meta_get_genre = _audio_meta_get_genrePtr.asFunction<
      int Function(audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the composer of the given audio metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no composer info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a composer using free().
  ///
  /// @param[in]  audio    The audio metadata handle
  /// @param[out] composer The composer of the audio metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int audio_meta_get_composer(
    audio_meta_h audio,
    ffi.Pointer<ffi.Pointer<ffi.Char>> composer,
  ) {
    return _audio_meta_get_composer(
      audio,
      composer,
    );
  }

  late final _audio_meta_get_composerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('audio_meta_get_composer');
  late final _audio_meta_get_composer = _audio_meta_get_composerPtr.asFunction<
      int Function(audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the year of the given audio metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no year info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a year using free().
  ///
  /// @param[in]  audio The audio metadata handle
  /// @param[out] year  The year of the audio metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int audio_meta_get_year(
    audio_meta_h audio,
    ffi.Pointer<ffi.Pointer<ffi.Char>> year,
  ) {
    return _audio_meta_get_year(
      audio,
      year,
    );
  }

  late final _audio_meta_get_yearPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('audio_meta_get_year');
  late final _audio_meta_get_year = _audio_meta_get_yearPtr.asFunction<
      int Function(audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the recorded date of the given audio metadata.
  /// @details The recorded date is got from audio file's metadata. Some formats like mp4 use UTC and the rest can be different. \n
  /// So, please refer to the format specification if needed.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a recorded_date using free().
  ///
  /// @param[in]  audio         The audio metadata handle
  /// @param[out] recorded_date The recorded date of the audio metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int audio_meta_get_recorded_date(
    audio_meta_h audio,
    ffi.Pointer<ffi.Pointer<ffi.Char>> recorded_date,
  ) {
    return _audio_meta_get_recorded_date(
      audio,
      recorded_date,
    );
  }

  late final _audio_meta_get_recorded_datePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'audio_meta_get_recorded_date');
  late final _audio_meta_get_recorded_date =
      _audio_meta_get_recorded_datePtr.asFunction<
          int Function(audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the copyright notice of the given audio metadata.
  /// @details If the media content has no copyright info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a copyright using free().
  ///
  /// @param[in]  audio     The audio metadata handle
  /// @param[out] copyright The copyright of the audio metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int audio_meta_get_copyright(
    audio_meta_h audio,
    ffi.Pointer<ffi.Pointer<ffi.Char>> copyright,
  ) {
    return _audio_meta_get_copyright(
      audio,
      copyright,
    );
  }

  late final _audio_meta_get_copyrightPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('audio_meta_get_copyright');
  late final _audio_meta_get_copyright =
      _audio_meta_get_copyrightPtr.asFunction<
          int Function(audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the track number of the given audio metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no track info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a track_num using free().
  ///
  /// @param[in]  audio     The audio metadata handle
  /// @param[out] track_num The audio track number of the audio metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int audio_meta_get_track_num(
    audio_meta_h audio,
    ffi.Pointer<ffi.Pointer<ffi.Char>> track_num,
  ) {
    return _audio_meta_get_track_num(
      audio,
      track_num,
    );
  }

  late final _audio_meta_get_track_numPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('audio_meta_get_track_num');
  late final _audio_meta_get_track_num =
      _audio_meta_get_track_numPtr.asFunction<
          int Function(audio_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the bitrate of the given audio metadata in bitrate per second.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  audio    The audio metadata handle
  /// @param[out] bit_rate The audio bitrate in bit per second [bps]
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_get_bit_rate(
    audio_meta_h audio,
    ffi.Pointer<ffi.Int> bit_rate,
  ) {
    return _audio_meta_get_bit_rate(
      audio,
      bit_rate,
    );
  }

  late final _audio_meta_get_bit_ratePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              audio_meta_h, ffi.Pointer<ffi.Int>)>>('audio_meta_get_bit_rate');
  late final _audio_meta_get_bit_rate = _audio_meta_get_bit_ratePtr
      .asFunction<int Function(audio_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets bit per sample of the given audio metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param [in]  audio        The handle to the audio metadata
  /// @param [out] bitpersample The audio bit per sample
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_get_bitpersample(
    audio_meta_h audio,
    ffi.Pointer<ffi.Int> bitpersample,
  ) {
    return _audio_meta_get_bitpersample(
      audio,
      bitpersample,
    );
  }

  late final _audio_meta_get_bitpersamplePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Int>)>>('audio_meta_get_bitpersample');
  late final _audio_meta_get_bitpersample = _audio_meta_get_bitpersamplePtr
      .asFunction<int Function(audio_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the sample rate of the given audio metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  audio       The audio metadata handle
  /// @param[out] sample_rate The audio sample rate[hz]
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_get_sample_rate(
    audio_meta_h audio,
    ffi.Pointer<ffi.Int> sample_rate,
  ) {
    return _audio_meta_get_sample_rate(
      audio,
      sample_rate,
    );
  }

  late final _audio_meta_get_sample_ratePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Int>)>>('audio_meta_get_sample_rate');
  late final _audio_meta_get_sample_rate = _audio_meta_get_sample_ratePtr
      .asFunction<int Function(audio_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the channel of the given audio metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  audio   The audio metadata handle
  /// @param[out] channel The channel of the audio
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_get_channel(
    audio_meta_h audio,
    ffi.Pointer<ffi.Int> channel,
  ) {
    return _audio_meta_get_channel(
      audio,
      channel,
    );
  }

  late final _audio_meta_get_channelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              audio_meta_h, ffi.Pointer<ffi.Int>)>>('audio_meta_get_channel');
  late final _audio_meta_get_channel = _audio_meta_get_channelPtr
      .asFunction<int Function(audio_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the track duration of the given audio metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  audio    The audio metadata handle
  /// @param[out] duration The audio file duration
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_get_duration(
    audio_meta_h audio,
    ffi.Pointer<ffi.Int> duration,
  ) {
    return _audio_meta_get_duration(
      audio,
      duration,
    );
  }

  late final _audio_meta_get_durationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              audio_meta_h, ffi.Pointer<ffi.Int>)>>('audio_meta_get_duration');
  late final _audio_meta_get_duration = _audio_meta_get_durationPtr
      .asFunction<int Function(audio_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played count value between applications. It is recommended that the value is managed by the application.
  /// @brief Gets the number of times the given audio has been played.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  audio        The audio metadata handle
  /// @param[out] played_count The counter of the audio played
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_get_played_count(
    audio_meta_h audio,
    ffi.Pointer<ffi.Int> played_count,
  ) {
    return _audio_meta_get_played_count(
      audio,
      played_count,
    );
  }

  late final _audio_meta_get_played_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Int>)>>('audio_meta_get_played_count');
  late final _audio_meta_get_played_count = _audio_meta_get_played_countPtr
      .asFunction<int Function(audio_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played time value between applications. It is recommended that the value is managed by the application.
  /// @brief Gets the last played time parameter of the audio.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  audio       The audio metadata handle
  /// @param[out] played_time The last played time of the audio
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_get_played_time(
    audio_meta_h audio,
    ffi.Pointer<time_t> played_time,
  ) {
    return _audio_meta_get_played_time(
      audio,
      played_time,
    );
  }

  late final _audio_meta_get_played_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<time_t>)>>('audio_meta_get_played_time');
  late final _audio_meta_get_played_time = _audio_meta_get_played_timePtr
      .asFunction<int Function(audio_meta_h, ffi.Pointer<time_t>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played position value between applications. It is recommended that the value is managed by the application.
  /// @brief Gets the played position parameter of the audio.
  /// @details This function returns the elapsed playback position parameter of the audio as a period
  /// starting from the beginning of the track.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  audio           The audio metadata handle
  /// @param[out] played_position The elapsed time of the audio
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_get_played_position(
    audio_meta_h audio,
    ffi.Pointer<ffi.Int> played_position,
  ) {
    return _audio_meta_get_played_position(
      audio,
      played_position,
    );
  }

  late final _audio_meta_get_played_positionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_meta_h,
              ffi.Pointer<ffi.Int>)>>('audio_meta_get_played_position');
  late final _audio_meta_get_played_position =
      _audio_meta_get_played_positionPtr
          .asFunction<int Function(audio_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played count value between applications. It is recommended that the value is managed by the application.
  /// @brief Sets the played count of the audio.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] audio        The audio metadata handle
  /// @param[in] played_count The played count of the audio
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_set_played_count(
    audio_meta_h audio,
    int played_count,
  ) {
    return _audio_meta_set_played_count(
      audio,
      played_count,
    );
  }

  late final _audio_meta_set_played_countPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_meta_h, ffi.Int)>>(
          'audio_meta_set_played_count');
  late final _audio_meta_set_played_count = _audio_meta_set_played_countPtr
      .asFunction<int Function(audio_meta_h, int)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played time value between applications. It is recommended that the value is managed by the application.
  /// @brief Sets the last played time of the audio.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] audio       The audio metadata handle
  /// @param[in] played_time The last played time of the audio
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_set_played_time(
    audio_meta_h audio,
    int played_time,
  ) {
    return _audio_meta_set_played_time(
      audio,
      played_time,
    );
  }

  late final _audio_meta_set_played_timePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_meta_h, time_t)>>(
          'audio_meta_set_played_time');
  late final _audio_meta_set_played_time = _audio_meta_set_played_timePtr
      .asFunction<int Function(audio_meta_h, int)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played position value between applications. It is recommended that the value is managed by the application.
  /// @brief Sets the played position of the audio.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks  It is NOT recommended to use this attribute for your application-specific purpose because this attribute can be overwritten by other applications (even 0).
  ///
  /// @param[in] audio           The audio metadata handle
  /// @param[in] played_position The played position of the audio
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_meta_set_played_position(
    audio_meta_h audio,
    int played_position,
  ) {
    return _audio_meta_set_played_position(
      audio,
      played_position,
    );
  }

  late final _audio_meta_set_played_positionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_meta_h, ffi.Int)>>(
          'audio_meta_set_played_position');
  late final _audio_meta_set_played_position =
      _audio_meta_set_played_positionPtr
          .asFunction<int Function(audio_meta_h, int)>();

  /// @deprecated Deprecated since 4.0. Related setter functions are deprecated, therefore this function is not needed anymore.
  /// @brief Updates an audio metadata with modified attributes in the media database.
  /// @details The function updates the given audio meta in the media database. The function should be called after any change in audio attributes, to be updated to the media
  /// database.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks Do not call this function in callback function of foreach function like media_info_foreach_media_from_db().
  ///
  /// @param[in] audio The audio metadata handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int audio_meta_update_to_db(
    audio_meta_h audio,
  ) {
    return _audio_meta_update_to_db(
      audio,
    );
  }

  late final _audio_meta_update_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_meta_h)>>(
          'audio_meta_update_to_db');
  late final _audio_meta_update_to_db =
      _audio_meta_update_to_dbPtr.asFunction<int Function(audio_meta_h)>();

  /// @brief Creates a media filter handle.
  /// @details This function creates a media filter handle. The handle can be
  /// used to get the filtered information based on filter properties i.e. offset, count, condition for searching and order.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release the @a filter handle using media_info_filter_destroy().
  ///
  /// @param[out] filter A handle to the media filter
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @see media_filter_destroy()
  int media_filter_create(
    ffi.Pointer<filter_h> filter,
  ) {
    return _media_filter_create(
      filter,
    );
  }

  late final _media_filter_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<filter_h>)>>(
          'media_filter_create');
  late final _media_filter_create =
      _media_filter_createPtr.asFunction<int Function(ffi.Pointer<filter_h>)>();

  /// @brief Destroys a media filter handle.
  /// @details The function frees all resources related to the media filter handle. The filter
  /// handle no longer can be used to perform any operation. A new filter handle
  /// has to be created before the next usage.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] filter The handle to the media filter
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_filter_create()
  int media_filter_destroy(
    filter_h filter,
  ) {
    return _media_filter_destroy(
      filter,
    );
  }

  late final _media_filter_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(filter_h)>>(
          'media_filter_destroy');
  late final _media_filter_destroy =
      _media_filter_destroyPtr.asFunction<int Function(filter_h)>();

  /// @brief Sets the media filter offset and count.
  /// @details This function sets the @a offset and @a count for the given filter used to limit number of items returned.
  /// For example, if you set the @a offset as @c 10 and @a count as @c 5, then only searched data from @c 10 to @c 14 will be returned when the filter is used with foreach functions.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] filter The handle to the media filter
  /// @param[in] offset The start position of the given filter (Starting from zero)
  /// @param[in] count  The number of items to be searched with respect to the offset
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_filter_create()
  /// @see media_filter_destroy()
  int media_filter_set_offset(
    filter_h filter,
    int offset,
    int count,
  ) {
    return _media_filter_set_offset(
      filter,
      offset,
      count,
    );
  }

  late final _media_filter_set_offsetPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(filter_h, ffi.Int, ffi.Int)>>(
          'media_filter_set_offset');
  late final _media_filter_set_offset = _media_filter_set_offsetPtr
      .asFunction<int Function(filter_h, int, int)>();

  /// @brief Sets the @a condition for the given @a filter.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] filter       The handle to the media filter
  /// @param[in] condition    The condition which is used WHERE clause on a query
  /// @param[in] collate_type The collate type for comparing two strings
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_filter_create()
  /// @see media_filter_destroy()
  int media_filter_set_condition(
    filter_h filter,
    ffi.Pointer<ffi.Char> condition,
    int collate_type,
  ) {
    return _media_filter_set_condition(
      filter,
      condition,
      collate_type,
    );
  }

  late final _media_filter_set_conditionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, ffi.Pointer<ffi.Char>,
              ffi.Int32)>>('media_filter_set_condition');
  late final _media_filter_set_condition = _media_filter_set_conditionPtr
      .asFunction<int Function(filter_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Sets the media filter content @a order and order keyword i.e. either descending or ascending.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] filter        The handle to the media filter
  /// @param[in] order_type    The search order type
  /// @param[in] order_keyword The search order keyword
  /// @param[in] collate_type  The collate type for comparing two strings
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_filter_create()
  /// @see media_filter_destroy()
  int media_filter_set_order(
    filter_h filter,
    int order_type,
    ffi.Pointer<ffi.Char> order_keyword,
    int collate_type,
  ) {
    return _media_filter_set_order(
      filter,
      order_type,
      order_keyword,
      collate_type,
    );
  }

  late final _media_filter_set_orderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, ffi.Int32, ffi.Pointer<ffi.Char>,
              ffi.Int32)>>('media_filter_set_order');
  late final _media_filter_set_order = _media_filter_set_orderPtr
      .asFunction<int Function(filter_h, int, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Sets the @a storage id for the given @a filter.
  /// @details You can use this API when you want to search items only in the specific storage
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] filter       The handle to the media filter
  /// @param[in] storage_id    The storage_id for browsing or searching
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_filter_create()
  /// @see media_filter_destroy()
  int media_filter_set_storage(
    filter_h filter,
    ffi.Pointer<ffi.Char> storage_id,
  ) {
    return _media_filter_set_storage(
      filter,
      storage_id,
    );
  }

  late final _media_filter_set_storagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              filter_h, ffi.Pointer<ffi.Char>)>>('media_filter_set_storage');
  late final _media_filter_set_storage = _media_filter_set_storagePtr
      .asFunction<int Function(filter_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the @a offset and @a count for the given @a filter used to limit the number of items returned.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  filter The handle to the media filter
  /// @param[out] offset The start position of the given filter (Starting from zero)
  /// @param[out] count  The number of items to be searched with respect to the offset
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_filter_create()
  /// @see media_filter_destroy()
  int media_filter_get_offset(
    filter_h filter,
    ffi.Pointer<ffi.Int> offset,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _media_filter_get_offset(
      filter,
      offset,
      count,
    );
  }

  late final _media_filter_get_offsetPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('media_filter_get_offset');
  late final _media_filter_get_offset = _media_filter_get_offsetPtr.asFunction<
      int Function(filter_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the @a condition for the given @a filter.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a condition using free().
  ///
  /// @param[in]  filter       The handle to the media info filter
  /// @param[out] condition    The condition which is used WHERE clause on a query
  /// @param[out] collate_type The collate type for comparing two strings
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_filter_create()
  /// @see media_filter_destroy()
  int media_filter_get_condition(
    filter_h filter,
    ffi.Pointer<ffi.Pointer<ffi.Char>> condition,
    ffi.Pointer<ffi.Int32> collate_type,
  ) {
    return _media_filter_get_condition(
      filter,
      condition,
      collate_type,
    );
  }

  late final _media_filter_get_conditionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int32>)>>('media_filter_get_condition');
  late final _media_filter_get_condition =
      _media_filter_get_conditionPtr.asFunction<
          int Function(filter_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the media filter's content @a order and order keyword i.e. either descending or ascending.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a order_keyword using free().
  ///
  /// @param[in]  filter        The handle to the media filter
  /// @param[out] order_type    The search order type
  /// @param[out] order_keyword The search order keyword
  /// @param[out] collate_type  The collate type for comparing two strings
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_filter_create()
  /// @see media_filter_destroy()
  int media_filter_get_order(
    filter_h filter,
    ffi.Pointer<ffi.Int32> order_type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> order_keyword,
    ffi.Pointer<ffi.Int32> collate_type,
  ) {
    return _media_filter_get_order(
      filter,
      order_type,
      order_keyword,
      collate_type,
    );
  }

  late final _media_filter_get_orderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              filter_h,
              ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int32>)>>('media_filter_get_order');
  late final _media_filter_get_order = _media_filter_get_orderPtr.asFunction<
      int Function(filter_h, ffi.Pointer<ffi.Int32>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Int32>)>();

  /// @brief Get the @a storage id for given @a filter.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a storage_id using free().
  ///
  /// @param[in] filter The handle to media info filter
  /// @param[out] storage_id The storage_id which is used in filter
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_filter_create()
  /// @see media_filter_destroy()
  int media_filter_get_storage(
    filter_h filter,
    ffi.Pointer<ffi.Pointer<ffi.Char>> storage_id,
  ) {
    return _media_filter_get_storage(
      filter,
      storage_id,
    );
  }

  late final _media_filter_get_storagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_filter_get_storage');
  late final _media_filter_get_storage = _media_filter_get_storagePtr
      .asFunction<int Function(filter_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the count of folder for the passed @a filter from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  filter       The handle to filter \n
  /// To allow searching over different content types, you should use #filter_h.
  /// @param[out] folder_count The count of the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_folder_get_folder_count_from_db(
    filter_h filter,
    ffi.Pointer<ffi.Int> folder_count,
  ) {
    return _media_folder_get_folder_count_from_db(
      filter,
      folder_count,
    );
  }

  late final _media_folder_get_folder_count_from_dbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(filter_h, ffi.Pointer<ffi.Int>)>>(
      'media_folder_get_folder_count_from_db');
  late final _media_folder_get_folder_count_from_db =
      _media_folder_get_folder_count_from_dbPtr
          .asFunction<int Function(filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through available media folders with optional @a filter from the media database.
  /// @details This function gets the media folder meeting the given @a filter.
  /// The @a callback function will be invoked for every retrieved
  /// folder. If @c NULL is passed to the @a filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Do not call updating DB fuction like media_folder_update_to_db() in your callback function, your callback function is invoked as inline function.\n
  /// So, your callback function is in read state in SQLite. When you are in read state, sometimes you do not update DB. \n
  /// We do not recommend you call updating DB function in callback of foreach function.
  ///
  /// @param[in] filter    The handle to the media folder filter
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @pre  A filter handle has to be created by calling media_filter_create().
  /// @post This function invokes media_folder_cb().
  ///
  /// @see media_content_connect()
  /// @see media_folder_cb()
  /// @see media_filter_create()
  int media_folder_foreach_folder_from_db(
    filter_h filter,
    media_folder_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_folder_foreach_folder_from_db(
      filter,
      callback,
      user_data,
    );
  }

  late final _media_folder_foreach_folder_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, media_folder_cb,
              ffi.Pointer<ffi.Void>)>>('media_folder_foreach_folder_from_db');
  late final _media_folder_foreach_folder_from_db =
      _media_folder_foreach_folder_from_dbPtr.asFunction<
          int Function(filter_h, media_folder_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the count of media files for the passed @a filter in the given @a folder from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] folder_id    The ID of the media folder
  /// @param[in] filter       The filter of the media content
  /// @param[out] media_count The count of media folder items
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_folder_get_media_count_from_db(
    ffi.Pointer<ffi.Char> folder_id,
    filter_h filter,
    ffi.Pointer<ffi.Int> media_count,
  ) {
    return _media_folder_get_media_count_from_db(
      folder_id,
      filter,
      media_count,
    );
  }

  late final _media_folder_get_media_count_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, filter_h,
              ffi.Pointer<ffi.Int>)>>('media_folder_get_media_count_from_db');
  late final _media_folder_get_media_count_from_db =
      _media_folder_get_media_count_from_dbPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media files with an optional @a filter in the given @a folder from the media database.
  /// @details This function gets all media files associated with the given folder and
  /// meeting desired filter option and calls @a callback for
  /// every retrieved media item. If @c NULL is passed to the @a filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks   Do not call updating DB function like media_info_update_to_db(), media_info_refresh_metadata_to_db(), audio_meta_update_to_db(), image_meta_update_to_db() and video_meta_update_to_db()  in your callback function,
  /// your callback function is invoked as inline function. \n
  /// So, your callback function is in read state in SQLite. When you are in read state, sometimes you do not update DB. \n
  /// We do not recommend you call updating DB function in callback of foreach function.
  ///
  /// @param[in] folder_id The ID of the media folder
  /// @param[in] filter    The handle to the media info filter
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_info_cb().
  ///
  /// @see #media_info_cb
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_folder_foreach_media_from_db(
    ffi.Pointer<ffi.Char> folder_id,
    filter_h filter,
    media_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_folder_foreach_media_from_db(
      folder_id,
      filter,
      callback,
      user_data,
    );
  }

  late final _media_folder_foreach_media_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, filter_h, media_info_cb,
              ffi.Pointer<ffi.Void>)>>('media_folder_foreach_media_from_db');
  late final _media_folder_foreach_media_from_db =
      _media_folder_foreach_media_from_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, filter_h, media_info_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Clones the media folder.
  /// @details This function copies the media folder handle from a source to
  /// destination. There is no media_folder_create() function. The media_folder_h is created internally and available through
  /// media folder foreach function such as media_folder_foreach_folder_from_db(). To use this handle outside of these foreach functions,
  /// use this function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks The destination handle must be released with media_folder_destroy().
  ///
  /// @param[out] dst The destination handle to the media folder
  /// @param[in]  src The source handle to the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_folder_destroy()
  /// @see media_folder_foreach_folder_from_db()
  int media_folder_clone(
    ffi.Pointer<media_folder_h> dst,
    media_folder_h src,
  ) {
    return _media_folder_clone(
      dst,
      src,
    );
  }

  late final _media_folder_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<media_folder_h>,
              media_folder_h)>>('media_folder_clone');
  late final _media_folder_clone = _media_folder_clonePtr
      .asFunction<int Function(ffi.Pointer<media_folder_h>, media_folder_h)>();

  /// @brief Destroys the media folder.
  /// @details The function frees all resources related to the folder handle. This handle
  /// no longer can be used to perform any operation. A new handle has to
  /// be created before the next use.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] folder The handle to the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre A copy of the media folder handle created by calling media_folder_clone().
  ///
  /// @see media_folder_clone()
  int media_folder_destroy(
    media_folder_h folder,
  ) {
    return _media_folder_destroy(
      folder,
    );
  }

  late final _media_folder_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_folder_h)>>(
          'media_folder_destroy');
  late final _media_folder_destroy =
      _media_folder_destroyPtr.asFunction<int Function(media_folder_h)>();

  /// @brief Gets the media folder ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a folder_id using free().
  ///
  /// @param[in]  folder    The handle to the media folder
  /// @param[out] folder_id The ID of the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_folder_get_folder_id(
    media_folder_h folder,
    ffi.Pointer<ffi.Pointer<ffi.Char>> folder_id,
  ) {
    return _media_folder_get_folder_id(
      folder,
      folder_id,
    );
  }

  late final _media_folder_get_folder_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_folder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_folder_get_folder_id');
  late final _media_folder_get_folder_id =
      _media_folder_get_folder_idPtr.asFunction<
          int Function(media_folder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the parent folder ID.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a parent_folder_id using free().
  ///
  /// @param[in]  folder    The handle to the media folder
  /// @param[out] parent_folder_id The ID of the upper media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_folder_get_parent_folder_id(
    media_folder_h folder,
    ffi.Pointer<ffi.Pointer<ffi.Char>> parent_folder_id,
  ) {
    return _media_folder_get_parent_folder_id(
      folder,
      parent_folder_id,
    );
  }

  late final _media_folder_get_parent_folder_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_folder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_folder_get_parent_folder_id');
  late final _media_folder_get_parent_folder_id =
      _media_folder_get_parent_folder_idPtr.asFunction<
          int Function(media_folder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the absolute path to the media folder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a path using free().
  ///
  /// @param[in]  folder The handle to the media folder
  /// @param[out] path   The path of the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_folder_get_path(
    media_folder_h folder,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _media_folder_get_path(
      folder,
      path,
    );
  }

  late final _media_folder_get_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_folder_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_folder_get_path');
  late final _media_folder_get_path = _media_folder_get_pathPtr.asFunction<
      int Function(media_folder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the media folder name.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a folder_name using free().
  ///
  /// @param[in]  folder      The handle to the media folder
  /// @param[out] folder_name The name of the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_folder_get_name(
    media_folder_h folder,
    ffi.Pointer<ffi.Pointer<ffi.Char>> folder_name,
  ) {
    return _media_folder_get_name(
      folder,
      folder_name,
    );
  }

  late final _media_folder_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_folder_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_folder_get_name');
  late final _media_folder_get_name = _media_folder_get_namePtr.asFunction<
      int Function(media_folder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the modified date of the folder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  folder The handle to the media folder
  /// @param[out] date   The modified date of the folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_folder_get_modified_time(
    media_folder_h folder,
    ffi.Pointer<time_t> date,
  ) {
    return _media_folder_get_modified_time(
      folder,
      date,
    );
  }

  late final _media_folder_get_modified_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_folder_h,
              ffi.Pointer<time_t>)>>('media_folder_get_modified_time');
  late final _media_folder_get_modified_time =
      _media_folder_get_modified_timePtr
          .asFunction<int Function(media_folder_h, ffi.Pointer<time_t>)>();

  /// @brief Gets the folder storage type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  folder       The handle to the media folder
  /// @param[out] storage_type The storage type of the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_folder_get_storage_type(
    media_folder_h folder,
    ffi.Pointer<ffi.Int32> storage_type,
  ) {
    return _media_folder_get_storage_type(
      folder,
      storage_type,
    );
  }

  late final _media_folder_get_storage_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_folder_h,
              ffi.Pointer<ffi.Int32>)>>('media_folder_get_storage_type');
  late final _media_folder_get_storage_type = _media_folder_get_storage_typePtr
      .asFunction<int Function(media_folder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the storage id of the folder.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a storage_id using free().
  ///
  /// @param[in]  folder      The handle to the media folder
  /// @param[out] storage_id The storage id of the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_folder_get_storage_id(
    media_folder_h folder,
    ffi.Pointer<ffi.Pointer<ffi.Char>> storage_id,
  ) {
    return _media_folder_get_storage_id(
      folder,
      storage_id,
    );
  }

  late final _media_folder_get_storage_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_folder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_folder_get_storage_id');
  late final _media_folder_get_storage_id =
      _media_folder_get_storage_idPtr.asFunction<
          int Function(media_folder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0. \n
  /// This function does not guarantee order independence between applications. It is recommended that the viewing order is managed by the application.
  ///
  /// @brief Gets the folder viewing order.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] folder The handle to the media folder
  /// @param[out] order   The viewing order of the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_folder_update_to_db()
  int media_folder_get_order(
    media_folder_h folder,
    ffi.Pointer<ffi.Int> order,
  ) {
    return _media_folder_get_order(
      folder,
      order,
    );
  }

  late final _media_folder_get_orderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_folder_h, ffi.Pointer<ffi.Int>)>>('media_folder_get_order');
  late final _media_folder_get_order = _media_folder_get_orderPtr
      .asFunction<int Function(media_folder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the media folder from the media database.
  ///
  /// @details This function creates a new media folder handle from the media database by the given @a folder_id.
  /// Media folder will be created, which is filled with folder information.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a folder using media_folder_destroy().
  ///
  /// @param[in]  folder_id The ID of the media folder
  /// @param[out] folder    The media folder handle associated with the folder ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY DB Operation busy
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_folder_destroy()
  int media_folder_get_folder_from_db(
    ffi.Pointer<ffi.Char> folder_id,
    ffi.Pointer<media_folder_h> folder,
  ) {
    return _media_folder_get_folder_from_db(
      folder_id,
      folder,
    );
  }

  late final _media_folder_get_folder_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<media_folder_h>)>>('media_folder_get_folder_from_db');
  late final _media_folder_get_folder_from_db =
      _media_folder_get_folder_from_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<media_folder_h>)>();

  /// @deprecated Deprecated since 4.0. Use media_content_scan_folder() or media_info_move_to_db() instead.
  /// @brief Sets the folder name.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] folder The handle to the media folder
  /// @param[in] name   The name of the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  int media_folder_set_name(
    media_folder_h folder,
    ffi.Pointer<ffi.Char> name,
  ) {
    return _media_folder_set_name(
      folder,
      name,
    );
  }

  late final _media_folder_set_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_folder_h, ffi.Pointer<ffi.Char>)>>('media_folder_set_name');
  late final _media_folder_set_name = _media_folder_set_namePtr
      .asFunction<int Function(media_folder_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. \n
  /// This function does not guarantee order independence between applications. It is recommended that the viewing order is managed by the application.
  /// @brief Sets the folder viewing order.
  /// @details If you set the order value for each folder, you can sort in ascending or descending order as the set order values using the filter. \n
  /// Moreover, more detailed settings are possible when used with the filter. \n
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks  If you don't set the order value, the order value will be set default value. Default is 0. \n
  /// If you don't use the filter, the set order value does not effect the folder viewing order.
  ///
  /// @param[in] folder The handle to the media folder
  /// @param[in] order   The viewing order of the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_folder_set_order(
    media_folder_h folder,
    int order,
  ) {
    return _media_folder_set_order(
      folder,
      order,
    );
  }

  late final _media_folder_set_orderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_folder_h, ffi.Int)>>(
          'media_folder_set_order');
  late final _media_folder_set_order = _media_folder_set_orderPtr
      .asFunction<int Function(media_folder_h, int)>();

  /// @deprecated Deprecated since 4.0. Related setter functions are deprecated, therefore this function is not needed anymore.
  /// @brief Updates the media folder to the media database.
  ///
  /// @details The function updates the given media folder in the media database. The function should be called after any change in folder attributes, to be updated to the media
  /// database.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] folder The handle to the media folder
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_folder_destroy()
  int media_folder_update_to_db(
    media_folder_h folder,
  ) {
    return _media_folder_update_to_db(
      folder,
    );
  }

  late final _media_folder_update_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_folder_h)>>(
          'media_folder_update_to_db');
  late final _media_folder_update_to_db =
      _media_folder_update_to_dbPtr.asFunction<int Function(media_folder_h)>();

  /// @brief Clones the image metadata.
  /// @details The function copies the image metadata handle from a source to destination.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks The destination handle must be released with image_meta_destroy().
  ///
  /// @param[out] dst  The destination handle to the image metadata
  /// @param[in]  src  The source handle to the image metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @see image_meta_destroy()
  int image_meta_clone(
    ffi.Pointer<image_meta_h> dst,
    image_meta_h src,
  ) {
    return _image_meta_clone(
      dst,
      src,
    );
  }

  late final _image_meta_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<image_meta_h>, image_meta_h)>>('image_meta_clone');
  late final _image_meta_clone = _image_meta_clonePtr
      .asFunction<int Function(ffi.Pointer<image_meta_h>, image_meta_h)>();

  /// @brief Destroys the image metadata.
  /// @details The function frees all resources related to the image metadata handle. This handle
  /// no longer can be used to perform any operation. A new handle has to
  /// be created before next usage.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] image The image metadata handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre Get a copy of image_meta handle by calling image_meta_clone().
  ///
  /// @see image_meta_clone()
  int image_meta_destroy(
    image_meta_h image,
  ) {
    return _image_meta_destroy(
      image,
    );
  }

  late final _image_meta_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(image_meta_h)>>(
          'image_meta_destroy');
  late final _image_meta_destroy =
      _image_meta_destroyPtr.asFunction<int Function(image_meta_h)>();

  /// @brief Gets the ID of an image.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  image    The image metadata handle
  /// @param[out] media_id The ID of an image
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_get_media_id(
    image_meta_h image,
    ffi.Pointer<ffi.Pointer<ffi.Char>> media_id,
  ) {
    return _image_meta_get_media_id(
      image,
      media_id,
    );
  }

  late final _image_meta_get_media_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(image_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('image_meta_get_media_id');
  late final _image_meta_get_media_id = _image_meta_get_media_idPtr.asFunction<
      int Function(image_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the image width in pixels.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  image The image metadata handle
  /// @param[out] width The image width in pixels
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_get_width(
    image_meta_h image,
    ffi.Pointer<ffi.Int> width,
  ) {
    return _image_meta_get_width(
      image,
      width,
    );
  }

  late final _image_meta_get_widthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              image_meta_h, ffi.Pointer<ffi.Int>)>>('image_meta_get_width');
  late final _image_meta_get_width = _image_meta_get_widthPtr
      .asFunction<int Function(image_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the image height in pixels.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  image  The image metadata handle
  /// @param[out] height The image height in pixels
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_get_height(
    image_meta_h image,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _image_meta_get_height(
      image,
      height,
    );
  }

  late final _image_meta_get_heightPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              image_meta_h, ffi.Pointer<ffi.Int>)>>('image_meta_get_height');
  late final _image_meta_get_height = _image_meta_get_heightPtr
      .asFunction<int Function(image_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the image orientation.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  image       The image metadata handle
  /// @param[out] orientation The image orientation
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_get_orientation(
    image_meta_h image,
    ffi.Pointer<ffi.Int32> orientation,
  ) {
    return _image_meta_get_orientation(
      image,
      orientation,
    );
  }

  late final _image_meta_get_orientationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(image_meta_h,
              ffi.Pointer<ffi.Int32>)>>('image_meta_get_orientation');
  late final _image_meta_get_orientation = _image_meta_get_orientationPtr
      .asFunction<int Function(image_meta_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the image creation time.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  image      The image metadata handle
  /// @param[out] date_taken The time, when image was taken (in seconds, since the Epoch)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_get_date_taken(
    image_meta_h image,
    ffi.Pointer<ffi.Pointer<ffi.Char>> date_taken,
  ) {
    return _image_meta_get_date_taken(
      image,
      date_taken,
    );
  }

  late final _image_meta_get_date_takenPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  image_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'image_meta_get_date_taken');
  late final _image_meta_get_date_taken =
      _image_meta_get_date_takenPtr.asFunction<
          int Function(image_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the burst shot ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a burst_id using free().
  ///
  /// @param[in]  image    The image metadata handle
  /// @param[out] burst_id The ID of burst shot\ n
  /// If @a burst_id is @c NULL, this is not burst shot
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_get_burst_id(
    image_meta_h image,
    ffi.Pointer<ffi.Pointer<ffi.Char>> burst_id,
  ) {
    return _image_meta_get_burst_id(
      image,
      burst_id,
    );
  }

  late final _image_meta_get_burst_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(image_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('image_meta_get_burst_id');
  late final _image_meta_get_burst_id = _image_meta_get_burst_idPtr.asFunction<
      int Function(image_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the exposure time from exif.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks @a exposure time must be released with free() by you.
  ///
  /// @param[in]  image    The image metadata handle
  /// @param[out] exposure_time The value of exposure_time, getting from exif
  ///
  /// @return 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_get_exposure_time(
    image_meta_h image,
    ffi.Pointer<ffi.Pointer<ffi.Char>> exposure_time,
  ) {
    return _image_meta_get_exposure_time(
      image,
      exposure_time,
    );
  }

  late final _image_meta_get_exposure_timePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  image_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'image_meta_get_exposure_time');
  late final _image_meta_get_exposure_time =
      _image_meta_get_exposure_timePtr.asFunction<
          int Function(image_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the fnumber from exif.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in]  image    The image metadata handle
  /// @param[out] fnumber The value of fnumber, getting from exif
  ///
  /// @return 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_get_fnumber(
    image_meta_h image,
    ffi.Pointer<ffi.Double> fnumber,
  ) {
    return _image_meta_get_fnumber(
      image,
      fnumber,
    );
  }

  late final _image_meta_get_fnumberPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(image_meta_h,
              ffi.Pointer<ffi.Double>)>>('image_meta_get_fnumber');
  late final _image_meta_get_fnumber = _image_meta_get_fnumberPtr
      .asFunction<int Function(image_meta_h, ffi.Pointer<ffi.Double>)>();

  /// @brief Gets the iso from exif.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in]  image    The image metadata handle
  /// @param[out] iso The value of iso, getting from exif
  ///
  /// @return 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_get_iso(
    image_meta_h image,
    ffi.Pointer<ffi.Int> iso,
  ) {
    return _image_meta_get_iso(
      image,
      iso,
    );
  }

  late final _image_meta_get_isoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              image_meta_h, ffi.Pointer<ffi.Int>)>>('image_meta_get_iso');
  late final _image_meta_get_iso = _image_meta_get_isoPtr
      .asFunction<int Function(image_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the model from exif.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks @a model must be released with free() by you.
  ///
  /// @param[in]  image    The image metadata handle
  /// @param[out] model The value of model, getting from exif
  ///
  /// @return 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_get_model(
    image_meta_h image,
    ffi.Pointer<ffi.Pointer<ffi.Char>> model,
  ) {
    return _image_meta_get_model(
      image,
      model,
    );
  }

  late final _image_meta_get_modelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(image_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('image_meta_get_model');
  late final _image_meta_get_model = _image_meta_get_modelPtr.asFunction<
      int Function(image_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Checks whether the media is a burst shot image.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  image         The image metadata handle
  /// @param[out] is_burst_shot @c true if the media is a burst shot image,
  /// otherwise @c false if the media is not a burst shot image
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_is_burst_shot(
    image_meta_h image,
    ffi.Pointer<ffi.Bool> is_burst_shot,
  ) {
    return _image_meta_is_burst_shot(
      image,
      is_burst_shot,
    );
  }

  late final _image_meta_is_burst_shotPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(image_meta_h,
              ffi.Pointer<ffi.Bool>)>>('image_meta_is_burst_shot');
  late final _image_meta_is_burst_shot = _image_meta_is_burst_shotPtr
      .asFunction<int Function(image_meta_h, ffi.Pointer<ffi.Bool>)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets an orientation of the image.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] image       The image metadata handle
  /// @param[in] orientation The image orientation
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int image_meta_set_orientation(
    image_meta_h image,
    int orientation,
  ) {
    return _image_meta_set_orientation(
      image,
      orientation,
    );
  }

  late final _image_meta_set_orientationPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(image_meta_h, ffi.Int32)>>(
          'image_meta_set_orientation');
  late final _image_meta_set_orientation = _image_meta_set_orientationPtr
      .asFunction<int Function(image_meta_h, int)>();

  /// @deprecated Deprecated since 4.0. Related setter functions are deprecated, therefore this function is not needed anymore.
  /// @brief Updates the image to the media database.
  ///
  /// @details The function updates the given image meta in the media database. \n
  /// The function should be called after any change in image attributes, to be updated to the media database.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks Do not call this function in callback function of foreach function like media_info_foreach_media_from_db().
  ///
  /// @param[in] image The handle to the image
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int image_meta_update_to_db(
    image_meta_h image,
  ) {
    return _image_meta_update_to_db(
      image,
    );
  }

  late final _image_meta_update_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(image_meta_h)>>(
          'image_meta_update_to_db');
  late final _image_meta_update_to_db =
      _image_meta_update_to_dbPtr.asFunction<int Function(image_meta_h)>();

  /// @brief  Inserts the content file into the media database.
  /// @details In general, you can use this API to insert content files into the media database. \n
  /// You can use media_content_scan_file()/media_content_scan_folder() API instead of this API.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write \n
  /// %http://tizen.org/privilege/mediastorage \n
  /// %http://tizen.org/privilege/externalstorage
  ///
  /// @remarks You must release the handle using media_info_destroy(). \n
  /// You must add privilege http://tizen.org/privilege/content.write. And You add more privilege depending on your choice of contents path. \n
  /// If you want to access only internal storage by using  this API, you should add privilege http://tizen.org/privilege/mediastorage. \n
  /// Or if you want to access only external storage by using  this API, you should add privilege http://tizen.org/privilege/externalstorage. \n
  /// If you can access both storage, you must add all privilege.
  /// @remarks Since 4.0, this function is related to the following feature:\n
  /// %http://tizen.org/feature/content.scanning.others\n
  /// If this feature is not suppported on the device, MEDIA_CONTENT_TYPE_OTHERS type file is not scanned.
  ///
  /// @param[in]  path The path of the content file to add
  /// @param[out] info The handle of the inserted content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_content_scan_file()
  /// @see media_content_scan_folder()
  int media_info_insert_to_db(
    ffi.Pointer<ffi.Char> path,
    ffi.Pointer<media_info_h> info,
  ) {
    return _media_info_insert_to_db(
      path,
      info,
    );
  }

  late final _media_info_insert_to_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<media_info_h>)>>('media_info_insert_to_db');
  late final _media_info_insert_to_db = _media_info_insert_to_dbPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<media_info_h>)>();

  /// @brief Inserts content files into the media database, asynchronously.
  /// @details This function can insert multiple content files into the media database.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write \n
  /// %http://tizen.org/privilege/mediastorage \n
  /// %http://tizen.org/privilege/externalstorage
  ///
  /// @remarks You must add privilege http://tizen.org/privilege/content.write. And You add more privilege depending on your choice of contents path. \n
  /// If you want to access only internal storage by using  this API, you should add privilege http://tizen.org/privilege/mediastorage. \n
  /// Or if you want to access only external storage by using  this API, you should add privilege http://tizen.org/privilege/externalstorage. \n
  /// If you can access both storage, you must add all privilege.
  /// @remarks Since 4.0, this function is related to the following feature:\n
  /// %http://tizen.org/feature/content.scanning.others\n
  /// If this feature is not suppported on the device, MEDIA_CONTENT_TYPE_OTHERS type file is not scanned.
  ///
  /// @param[in] path_array   The path array of the content files to add
  /// @param[in] array_length The length of the array
  /// @param[in] callback     The callback to be invoked when media items inserted completely
  /// @param[in] user_data    The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_insert_completed_cb()
  int media_info_insert_batch_to_db(
    ffi.Pointer<ffi.Pointer<ffi.Char>> path_array,
    int array_length,
    media_insert_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_info_insert_batch_to_db(
      path_array,
      array_length,
      callback,
      user_data,
    );
  }

  late final _media_info_insert_batch_to_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.UnsignedInt,
              media_insert_completed_cb,
              ffi.Pointer<ffi.Void>)>>('media_info_insert_batch_to_db');
  late final _media_info_insert_batch_to_db =
      _media_info_insert_batch_to_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>, int,
              media_insert_completed_cb, ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Inserts the burst shot images into the media database, asynchronously.
  /// @details This function inserts burst images into the media database.
  /// media_insert_burst_shot_completed_cb() will be called when insertion to media database is finished.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write \n
  /// %http://tizen.org/privilege/mediastorage \n
  /// %http://tizen.org/privilege/externalstorage
  ///
  /// @remarks You must add privilege http://tizen.org/privilege/content.write. And You add more privilege depending on your choice of contents path. \n
  /// If you want to access only internal storage with this API, you should add privilege http://tizen.org/privilege/mediastorage. \n
  /// Or if you want to access only external storage with this API, you should add privilege http://tizen.org/privilege/externalstorage. \n
  /// If you can access both storage, you must add all privilege.
  ///
  /// @param[in] path_array   The path array of the burst shot images to add
  /// @param[in] array_length The length of the array
  /// @param[in] callback     The callback to be invoked when the images are inserted completely
  /// @param[in] user_data    The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_insert_burst_shot_completed_cb()
  int media_info_insert_burst_shot_to_db(
    ffi.Pointer<ffi.Pointer<ffi.Char>> path_array,
    int array_length,
    media_insert_burst_shot_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_info_insert_burst_shot_to_db(
      path_array,
      array_length,
      callback,
      user_data,
    );
  }

  late final _media_info_insert_burst_shot_to_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.UnsignedInt,
              media_insert_burst_shot_completed_cb,
              ffi.Pointer<ffi.Void>)>>('media_info_insert_burst_shot_to_db');
  late final _media_info_insert_burst_shot_to_db =
      _media_info_insert_burst_shot_to_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>, int,
              media_insert_burst_shot_completed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Deletes the media information from the media database.
  /// @details This function only remove media information in the media database. \n
  /// You can use media_content_scan_file()/media_content_scan_folder() API instead of this API if file is removed from the file system.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] media_id  The media ID. It can get from media info handle.
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_content_scan_file()
  /// @see media_content_scan_folder()
  int media_info_delete_from_db(
    ffi.Pointer<ffi.Char> media_id,
  ) {
    return _media_info_delete_from_db(
      media_id,
    );
  }

  late final _media_info_delete_from_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'media_info_delete_from_db');
  late final _media_info_delete_from_db = _media_info_delete_from_dbPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Deletes media information that meets the conditions of the filter from the media database.
  /// @details This function can delete multiple media information from the media database.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] filter  The filter handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_info_delete_batch_from_db(
    filter_h filter,
  ) {
    return _media_info_delete_batch_from_db(
      filter,
    );
  }

  late final _media_info_delete_batch_from_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(filter_h)>>(
          'media_info_delete_batch_from_db');
  late final _media_info_delete_batch_from_db =
      _media_info_delete_batch_from_dbPtr.asFunction<int Function(filter_h)>();

  /// @brief Destroys media info.
  /// @details The function frees all resources related to the media info handle. This handle
  /// can no longer be used to perform any operation. New media info handle has to
  /// be created before the next usage.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media  The media info handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre Get copy of media_info handle by calling media_info_clone().
  ///
  /// @see media_info_clone()
  int media_info_destroy(
    media_info_h media,
  ) {
    return _media_info_destroy(
      media,
    );
  }

  late final _media_info_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h)>>(
          'media_info_destroy');
  late final _media_info_destroy =
      _media_info_destroyPtr.asFunction<int Function(media_info_h)>();

  /// @brief Clones the media info handle.
  ///
  /// @details This function copies the media info handle from a source to the destination.
  /// There is no media_info_create() function. The media_info_h is created internally and
  /// available through media info foreach function such as media_info_foreach_media_from_db() or media_info_insert_to_db().
  /// To use this handle outside of these foreach functions, use this function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release the destination handle using media_info_destroy().
  ///
  /// @param[out] dst  The destination handle to the media info
  /// @param[in]  src  The source handle to media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_info_destroy()
  /// @see media_album_foreach_media_from_db()
  /// @see media_playlist_foreach_media_from_db()
  /// @see media_group_foreach_media_from_db()
  /// @see media_tag_foreach_media_from_db()
  /// @see media_info_foreach_media_from_db()
  /// @see media_info_insert_to_db()
  /// @see media_folder_foreach_media_from_db()
  int media_info_clone(
    ffi.Pointer<media_info_h> dst,
    media_info_h src,
  ) {
    return _media_info_clone(
      dst,
      src,
    );
  }

  late final _media_info_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<media_info_h>, media_info_h)>>('media_info_clone');
  late final _media_info_clone = _media_info_clonePtr
      .asFunction<int Function(ffi.Pointer<media_info_h>, media_info_h)>();

  /// @brief Gets the count of media info for the passed @a filter from the media database.
  /// @details If @c NULL is passed to the @a filter, then no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  ///
  /// @param[in]  filter      The handle to filter
  /// @param[out] media_count The count of media
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_info_get_media_count_from_db(
    filter_h filter,
    ffi.Pointer<ffi.Int> media_count,
  ) {
    return _media_info_get_media_count_from_db(
      filter,
      media_count,
    );
  }

  late final _media_info_get_media_count_from_dbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(filter_h, ffi.Pointer<ffi.Int>)>>(
      'media_info_get_media_count_from_db');
  late final _media_info_get_media_count_from_db =
      _media_info_get_media_count_from_dbPtr
          .asFunction<int Function(filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through media info from the media database.
  /// @details This function gets all media info handles meeting the given @a filter.
  /// The @a callback function will be invoked for every retrieved media info.
  /// If @c NULL is passed to the @a filter, then no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Do not call updating DB function like media_info_update_to_db(), media_info_refresh_metadata_to_db(), audio_meta_update_to_db(), image_meta_update_to_db() and video_meta_update_to_db()  in your callback function,
  /// your callback function is invoked as inline function.
  /// So, your callback function is in read state in SQLite. When you are in read state, sometimes you do not update DB.
  /// We do not recommend you call updating DB function in callback of foreach function.
  ///
  /// @param[in] filter    The media info handle filter
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_info_cb().
  ///
  /// @see media_content_connect()
  /// @see #media_info_cb
  /// @see media_filter_create()
  int media_info_foreach_media_from_db(
    filter_h filter,
    media_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_info_foreach_media_from_db(
      filter,
      callback,
      user_data,
    );
  }

  late final _media_info_foreach_media_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, media_info_cb,
              ffi.Pointer<ffi.Void>)>>('media_info_foreach_media_from_db');
  late final _media_info_foreach_media_from_db =
      _media_info_foreach_media_from_dbPtr.asFunction<
          int Function(filter_h, media_info_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the count of media tags for the passed @a filter in the given @a media_id from the media database.
  /// @details If @c NULL is passed to the @a filter, then no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media_id  The ID of the media info
  /// @param[in]  filter    The handle to the media filter
  /// @param[out] tag_count The count of the media tag
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_info_get_tag_count_from_db(
    ffi.Pointer<ffi.Char> media_id,
    filter_h filter,
    ffi.Pointer<ffi.Int> tag_count,
  ) {
    return _media_info_get_tag_count_from_db(
      media_id,
      filter,
      tag_count,
    );
  }

  late final _media_info_get_tag_count_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, filter_h,
              ffi.Pointer<ffi.Int>)>>('media_info_get_tag_count_from_db');
  late final _media_info_get_tag_count_from_db =
      _media_info_get_tag_count_from_dbPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media tag in the given media info from the media database.
  /// @details This function gets all the media tags associated with the given @a media_id and calls @a callback for every retrieved media tag. \n
  /// If @c NULL is passed to the @a filter, then no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media_id  The ID of the media info
  /// @param[in] filter    The handle to the media filter
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_tag_cb().
  ///
  /// @see media_content_connect()
  /// @see #media_tag_cb
  /// @see media_filter_create()
  int media_info_foreach_tag_from_db(
    ffi.Pointer<ffi.Char> media_id,
    filter_h filter,
    media_tag_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_info_foreach_tag_from_db(
      media_id,
      filter,
      callback,
      user_data,
    );
  }

  late final _media_info_foreach_tag_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, filter_h, media_tag_cb,
              ffi.Pointer<ffi.Void>)>>('media_info_foreach_tag_from_db');
  late final _media_info_foreach_tag_from_db =
      _media_info_foreach_tag_from_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, filter_h, media_tag_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the number of bookmarks for the passed @a filter in the given media ID from the media database.
  /// @details If @c NULL is passed to the @a filter, then no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media_id        The ID of the media info
  /// @param[in]  filter          The handle to the media filter
  /// @param[out] bookmark_count  The count of the media tag
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_info_get_bookmark_count_from_db(
    ffi.Pointer<ffi.Char> media_id,
    filter_h filter,
    ffi.Pointer<ffi.Int> bookmark_count,
  ) {
    return _media_info_get_bookmark_count_from_db(
      media_id,
      filter,
      bookmark_count,
    );
  }

  late final _media_info_get_bookmark_count_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, filter_h,
              ffi.Pointer<ffi.Int>)>>('media_info_get_bookmark_count_from_db');
  late final _media_info_get_bookmark_count_from_db =
      _media_info_get_bookmark_count_from_dbPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media bookmark in the given media info from the media database.
  /// @details This function gets all media bookmarks associated with the given media and calls @a callback for every retrieved media bookmark.
  /// If @c NULL is passed to the @a filter, then no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media_id  The ID of the media info
  /// @param[in] filter    The handle to the media filter
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_bookmark_cb().
  ///
  /// @see media_content_connect()
  /// @see media_bookmark_cb()
  /// @see media_filter_create()
  int media_info_foreach_bookmark_from_db(
    ffi.Pointer<ffi.Char> media_id,
    filter_h filter,
    media_bookmark_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_info_foreach_bookmark_from_db(
      media_id,
      filter,
      callback,
      user_data,
    );
  }

  late final _media_info_foreach_bookmark_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, filter_h, media_bookmark_cb,
              ffi.Pointer<ffi.Void>)>>('media_info_foreach_bookmark_from_db');
  late final _media_info_foreach_bookmark_from_db =
      _media_info_foreach_bookmark_from_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, filter_h, media_bookmark_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the number of face for the passed @a media_id from the media database.
  /// @details If @c NULL is passed to the @a filter, then no filtering is applied.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] media_id media id
  /// @param[in]  filter          The handle to the media filter
  /// @param[out] face_count The count of media face
  ///
  /// @return 0 on success, otherwise a negative error value.
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED DB operation failed
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_info_get_face_count_from_db(
    ffi.Pointer<ffi.Char> media_id,
    filter_h filter,
    ffi.Pointer<ffi.Int> face_count,
  ) {
    return _media_info_get_face_count_from_db(
      media_id,
      filter,
      face_count,
    );
  }

  late final _media_info_get_face_count_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, filter_h,
              ffi.Pointer<ffi.Int>)>>('media_info_get_face_count_from_db');
  late final _media_info_get_face_count_from_db =
      _media_info_get_face_count_from_dbPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media files with optional @a media_id in the given @a face @a face from the media database.
  /// @details This function gets all media face info associated with the given media id and
  /// meeting desired filter option and calls @a callback for
  /// every retrieved media face info. If NULL is passed to the @a filter, no filtering is applied.
  ///
  /// @since_tizen 3.0
  ///
  /// @param [in] media_id media id
  /// @param[in]  filter          The handle to the media filter
  /// @param [in] callback The callback function to invoke
  /// @param [in] user_data The user data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value.
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_info_foreach_face_from_db(
    ffi.Pointer<ffi.Char> media_id,
    filter_h filter,
    media_face_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_info_foreach_face_from_db(
      media_id,
      filter,
      callback,
      user_data,
    );
  }

  late final _media_info_foreach_face_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, filter_h, media_face_cb,
              ffi.Pointer<ffi.Void>)>>('media_info_foreach_face_from_db');
  late final _media_info_foreach_face_from_db =
      _media_info_foreach_face_from_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, filter_h, media_face_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the image metadata handle for a given media info
  /// @details This function returns an image metadata handle retrieved from the media info.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release the @a image handle using image_meta_destroy().
  ///
  /// @param[in]  media  The media info handle
  /// @param[out] image  A handle to image metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see image_meta_destroy()
  int media_info_get_image(
    media_info_h media,
    ffi.Pointer<image_meta_h> image,
  ) {
    return _media_info_get_image(
      media,
      image,
    );
  }

  late final _media_info_get_imagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<image_meta_h>)>>('media_info_get_image');
  late final _media_info_get_image = _media_info_get_imagePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<image_meta_h>)>();

  /// @brief Gets a video metadata handle for a given media info.
  /// @details This function returns a video metadata handle retrieved from the media info handle.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release the @a video handle using video_meta_destroy().
  ///
  /// @param[in]  media The media info handle
  /// @param[out] video A handle to the video meta
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see video_meta_destroy()
  int media_info_get_video(
    media_info_h media,
    ffi.Pointer<video_meta_h> video,
  ) {
    return _media_info_get_video(
      media,
      video,
    );
  }

  late final _media_info_get_videoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<video_meta_h>)>>('media_info_get_video');
  late final _media_info_get_video = _media_info_get_videoPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<video_meta_h>)>();

  /// @brief Gets an audio metadata handle for a given media info.
  /// @details This function returns an audio metadata handle retrieved from the media info handle.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release the @a audio handle using audio_meta_destroy().
  ///
  /// @param[in]  media The media info handle
  /// @param[out] audio A handle to the audio meta
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see audio_meta_destroy()
  int media_info_get_audio(
    media_info_h media,
    ffi.Pointer<audio_meta_h> audio,
  ) {
    return _media_info_get_audio(
      media,
      audio,
    );
  }

  late final _media_info_get_audioPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<audio_meta_h>)>>('media_info_get_audio');
  late final _media_info_get_audio = _media_info_get_audioPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<audio_meta_h>)>();

  /// @brief Gets the media ID
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media The media info handle
  /// @param[out] media_id     The media ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_media_id(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> media_id,
  ) {
    return _media_info_get_media_id(
      media,
      media_id,
    );
  }

  late final _media_info_get_media_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_info_get_media_id');
  late final _media_info_get_media_id = _media_info_get_media_idPtr.asFunction<
      int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the full path of the content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a path using free().
  ///
  /// @param[in]  media The media info handle
  /// @param[out] path  The full path of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_file_path(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _media_info_get_file_path(
      media,
      path,
    );
  }

  late final _media_info_get_file_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_info_get_file_path');
  late final _media_info_get_file_path =
      _media_info_get_file_pathPtr.asFunction<
          int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the file name including the extension of the content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a name using free().
  ///
  /// @param[in]  media The media info handle
  /// @param[out] name  The file name including the extension of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_display_name(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _media_info_get_display_name(
      media,
      name,
    );
  }

  late final _media_info_get_display_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_info_get_display_name');
  late final _media_info_get_display_name =
      _media_info_get_display_namePtr.asFunction<
          int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the content type of the content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media The media info handle
  /// @param[out] type  The content type of the content file (#media_content_type_e)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see #media_content_type_e
  int media_info_get_media_type(
    media_info_h media,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _media_info_get_media_type(
      media,
      type,
    );
  }

  late final _media_info_get_media_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Int32>)>>('media_info_get_media_type');
  late final _media_info_get_media_type = _media_info_get_media_typePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the MIME type of the content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a mime_type using free().
  ///
  /// @param[in]  media     The media info handle
  /// @param[out] mime_type The MIME type of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_mime_type(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mime_type,
  ) {
    return _media_info_get_mime_type(
      media,
      mime_type,
    );
  }

  late final _media_info_get_mime_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_info_get_mime_type');
  late final _media_info_get_mime_type =
      _media_info_get_mime_typePtr.asFunction<
          int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the content file size.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media The media info handle
  /// @param[out] size  The content file size
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_size(
    media_info_h media,
    ffi.Pointer<ffi.UnsignedLongLong> size,
  ) {
    return _media_info_get_size(
      media,
      size,
    );
  }

  late final _media_info_get_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.UnsignedLongLong>)>>('media_info_get_size');
  late final _media_info_get_size = _media_info_get_sizePtr.asFunction<
      int Function(media_info_h, ffi.Pointer<ffi.UnsignedLongLong>)>();

  /// @brief Gets the added time of the content file.
  /// @details The added time refers to the time that content file was first added to media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media      The media info handle
  /// @param[out] added_time The added time to the media database
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_added_time(
    media_info_h media,
    ffi.Pointer<time_t> added_time,
  ) {
    return _media_info_get_added_time(
      media,
      added_time,
    );
  }

  late final _media_info_get_added_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<time_t>)>>('media_info_get_added_time');
  late final _media_info_get_added_time = _media_info_get_added_timePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<time_t>)>();

  /// @brief Gets the modified time of the content file.
  /// @details The modified time refers to the last modification time provided by the file system.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media The media info handle
  /// @param[out] time  The last modification time of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_modified_time(
    media_info_h media,
    ffi.Pointer<time_t> time,
  ) {
    return _media_info_get_modified_time(
      media,
      time,
    );
  }

  late final _media_info_get_modified_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<time_t>)>>('media_info_get_modified_time');
  late final _media_info_get_modified_time = _media_info_get_modified_timePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<time_t>)>();

  /// @brief Gets the timeline of content file.
  /// @details If the content file has the creation time information (like Content recored date or Image creation date), that value is timeline. \n
  /// Otherwise, timeline value is the same as modified time.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media The media info handle
  /// @param[out] time  The timeline of content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_timeline(
    media_info_h media,
    ffi.Pointer<time_t> time,
  ) {
    return _media_info_get_timeline(
      media,
      time,
    );
  }

  late final _media_info_get_timelinePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<time_t>)>>('media_info_get_timeline');
  late final _media_info_get_timeline = _media_info_get_timelinePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<time_t>)>();

  /// @brief Gets the thumbnail path of content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a path using free(). \n
  /// If the thumbnail extraction for the given media has not been requested yet, this API returns NULL. To create a thumbnail, you should use media_info_create_thumbnail() API. \n
  /// Since 3.0, this function returns an empty string if media_info_create_thumbnail() has failed to create a thumbnail for the given media.
  ///
  /// @param[in]  media The media info handle
  /// @param[out] path  The thumbnail path
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_thumbnail_path(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _media_info_get_thumbnail_path(
      media,
      path,
    );
  }

  late final _media_info_get_thumbnail_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_info_get_thumbnail_path');
  late final _media_info_get_thumbnail_path =
      _media_info_get_thumbnail_pathPtr.asFunction<
          int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the description of content file.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media info has no description, the method returns empty string.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a description using free().
  ///
  /// @param[in]  media       The media info handle
  /// @param[out] description The description of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_description(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> description,
  ) {
    return _media_info_get_description(
      media,
      description,
    );
  }

  late final _media_info_get_descriptionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_info_get_description');
  late final _media_info_get_description =
      _media_info_get_descriptionPtr.asFunction<
          int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the longitude of content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media     The media info handle
  /// @param[out] longitude The longitude of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_longitude(
    media_info_h media,
    ffi.Pointer<ffi.Double> longitude,
  ) {
    return _media_info_get_longitude(
      media,
      longitude,
    );
  }

  late final _media_info_get_longitudePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Double>)>>('media_info_get_longitude');
  late final _media_info_get_longitude = _media_info_get_longitudePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Double>)>();

  /// @brief Gets the latitude of content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media    The media info handle
  /// @param[out] latitude The latitude of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_latitude(
    media_info_h media,
    ffi.Pointer<ffi.Double> latitude,
  ) {
    return _media_info_get_latitude(
      media,
      latitude,
    );
  }

  late final _media_info_get_latitudePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Double>)>>('media_info_get_latitude');
  late final _media_info_get_latitude = _media_info_get_latitudePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Double>)>();

  /// @brief Gets the altitude of content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media    The media info handle
  /// @param[out] altitude The altitude of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_altitude(
    media_info_h media,
    ffi.Pointer<ffi.Double> altitude,
  ) {
    return _media_info_get_altitude(
      media,
      altitude,
    );
  }

  late final _media_info_get_altitudePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Double>)>>('media_info_get_altitude');
  late final _media_info_get_altitude = _media_info_get_altitudePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Double>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the weather of content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media   The media info handle
  /// @param[out] weather The weather of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_weather(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> weather,
  ) {
    return _media_info_get_weather(
      media,
      weather,
    );
  }

  late final _media_info_get_weatherPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_info_get_weather');
  late final _media_info_get_weather = _media_info_get_weatherPtr.asFunction<
      int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the rating of content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media  The media info handle
  /// @param[out] rating The rating of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_rating(
    media_info_h media,
    ffi.Pointer<ffi.Int> rating,
  ) {
    return _media_info_get_rating(
      media,
      rating,
    );
  }

  late final _media_info_get_ratingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Int>)>>('media_info_get_rating');
  late final _media_info_get_rating = _media_info_get_ratingPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the favorite status of content file which User set.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media     The media info handle
  /// @param[out] favorite  @c true if content file is set as favorite,
  /// otherwise @c false if content file is not set as favorite
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_info_set_favorite()
  int media_info_get_favorite(
    media_info_h media,
    ffi.Pointer<ffi.Bool> favorite,
  ) {
    return _media_info_get_favorite(
      media,
      favorite,
    );
  }

  late final _media_info_get_favoritePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Bool>)>>('media_info_get_favorite');
  late final _media_info_get_favorite = _media_info_get_favoritePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the author of content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a author using free().
  ///
  /// @param[in]  media  The media info handle
  /// @param[out] author The author of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_author(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> author,
  ) {
    return _media_info_get_author(
      media,
      author,
    );
  }

  late final _media_info_get_authorPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_info_get_author');
  late final _media_info_get_author = _media_info_get_authorPtr.asFunction<
      int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the provider of content file which User set.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a provider using free().
  ///
  /// @param[in]  media    The media info handle
  /// @param[out] provider The provider of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_info_set_provider()
  int media_info_get_provider(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> provider,
  ) {
    return _media_info_get_provider(
      media,
      provider,
    );
  }

  late final _media_info_get_providerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_info_get_provider');
  late final _media_info_get_provider = _media_info_get_providerPtr.asFunction<
      int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0. Redundant, use media_info_get_display_name() instead.
  /// @brief Gets the content name of content file which User set.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a content_name using free().
  ///
  /// @param[in]  media        The media info handle
  /// @param[out] content_name The content name of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_info_set_content_name()
  int media_info_get_content_name(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> content_name,
  ) {
    return _media_info_get_content_name(
      media,
      content_name,
    );
  }

  late final _media_info_get_content_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_info_get_content_name');
  late final _media_info_get_content_name =
      _media_info_get_content_namePtr.asFunction<
          int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the title of content file.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the content file has no title, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a title using free().
  ///
  /// @param[in]  media  The media info handle
  /// @param[out] title  The title of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_title(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> title,
  ) {
    return _media_info_get_title(
      media,
      title,
    );
  }

  late final _media_info_get_titlePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_info_get_title');
  late final _media_info_get_title = _media_info_get_titlePtr.asFunction<
      int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the category of content file which User set.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a category using free().
  ///
  /// @param[in]  media    The media info handle
  /// @param[out] category The category of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_info_set_category()
  int media_info_get_category(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> category,
  ) {
    return _media_info_get_category(
      media,
      category,
    );
  }

  late final _media_info_get_categoryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_info_get_category');
  late final _media_info_get_category = _media_info_get_categoryPtr.asFunction<
      int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the location tag of content file which User set.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a location_tag using free().
  ///
  /// @param[in]  media        The media info handle
  /// @param[out] location_tag The location of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_info_set_location_tag()
  int media_info_get_location_tag(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> location_tag,
  ) {
    return _media_info_get_location_tag(
      media,
      location_tag,
    );
  }

  late final _media_info_get_location_tagPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_info_get_location_tag');
  late final _media_info_get_location_tag =
      _media_info_get_location_tagPtr.asFunction<
          int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the age_rating of content file which User set.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a age_rating using free().
  ///
  /// @param[in]  media      The media info handle
  /// @param[out] age_rating The age rating of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_info_set_age_rating()
  int media_info_get_age_rating(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> age_rating,
  ) {
    return _media_info_get_age_rating(
      media,
      age_rating,
    );
  }

  late final _media_info_get_age_ratingPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_info_get_age_rating');
  late final _media_info_get_age_rating =
      _media_info_get_age_ratingPtr.asFunction<
          int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0. Use media_tag_insert_to_db() instead.
  /// @brief Gets the keyword of content file which User set.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a keyword using free().
  ///
  /// @param[in]  media   The media info handle
  /// @param[out] keyword The keyword of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_info_set_keyword()
  int media_info_get_keyword(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> keyword,
  ) {
    return _media_info_get_keyword(
      media,
      keyword,
    );
  }

  late final _media_info_get_keywordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_info_get_keyword');
  late final _media_info_get_keyword = _media_info_get_keywordPtr.asFunction<
      int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the storage id of content file.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a storage_id using free().
  ///
  /// @param[in]  media   The media info handle
  /// @param[out] storage_id The storage id of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_storage_id(
    media_info_h media,
    ffi.Pointer<ffi.Pointer<ffi.Char>> storage_id,
  ) {
    return _media_info_get_storage_id(
      media,
      storage_id,
    );
  }

  late final _media_info_get_storage_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_info_get_storage_id');
  late final _media_info_get_storage_id =
      _media_info_get_storage_idPtr.asFunction<
          int Function(media_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Checks whether the media is protected via DRM.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media  The media info handle
  /// @param[out] is_drm @c true if media is DRM media,
  /// otherwise @c false if media is not DRM media
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_is_drm(
    media_info_h media,
    ffi.Pointer<ffi.Bool> is_drm,
  ) {
    return _media_info_is_drm(
      media,
      is_drm,
    );
  }

  late final _media_info_is_drmPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Bool>)>>('media_info_is_drm');
  late final _media_info_is_drm = _media_info_is_drmPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the content file is 360 content.
  /// @since_tizen 3.0
  ///
  /// @param[in]  media  The media info handle
  /// @param[out] is_360 @c true if media is 360 content,
  /// otherwise @c false if media is not 360 content
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_is_360_content(
    media_info_h media,
    ffi.Pointer<ffi.Bool> is_360,
  ) {
    return _media_info_is_360_content(
      media,
      is_360,
    );
  }

  late final _media_info_is_360_contentPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Bool>)>>('media_info_is_360_content');
  late final _media_info_is_360_content = _media_info_is_360_contentPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the storage type of content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  media        The media info handle
  /// @param[out] storage_type The storage type of the content file
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_storage_type(
    media_info_h media,
    ffi.Pointer<ffi.Int32> storage_type,
  ) {
    return _media_info_get_storage_type(
      media,
      storage_type,
    );
  }

  late final _media_info_get_storage_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Int32>)>>('media_info_get_storage_type');
  late final _media_info_get_storage_type = _media_info_get_storage_typePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since 4.0. \n
  /// This function does not guarantee independence of the played count value between applications. It is recommended that the value is managed by the application.
  /// @brief Gets number which represents how many times given content has been played.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param [in] media The handle to media info
  /// @param [out] played_count The counter of content played
  ///
  /// @return 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_played_count(
    media_info_h media,
    ffi.Pointer<ffi.Int> played_count,
  ) {
    return _media_info_get_played_count(
      media,
      played_count,
    );
  }

  late final _media_info_get_played_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Int>)>>('media_info_get_played_count');
  late final _media_info_get_played_count = _media_info_get_played_countPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since 4.0. \n
  /// This function does not guarantee independence of the played time value between applications. It is recommended that the value is managed by the application.
  /// @brief Gets the content's played time parameter.
  /// @details Function returns content's elapsed playback time parameter as period
  /// starting from the beginning of the track.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param [in] media The handle to media info
  /// @param [out] played_time The elapsed time of the content
  ///
  /// @return 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_get_played_time(
    media_info_h media,
    ffi.Pointer<time_t> played_time,
  ) {
    return _media_info_get_played_time(
      media,
      played_time,
    );
  }

  late final _media_info_get_played_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<time_t>)>>('media_info_get_played_time');
  late final _media_info_get_played_time = _media_info_get_played_timePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<time_t>)>();

  /// @brief Gets the media info from the media database.
  ///
  /// @details This function creates a new media handle from the media database by the given @a media_id.
  /// Media info will be created and filled with information.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a media using media_tag_destroy().
  ///
  /// @param[in]  media_id The ID of media info
  /// @param[out] media    The media handle associated with the media ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY DB Operation busy
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_info_destroy()
  int media_info_get_media_from_db(
    ffi.Pointer<ffi.Char> media_id,
    ffi.Pointer<media_info_h> media,
  ) {
    return _media_info_get_media_from_db(
      media_id,
      media,
    );
  }

  late final _media_info_get_media_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<media_info_h>)>>('media_info_get_media_from_db');
  late final _media_info_get_media_from_db =
      _media_info_get_media_from_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<media_info_h>)>();

  /// @deprecated Deprecated since 4.0. \n
  /// This function does not guarantee independence of the played count value between applications. It is recommended that the value is managed by the application.
  /// @brief Increments the played count to content meta handle.
  /// @details You can increase the played(opened) count of the content file.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param [in] media The handle to media info
  ///
  /// @return 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db()
  int media_info_increase_played_count(
    media_info_h media,
  ) {
    return _media_info_increase_played_count(
      media,
    );
  }

  late final _media_info_increase_played_countPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h)>>(
          'media_info_increase_played_count');
  late final _media_info_increase_played_count =
      _media_info_increase_played_countPtr
          .asFunction<int Function(media_info_h)>();

  /// @deprecated Deprecated since 4.0. \n
  /// This function does not guarantee independence of the played time value between applications. It is recommended that the value is managed by the application.
  /// @brief Sets the played time to content meta handle.
  /// @details You can set the latest played(opened) time of the content file. the latest played time to be set the current time on the system.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param [in] media The handle to media info
  ///
  /// @return 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db()
  int media_info_set_played_time(
    media_info_h media,
  ) {
    return _media_info_set_played_time(
      media,
    );
  }

  late final _media_info_set_played_timePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h)>>(
          'media_info_set_played_time');
  late final _media_info_set_played_time =
      _media_info_set_played_timePtr.asFunction<int Function(media_info_h)>();

  /// @deprecated Deprecated since 4.0. Redundant, use media_info_move_to_db() instead.
  /// @brief Sets the file name including the extension of the content file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media        The media info handle
  /// @param[in] display_name The file name including the extension of the content file.
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db().
  int media_info_set_display_name(
    media_info_h media,
    ffi.Pointer<ffi.Char> display_name,
  ) {
    return _media_info_set_display_name(
      media,
      display_name,
    );
  }

  late final _media_info_set_display_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Char>)>>('media_info_set_display_name');
  late final _media_info_set_display_name = _media_info_set_display_namePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the description of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media       The media info handle
  /// @param[in] description The description of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db().
  int media_info_set_description(
    media_info_h media,
    ffi.Pointer<ffi.Char> description,
  ) {
    return _media_info_set_description(
      media,
      description,
    );
  }

  late final _media_info_set_descriptionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Char>)>>('media_info_set_description');
  late final _media_info_set_description = _media_info_set_descriptionPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the longitude of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media     The media info handle
  /// @param[in] longitude The longitude of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db().
  int media_info_set_longitude(
    media_info_h media,
    double longitude,
  ) {
    return _media_info_set_longitude(
      media,
      longitude,
    );
  }

  late final _media_info_set_longitudePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h, ffi.Double)>>(
          'media_info_set_longitude');
  late final _media_info_set_longitude = _media_info_set_longitudePtr
      .asFunction<int Function(media_info_h, double)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the latitude of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media    The media info handle
  /// @param[in] latitude The latitude of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db().
  int media_info_set_latitude(
    media_info_h media,
    double latitude,
  ) {
    return _media_info_set_latitude(
      media,
      latitude,
    );
  }

  late final _media_info_set_latitudePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h, ffi.Double)>>(
          'media_info_set_latitude');
  late final _media_info_set_latitude = _media_info_set_latitudePtr
      .asFunction<int Function(media_info_h, double)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the altitude of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media    The media info handle
  /// @param[in] altitude The altitude of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db().
  int media_info_set_altitude(
    media_info_h media,
    double altitude,
  ) {
    return _media_info_set_altitude(
      media,
      altitude,
    );
  }

  late final _media_info_set_altitudePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h, ffi.Double)>>(
          'media_info_set_altitude');
  late final _media_info_set_altitude = _media_info_set_altitudePtr
      .asFunction<int Function(media_info_h, double)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the weather of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media   The media info handle
  /// @param[in] weather The weather of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db().
  int media_info_set_weather(
    media_info_h media,
    ffi.Pointer<ffi.Char> weather,
  ) {
    return _media_info_set_weather(
      media,
      weather,
    );
  }

  late final _media_info_set_weatherPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Char>)>>('media_info_set_weather');
  late final _media_info_set_weather = _media_info_set_weatherPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the rating of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media  The media info handle
  /// @param[in] rating The rating of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db().
  int media_info_set_rating(
    media_info_h media,
    int rating,
  ) {
    return _media_info_set_rating(
      media,
      rating,
    );
  }

  late final _media_info_set_ratingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h, ffi.Int)>>(
          'media_info_set_rating');
  late final _media_info_set_rating =
      _media_info_set_ratingPtr.asFunction<int Function(media_info_h, int)>();

  /// @brief Sets the favorite of media info.
  /// @details This function can mark favorite of the media. If set to @c true, this fuction record the time of the change moment. \n
  /// So, If you use it in order parameter, you can sort the order of the time was a favorite. \n
  /// Or, if you use it in condition parameter, you can get the result of the favorite media.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media    The media info handle
  /// @param[in] favorite Set @c true to set the media info as favorite,
  /// otherwise set @c false to not set the media info as favorite
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_set_favorite(
    media_info_h media,
    bool favorite,
  ) {
    return _media_info_set_favorite(
      media,
      favorite,
    );
  }

  late final _media_info_set_favoritePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h, ffi.Bool)>>(
          'media_info_set_favorite');
  late final _media_info_set_favorite = _media_info_set_favoritePtr
      .asFunction<int Function(media_info_h, bool)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the author of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media  The media info handle
  /// @param[in] author The author of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_set_author(
    media_info_h media,
    ffi.Pointer<ffi.Char> author,
  ) {
    return _media_info_set_author(
      media,
      author,
    );
  }

  late final _media_info_set_authorPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Char>)>>('media_info_set_author');
  late final _media_info_set_author = _media_info_set_authorPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the provider of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media    The media info handle
  /// @param[in] provider The provider of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_set_provider(
    media_info_h media,
    ffi.Pointer<ffi.Char> provider,
  ) {
    return _media_info_set_provider(
      media,
      provider,
    );
  }

  late final _media_info_set_providerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Char>)>>('media_info_set_provider');
  late final _media_info_set_provider = _media_info_set_providerPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. Redundant, use media_info_move_to_db() instead.
  /// @brief Sets the content name of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media        The media info handle
  /// @param[in] content_name The content name of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db()
  int media_info_set_content_name(
    media_info_h media,
    ffi.Pointer<ffi.Char> content_name,
  ) {
    return _media_info_set_content_name(
      media,
      content_name,
    );
  }

  late final _media_info_set_content_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Char>)>>('media_info_set_content_name');
  late final _media_info_set_content_name = _media_info_set_content_namePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the category of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media    The media info handle
  /// @param[in] category The category of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db()
  int media_info_set_category(
    media_info_h media,
    ffi.Pointer<ffi.Char> category,
  ) {
    return _media_info_set_category(
      media,
      category,
    );
  }

  late final _media_info_set_categoryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Char>)>>('media_info_set_category');
  late final _media_info_set_category = _media_info_set_categoryPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the location tag of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media        The media info handle
  /// @param[in] location_tag The location of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db()
  int media_info_set_location_tag(
    media_info_h media,
    ffi.Pointer<ffi.Char> location_tag,
  ) {
    return _media_info_set_location_tag(
      media,
      location_tag,
    );
  }

  late final _media_info_set_location_tagPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Char>)>>('media_info_set_location_tag');
  late final _media_info_set_location_tag = _media_info_set_location_tagPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the age rating of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media      The media info handle
  /// @param[in] age_rating The age rating of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db()
  int media_info_set_age_rating(
    media_info_h media,
    ffi.Pointer<ffi.Char> age_rating,
  ) {
    return _media_info_set_age_rating(
      media,
      age_rating,
    );
  }

  late final _media_info_set_age_ratingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Char>)>>('media_info_set_age_rating');
  late final _media_info_set_age_rating = _media_info_set_age_ratingPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. Use media_tag_insert_to_db() instead.
  /// @brief Sets the keyword of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media   The media info handle
  /// @param[in] keyword The keyword of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db()
  int media_info_set_keyword(
    media_info_h media,
    ffi.Pointer<ffi.Char> keyword,
  ) {
    return _media_info_set_keyword(
      media,
      keyword,
    );
  }

  late final _media_info_set_keywordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Char>)>>('media_info_set_keyword');
  late final _media_info_set_keyword = _media_info_set_keywordPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Updates the media info to the media database.
  ///
  /// @details The function updates the given media info in the media database.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks The function should be called after any change in media, to be updated to the media
  /// database. For example, after using media_info_set_favorite()
  /// for setting the name of the media, the media_info_update_to_db() function should be called so as to update
  /// the given media info attributes in the media database.
  ///
  /// @param[in] media The media info handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_info_set_favorite()
  /// @see media_info_set_provider()
  /// @see media_info_set_category()
  /// @see media_info_set_location_tag()
  /// @see media_info_set_age_rating()
  int media_info_update_to_db(
    media_info_h media,
  ) {
    return _media_info_update_to_db(
      media,
    );
  }

  late final _media_info_update_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h)>>(
          'media_info_update_to_db');
  late final _media_info_update_to_db =
      _media_info_update_to_dbPtr.asFunction<int Function(media_info_h)>();

  /// @deprecated Deprecated since 4.0. Use media_content_scan_file() instead.
  /// @brief Refreshes the media metadata to the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write \n
  /// %http://tizen.org/privilege/mediastorage \n
  /// %http://tizen.org/privilege/externalstorage
  ///
  /// @remarks You must add privilege http://tizen.org/privilege/content.write. And You add more privilege depending on your choice of contents path. \n
  /// If you want to access only internal storage by using  this API, you should add privilege http://tizen.org/privilege/mediastorage. \n
  /// Or if you want to access only external storage by using  this API, you should add privilege http://tizen.org/privilege/externalstorage. \n
  /// If you can access both storage, you should add all privilege.
  ///
  /// @param[in] media_id The ID of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_info_refresh_metadata_to_db(
    ffi.Pointer<ffi.Char> media_id,
  ) {
    return _media_info_refresh_metadata_to_db(
      media_id,
    );
  }

  late final _media_info_refresh_metadata_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'media_info_refresh_metadata_to_db');
  late final _media_info_refresh_metadata_to_db =
      _media_info_refresh_metadata_to_dbPtr
          .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. This data cannot be saved to the file.
  /// @brief Sets the added time of media info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] media      The media info handle
  /// @param[in] added_time The added time of the media info
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_info_update_to_db()
  int media_info_set_added_time(
    media_info_h media,
    int added_time,
  ) {
    return _media_info_set_added_time(
      media,
      added_time,
    );
  }

  late final _media_info_set_added_timePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h, time_t)>>(
          'media_info_set_added_time');
  late final _media_info_set_added_time = _media_info_set_added_timePtr
      .asFunction<int Function(media_info_h, int)>();

  /// @brief Moves the media info to the given destination path in the media database.
  /// @details After moving or renaming a file in the filesystem, call this function to update the database. \n
  /// If the source path and destination path are the same, then this API does nothing.
  /// If you want to refresh media information, you should use media_content_scan_file() API.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write \n
  /// %http://tizen.org/privilege/mediastorage \n
  /// %http://tizen.org/privilege/externalstorage
  ///
  /// @remarks You must add privilege http://tizen.org/privilege/content.write. And You add more privilege depending on your choice of contents path. \n
  /// If you want to access only internal storage by using  this API, you should add privilege http://tizen.org/privilege/mediastorage. \n
  /// Or if you want to access only external storage by using this API, you should add privilege http://tizen.org/privilege/externalstorage. \n
  /// If you can access both storage, you should add all privilege. \n
  /// This API does not support USB storage.
  ///
  /// @param[in] media    The media info handle
  /// @param[in] dst_path The path of destination
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter (Especially, if the request is duplicated, this error returns.)
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_content_scan_folder()
  int media_info_move_to_db(
    media_info_h media,
    ffi.Pointer<ffi.Char> dst_path,
  ) {
    return _media_info_move_to_db(
      media,
      dst_path,
    );
  }

  late final _media_info_move_to_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Char>)>>('media_info_move_to_db');
  late final _media_info_move_to_db = _media_info_move_to_dbPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Creates a thumbnail file for the given media, asynchronously.
  /// @details This function creates an thumbnail file for given media item and calls @a callback for completion of creating the thumbnail.
  /// If a thumbnail already exists for the given media, then the path of thumbnail will be returned in callback function. \n
  /// Since 3.0, a thumbnail is not automatically extracted during media scanning. \n
  /// Therefore, if there exists no thumbnail for the given media, you MUST call this function to create a thumbnail.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks If you want to destroy media handle before callback invoked, you must cancel thumbnail request by using media_info_cancel_thumbnail() \n
  /// Since 3.0, if creation of a thumbnail is failed, empty string will be passed through media_thumbnail_completed_cb().
  /// Items in external storage except MMC not supported.
  ///
  /// @param[in] media     The media info handle
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_info_create_thumbnail(
    media_info_h media,
    media_thumbnail_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_info_create_thumbnail(
      media,
      callback,
      user_data,
    );
  }

  late final _media_info_create_thumbnailPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h, media_thumbnail_completed_cb,
              ffi.Pointer<ffi.Void>)>>('media_info_create_thumbnail');
  late final _media_info_create_thumbnail =
      _media_info_create_thumbnailPtr.asFunction<
          int Function(media_info_h, media_thumbnail_completed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Cancels the creation of thumbnail file for the given media.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks If you request cancel for the already thumbnail created media, this API return MEDIA_CONTENT_ERROR_INVALID_OPERATION
  ///
  /// @param[in] media The media info handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  /// @see media_content_connect()
  int media_info_cancel_thumbnail(
    media_info_h media,
  ) {
    return _media_info_cancel_thumbnail(
      media,
    );
  }

  late final _media_info_cancel_thumbnailPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h)>>(
          'media_info_cancel_thumbnail');
  late final _media_info_cancel_thumbnail =
      _media_info_cancel_thumbnailPtr.asFunction<int Function(media_info_h)>();

  /// @ingroup CAPI_CONTENT_MEDIA_FACE_DETECTION_MODULE
  /// @brief Starts face detection for the given image, asynchronously.
  /// @details This function detects faces for given image item and calls the given callback function when the detection is completed. \n
  /// The given callback function is called when the detection is completed. \n
  /// To obtain the detected faces, call the media_info_foreach_face_from_db() function.
  ///
  /// @since_tizen 3.0
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write \n
  /// %http://tizen.org/privilege/mediastorage
  ///
  /// @remarks If you want to destroy the media handle before callback invoked, you must cancel the face detection request by using media_info_cancel_face_detection(). \n
  /// If face detection fails, the @a face_count argument in media_face_detection_completed_cb() will be set to 0.
  /// Media items in external storage are not supported, with the exception of MMC items.
  ///
  /// @param[in] media     The media info handle
  /// @param[in] callback  The callback function to be invoked when detection is completed
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_info_cancel_face_detection()
  int media_info_start_face_detection(
    media_info_h media,
    media_face_detection_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_info_start_face_detection(
      media,
      callback,
      user_data,
    );
  }

  late final _media_info_start_face_detectionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h, media_face_detection_completed_cb,
              ffi.Pointer<ffi.Void>)>>('media_info_start_face_detection');
  late final _media_info_start_face_detection =
      _media_info_start_face_detectionPtr.asFunction<
          int Function(media_info_h, media_face_detection_completed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_CONTENT_MEDIA_FACE_DETECTION_MODULE
  /// @brief Cancels face detection of image for the given media.
  /// @details This function cancels face detection for given media item. \n
  /// If you cancel face detection request before callback is invoked, the callback registered by media_info_start_face_detection() API will not be invoked.
  ///
  /// @since_tizen 3.0
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks If face detection is already done when you request the cancellation, this API return MEDIA_CONTENT_ERROR_INVALID_OPERATION
  ///
  /// @param[in] media The media info handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_info_start_face_detection()
  int media_info_cancel_face_detection(
    media_info_h media,
  ) {
    return _media_info_cancel_face_detection(
      media,
    );
  }

  late final _media_info_cancel_face_detectionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h)>>(
          'media_info_cancel_face_detection');
  late final _media_info_cancel_face_detection =
      _media_info_cancel_face_detectionPtr
          .asFunction<int Function(media_info_h)>();

  /// @deprecated Deprecated since 4.0. Use media_info_insert_to_db() instead.
  /// @brief Creates the media info handle.
  /// @details If the information about the file that is already known, you can use this API to generate empty handler.
  /// @since_tizen 3.0
  ///
  ///
  /// @privilege %http://tizen.org/privilege/mediastorage \n
  /// %http://tizen.org/privilege/externalstorage
  ///
  /// @remarks If you want to access only internal storage with this API, you should add privilege http://tizen.org/privilege/mediastorage. \n
  /// Or if you want to access only external storage with this API, you should add privilege http://tizen.org/privilege/externalstorage. \n
  /// If you can access both storage, you must add all privilege.
  ///
  /// @param[in] path The path to create the media info handle
  /// @param[out] media The media info handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED		 DB operation failed
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION	Invalid operation
  ///
  /// @see media_info_destroy()
  int media_info_create(
    ffi.Pointer<ffi.Char> path,
    ffi.Pointer<media_info_h> media,
  ) {
    return _media_info_create(
      path,
      media,
    );
  }

  late final _media_info_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<media_info_h>)>>('media_info_create');
  late final _media_info_create = _media_info_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<media_info_h>)>();

  /// @deprecated Deprecated since 4.0. Use media_info_insert_to_db() instead.
  /// @brief Inserts media info to database with media info data.
  /// @since_tizen 3.0
  ///
  /// @remarks You must release @a info using media_info_destroy().
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] media The media info handle to be inserted
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED		 DB operation failed
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  int media_info_insert_to_db_with_data(
    media_info_h media,
  ) {
    return _media_info_insert_to_db_with_data(
      media,
    );
  }

  late final _media_info_insert_to_db_with_dataPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_info_h)>>(
          'media_info_insert_to_db_with_data');
  late final _media_info_insert_to_db_with_data =
      _media_info_insert_to_db_with_dataPtr
          .asFunction<int Function(media_info_h)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Sets the title of media info handle.
  /// @since_tizen 3.0
  ///
  /// @param[in] media The media info handle
  /// @param[in] title The title of media info handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_set_title(
    media_info_h media,
    ffi.Pointer<ffi.Char> title,
  ) {
    return _media_info_set_title(
      media,
      title,
    );
  }

  late final _media_info_set_titlePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Char>)>>('media_info_set_title');
  late final _media_info_set_title = _media_info_set_titlePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Sets the album of media info handle.
  /// @since_tizen 3.0
  ///
  /// @param[in] media The media info handle
  /// @param[in] album The album of media info handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_set_album(
    media_info_h media,
    ffi.Pointer<ffi.Char> album,
  ) {
    return _media_info_set_album(
      media,
      album,
    );
  }

  late final _media_info_set_albumPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Char>)>>('media_info_set_album');
  late final _media_info_set_album = _media_info_set_albumPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Sets the artist of media info handle.
  /// @since_tizen 3.0
  ///
  /// @param[in] media The media info handle
  /// @param[in] artist The artist of media info handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_set_artist(
    media_info_h media,
    ffi.Pointer<ffi.Char> artist,
  ) {
    return _media_info_set_artist(
      media,
      artist,
    );
  }

  late final _media_info_set_artistPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Char>)>>('media_info_set_artist');
  late final _media_info_set_artist = _media_info_set_artistPtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Sets the genre of media info handle.
  /// @since_tizen 3.0
  ///
  /// @param[in] media The media info handle
  /// @param[in] genre The genre of media info handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_set_genre(
    media_info_h media,
    ffi.Pointer<ffi.Char> genre,
  ) {
    return _media_info_set_genre(
      media,
      genre,
    );
  }

  late final _media_info_set_genrePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_info_h, ffi.Pointer<ffi.Char>)>>('media_info_set_genre');
  late final _media_info_set_genre = _media_info_set_genrePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Sets the recorded date of media info handle.
  /// @since_tizen 3.0
  ///
  /// @param[in] media The media info handle
  /// @param[in] recorded_date The recorded date of media info handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_info_set_recorded_date(
    media_info_h media,
    ffi.Pointer<ffi.Char> recorded_date,
  ) {
    return _media_info_set_recorded_date(
      media,
      recorded_date,
    );
  }

  late final _media_info_set_recorded_datePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_info_h,
              ffi.Pointer<ffi.Char>)>>('media_info_set_recorded_date');
  late final _media_info_set_recorded_date = _media_info_set_recorded_datePtr
      .asFunction<int Function(media_info_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Inserts a new tag in the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks The created tag handle must be released using media_tag_destroy().
  ///
  /// @param[in]  tag_name The tag name to be inserted
  /// @param[out] tag      The created handle to the media tag
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_tag_delete_from_db()
  /// @see media_tag_destroy()
  int media_tag_insert_to_db(
    ffi.Pointer<ffi.Char> tag_name,
    ffi.Pointer<media_tag_h> tag,
  ) {
    return _media_tag_insert_to_db(
      tag_name,
      tag,
    );
  }

  late final _media_tag_insert_to_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<media_tag_h>)>>('media_tag_insert_to_db');
  late final _media_tag_insert_to_db = _media_tag_insert_to_dbPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<media_tag_h>)>();

  /// @brief Deletes a given tag from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] tag_id The ID of media tag
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_tag_insert_to_db()
  int media_tag_delete_from_db(
    int tag_id,
  ) {
    return _media_tag_delete_from_db(
      tag_id,
    );
  }

  late final _media_tag_delete_from_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'media_tag_delete_from_db');
  late final _media_tag_delete_from_db =
      _media_tag_delete_from_dbPtr.asFunction<int Function(int)>();

  /// @brief Gets the count of the tag for the passed @a filter from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  filter    The handle to the filter
  /// @param[out] tag_count The count of the media tag
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_tag_get_tag_count_from_db(
    filter_h filter,
    ffi.Pointer<ffi.Int> tag_count,
  ) {
    return _media_tag_get_tag_count_from_db(
      filter,
      tag_count,
    );
  }

  late final _media_tag_get_tag_count_from_dbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(filter_h, ffi.Pointer<ffi.Int>)>>(
      'media_tag_get_tag_count_from_db');
  late final _media_tag_get_tag_count_from_db =
      _media_tag_get_tag_count_from_dbPtr
          .asFunction<int Function(filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through tags from the media database.
  /// @details This function gets all tags meeting a desired @a filter
  /// and calls a registered callback function for every retrieved tag.
  /// If @c NULL is passed to the @a filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] filter    The tag filter handle
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_tag_cb().
  ///
  /// @see media_content_connect()
  /// @see #media_tag_cb
  /// @see media_filter_create()
  int media_tag_foreach_tag_from_db(
    filter_h filter,
    media_tag_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_tag_foreach_tag_from_db(
      filter,
      callback,
      user_data,
    );
  }

  late final _media_tag_foreach_tag_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, media_tag_cb,
              ffi.Pointer<ffi.Void>)>>('media_tag_foreach_tag_from_db');
  late final _media_tag_foreach_tag_from_db =
      _media_tag_foreach_tag_from_dbPtr.asFunction<
          int Function(filter_h, media_tag_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the number of media files for the passed @a filter in the given @a tag from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  tag_id      The ID of the media tag
  /// @param[in]  filter      The handle to the media filter
  /// @param[out] media_count The count of media items
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_tag_get_media_count_from_db(
    int tag_id,
    filter_h filter,
    ffi.Pointer<ffi.Int> media_count,
  ) {
    return _media_tag_get_media_count_from_db(
      tag_id,
      filter,
      media_count,
    );
  }

  late final _media_tag_get_media_count_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, filter_h,
              ffi.Pointer<ffi.Int>)>>('media_tag_get_media_count_from_db');
  late final _media_tag_get_media_count_from_db =
      _media_tag_get_media_count_from_dbPtr
          .asFunction<int Function(int, filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through media items for a given tag from the media database.
  /// @details This function gets all media items associated with a given tag and
  /// meeting a desired @a filter and calls a registered callback function for
  /// every retrieved media item. If @c NULL is passed to the @a filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] tag_id    The ID of the media tag
  /// @param[in] filter    The handle to the media filter
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_info_cb().
  ///
  /// @see media_content_connect()
  /// @see media_info_cb()
  /// @see media_filter_create()
  int media_tag_foreach_media_from_db(
    int tag_id,
    filter_h filter,
    media_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_tag_foreach_media_from_db(
      tag_id,
      filter,
      callback,
      user_data,
    );
  }

  late final _media_tag_foreach_media_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, filter_h, media_info_cb,
              ffi.Pointer<ffi.Void>)>>('media_tag_foreach_media_from_db');
  late final _media_tag_foreach_media_from_db =
      _media_tag_foreach_media_from_dbPtr.asFunction<
          int Function(int, filter_h, media_info_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Clones the media tag.
  /// @details This function copies the media tag handle from a source to destination.
  /// There is no media_tag_create() function. The media_tag_h is created internally and available through media tag foreach function
  /// such as media_tag_foreach_tag_from_db().
  /// To use this handle outside of these foreach functions, use this function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release the destination handle using media_tag_destroy().
  ///
  /// @param[out] dst The destination handle to the media tag
  /// @param[in]  src The source handle to the media tag
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_tag_destroy()
  int media_tag_clone(
    ffi.Pointer<media_tag_h> dst,
    media_tag_h src,
  ) {
    return _media_tag_clone(
      dst,
      src,
    );
  }

  late final _media_tag_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<media_tag_h>, media_tag_h)>>('media_tag_clone');
  late final _media_tag_clone = _media_tag_clonePtr
      .asFunction<int Function(ffi.Pointer<media_tag_h>, media_tag_h)>();

  /// @brief Destroys the media tag.
  /// @details This function frees all resources related to the tag handle. The tag handle can no longer
  /// be used for any operation. A new tag handle has to be created before next usage.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] tag The media tag handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre A copy of the media tag handle created by calling media_tag_clone() or media_tag_insert_to_db().
  ///
  /// @see media_tag_clone()
  /// @see media_tag_insert_to_db()
  int media_tag_destroy(
    media_tag_h tag,
  ) {
    return _media_tag_destroy(
      tag,
    );
  }

  late final _media_tag_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_tag_h)>>(
          'media_tag_destroy');
  late final _media_tag_destroy =
      _media_tag_destroyPtr.asFunction<int Function(media_tag_h)>();

  /// @brief Gets the media tag ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  tag     The media tag handle
  /// @param[out] tag_id  The ID of the media tag
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_tag_get_tag_id(
    media_tag_h tag,
    ffi.Pointer<ffi.Int> tag_id,
  ) {
    return _media_tag_get_tag_id(
      tag,
      tag_id,
    );
  }

  late final _media_tag_get_tag_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_tag_h, ffi.Pointer<ffi.Int>)>>('media_tag_get_tag_id');
  late final _media_tag_get_tag_id = _media_tag_get_tag_idPtr
      .asFunction<int Function(media_tag_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the tag name.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a tag_name using free().
  ///
  /// @param[in]  tag      The media tag handle
  /// @param[out] tag_name The name of the tag
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_tag_get_name(
    media_tag_h tag,
    ffi.Pointer<ffi.Pointer<ffi.Char>> tag_name,
  ) {
    return _media_tag_get_name(
      tag,
      tag_name,
    );
  }

  late final _media_tag_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_tag_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_tag_get_name');
  late final _media_tag_get_name = _media_tag_get_namePtr.asFunction<
      int Function(media_tag_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the media tag from the media database.
  ///
  /// @details This function creates a new media tag handle from the media database by the given @a tag_id.
  /// Media tag will be created and will be filled with tag information.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a folder using media_tag_destroy().
  ///
  /// @param[in]  tag_id The ID of the media tag
  /// @param[out] tag    The media tag handle associated with the tag ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_tag_destroy()
  int media_tag_get_tag_from_db(
    int tag_id,
    ffi.Pointer<media_tag_h> tag,
  ) {
    return _media_tag_get_tag_from_db(
      tag_id,
      tag,
    );
  }

  late final _media_tag_get_tag_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<media_tag_h>)>>('media_tag_get_tag_from_db');
  late final _media_tag_get_tag_from_db = _media_tag_get_tag_from_dbPtr
      .asFunction<int Function(int, ffi.Pointer<media_tag_h>)>();

  /// @brief Adds a new media info to the tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] tag      The media tag handle
  /// @param[in] media_id The ID to the media info which is added
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post media_tag_update_to_db()
  ///
  /// @see media_content_connect()
  /// @see media_tag_remove_media()
  int media_tag_add_media(
    media_tag_h tag,
    ffi.Pointer<ffi.Char> media_id,
  ) {
    return _media_tag_add_media(
      tag,
      media_id,
    );
  }

  late final _media_tag_add_mediaPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_tag_h, ffi.Pointer<ffi.Char>)>>('media_tag_add_media');
  late final _media_tag_add_media = _media_tag_add_mediaPtr
      .asFunction<int Function(media_tag_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Removes the media info from the given tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] tag      The media tag handle
  /// @param[in] media_id The ID to the media info which is removed
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post media_tag_update_to_db()
  ///
  /// @see media_content_connect()
  /// @see media_tag_add_media()
  int media_tag_remove_media(
    media_tag_h tag,
    ffi.Pointer<ffi.Char> media_id,
  ) {
    return _media_tag_remove_media(
      tag,
      media_id,
    );
  }

  late final _media_tag_remove_mediaPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_tag_h, ffi.Pointer<ffi.Char>)>>('media_tag_remove_media');
  late final _media_tag_remove_media = _media_tag_remove_mediaPtr
      .asFunction<int Function(media_tag_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the name of the tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] tag      The media tag handle
  /// @param[in] tag_name The name of the media tag
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @post media_tag_update_to_db()
  int media_tag_set_name(
    media_tag_h tag,
    ffi.Pointer<ffi.Char> tag_name,
  ) {
    return _media_tag_set_name(
      tag,
      tag_name,
    );
  }

  late final _media_tag_set_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_tag_h, ffi.Pointer<ffi.Char>)>>('media_tag_set_name');
  late final _media_tag_set_name = _media_tag_set_namePtr
      .asFunction<int Function(media_tag_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Updates the media tag to the media database.
  ///
  /// @details The function updates the given media tag in the media database. The function should be called after any change in tag attributes, to be updated to the media
  /// database. For example, after using media_tag_set_name() for setting the name of the tag, the media_tag_update_to_db() function should be called so as to update
  /// the given tag attributes in the media database.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] tag The media tag handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_tag_destroy()
  /// @see media_tag_add_media()
  /// @see media_tag_remove_media()
  /// @see media_tag_set_name()
  int media_tag_update_to_db(
    media_tag_h tag,
  ) {
    return _media_tag_update_to_db(
      tag,
    );
  }

  late final _media_tag_update_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_tag_h)>>(
          'media_tag_update_to_db');
  late final _media_tag_update_to_db =
      _media_tag_update_to_dbPtr.asFunction<int Function(media_tag_h)>();

  /// @brief Clones the video metadata.
  /// @details This function copies the video metadata handle from a source to destination.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release the destination handle using video_meta_destroy().
  ///
  /// @param[out] dst The destination handle to the video metadata
  /// @param[in]  src The source handle to the video metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @see video_meta_destroy()
  int video_meta_clone(
    ffi.Pointer<video_meta_h> dst,
    video_meta_h src,
  ) {
    return _video_meta_clone(
      dst,
      src,
    );
  }

  late final _video_meta_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<video_meta_h>, video_meta_h)>>('video_meta_clone');
  late final _video_meta_clone = _video_meta_clonePtr
      .asFunction<int Function(ffi.Pointer<video_meta_h>, video_meta_h)>();

  /// @brief Destroys the video metadata.
  /// @details This function frees all resources related to the video metadata handle. This handle
  /// no longer can be used to perform any operation. A new handle has to
  /// be created before the next use.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] video The video metadata handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre Get copy of video metadata handle by calling video_meta_clone().
  ///
  /// @see video_meta_clone()
  int video_meta_destroy(
    video_meta_h video,
  ) {
    return _video_meta_destroy(
      video,
    );
  }

  late final _video_meta_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_meta_h)>>(
          'video_meta_destroy');
  late final _video_meta_destroy =
      _video_meta_destroyPtr.asFunction<int Function(video_meta_h)>();

  /// @brief Gets the ID of the media of the given video metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a media_id using free().
  ///
  /// @param[in]  video    The video metadata handle
  /// @param[out] media_id The ID of the video
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int video_meta_get_media_id(
    video_meta_h video,
    ffi.Pointer<ffi.Pointer<ffi.Char>> media_id,
  ) {
    return _video_meta_get_media_id(
      video,
      media_id,
    );
  }

  late final _video_meta_get_media_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('video_meta_get_media_id');
  late final _video_meta_get_media_id = _video_meta_get_media_idPtr.asFunction<
      int Function(video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the album of the given video metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no album info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a album using free().
  ///
  /// @param[in]  video The video metadata handle
  /// @param[out] album The album of the video metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int video_meta_get_album(
    video_meta_h video,
    ffi.Pointer<ffi.Pointer<ffi.Char>> album,
  ) {
    return _video_meta_get_album(
      video,
      album,
    );
  }

  late final _video_meta_get_albumPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('video_meta_get_album');
  late final _video_meta_get_album = _video_meta_get_albumPtr.asFunction<
      int Function(video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the artist of the given video metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no artist info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a artist using free().
  ///
  /// @param[in]  video  The video metadata handle
  /// @param[out] artist The artist of the video metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int video_meta_get_artist(
    video_meta_h video,
    ffi.Pointer<ffi.Pointer<ffi.Char>> artist,
  ) {
    return _video_meta_get_artist(
      video,
      artist,
    );
  }

  late final _video_meta_get_artistPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('video_meta_get_artist');
  late final _video_meta_get_artist = _video_meta_get_artistPtr.asFunction<
      int Function(video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the video album artist.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no album artist info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a album_artist using free().
  ///
  /// @param[in]  video        The video metadata handle
  /// @param[out] album_artist The album artist of the video metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int video_meta_get_album_artist(
    video_meta_h video,
    ffi.Pointer<ffi.Pointer<ffi.Char>> album_artist,
  ) {
    return _video_meta_get_album_artist(
      video,
      album_artist,
    );
  }

  late final _video_meta_get_album_artistPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'video_meta_get_album_artist');
  late final _video_meta_get_album_artist =
      _video_meta_get_album_artistPtr.asFunction<
          int Function(video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the genre of the given video metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no genre info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a genre using free().
  ///
  /// @param[in]  video The video metadata handle
  /// @param[out] genre The genre of the video metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int video_meta_get_genre(
    video_meta_h video,
    ffi.Pointer<ffi.Pointer<ffi.Char>> genre,
  ) {
    return _video_meta_get_genre(
      video,
      genre,
    );
  }

  late final _video_meta_get_genrePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('video_meta_get_genre');
  late final _video_meta_get_genre = _video_meta_get_genrePtr.asFunction<
      int Function(video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the composer of the given video metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no composer info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a composer using free().
  ///
  /// @param[in]  video    The video metadata handle
  /// @param[out] composer The composer of the video metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int video_meta_get_composer(
    video_meta_h video,
    ffi.Pointer<ffi.Pointer<ffi.Char>> composer,
  ) {
    return _video_meta_get_composer(
      video,
      composer,
    );
  }

  late final _video_meta_get_composerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('video_meta_get_composer');
  late final _video_meta_get_composer = _video_meta_get_composerPtr.asFunction<
      int Function(video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the year of the given video metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no year info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a year using free().
  ///
  /// @param[in]  video The video metadata handle
  /// @param[out] year  The year of the video metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int video_meta_get_year(
    video_meta_h video,
    ffi.Pointer<ffi.Pointer<ffi.Char>> year,
  ) {
    return _video_meta_get_year(
      video,
      year,
    );
  }

  late final _video_meta_get_yearPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('video_meta_get_year');
  late final _video_meta_get_year = _video_meta_get_yearPtr.asFunction<
      int Function(video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the recorded date of the video.
  /// @details The recorded date is got from video file's metadata. Some formats like mp4 use UTC and the rest can be different. \n
  /// So, please refer to the format specification if needed.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a recorded_date using free().
  ///
  /// @param[in]  video         The video metadata handle
  /// @param[out] recorded_date The recorded date of the video metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int video_meta_get_recorded_date(
    video_meta_h video,
    ffi.Pointer<ffi.Pointer<ffi.Char>> recorded_date,
  ) {
    return _video_meta_get_recorded_date(
      video,
      recorded_date,
    );
  }

  late final _video_meta_get_recorded_datePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'video_meta_get_recorded_date');
  late final _video_meta_get_recorded_date =
      _video_meta_get_recorded_datePtr.asFunction<
          int Function(video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the copyright notice of the given video metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no copyright info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a copyright using free().
  ///
  /// @param[in]  video     The video metadata handle
  /// @param[out] copyright The copyright of the video metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int video_meta_get_copyright(
    video_meta_h video,
    ffi.Pointer<ffi.Pointer<ffi.Char>> copyright,
  ) {
    return _video_meta_get_copyright(
      video,
      copyright,
    );
  }

  late final _video_meta_get_copyrightPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('video_meta_get_copyright');
  late final _video_meta_get_copyright =
      _video_meta_get_copyrightPtr.asFunction<
          int Function(video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the track number of the given video metadata.
  /// @details If the value is an empty string, the method returns "Unknown". \n
  /// Since 3.0, if the media content has no track info, the method returns empty string.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a track_num using free().
  ///
  /// @param[in]  video     The video metadata handle
  /// @param[out] track_num The track number of the video metadata
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int video_meta_get_track_num(
    video_meta_h video,
    ffi.Pointer<ffi.Pointer<ffi.Char>> track_num,
  ) {
    return _video_meta_get_track_num(
      video,
      track_num,
    );
  }

  late final _video_meta_get_track_numPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('video_meta_get_track_num');
  late final _video_meta_get_track_num =
      _video_meta_get_track_numPtr.asFunction<
          int Function(video_meta_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the bitrate of the given video metadata in bitrate per second.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  video    The video metadata handle
  /// @param[out] bit_rate The video bit rate in bit per second [bps]
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_get_bit_rate(
    video_meta_h video,
    ffi.Pointer<ffi.Int> bit_rate,
  ) {
    return _video_meta_get_bit_rate(
      video,
      bit_rate,
    );
  }

  late final _video_meta_get_bit_ratePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              video_meta_h, ffi.Pointer<ffi.Int>)>>('video_meta_get_bit_rate');
  late final _video_meta_get_bit_rate = _video_meta_get_bit_ratePtr
      .asFunction<int Function(video_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the track duration of the given video metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  video    The video metadata handle
  /// @param[out] duration The video duration in milliseconds
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_get_duration(
    video_meta_h video,
    ffi.Pointer<ffi.Int> duration,
  ) {
    return _video_meta_get_duration(
      video,
      duration,
    );
  }

  late final _video_meta_get_durationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              video_meta_h, ffi.Pointer<ffi.Int>)>>('video_meta_get_duration');
  late final _video_meta_get_duration = _video_meta_get_durationPtr
      .asFunction<int Function(video_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the width of the given video metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  video The video metadata handle
  /// @param[out] width The video width in pixels
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_get_width(
    video_meta_h video,
    ffi.Pointer<ffi.Int> width,
  ) {
    return _video_meta_get_width(
      video,
      width,
    );
  }

  late final _video_meta_get_widthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              video_meta_h, ffi.Pointer<ffi.Int>)>>('video_meta_get_width');
  late final _video_meta_get_width = _video_meta_get_widthPtr
      .asFunction<int Function(video_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the height of the given video metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  video  The video metadata handle
  /// @param[out] height The video height in pixels
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_get_height(
    video_meta_h video,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _video_meta_get_height(
      video,
      height,
    );
  }

  late final _video_meta_get_heightPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              video_meta_h, ffi.Pointer<ffi.Int>)>>('video_meta_get_height');
  late final _video_meta_get_height = _video_meta_get_heightPtr
      .asFunction<int Function(video_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the rotation of the given video metadata.
  /// @since_tizen 4.0
  ///
  /// @param[in]  video  The video metadata handle
  /// @param[out] rotation The clockwise rotation angle of the video in degrees (can be returned from 0 to less than 360)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_get_rotation(
    video_meta_h video,
    ffi.Pointer<ffi.Int> rotation,
  ) {
    return _video_meta_get_rotation(
      video,
      rotation,
    );
  }

  late final _video_meta_get_rotationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              video_meta_h, ffi.Pointer<ffi.Int>)>>('video_meta_get_rotation');
  late final _video_meta_get_rotation = _video_meta_get_rotationPtr
      .asFunction<int Function(video_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played count value between applications. It is recommended that the value is managed by the application.
  /// @brief Gets the played count of the video.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  video        The video metadata handle
  /// @param[out] played_count The counter of the video played
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_get_played_count(
    video_meta_h video,
    ffi.Pointer<ffi.Int> played_count,
  ) {
    return _video_meta_get_played_count(
      video,
      played_count,
    );
  }

  late final _video_meta_get_played_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<ffi.Int>)>>('video_meta_get_played_count');
  late final _video_meta_get_played_count = _video_meta_get_played_countPtr
      .asFunction<int Function(video_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played time value between applications. It is recommended that the value is managed by the application.
  /// @brief Gets the last played time parameter of the video.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  video       The video metadata handle
  /// @param[out] played_time The last played time of the video
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_get_played_time(
    video_meta_h video,
    ffi.Pointer<time_t> played_time,
  ) {
    return _video_meta_get_played_time(
      video,
      played_time,
    );
  }

  late final _video_meta_get_played_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<time_t>)>>('video_meta_get_played_time');
  late final _video_meta_get_played_time = _video_meta_get_played_timePtr
      .asFunction<int Function(video_meta_h, ffi.Pointer<time_t>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played position value between applications. It is recommended that the value is managed by the application.
  /// @brief Gets the played position parameter of the video.
  /// @details This function returns the elapsed playback position parameter of the video as period
  /// starting from the beginning of the movie.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  video           The video metadata handle
  /// @param[out] played_position The elapsed time of the video
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_get_played_position(
    video_meta_h video,
    ffi.Pointer<ffi.Int> played_position,
  ) {
    return _video_meta_get_played_position(
      video,
      played_position,
    );
  }

  late final _video_meta_get_played_positionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_meta_h,
              ffi.Pointer<ffi.Int>)>>('video_meta_get_played_position');
  late final _video_meta_get_played_position =
      _video_meta_get_played_positionPtr
          .asFunction<int Function(video_meta_h, ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played count value between applications. It is recommended that the value is managed by the application.
  /// @brief Sets the played count of the video.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] video        The video metadata handle
  /// @param[in] played_count The number of played
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_set_played_count(
    video_meta_h video,
    int played_count,
  ) {
    return _video_meta_set_played_count(
      video,
      played_count,
    );
  }

  late final _video_meta_set_played_countPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_meta_h, ffi.Int)>>(
          'video_meta_set_played_count');
  late final _video_meta_set_played_count = _video_meta_set_played_countPtr
      .asFunction<int Function(video_meta_h, int)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played time value between applications. It is recommended that the value is managed by the application.
  /// @brief Sets the last played time of the video.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] video       The video metadata handle
  /// @param[in] played_time The last played time of the video
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_set_played_time(
    video_meta_h video,
    int played_time,
  ) {
    return _video_meta_set_played_time(
      video,
      played_time,
    );
  }

  late final _video_meta_set_played_timePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_meta_h, time_t)>>(
          'video_meta_set_played_time');
  late final _video_meta_set_played_time = _video_meta_set_played_timePtr
      .asFunction<int Function(video_meta_h, int)>();

  /// @deprecated Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. \n
  /// This function does not guarantee independence of the played position value between applications. It is recommended that the value is managed by the application.
  /// @brief Sets the played position of the video.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks  It is NOT recommended to use this attribute for your application-specific purpose because this attribute can be overwritten by other applications (even 0).
  ///
  /// @param[in] video           The video metadata handle
  /// @param[in] played_position The position from the beginning of the video (in milliseconds)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int video_meta_set_played_position(
    video_meta_h video,
    int played_position,
  ) {
    return _video_meta_set_played_position(
      video,
      played_position,
    );
  }

  late final _video_meta_set_played_positionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_meta_h, ffi.Int)>>(
          'video_meta_set_played_position');
  late final _video_meta_set_played_position =
      _video_meta_set_played_positionPtr
          .asFunction<int Function(video_meta_h, int)>();

  /// @deprecated Deprecated since 4.0. Related setter functions are deprecated, therefore this function is not needed anymore.
  /// @brief Updates an video metadata with modified attributes in the media database.
  /// @details The function updates the given video meta in the media database. The function should be called after any change in video attributes, to be updated to the media
  /// database.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks Do not call this function in callback function of foreach function like media_info_foreach_media_from_db().
  ///
  /// @param[in] video The video metadata handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int video_meta_update_to_db(
    video_meta_h video,
  ) {
    return _video_meta_update_to_db(
      video,
    );
  }

  late final _video_meta_update_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_meta_h)>>(
          'video_meta_update_to_db');
  late final _video_meta_update_to_db =
      _video_meta_update_to_dbPtr.asFunction<int Function(video_meta_h)>();

  /// @brief Gets the number of the album for the passed @a filter from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  filter      The media filter handle
  /// @param[out] album_count The count of the media album
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_album_get_album_count_from_db(
    filter_h filter,
    ffi.Pointer<ffi.Int> album_count,
  ) {
    return _media_album_get_album_count_from_db(
      filter,
      album_count,
    );
  }

  late final _media_album_get_album_count_from_dbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(filter_h, ffi.Pointer<ffi.Int>)>>(
      'media_album_get_album_count_from_db');
  late final _media_album_get_album_count_from_db =
      _media_album_get_album_count_from_dbPtr
          .asFunction<int Function(filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media album with optional @a filter from the media database.
  /// @details This function gets all media album handles meeting the given filter.
  /// The callback function will be invoked for every retrieved media album.
  /// If @c NULL is passed to the filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] filter    The media filter handle
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_album_cb().
  ///
  /// @see #media_album_cb
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_album_foreach_album_from_db(
    filter_h filter,
    media_album_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_album_foreach_album_from_db(
      filter,
      callback,
      user_data,
    );
  }

  late final _media_album_foreach_album_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, media_album_cb,
              ffi.Pointer<ffi.Void>)>>('media_album_foreach_album_from_db');
  late final _media_album_foreach_album_from_db =
      _media_album_foreach_album_from_dbPtr.asFunction<
          int Function(filter_h, media_album_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the number of media info for the given album present in the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  album_id    The ID of the media album
  /// @param[in]  filter      The media filter handle
  /// @param[out] media_count The count of the album
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_album_get_media_count_from_db(
    int album_id,
    filter_h filter,
    ffi.Pointer<ffi.Int> media_count,
  ) {
    return _media_album_get_media_count_from_db(
      album_id,
      filter,
      media_count,
    );
  }

  late final _media_album_get_media_count_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, filter_h,
              ffi.Pointer<ffi.Int>)>>('media_album_get_media_count_from_db');
  late final _media_album_get_media_count_from_db =
      _media_album_get_media_count_from_dbPtr
          .asFunction<int Function(int, filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media files with an optional @a filter in the given media album from the media database.
  /// @details This function gets all media files associated with the given media album and
  /// meeting desired filter option and calls @a callback for
  /// every retrieved media info. If @c NULL is passed to the @a filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] album_id  The ID of the media album
  /// @param[in] filter    The media filter handle
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_info_cb().
  ///
  /// @see #media_info_cb
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_album_foreach_media_from_db(
    int album_id,
    filter_h filter,
    media_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_album_foreach_media_from_db(
      album_id,
      filter,
      callback,
      user_data,
    );
  }

  late final _media_album_foreach_media_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, filter_h, media_info_cb,
              ffi.Pointer<ffi.Void>)>>('media_album_foreach_media_from_db');
  late final _media_album_foreach_media_from_db =
      _media_album_foreach_media_from_dbPtr.asFunction<
          int Function(int, filter_h, media_info_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Destroys the album handle.
  /// @details This function frees all resources related to the album handle. This handle
  /// can no longer be used to perform any operation. A new handle has to
  /// be created before the next use.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] album The media album handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre Get copy of album handle by calling media_album_clone().
  ///
  /// @see media_album_clone()
  int media_album_destroy(
    media_album_h album,
  ) {
    return _media_album_destroy(
      album,
    );
  }

  late final _media_album_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_album_h)>>(
          'media_album_destroy');
  late final _media_album_destroy =
      _media_album_destroyPtr.asFunction<int Function(media_album_h)>();

  /// @brief Clones a media album.
  /// @details This function copies the media album handle from a source to
  /// destination. There is no media_album_create() function. The media_album_h is created internally and available through
  /// media album foreach function such as media_album_foreach_album_from_db(). To use this handle outside of these foreach functions,
  /// use this function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release the destination handle using media_album_destroy().
  ///
  /// @param[in]  src  The source handle to the media album
  /// @param[out] dst  The destination handle to the media album
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @see media_album_destroy()
  /// @see media_album_foreach_album_from_db()
  int media_album_clone(
    ffi.Pointer<media_album_h> dst,
    media_album_h src,
  ) {
    return _media_album_clone(
      dst,
      src,
    );
  }

  late final _media_album_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<media_album_h>, media_album_h)>>('media_album_clone');
  late final _media_album_clone = _media_album_clonePtr
      .asFunction<int Function(ffi.Pointer<media_album_h>, media_album_h)>();

  /// @brief Gets the ID of the album.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  album    The media album handle
  /// @param[out] album_id The media album ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_album_foreach_album_from_db()
  int media_album_get_album_id(
    media_album_h album,
    ffi.Pointer<ffi.Int> album_id,
  ) {
    return _media_album_get_album_id(
      album,
      album_id,
    );
  }

  late final _media_album_get_album_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_album_h,
              ffi.Pointer<ffi.Int>)>>('media_album_get_album_id');
  late final _media_album_get_album_id = _media_album_get_album_idPtr
      .asFunction<int Function(media_album_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the name of the album.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a album_name using free().
  ///
  /// @param[in]  album       The media album handle
  /// @param[out] album_name  The name of the media album handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_album_get_name(
    media_album_h album,
    ffi.Pointer<ffi.Pointer<ffi.Char>> album_name,
  ) {
    return _media_album_get_name(
      album,
      album_name,
    );
  }

  late final _media_album_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_album_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_album_get_name');
  late final _media_album_get_name = _media_album_get_namePtr.asFunction<
      int Function(media_album_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the name of the artist from the given album.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a artist using free().
  ///
  /// @param[in]  album  The media album handle
  /// @param[out] artist The name of the media artist
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_album_get_artist(
    media_album_h album,
    ffi.Pointer<ffi.Pointer<ffi.Char>> artist,
  ) {
    return _media_album_get_artist(
      album,
      artist,
    );
  }

  late final _media_album_get_artistPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_album_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_album_get_artist');
  late final _media_album_get_artist = _media_album_get_artistPtr.asFunction<
      int Function(media_album_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the album art path from the album.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a album_art using free().
  ///
  /// @param[in]  album     The media album handle
  /// @param[out] album_art The path of the media album_art
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_album_get_album_art(
    media_album_h album,
    ffi.Pointer<ffi.Pointer<ffi.Char>> album_art,
  ) {
    return _media_album_get_album_art(
      album,
      album_art,
    );
  }

  late final _media_album_get_album_artPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_album_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_album_get_album_art');
  late final _media_album_get_album_art =
      _media_album_get_album_artPtr.asFunction<
          int Function(media_album_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the media album from the media database.
  ///
  /// @details This function creates a new media album handle from the media database by the given @a album_id.
  /// Media album will be created and will be filled with the album information.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a folder using media_album_destroy().
  ///
  /// @param[in]  album_id The ID of the media album
  /// @param[out] album    The album handle associated with the album ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_album_destroy()
  int media_album_get_album_from_db(
    int album_id,
    ffi.Pointer<media_album_h> album,
  ) {
    return _media_album_get_album_from_db(
      album_id,
      album,
    );
  }

  late final _media_album_get_album_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<media_album_h>)>>('media_album_get_album_from_db');
  late final _media_album_get_album_from_db = _media_album_get_album_from_dbPtr
      .asFunction<int Function(int, ffi.Pointer<media_album_h>)>();

  /// @brief Gets the number of the group for the passed @a filter from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  filter       The media filter handle
  /// @param[in]  group        The type of the media group
  /// @param[out] group_count  The count of the media group
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_group_get_group_count_from_db(
    filter_h filter,
    int group,
    ffi.Pointer<ffi.Int> group_count,
  ) {
    return _media_group_get_group_count_from_db(
      filter,
      group,
      group_count,
    );
  }

  late final _media_group_get_group_count_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, ffi.Int32,
              ffi.Pointer<ffi.Int>)>>('media_group_get_group_count_from_db');
  late final _media_group_get_group_count_from_db =
      _media_group_get_group_count_from_dbPtr
          .asFunction<int Function(filter_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media group with an optional @a filter from the media database.
  /// @details This function gets names of media group meeting the given filter.
  /// The callback function will be invoked for every retrieved media group.
  /// If @c NULL is passed to the filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] filter    The media filter handle
  /// @param[in] group     The type of the media group
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_group_cb().
  ///
  /// @see #media_group_cb
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_group_foreach_group_from_db(
    filter_h filter,
    int group,
    media_group_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_group_foreach_group_from_db(
      filter,
      group,
      callback,
      user_data,
    );
  }

  late final _media_group_foreach_group_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, ffi.Int32, media_group_cb,
              ffi.Pointer<ffi.Void>)>>('media_group_foreach_group_from_db');
  late final _media_group_foreach_group_from_db =
      _media_group_foreach_group_from_dbPtr.asFunction<
          int Function(filter_h, int, media_group_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the count of the media info for the given media group present in the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  group_name  The name of the media group
  /// @param[in]  group       The type of the media group
  /// @param[in]  filter      The media filter handle
  /// @param[out] media_count The count of the media
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_group_get_media_count_from_db(
    ffi.Pointer<ffi.Char> group_name,
    int group,
    filter_h filter,
    ffi.Pointer<ffi.Int> media_count,
  ) {
    return _media_group_get_media_count_from_db(
      group_name,
      group,
      filter,
      media_count,
    );
  }

  late final _media_group_get_media_count_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int32, filter_h,
              ffi.Pointer<ffi.Int>)>>('media_group_get_media_count_from_db');
  late final _media_group_get_media_count_from_db =
      _media_group_get_media_count_from_dbPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, int, filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media files with an optional @a filter in the given @a group from the media database.
  /// @details This function gets all media files associated with the given group and
  /// meeting desired filter option and calls @a callback for
  /// every retrieved media info. If @c NULL is passed to the @a filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] group_name The name of the media group
  /// @param[in] group      The type of the media group
  /// @param[in] filter     The media filter handle
  /// @param[in] callback   The callback function to be invoked
  /// @param[in] user_data  The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_info_cb().
  ///
  /// @see media_info_cb()
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_group_foreach_media_from_db(
    ffi.Pointer<ffi.Char> group_name,
    int group,
    filter_h filter,
    media_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_group_foreach_media_from_db(
      group_name,
      group,
      filter,
      callback,
      user_data,
    );
  }

  late final _media_group_foreach_media_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              filter_h,
              media_info_cb,
              ffi.Pointer<ffi.Void>)>>('media_group_foreach_media_from_db');
  late final _media_group_foreach_media_from_db =
      _media_group_foreach_media_from_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, filter_h, media_info_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the number of playlists for the passed @a filter from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  filter         The handle to the filter
  /// @param[out] playlist_count The count of the media playlist
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_playlist_get_playlist_count_from_db(
    filter_h filter,
    ffi.Pointer<ffi.Int> playlist_count,
  ) {
    return _media_playlist_get_playlist_count_from_db(
      filter,
      playlist_count,
    );
  }

  late final _media_playlist_get_playlist_count_from_dbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(filter_h, ffi.Pointer<ffi.Int>)>>(
      'media_playlist_get_playlist_count_from_db');
  late final _media_playlist_get_playlist_count_from_db =
      _media_playlist_get_playlist_count_from_dbPtr
          .asFunction<int Function(filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media playlists with an optional @a filter from the media database.
  /// @details This function gets all media playlists meeting the given filter.
  /// The callback function will be invoked for every retrieved media playlist.
  /// If @c NULL is passed to the filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] filter    The handle to the audio filter
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_playlist_cb().
  ///
  /// @see media_playlist_cb()
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_playlist_foreach_playlist_from_db(
    filter_h filter,
    media_playlist_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_playlist_foreach_playlist_from_db(
      filter,
      callback,
      user_data,
    );
  }

  late final _media_playlist_foreach_playlist_from_dbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  filter_h, media_playlist_cb, ffi.Pointer<ffi.Void>)>>(
      'media_playlist_foreach_playlist_from_db');
  late final _media_playlist_foreach_playlist_from_db =
      _media_playlist_foreach_playlist_from_dbPtr.asFunction<
          int Function(filter_h, media_playlist_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the number of the media info for the given playlist present in the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  playlist_id  The ID of the media playlist
  /// @param[in]  filter       The media filter handle
  /// @param[out] media_count  The number of media items
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_playlist_get_media_count_from_db(
    int playlist_id,
    filter_h filter,
    ffi.Pointer<ffi.Int> media_count,
  ) {
    return _media_playlist_get_media_count_from_db(
      playlist_id,
      filter,
      media_count,
    );
  }

  late final _media_playlist_get_media_count_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, filter_h,
              ffi.Pointer<ffi.Int>)>>('media_playlist_get_media_count_from_db');
  late final _media_playlist_get_media_count_from_db =
      _media_playlist_get_media_count_from_dbPtr
          .asFunction<int Function(int, filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media files with an optional @a filter in the given audio playlist from the media database.
  /// @details This function gets all media files associated with the given media playlist and
  /// meeting desired filter option and calls @a callback for
  /// every retrieved media info. If @c NULL is passed to the @a filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] playlist_id The ID of the media playlist
  /// @param[in] filter      The audio filter handle
  /// @param[in] callback    The callback function to be invoked
  /// @param[in] user_data   The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_info_cb().
  ///
  /// @see media_info_cb()
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_playlist_foreach_media_from_db(
    int playlist_id,
    filter_h filter,
    playlist_member_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_playlist_foreach_media_from_db(
      playlist_id,
      filter,
      callback,
      user_data,
    );
  }

  late final _media_playlist_foreach_media_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, filter_h, playlist_member_cb,
              ffi.Pointer<ffi.Void>)>>('media_playlist_foreach_media_from_db');
  late final _media_playlist_foreach_media_from_db =
      _media_playlist_foreach_media_from_dbPtr.asFunction<
          int Function(
              int, filter_h, playlist_member_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Inserts a new playlist with the given name into the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks You must release the created handle using media_playlist_destroy().
  ///
  /// @param[in]  name     The name of the inserted playlist
  /// @param[out] playlist A created handle to media playlist
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_playlist_delete_from_db()
  int media_playlist_insert_to_db(
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<media_playlist_h> playlist,
  ) {
    return _media_playlist_insert_to_db(
      name,
      playlist,
    );
  }

  late final _media_playlist_insert_to_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<media_playlist_h>)>>('media_playlist_insert_to_db');
  late final _media_playlist_insert_to_db =
      _media_playlist_insert_to_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<media_playlist_h>)>();

  /// @brief Deletes the given playlist from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] playlist_id The ID of media playlist
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_playlist_insert_to_db()
  int media_playlist_delete_from_db(
    int playlist_id,
  ) {
    return _media_playlist_delete_from_db(
      playlist_id,
    );
  }

  late final _media_playlist_delete_from_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'media_playlist_delete_from_db');
  late final _media_playlist_delete_from_db =
      _media_playlist_delete_from_dbPtr.asFunction<int Function(int)>();

  /// @brief Gets the media playlist from the media database.
  ///
  /// @details This function creates a new media playlist handle from the media database by the given @a playlist_id.
  /// The media playlist will be created and will be filled with the playlist information.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a playlist using media_playlist_destroy().
  ///
  /// @param[in]  playlist_id The ID of the media playlist
  /// @param[out] playlist    The media playlist handle associated with the playlist ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_playlist_destroy()
  int media_playlist_get_playlist_from_db(
    int playlist_id,
    ffi.Pointer<media_playlist_h> playlist,
  ) {
    return _media_playlist_get_playlist_from_db(
      playlist_id,
      playlist,
    );
  }

  late final _media_playlist_get_playlist_from_dbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<media_playlist_h>)>>(
      'media_playlist_get_playlist_from_db');
  late final _media_playlist_get_playlist_from_db =
      _media_playlist_get_playlist_from_dbPtr
          .asFunction<int Function(int, ffi.Pointer<media_playlist_h>)>();

  /// @brief Destroys a playlist handle.
  /// @details This function frees all resources related to the playlist handle. This
  /// handle no longer can be used to perform any operation. A new handle has to
  /// be created before next usage.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] playlist The media playlist handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre Get a copy of playlist handle by calling media_playlist_clone() or media_playlist_insert_to_db().
  ///
  /// @see media_playlist_clone()
  int media_playlist_destroy(
    media_playlist_h playlist,
  ) {
    return _media_playlist_destroy(
      playlist,
    );
  }

  late final _media_playlist_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_playlist_h)>>(
          'media_playlist_destroy');
  late final _media_playlist_destroy =
      _media_playlist_destroyPtr.asFunction<int Function(media_playlist_h)>();

  /// @brief Clones a playlist handle.
  /// @details This function copies the media playlist handle from a source to
  /// destination. There is no media_playlist_create() function. The media_playlist_h is created internally and available through
  /// media playlist foreach function such as media_playlist_foreach_playlist_from_db().
  /// To use this handle outside of these foreach functions, use this function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks The destination handle must be released using media_playlist_destroy().
  ///
  /// @param[in]  src  The source handle of a media playlist
  /// @param[out] dst  The destination handle to a media playlist
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @see media_playlist_destroy()
  /// @see media_playlist_foreach_playlist_from_db()
  int media_playlist_clone(
    ffi.Pointer<media_playlist_h> dst,
    media_playlist_h src,
  ) {
    return _media_playlist_clone(
      dst,
      src,
    );
  }

  late final _media_playlist_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<media_playlist_h>,
              media_playlist_h)>>('media_playlist_clone');
  late final _media_playlist_clone = _media_playlist_clonePtr.asFunction<
      int Function(ffi.Pointer<media_playlist_h>, media_playlist_h)>();

  /// @brief Gets the media playlist ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  playlist    The media playlist handle
  /// @param[out] playlist_id The ID of the media playlist
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_playlist_get_playlist_id(
    media_playlist_h playlist,
    ffi.Pointer<ffi.Int> playlist_id,
  ) {
    return _media_playlist_get_playlist_id(
      playlist,
      playlist_id,
    );
  }

  late final _media_playlist_get_playlist_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_playlist_h,
              ffi.Pointer<ffi.Int>)>>('media_playlist_get_playlist_id');
  late final _media_playlist_get_playlist_id =
      _media_playlist_get_playlist_idPtr
          .asFunction<int Function(media_playlist_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets a name of the playlist.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a playlist_name using free().
  ///
  /// @param[in]  playlist      The media playlist handle
  /// @param[out] playlist_name The playlist name
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_playlist_get_name(
    media_playlist_h playlist,
    ffi.Pointer<ffi.Pointer<ffi.Char>> playlist_name,
  ) {
    return _media_playlist_get_name(
      playlist,
      playlist_name,
    );
  }

  late final _media_playlist_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_playlist_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_playlist_get_name');
  late final _media_playlist_get_name = _media_playlist_get_namePtr.asFunction<
      int Function(media_playlist_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the name of the playlist.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] playlist      The media playlist handle
  /// @param[in] playlist_name The name of the media playlist
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @post media_playlist_update_to_db()
  int media_playlist_set_name(
    media_playlist_h playlist,
    ffi.Pointer<ffi.Char> playlist_name,
  ) {
    return _media_playlist_set_name(
      playlist,
      playlist_name,
    );
  }

  late final _media_playlist_set_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_playlist_h,
              ffi.Pointer<ffi.Char>)>>('media_playlist_set_name');
  late final _media_playlist_set_name = _media_playlist_set_namePtr
      .asFunction<int Function(media_playlist_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets a thumbnail path of the playlist.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a path using free().
  ///
  /// @param[in]  playlist The media playlist handle
  /// @param[out] path     The path of the thumbnail
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_playlist_get_thumbnail_path(
    media_playlist_h playlist,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _media_playlist_get_thumbnail_path(
      playlist,
      path,
    );
  }

  late final _media_playlist_get_thumbnail_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_playlist_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_playlist_get_thumbnail_path');
  late final _media_playlist_get_thumbnail_path =
      _media_playlist_get_thumbnail_pathPtr.asFunction<
          int Function(media_playlist_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the thumbnail path of the playlist.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] playlist The media playlist handle
  /// @param[in] path     The path of the thumbnail
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @post media_playlist_update_to_db()
  int media_playlist_set_thumbnail_path(
    media_playlist_h playlist,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _media_playlist_set_thumbnail_path(
      playlist,
      path,
    );
  }

  late final _media_playlist_set_thumbnail_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_playlist_h,
              ffi.Pointer<ffi.Char>)>>('media_playlist_set_thumbnail_path');
  late final _media_playlist_set_thumbnail_path =
      _media_playlist_set_thumbnail_pathPtr
          .asFunction<int Function(media_playlist_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the playing order in the playlist.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] playlist           The media playlist handle
  /// @param[in] playlist_member_id The playlist member ID
  /// @param[in] play_order         The playing order
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @post media_playlist_update_to_db()
  int media_playlist_set_play_order(
    media_playlist_h playlist,
    int playlist_member_id,
    int play_order,
  ) {
    return _media_playlist_set_play_order(
      playlist,
      playlist_member_id,
      play_order,
    );
  }

  late final _media_playlist_set_play_orderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_playlist_h, ffi.Int,
              ffi.Int)>>('media_playlist_set_play_order');
  late final _media_playlist_set_play_order = _media_playlist_set_play_orderPtr
      .asFunction<int Function(media_playlist_h, int, int)>();

  /// @brief Adds a new media info to the playlist.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] playlist The media playlist handle
  /// @param[in] media_id The ID to the media info which is added
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post media_playlist_update_to_db()
  ///
  /// @see media_content_connect()
  /// @see media_playlist_remove_media()
  int media_playlist_add_media(
    media_playlist_h playlist,
    ffi.Pointer<ffi.Char> media_id,
  ) {
    return _media_playlist_add_media(
      playlist,
      media_id,
    );
  }

  late final _media_playlist_add_mediaPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_playlist_h,
              ffi.Pointer<ffi.Char>)>>('media_playlist_add_media');
  late final _media_playlist_add_media = _media_playlist_add_mediaPtr
      .asFunction<int Function(media_playlist_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Removes the playlist members related with the media from the given playlist.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] playlist           The media playlist handle
  /// @param[in] playlist_member_id The playlist member ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post media_playlist_update_to_db()
  ///
  /// @see media_content_connect()
  /// @see media_playlist_add_media()
  int media_playlist_remove_media(
    media_playlist_h playlist,
    int playlist_member_id,
  ) {
    return _media_playlist_remove_media(
      playlist,
      playlist_member_id,
    );
  }

  late final _media_playlist_remove_mediaPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_playlist_h, ffi.Int)>>(
          'media_playlist_remove_media');
  late final _media_playlist_remove_media = _media_playlist_remove_mediaPtr
      .asFunction<int Function(media_playlist_h, int)>();

  /// @brief Gets the played order of the playlist.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] playlist           The media playlist handle
  /// @param[in] playlist_member_id The playlist member ID
  /// @param[out] play_order        The played order
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_playlist_get_play_order(
    media_playlist_h playlist,
    int playlist_member_id,
    ffi.Pointer<ffi.Int> play_order,
  ) {
    return _media_playlist_get_play_order(
      playlist,
      playlist_member_id,
      play_order,
    );
  }

  late final _media_playlist_get_play_orderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_playlist_h, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('media_playlist_get_play_order');
  late final _media_playlist_get_play_order = _media_playlist_get_play_orderPtr
      .asFunction<int Function(media_playlist_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Updates the media playlist to the media database.
  ///
  /// @details The function updates the given media playlist in the media database.
  /// The function should be called after any change in the playlist, to be updated to the media database.
  /// For example, after using media_playlist_set_name() for setting the name of the playlist, the
  /// media_playlist_update_to_db() function should be called so as to update
  /// the given playlist attributes in the media database.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] playlist The media playlist handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_playlist_destroy()
  /// @see media_playlist_add_media()
  /// @see media_playlist_remove_media()
  /// @see media_playlist_set_name()
  /// @see media_playlist_set_play_order()
  int media_playlist_update_to_db(
    media_playlist_h playlist,
  ) {
    return _media_playlist_update_to_db(
      playlist,
    );
  }

  late final _media_playlist_update_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_playlist_h)>>(
          'media_playlist_update_to_db');
  late final _media_playlist_update_to_db = _media_playlist_update_to_dbPtr
      .asFunction<int Function(media_playlist_h)>();

  /// @brief Imports the playlist from m3u playlist file.
  /// @details This api reads a playlist from the m3u playlist file and insert into the db.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks   http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage. \n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage. \n
  /// This api does not support the file of extended m3u playlist.
  ///
  /// @param[in] playlist_name The name of the playlist to save
  /// @param[in] path The path to import the playlist file
  /// @param[out] playlist The media playlist handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  int media_playlist_import_from_file(
    ffi.Pointer<ffi.Char> playlist_name,
    ffi.Pointer<ffi.Char> path,
    ffi.Pointer<media_playlist_h> playlist,
  ) {
    return _media_playlist_import_from_file(
      playlist_name,
      path,
      playlist,
    );
  }

  late final _media_playlist_import_from_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<media_playlist_h>)>>(
      'media_playlist_import_from_file');
  late final _media_playlist_import_from_file =
      _media_playlist_import_from_filePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<media_playlist_h>)>();

  /// @brief Exports the playlist to m3u playlist file.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks   http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage. \n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage. \n
  ///
  /// @param[in] playlist The media playlist handle
  /// @param[in] path path The path to export the playlist
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  int media_playlist_export_to_file(
    media_playlist_h playlist,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _media_playlist_export_to_file(
      playlist,
      path,
    );
  }

  late final _media_playlist_export_to_filePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_playlist_h,
              ffi.Pointer<ffi.Char>)>>('media_playlist_export_to_file');
  late final _media_playlist_export_to_file = _media_playlist_export_to_filePtr
      .asFunction<int Function(media_playlist_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Inserts a new bookmark in media on the specified time offset to the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] media_id       The media ID
  /// @param[in] time           The bookmark time offset (in seconds)
  /// @param[in] thumbnail_path The thumbnail path of video bookmark\ n
  /// If the media type is audio, then thumbnail is null.
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_bookmark_delete_from_db()
  int media_bookmark_insert_to_db(
    ffi.Pointer<ffi.Char> media_id,
    int time,
    ffi.Pointer<ffi.Char> thumbnail_path,
  ) {
    return _media_bookmark_insert_to_db(
      media_id,
      time,
      thumbnail_path,
    );
  }

  late final _media_bookmark_insert_to_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, time_t,
              ffi.Pointer<ffi.Char>)>>('media_bookmark_insert_to_db');
  late final _media_bookmark_insert_to_db =
      _media_bookmark_insert_to_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Removes a media bookmark from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] bookmark_id The ID of media bookmark
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_bookmark_insert_to_db()
  int media_bookmark_delete_from_db(
    int bookmark_id,
  ) {
    return _media_bookmark_delete_from_db(
      bookmark_id,
    );
  }

  late final _media_bookmark_delete_from_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'media_bookmark_delete_from_db');
  late final _media_bookmark_delete_from_db =
      _media_bookmark_delete_from_dbPtr.asFunction<int Function(int)>();

  /// @brief Gets the number of bookmarks with an optional filter from the media database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  filter         The handle to the media filter
  /// @param[out] bookmark_count The count of the media bookmark
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_bookmark_get_bookmark_count_from_db(
    filter_h filter,
    ffi.Pointer<ffi.Int> bookmark_count,
  ) {
    return _media_bookmark_get_bookmark_count_from_db(
      filter,
      bookmark_count,
    );
  }

  late final _media_bookmark_get_bookmark_count_from_dbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(filter_h, ffi.Pointer<ffi.Int>)>>(
      'media_bookmark_get_bookmark_count_from_db');
  late final _media_bookmark_get_bookmark_count_from_db =
      _media_bookmark_get_bookmark_count_from_dbPtr
          .asFunction<int Function(filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the bookmarks with an optional filter from the media database.
  /// @details This function gets all bookmarks associated with the given filter and calls @a callback for every retrieved media bookmark.
  /// If @c NULL is passed to the @a filter, then no filtering is applied.
  /// @since_tizen 4.0
  ///
  /// @param[in] filter     The handle to the bookmark filter
  /// @param[in] callback   The callback function to be invoked
  /// @param[in] user_data  The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_bookmark_cb().
  ///
  /// @see media_content_connect()
  /// @see media_bookmark_cb()
  /// @see media_filter_create()
  int media_bookmark_foreach_bookmark_from_db(
    filter_h filter,
    media_bookmark_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_bookmark_foreach_bookmark_from_db(
      filter,
      callback,
      user_data,
    );
  }

  late final _media_bookmark_foreach_bookmark_from_dbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  filter_h, media_bookmark_cb, ffi.Pointer<ffi.Void>)>>(
      'media_bookmark_foreach_bookmark_from_db');
  late final _media_bookmark_foreach_bookmark_from_db =
      _media_bookmark_foreach_bookmark_from_dbPtr.asFunction<
          int Function(filter_h, media_bookmark_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Clones a media bookmark.
  /// @details This function copies the media bookmark handle from a source to destination. There is no media_bookmark_create() function.
  /// The media_bookmark_h is created internally and available through media bookmark foreach function such as media_info_foreach_bookmark_from_db().
  /// To use this handle outside of these foreach functions, use this function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks The destination handle must be released using media_bookmark_destroy().
  ///
  /// @param[out] dst The destination handle to media bookmark
  /// @param[in]  src The source handle to media bookmark
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @see media_bookmark_destroy()
  /// @see media_info_foreach_bookmark_from_db()
  int media_bookmark_clone(
    ffi.Pointer<media_bookmark_h> dst,
    media_bookmark_h src,
  ) {
    return _media_bookmark_clone(
      dst,
      src,
    );
  }

  late final _media_bookmark_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<media_bookmark_h>,
              media_bookmark_h)>>('media_bookmark_clone');
  late final _media_bookmark_clone = _media_bookmark_clonePtr.asFunction<
      int Function(ffi.Pointer<media_bookmark_h>, media_bookmark_h)>();

  /// @brief Destroys a media bookmark.
  /// @details This function frees all the resources related to the bookmark handle. This handle
  /// no longer can be used to perform any operation. A new handle has to
  /// be created before the next use.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] bookmark The handle to media bookmark
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre Get copy of bookmark handle by calling media_bookmark_clone().
  ///
  /// @see media_bookmark_clone()
  int media_bookmark_destroy(
    media_bookmark_h bookmark,
  ) {
    return _media_bookmark_destroy(
      bookmark,
    );
  }

  late final _media_bookmark_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_bookmark_h)>>(
          'media_bookmark_destroy');
  late final _media_bookmark_destroy =
      _media_bookmark_destroyPtr.asFunction<int Function(media_bookmark_h)>();

  /// @brief Gets the bookmark ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  bookmark    The handle to media bookmark
  /// @param[out] bookmark_id The media bookmark ID
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_bookmark_get_bookmark_id(
    media_bookmark_h bookmark,
    ffi.Pointer<ffi.Int> bookmark_id,
  ) {
    return _media_bookmark_get_bookmark_id(
      bookmark,
      bookmark_id,
    );
  }

  late final _media_bookmark_get_bookmark_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_bookmark_h,
              ffi.Pointer<ffi.Int>)>>('media_bookmark_get_bookmark_id');
  late final _media_bookmark_get_bookmark_id =
      _media_bookmark_get_bookmark_idPtr
          .asFunction<int Function(media_bookmark_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the bookmark time marked parameter.
  /// @details This function returns time offset in seconds from beginning of the movie on which bookmark
  /// was placed.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  bookmark    The handle to media bookmark
  /// @param[out] marked_time The bookmark time offset (in seconds)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_bookmark_get_marked_time(
    media_bookmark_h bookmark,
    ffi.Pointer<time_t> marked_time,
  ) {
    return _media_bookmark_get_marked_time(
      bookmark,
      marked_time,
    );
  }

  late final _media_bookmark_get_marked_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_bookmark_h,
              ffi.Pointer<time_t>)>>('media_bookmark_get_marked_time');
  late final _media_bookmark_get_marked_time =
      _media_bookmark_get_marked_timePtr
          .asFunction<int Function(media_bookmark_h, ffi.Pointer<time_t>)>();

  /// @brief Gets the media bookmark thumbnail.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a path using free().
  ///
  /// @param[in]  bookmark The handle to media bookmark
  /// @param[out] path     The thumbnail path of media bookmark
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_bookmark_get_thumbnail_path(
    media_bookmark_h bookmark,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _media_bookmark_get_thumbnail_path(
      bookmark,
      path,
    );
  }

  late final _media_bookmark_get_thumbnail_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_bookmark_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_bookmark_get_thumbnail_path');
  late final _media_bookmark_get_thumbnail_path =
      _media_bookmark_get_thumbnail_pathPtr.asFunction<
          int Function(media_bookmark_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the media bookmark name which user set.
  /// @since_tizen 4.0
  ///
  /// @remarks You must release @a name using free().
  ///
  /// @param[in] bookmark The handle to media bookmark
  /// @param[out] name     The name of media bookmark. If name was not set, empty string is returned.
  /// If User set bookmark name to NULL, name will be empty string also.
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_bookmark_get_name(
    media_bookmark_h bookmark,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _media_bookmark_get_name(
      bookmark,
      name,
    );
  }

  late final _media_bookmark_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_bookmark_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_bookmark_get_name');
  late final _media_bookmark_get_name = _media_bookmark_get_namePtr.asFunction<
      int Function(media_bookmark_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the media bookmark name.
  /// @since_tizen 4.0
  ///
  /// @param[in] bookmark The handle to media bookmark
  /// @param[in] name     The name of media bookmark. Can be NULL, empty or non-empty string.
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @post media_bookmark_update_to_db()
  int media_bookmark_set_name(
    media_bookmark_h bookmark,
    ffi.Pointer<ffi.Char> name,
  ) {
    return _media_bookmark_set_name(
      bookmark,
      name,
    );
  }

  late final _media_bookmark_set_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_bookmark_h,
              ffi.Pointer<ffi.Char>)>>('media_bookmark_set_name');
  late final _media_bookmark_set_name = _media_bookmark_set_namePtr
      .asFunction<int Function(media_bookmark_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Updates bookmark information to the media database.
  /// @details The function updates the given bookmark meta in the media database. \n
  /// The function should be called after any change in bookmark attributes, to be updated to the media database. \n
  /// For example, after using media_bookmark_set_name() for setting the name of the bookmark, \n
  /// the media_bookmark_update_to_db() function should be called so as to update the given bookmark attributes in the media database.
  /// @since_tizen 4.0
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks Do not call this function in callback function of foreach function like media_info_foreach_bookmark_from_db().
  /// @param[in] bookmark The handle to media bookmark
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE					Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY		Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION	Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED				DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY				DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK				Network fail
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED	Permission denied when Application has no privilege
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_bookmark_set_name()
  int media_bookmark_update_to_db(
    media_bookmark_h bookmark,
  ) {
    return _media_bookmark_update_to_db(
      bookmark,
    );
  }

  late final _media_bookmark_update_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_bookmark_h)>>(
          'media_bookmark_update_to_db');
  late final _media_bookmark_update_to_db = _media_bookmark_update_to_dbPtr
      .asFunction<int Function(media_bookmark_h)>();

  /// @brief Gets media storage from database.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release the handle using media_storage_destroy(). \n
  ///
  /// @param[in] storage_id The storage id to get media storage info
  /// @param[out] storage The media storage handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY	 Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED		 DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY			 DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_storage_get_storage_info_from_db(
    ffi.Pointer<ffi.Char> storage_id,
    ffi.Pointer<media_storage_h> storage,
  ) {
    return _media_storage_get_storage_info_from_db(
      storage_id,
      storage,
    );
  }

  late final _media_storage_get_storage_info_from_dbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<media_storage_h>)>>(
      'media_storage_get_storage_info_from_db');
  late final _media_storage_get_storage_info_from_db =
      _media_storage_get_storage_info_from_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<media_storage_h>)>();

  /// @brief Gets the count of media storage for the passed @a filter from the media database.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] filter The handle to filter
  /// @param[out] storage_count The count of storage
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED		 DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY			 DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_storage_get_storage_count_from_db(
    filter_h filter,
    ffi.Pointer<ffi.Int> storage_count,
  ) {
    return _media_storage_get_storage_count_from_db(
      filter,
      storage_count,
    );
  }

  late final _media_storage_get_storage_count_from_dbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(filter_h, ffi.Pointer<ffi.Int>)>>(
      'media_storage_get_storage_count_from_db');
  late final _media_storage_get_storage_count_from_db =
      _media_storage_get_storage_count_from_dbPtr
          .asFunction<int Function(filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through media storage from the media database.
  /// @details This function gets all media storage handles meeting the given @a filter.
  /// The @a callback function will be invoked for every retrieved media storage.
  /// If @c NULL is passed to the @a filter, then no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] filter    The media storage handle filter
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_storage_destroy().
  ///
  /// @see media_content_connect()
  /// @see media_storage_destroy()
  int media_storage_foreach_storage_from_db(
    filter_h filter,
    media_storage_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_storage_foreach_storage_from_db(
      filter,
      callback,
      user_data,
    );
  }

  late final _media_storage_foreach_storage_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, media_storage_cb,
              ffi.Pointer<ffi.Void>)>>('media_storage_foreach_storage_from_db');
  late final _media_storage_foreach_storage_from_db =
      _media_storage_foreach_storage_from_dbPtr.asFunction<
          int Function(filter_h, media_storage_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the count of media files for the passed @a filter in the given @a storage from the media database.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] storage_id    The ID of the media storage
  /// @param[in] filter       The filter of the media content
  /// @param[out] media_count The count of media storage items
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  int media_storage_get_media_count_from_db(
    ffi.Pointer<ffi.Char> storage_id,
    filter_h filter,
    ffi.Pointer<ffi.Int> media_count,
  ) {
    return _media_storage_get_media_count_from_db(
      storage_id,
      filter,
      media_count,
    );
  }

  late final _media_storage_get_media_count_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, filter_h,
              ffi.Pointer<ffi.Int>)>>('media_storage_get_media_count_from_db');
  late final _media_storage_get_media_count_from_db =
      _media_storage_get_media_count_from_dbPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the media files with an optional @a filter in the given @a storage from the media database.
  /// @details This function gets all media files associated with the given storage and
  /// meeting desired filter option and calls @a callback for
  /// every retrieved media item. If @c NULL is passed to the @a filter, no filtering is applied.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks   Do not call updating DB function like media_info_update_to_db(), media_info_refresh_metadata_to_db(), audio_meta_update_to_db(), image_meta_update_to_db() and video_meta_update_to_db()  in your callback function,
  /// your callback function is invoked as inline function. \n
  /// So, your callback function is in read state in SQLite. When you are in read state, sometimes you do not update DB. \n
  /// We do not recommend you call updating DB function in callback of foreach function.
  ///
  /// @param[in] storage_id The ID of the media storage
  /// @param[in] filter    The handle to the media info filter
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre  This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_info_cb().
  ///
  /// @see #media_info_cb
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_storage_foreach_media_from_db(
    ffi.Pointer<ffi.Char> storage_id,
    filter_h filter,
    media_info_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_storage_foreach_media_from_db(
      storage_id,
      filter,
      callback,
      user_data,
    );
  }

  late final _media_storage_foreach_media_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, filter_h, media_info_cb,
              ffi.Pointer<ffi.Void>)>>('media_storage_foreach_media_from_db');
  late final _media_storage_foreach_media_from_db =
      _media_storage_foreach_media_from_dbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, filter_h, media_info_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Destroys media storage handle.
  /// @details The function frees all resources related to the media storage handle. This handle
  /// can no longer be used to perform any operation. New media storage handle has to
  /// be created before the next usage.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in]  storage  The media storage handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre Get copy of media_storage_h handle by calling media_storage_clone().
  ///
  /// @see media_storage_clone()
  int media_storage_destroy(
    media_storage_h storage,
  ) {
    return _media_storage_destroy(
      storage,
    );
  }

  late final _media_storage_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_storage_h)>>(
          'media_storage_destroy');
  late final _media_storage_destroy =
      _media_storage_destroyPtr.asFunction<int Function(media_storage_h)>();

  /// @brief Clones the media storage handle.
  ///
  /// @details This function copies the media storage handle from a source to the destination.
  /// There is no media_storage_create() function. The media_storage_h is created internally and
  /// available through media storage foreach function such as media_storage_foreach_storage_from_db().
  /// To use this handle outside of these foreach functions, use this function.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release the destination handle using media_storage_destroy().
  ///
  /// @param[out] dst  The destination handle to the media storage
  /// @param[in]  src  The source handle to media storage
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_storage_destroy()
  /// @see media_storage_foreach_storage_from_db()
  /// @see media_storage_get_storage_info_from_db()
  int media_storage_clone(
    ffi.Pointer<media_storage_h> dst,
    media_storage_h src,
  ) {
    return _media_storage_clone(
      dst,
      src,
    );
  }

  late final _media_storage_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<media_storage_h>,
              media_storage_h)>>('media_storage_clone');
  late final _media_storage_clone = _media_storage_clonePtr.asFunction<
      int Function(ffi.Pointer<media_storage_h>, media_storage_h)>();

  /// @brief Gets the storage id of media storage.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a storage_id using free().
  ///
  /// @param[in]  storage The media storage handle
  /// @param[out] storage_id  The storage id of the media storage
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_storage_get_id(
    media_storage_h storage,
    ffi.Pointer<ffi.Pointer<ffi.Char>> storage_id,
  ) {
    return _media_storage_get_id(
      storage,
      storage_id,
    );
  }

  late final _media_storage_get_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_storage_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_storage_get_id');
  late final _media_storage_get_id = _media_storage_get_idPtr.asFunction<
      int Function(media_storage_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the storage name of media storage.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a storage_name using free().
  /// If the requested storage is not the cloud storage, this API returns NULL.
  ///
  /// @param[in]  storage The media storage handle
  /// @param[out] storage_name  The storage name of the media storage
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_storage_get_name(
    media_storage_h storage,
    ffi.Pointer<ffi.Pointer<ffi.Char>> storage_name,
  ) {
    return _media_storage_get_name(
      storage,
      storage_name,
    );
  }

  late final _media_storage_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_storage_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_storage_get_name');
  late final _media_storage_get_name = _media_storage_get_namePtr.asFunction<
      int Function(media_storage_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the storage path of media storage.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a storage_path using free().
  ///
  /// @param[in]  storage The media storage handle
  /// @param[out] storage_path  The storage path of the media storage
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  int media_storage_get_path(
    media_storage_h storage,
    ffi.Pointer<ffi.Pointer<ffi.Char>> storage_path,
  ) {
    return _media_storage_get_path(
      storage,
      storage_path,
    );
  }

  late final _media_storage_get_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_storage_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_storage_get_path');
  late final _media_storage_get_path = _media_storage_get_pathPtr.asFunction<
      int Function(media_storage_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the storage type of media storage.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in]  storage The media storage handle
  /// @param[out] storage_type  The storage type of the media storage
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_storage_get_type(
    media_storage_h storage,
    ffi.Pointer<ffi.Int32> storage_type,
  ) {
    return _media_storage_get_type(
      storage,
      storage_type,
    );
  }

  late final _media_storage_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_storage_h,
              ffi.Pointer<ffi.Int32>)>>('media_storage_get_type');
  late final _media_storage_get_type = _media_storage_get_typePtr
      .asFunction<int Function(media_storage_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Clones the face handle.
  /// @details This function copies the face handle from a source to
  /// destination. There is no media_face_create() function. The media_face_h is created internally and available through
  /// media face foreach function such as media_face_foreach_face_from_db(). To use this handle outside of these foreach functions,
  /// use this function.
  ///
  /// @since_tizen 3.0
  /// @remark The destination handle must be released with media_event_destroy() by you.
  ///
  /// @param [in] src The source face handle
  /// @param [out] dst A destination face handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @see media_face_destroy()
  /// @see media_face_foreach_face_from_db()
  int media_face_clone(
    ffi.Pointer<media_face_h> dst,
    media_face_h src,
  ) {
    return _media_face_clone(
      dst,
      src,
    );
  }

  late final _media_face_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<media_face_h>, media_face_h)>>('media_face_clone');
  late final _media_face_clone = _media_face_clonePtr
      .asFunction<int Function(ffi.Pointer<media_face_h>, media_face_h)>();

  /// @brief Destroys the face handle.
  /// @details Function frees all resources related to face handle. This
  /// handle no longer can be used to perform any operation. New handle has to
  /// be created before next usage.
  ///
  /// @since_tizen 3.0
  ///
  /// @param [in] face The face handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_face_clone()
  ///
  /// @pre Get copy of face handle by calling media_face_clone() or Get face handle by calling media_info_foreach_face_from_db()
  int media_face_destroy(
    media_face_h face,
  ) {
    return _media_face_destroy(
      face,
    );
  }

  late final _media_face_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_face_h)>>(
          'media_face_destroy');
  late final _media_face_destroy =
      _media_face_destroyPtr.asFunction<int Function(media_face_h)>();

  /// @brief Gets the face id from the face handle.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks You must release @a face_id using free().
  ///
  /// @param [in] face The face handle
  /// @param [out] face_id The uuid of the face handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_face_get_face_id(
    media_face_h face,
    ffi.Pointer<ffi.Pointer<ffi.Char>> face_id,
  ) {
    return _media_face_get_face_id(
      face,
      face_id,
    );
  }

  late final _media_face_get_face_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_face_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_face_get_face_id');
  late final _media_face_get_face_id = _media_face_get_face_idPtr.asFunction<
      int Function(media_face_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the media uuid from the face handle.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks You must release @a media_id using free().
  ///
  /// @param [in] face The face handle
  /// @param [out] media_id The media uuid of the face handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_face_get_media_id(
    media_face_h face,
    ffi.Pointer<ffi.Pointer<ffi.Char>> media_id,
  ) {
    return _media_face_get_media_id(
      face,
      media_id,
    );
  }

  late final _media_face_get_media_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_face_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_face_get_media_id');
  late final _media_face_get_media_id = _media_face_get_media_idPtr.asFunction<
      int Function(media_face_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the face's rectangle from the face handle.
  /// @details This API can get the face's rectangle information. returned rectangle information includes the orientation value.
  ///
  /// @since_tizen 3.0
  ///
  /// @param [in] face The face handle
  /// @param [out] rect_x The x position of face of the face handle
  /// @param [out] rect_y The y position of face of the face handle
  /// @param [out] rect_w The width of face of the face handle
  /// @param [out] rect_h The height of face of the face handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_face_get_face_rect(
    media_face_h face,
    ffi.Pointer<ffi.UnsignedInt> rect_x,
    ffi.Pointer<ffi.UnsignedInt> rect_y,
    ffi.Pointer<ffi.UnsignedInt> rect_w,
    ffi.Pointer<ffi.UnsignedInt> rect_h,
  ) {
    return _media_face_get_face_rect(
      face,
      rect_x,
      rect_y,
      rect_w,
      rect_h,
    );
  }

  late final _media_face_get_face_rectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_face_h,
              ffi.Pointer<ffi.UnsignedInt>,
              ffi.Pointer<ffi.UnsignedInt>,
              ffi.Pointer<ffi.UnsignedInt>,
              ffi.Pointer<ffi.UnsignedInt>)>>('media_face_get_face_rect');
  late final _media_face_get_face_rect =
      _media_face_get_face_rectPtr.asFunction<
          int Function(
              media_face_h,
              ffi.Pointer<ffi.UnsignedInt>,
              ffi.Pointer<ffi.UnsignedInt>,
              ffi.Pointer<ffi.UnsignedInt>,
              ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets the orientation from the face handle.
  /// @details This API can get the orientation value from the original image.
  ///
  /// @since_tizen 3.0
  ///
  /// @param [in] face The face handle
  /// @param [out] orientation The orientation of the face handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_face_get_orientation(
    media_face_h face,
    ffi.Pointer<ffi.Int32> orientation,
  ) {
    return _media_face_get_orientation(
      face,
      orientation,
    );
  }

  late final _media_face_get_orientationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_face_h,
              ffi.Pointer<ffi.Int32>)>>('media_face_get_orientation');
  late final _media_face_get_orientation = _media_face_get_orientationPtr
      .asFunction<int Function(media_face_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the tag from the face handle.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks You must release @a tag using free().
  ///
  /// @param [in] face The face handle
  /// @param [out] tag The tag of the face handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  int media_face_get_tag(
    media_face_h face,
    ffi.Pointer<ffi.Pointer<ffi.Char>> tag,
  ) {
    return _media_face_get_tag(
      face,
      tag,
    );
  }

  late final _media_face_get_tagPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_face_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('media_face_get_tag');
  late final _media_face_get_tag = _media_face_get_tagPtr.asFunction<
      int Function(media_face_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Creates the face handle.
  ///
  /// @since_tizen 3.0
  ///
  /// @param [in] media_id The media uuid to create the face handle
  /// @param [out] face The face handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_face_destroy()
  int media_face_create(
    ffi.Pointer<ffi.Char> media_id,
    ffi.Pointer<media_face_h> face,
  ) {
    return _media_face_create(
      media_id,
      face,
    );
  }

  late final _media_face_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<media_face_h>)>>('media_face_create');
  late final _media_face_create = _media_face_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<media_face_h>)>();

  /// @brief Sets the face rectangle of the face handle
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] face The face handle
  /// @param[in] rect_x The integer to set as a position x of face rectangle
  /// @param[in] rect_y The integer to set as a position y of face rectangle
  /// @param[in] rect_w The integer to set as a width  of face rectangle
  /// @param[in] rect_h The integer to set as a height of face rectangle
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_face_insert_to_db()
  /// @post media_face_update_to_db()
  int media_face_set_face_rect(
    media_face_h face,
    int rect_x,
    int rect_y,
    int rect_w,
    int rect_h,
  ) {
    return _media_face_set_face_rect(
      face,
      rect_x,
      rect_y,
      rect_w,
      rect_h,
    );
  }

  late final _media_face_set_face_rectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_face_h, ffi.UnsignedInt, ffi.UnsignedInt,
              ffi.UnsignedInt, ffi.UnsignedInt)>>('media_face_set_face_rect');
  late final _media_face_set_face_rect = _media_face_set_face_rectPtr
      .asFunction<int Function(media_face_h, int, int, int, int)>();

  /// @brief Sets the orientation of the face handle
  /// @details This API may set the value of the original image orientation.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] face The face handle
  /// @param[in] orientation The integer to set as an orientation
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @post media_face_insert_to_db()
  /// @post media_face_update_to_db()
  int media_face_set_orientation(
    media_face_h face,
    int orientation,
  ) {
    return _media_face_set_orientation(
      face,
      orientation,
    );
  }

  late final _media_face_set_orientationPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_face_h, ffi.Int32)>>(
          'media_face_set_orientation');
  late final _media_face_set_orientation = _media_face_set_orientationPtr
      .asFunction<int Function(media_face_h, int)>();

  /// @brief Sets the tag of the face handle.
  ///
  /// @since_tizen 3.0
  ///
  /// @param [in] face The face handle
  /// @param [in] tag The tag of the face handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @post media_face_insert_to_db()
  /// @post media_face_update_to_db()
  int media_face_set_tag(
    media_face_h face,
    ffi.Pointer<ffi.Char> tag,
  ) {
    return _media_face_set_tag(
      face,
      tag,
    );
  }

  late final _media_face_set_tagPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_face_h, ffi.Pointer<ffi.Char>)>>('media_face_set_tag');
  late final _media_face_set_tag = _media_face_set_tagPtr
      .asFunction<int Function(media_face_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Inserts a new face in the media database.
  /// @since_tizen 3.0
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @remarks The created tag handle must be released using media_tag_destroy().
  ///
  /// @param [in] face The face handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  ///
  /// @see media_content_connect()
  /// @see media_face_destroy()
  /// @see media_face_set_xxx()
  int media_face_insert_to_db(
    media_face_h face,
  ) {
    return _media_face_insert_to_db(
      face,
    );
  }

  late final _media_face_insert_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_face_h)>>(
          'media_face_insert_to_db');
  late final _media_face_insert_to_db =
      _media_face_insert_to_dbPtr.asFunction<int Function(media_face_h)>();

  /// @brief Updates the face details to the media database.
  ///
  /// @details The function updates the given media face in the media database. The function should be called after any change in face, to be updated to the media
  /// database. For example, after using media_face_set_orientation() for setting the orientation of the face, media_face_update_to_db() function should be called so as to update
  /// the given face attributes in the media database.
  /// @since_tizen 3.0
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param[in] face The face handle to update
  ///
  /// @return 0 on success, otherwise a negative error value.
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_face_destroy()
  /// @see media_face_set_xxx()
  int media_face_update_to_db(
    media_face_h face,
  ) {
    return _media_face_update_to_db(
      face,
    );
  }

  late final _media_face_update_to_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_face_h)>>(
          'media_face_update_to_db');
  late final _media_face_update_to_db =
      _media_face_update_to_dbPtr.asFunction<int Function(media_face_h)>();

  /// @brief Deletes the face with given face uuid from the media database.
  ///
  /// @since_tizen 3.0
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write
  ///
  /// @param [in] face_id The id of media face
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NETWORK           Network fail
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  /// @see media_content_connect()
  int media_face_delete_from_db(
    ffi.Pointer<ffi.Char> face_id,
  ) {
    return _media_face_delete_from_db(
      face_id,
    );
  }

  late final _media_face_delete_from_dbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'media_face_delete_from_db');
  late final _media_face_delete_from_db = _media_face_delete_from_dbPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the number of media faces with an optional filter from the media database.
  /// @since_tizen 4.0
  ///
  /// @param[in]  filter      The handle to the face filter
  /// @param[out] face_count  The count of the media faces
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  ///
  /// @see media_content_connect()
  /// @see media_filter_create()
  int media_face_get_face_count_from_db(
    filter_h filter,
    ffi.Pointer<ffi.Int> face_count,
  ) {
    return _media_face_get_face_count_from_db(
      filter,
      face_count,
    );
  }

  late final _media_face_get_face_count_from_dbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(filter_h, ffi.Pointer<ffi.Int>)>>(
      'media_face_get_face_count_from_db');
  late final _media_face_get_face_count_from_db =
      _media_face_get_face_count_from_dbPtr
          .asFunction<int Function(filter_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Iterates through the faces with an optional filter from the media database.
  /// @details This function gets all faces associated with the given filter and calls @a callback for every retrieved media face.
  /// If @c NULL is passed to the @a filter, then no filtering is applied.
  /// @since_tizen 4.0
  ///
  /// @param[in] filter     The handle to the face filter
  /// @param[in] callback   The callback function to be invoked
  /// @param[in] user_data  The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE              Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED         DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY           DB Operation busy
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  /// @post This function invokes media_face_cb().
  ///
  /// @see media_content_connect()
  /// @see media_face_cb()
  /// @see media_filter_create()
  int media_face_foreach_face_from_db(
    filter_h filter,
    media_face_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_face_foreach_face_from_db(
      filter,
      callback,
      user_data,
    );
  }

  late final _media_face_foreach_face_from_dbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(filter_h, media_face_cb,
              ffi.Pointer<ffi.Void>)>>('media_face_foreach_face_from_db');
  late final _media_face_foreach_face_from_db =
      _media_face_foreach_face_from_dbPtr.asFunction<
          int Function(filter_h, media_face_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Connects to the media content service.
  /// @details Any media content related function call should be invoked after this function call.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE      Successful
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED DB operation failed
  ///
  /// @post media_content_disconnect()
  ///
  /// @see media_content_disconnect()
  int media_content_connect() {
    return _media_content_connect();
  }

  late final _media_content_connectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('media_content_connect');
  late final _media_content_connect =
      _media_content_connectPtr.asFunction<int Function()>();

  /// @brief Disconnects from the media content service.
  /// @details This function closes connection to the media content service. Any further media content related operation
  /// cannot be performed after this function is called.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE      Successful
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED DB operation failed
  ///
  /// @pre media_content_connect()
  ///
  /// @see media_content_connect()
  int media_content_disconnect() {
    return _media_content_disconnect();
  }

  late final _media_content_disconnectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'media_content_disconnect');
  late final _media_content_disconnect =
      _media_content_disconnectPtr.asFunction<int Function()>();

  /// @brief Requests to scan a media file.
  /// @details This function requests to scan a media file to the media server.
  /// If media file is not registered to DB yet, that media file information will be added to the media DB. If it is already registered to the DB, then this tries to refresh information. \n
  /// If requested file does not exist on file system, information of the media file will be removed from the media DB. \n
  /// If file information does not exist in DB, this API will be return #MEDIA_CONTENT_ERROR_INVALID_PARAMETER.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write \n
  /// %http://tizen.org/privilege/mediastorage \n
  /// %http://tizen.org/privilege/externalstorage
  ///
  /// @remarks You must add privilege http://tizen.org/privilege/content.write. And You add more privilege depending on your choice of contents path. \n
  /// If you want to access only internal storage by using  this API, you should add privilege http://tizen.org/privilege/mediastorage. \n
  /// Or if you want to access only external storage by using  this API, you should add privilege http://tizen.org/privilege/externalstorage. \n
  /// If you can access both storage, you must add all privilege.
  /// @remarks Since 4.0, this function is related to the following feature:\n
  /// %http://tizen.org/feature/content.scanning.others\n
  /// If this feature is not suppported on the device, MEDIA_CONTENT_TYPE_OTHERS type file is not scanned.
  ///
  /// @param[in] path The file path
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED    DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY    DB Operation busy
  /// @retval #MEDIA_CONTENT_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  /// @see media_content_connect()
  int media_content_scan_file(
    ffi.Pointer<ffi.Char> path,
  ) {
    return _media_content_scan_file(
      path,
    );
  }

  late final _media_content_scan_filePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'media_content_scan_file');
  late final _media_content_scan_file = _media_content_scan_filePtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Requests to scan a media folder, asynchronously.
  /// @details This function requests to scan a media folder to the media server with given completed callback function.
  /// media_scan_completed_cb() function will be called when the scanning is finished.
  /// The sub folders are also scanned, if there are sub folders in that folder. \n
  /// If any folder must not be scanned, a blank file ".scan_ignore" has to be created in that folder.
  /// After adding or removing a folder from the filesystem, call this function on its source location
  /// (this will add or remove an entry from the database). \n
  /// After moving or renaming a folder in the filesystem, call this function on its source location
  /// (this will remove an entry from the database) and call this function again on its destination location
  /// (this will add a new entry to the database).\n
  /// Alternatively, you can call this API on any parent of source location and on any parent of destination location.\n
  /// You can also call the function once, on a folder which is a parent of both source and destination.\n
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/content.write \n
  /// %http://tizen.org/privilege/mediastorage \n
  /// %http://tizen.org/privilege/externalstorage
  ///
  /// @remarks You must add privilege http://tizen.org/privilege/content.write. And You add more privilege depending on your choice of contents path. \n
  /// If you want to access only internal storage by using  this API, you should add privilege http://tizen.org/privilege/mediastorage. \n
  /// Or if you want to access only external storage by using  this API, you should add privilege http://tizen.org/privilege/externalstorage. \n
  /// If you can access both storage, you must add all privilege.
  ///
  /// @param[in] path         The folder path
  /// @param[in] is_recursive Set @c true to scan recursively subdirectories,
  /// otherwise @c false to scan only the current directory
  /// @param[in] callback     The callback to be invoked when the scanning is finished
  /// @param[in] user_data    The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_CONTENT_ERROR_DB_FAILED    DB Operation failed
  /// @retval #MEDIA_CONTENT_ERROR_DB_BUSY    DB Operation busy
  ///
  /// @pre This function requires opened connection to content service by media_content_connect().
  /// @see media_scan_completed_cb()
  /// @see media_content_connect()
  int media_content_scan_folder(
    ffi.Pointer<ffi.Char> path,
    bool is_recursive,
    media_scan_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_content_scan_folder(
      path,
      is_recursive,
      callback,
      user_data,
    );
  }

  late final _media_content_scan_folderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Bool,
              media_scan_completed_cb,
              ffi.Pointer<ffi.Void>)>>('media_content_scan_folder');
  late final _media_content_scan_folder =
      _media_content_scan_folderPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, bool, media_scan_completed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Requests to cancel the media folder scanning.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] path         The folder path
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre media_content_scan_folder()
  int media_content_cancel_scan_folder(
    ffi.Pointer<ffi.Char> path,
  ) {
    return _media_content_cancel_scan_folder(
      path,
    );
  }

  late final _media_content_cancel_scan_folderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'media_content_cancel_scan_folder');
  late final _media_content_cancel_scan_folder =
      _media_content_cancel_scan_folderPtr
          .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 3.0. Use media_content_add_db_updated_cb() instead.
  /// @brief Subscribes notifications of the media DB change.
  /// @details This function subscribes notifications of the media DB change which are published by the media server or other apps.
  /// media_content_db_update_cb() function will be called when notification of the media DB change is subscribed.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] callback  The callback to be invoked when the scanning is finished
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @see media_content_db_update_cb()
  /// @see media_content_unset_db_updated_cb()
  int media_content_set_db_updated_cb(
    media_content_db_update_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_content_set_db_updated_cb(
      callback,
      user_data,
    );
  }

  late final _media_content_set_db_updated_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_content_db_update_cb,
              ffi.Pointer<ffi.Void>)>>('media_content_set_db_updated_cb');
  late final _media_content_set_db_updated_cb =
      _media_content_set_db_updated_cbPtr.asFunction<
          int Function(media_content_db_update_cb, ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 3.0. Use media_content_remove_db_updated_cb() instead.
  /// @brief Unsubscribes notifications of the media DB change.
  /// @details This function unsubscribes notifications of the media DB change which are published by the media server or other apps.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  ///
  /// @pre media_content_set_db_updated_cb()
  ///
  /// @see media_content_set_db_updated_cb()
  int media_content_unset_db_updated_cb() {
    return _media_content_unset_db_updated_cb();
  }

  late final _media_content_unset_db_updated_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'media_content_unset_db_updated_cb');
  late final _media_content_unset_db_updated_cb =
      _media_content_unset_db_updated_cbPtr.asFunction<int Function()>();

  /// @brief Subscribes notifications of the media DB change.
  /// @details This function subscribes notifications of the media DB change which are published by the media server or other apps. \n
  /// media_content_db_update_cb() function will be called when notification of the media DB change is subscribed. \n
  /// Using this API, multiple callback is possible to register in one process.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  To release the registered callback, you must use media_content_remove_db_updated_cb() API. \n
  /// media_content_unset_db_updated_cb() API can not release the callbacks added by this API. \n
  /// If you set the same callback that you previously added, this API returns MEDIA_CONTENT_ERROR_INVALID_OPERATION error. \n
  ///
  /// @param[in] callback  The callback to be invoked when the scanning is finished
  /// @param[in] user_data The user data to be passed to the callback function
  /// @param[out] noti_handle The handle to db updated notification
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY     Out of memory
  ///
  /// @see media_content_db_update_cb()
  /// @see media_content_remove_db_updated_cb()
  int media_content_add_db_updated_cb(
    media_content_db_update_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<media_content_noti_h> noti_handle,
  ) {
    return _media_content_add_db_updated_cb(
      callback,
      user_data,
      noti_handle,
    );
  }

  late final _media_content_add_db_updated_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(media_content_db_update_cb,
                  ffi.Pointer<ffi.Void>, ffi.Pointer<media_content_noti_h>)>>(
      'media_content_add_db_updated_cb');
  late final _media_content_add_db_updated_cb =
      _media_content_add_db_updated_cbPtr.asFunction<
          int Function(media_content_db_update_cb, ffi.Pointer<ffi.Void>,
              ffi.Pointer<media_content_noti_h>)>();

  /// @brief Unsubscribes notifications of the media DB change.
  /// @details This function unsubscribes notifications of the media DB change which are published by the media server or other apps.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] noti_handle The handle to db updated notification
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #MEDIA_CONTENT_ERROR_NONE Successful
  /// @retval #MEDIA_CONTENT_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre media_content_add_db_updated_cb()
  ///
  /// @see media_content_add_db_updated_cb()
  int media_content_remove_db_updated_cb(
    media_content_noti_h noti_handle,
  ) {
    return _media_content_remove_db_updated_cb(
      noti_handle,
    );
  }

  late final _media_content_remove_db_updated_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_content_noti_h)>>(
          'media_content_remove_db_updated_cb');
  late final _media_content_remove_db_updated_cb =
      _media_content_remove_db_updated_cbPtr
          .asFunction<int Function(media_content_noti_h)>();

  /// @brief Creates an email message handle for sending an email message.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/email
  /// @remarks You must release @a email using email_destroy_message().
  /// @param[out] email A handle to the email message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #EMAILS_ERROR_ACCOUNT_NOT_FOUND Email account not found
  /// @retval #EMAILS_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @pre At least one email account should be set up on the device.
  /// @see email_destroy_message()
  int email_create_message(
    ffi.Pointer<email_h> email,
  ) {
    return _email_create_message(
      email,
    );
  }

  late final _email_create_messagePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<email_h>)>>(
          'email_create_message');
  late final _email_create_message =
      _email_create_messagePtr.asFunction<int Function(ffi.Pointer<email_h>)>();

  /// @brief Destroys the email message handle and releases all its resources.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] email The handle to the email message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_OPERATION_FAILED Operation failed
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @see email_create_message()
  int email_destroy_message(
    email_h email,
  ) {
    return _email_destroy_message(
      email,
    );
  }

  late final _email_destroy_messagePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(email_h)>>(
          'email_destroy_message');
  late final _email_destroy_message =
      _email_destroy_messagePtr.asFunction<int Function(email_h)>();

  /// @brief Sets a subject of the email message.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/email
  /// @param[in] email The handle to the email message
  /// @param[in] subject The subject of the email message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #EMAILS_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @pre An email message handle is created using email_create_message().
  /// @see email_create_message()
  int email_set_subject(
    email_h email,
    ffi.Pointer<ffi.Char> subject,
  ) {
    return _email_set_subject(
      email,
      subject,
    );
  }

  late final _email_set_subjectPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(email_h, ffi.Pointer<ffi.Char>)>>(
      'email_set_subject');
  late final _email_set_subject = _email_set_subjectPtr
      .asFunction<int Function(email_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Populates a body of the email message.
  /// @details Email message body means the text data to be delivered.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediastorage
  /// @param[in] email The handle to the email message
  /// @param[in] body The message body
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_OPERATION_FAILED Operation failed
  /// @retval #EMAILS_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @pre An email message handle is created using email_create_message().
  /// @see email_create_message()
  int email_set_body(
    email_h email,
    ffi.Pointer<ffi.Char> body,
  ) {
    return _email_set_body(
      email,
      body,
    );
  }

  late final _email_set_bodyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(email_h, ffi.Pointer<ffi.Char>)>>(
      'email_set_body');
  late final _email_set_body = _email_set_bodyPtr
      .asFunction<int Function(email_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Adds a recipient to the email message.
  /// @details The email API supports sending an email message to multiple recipients.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks Email address should be in standard format (as described in
  /// Internet standards RFC 5321 and RFC 5322).
  /// @param[in] email The handle to the email message
  /// @param[in] type The recipient type
  /// @param[in] address The recipient email address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @pre An email message handle is created using email_create_message().
  /// @see email_create_message()
  /// @see email_remove_all_recipients()
  int email_add_recipient(
    email_h email,
    int type,
    ffi.Pointer<ffi.Char> address,
  ) {
    return _email_add_recipient(
      email,
      type,
      address,
    );
  }

  late final _email_add_recipientPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(email_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('email_add_recipient');
  late final _email_add_recipient = _email_add_recipientPtr
      .asFunction<int Function(email_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Removes all recipients for the email message.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] email The handle to the email message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @pre An email message handle is created using email_create_message().
  /// @see email_add_recipient()
  int email_remove_all_recipients(
    email_h email,
  ) {
    return _email_remove_all_recipients(
      email,
    );
  }

  late final _email_remove_all_recipientsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(email_h)>>(
          'email_remove_all_recipients');
  late final _email_remove_all_recipients =
      _email_remove_all_recipientsPtr.asFunction<int Function(email_h)>();

  /// @brief Adds a file as an attachment to the email message.
  /// @details It should be used to add a file to the attachment list
  /// of the email message.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks The maximum attachment file size is 10MB.
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  /// @param[in] email The handle to the email message
  /// @param[in] filepath The absolute full path of the file to be attached
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #EMAILS_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @pre An email message handle is created using email_create_message().
  /// @see email_remove_all_attachments()
  int email_add_attach(
    email_h email,
    ffi.Pointer<ffi.Char> filepath,
  ) {
    return _email_add_attach(
      email,
      filepath,
    );
  }

  late final _email_add_attachPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(email_h, ffi.Pointer<ffi.Char>)>>(
      'email_add_attach');
  late final _email_add_attach = _email_add_attachPtr
      .asFunction<int Function(email_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Clears all attachments of the email message.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] email The handle to the email message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @pre An email message handle is created using email_create_message().
  /// @see email_create_message()
  /// @see email_add_attach()
  int email_remove_all_attachments(
    email_h email,
  ) {
    return _email_remove_all_attachments(
      email,
    );
  }

  late final _email_remove_all_attachmentsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(email_h)>>(
          'email_remove_all_attachments');
  late final _email_remove_all_attachments =
      _email_remove_all_attachmentsPtr.asFunction<int Function(email_h)>();

  /// @brief Saves the email message at outbox.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/email
  /// @param[in] email The handle to the email message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_COMMUNICATION_WITH_SERVER_FAILED Communication with server failed.
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @pre An email message handle is created using email_create_message().
  /// @see email_create_message()
  /// @see email_add_recipient()
  /// @see email_set_body()
  /// @see email_save_message
  int email_save_message(
    email_h email,
  ) {
    return _email_save_message(
      email,
    );
  }

  late final _email_save_messagePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(email_h)>>(
          'email_save_message');
  late final _email_save_message =
      _email_save_messagePtr.asFunction<int Function(email_h)>();

  /// @brief Sends the email message.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks In order to check whether sending a message succeeds,
  /// you should register email_message_sent_cb() using email_set_message_sent_cb().
  /// @param[in] email The handle to the email message
  /// @param[in] save_to_sentbox Set to @c true to save the message in the sentbox,
  /// otherwise set to @c false to not save the message in the sentbox
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_COMMUNICATION_WITH_SERVER_FAILED Communication with server failed
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @pre An email message is stored using email_save_message().
  /// @see email_save_message()
  /// @see email_set_message_sent_cb()
  int email_send_message(
    email_h email,
    bool save_to_sentbox,
  ) {
    return _email_send_message(
      email,
      save_to_sentbox,
    );
  }

  late final _email_send_messagePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(email_h, ffi.Bool)>>(
          'email_send_message');
  late final _email_send_message =
      _email_send_messagePtr.asFunction<int Function(email_h, bool)>();

  /// @brief Registers a callback function to be invoked when an email message is sent.
  /// @details You will be notified when sending a message finishes and check whether it succeeds using this function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] email The handle to the email message
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @post It will invoke email_message_sent_cb().
  /// @see email_message_sent_cb()
  /// @see email_unset_message_sent_cb()
  /// @see email_send_message()
  int email_set_message_sent_cb(
    email_h email,
    email_message_sent_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _email_set_message_sent_cb(
      email,
      callback,
      user_data,
    );
  }

  late final _email_set_message_sent_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(email_h, email_message_sent_cb,
              ffi.Pointer<ffi.Void>)>>('email_set_message_sent_cb');
  late final _email_set_message_sent_cb =
      _email_set_message_sent_cbPtr.asFunction<
          int Function(
              email_h, email_message_sent_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] msg The handle to the email message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #EMAILS_ERROR_NONE Successful
  /// @retval #EMAILS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EMAILS_ERROR_NOT_SUPPORTED Not supported
  /// @see email_message_sent_cb()
  /// @see email_set_message_sent_cb()
  /// @see email_send_message()
  int email_unset_message_sent_cb(
    email_h msg,
  ) {
    return _email_unset_message_sent_cb(
      msg,
    );
  }

  late final _email_unset_message_sent_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(email_h)>>(
          'email_unset_message_sent_cb');
  late final _email_unset_message_sent_cb =
      _email_unset_message_sent_cbPtr.asFunction<int Function(email_h)>();

  /// @brief Opens a handle for the messaging service.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.read
  /// @remarks You must release @a service using messages_close_service().
  /// @param[out] service The message service handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_SERVER_NOT_READY Server is not ready
  /// @retval #MESSAGES_ERROR_COMMUNICATION_WITH_SERVER_FAILED Communication with server failed
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see	messages_close_service()
  int messages_open_service(
    ffi.Pointer<messages_service_h> service,
  ) {
    return _messages_open_service(
      service,
    );
  }

  late final _messages_open_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<messages_service_h>)>>('messages_open_service');
  late final _messages_open_service = _messages_open_servicePtr
      .asFunction<int Function(ffi.Pointer<messages_service_h>)>();

  /// @brief Closes a handle for the messaging service.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.read
  /// @param[in] service The message service handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_COMMUNICATION_WITH_SERVER_FAILED Communication with server failed
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see	messages_open_service()
  int messages_close_service(
    messages_service_h service,
  ) {
    return _messages_close_service(
      service,
    );
  }

  late final _messages_close_servicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(messages_service_h)>>(
          'messages_close_service');
  late final _messages_close_service =
      _messages_close_servicePtr.asFunction<int Function(messages_service_h)>();

  /// @brief Creates a message handle.
  /// @since_tizen 2.3
  /// @remarks You must release @a msg using messages_destroy_message().
  /// @param[in] type The message type (#MESSAGES_TYPE_SMS or #MESSAGES_TYPE_MMS) \n
  /// If @a type is #MESSAGES_TYPE_UNKNOWN, #MESSAGES_ERROR_INVALID_PARAMETER occurs
  /// @param[out] msg The message handle that is newly created if successful
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see	messages_destroy_message()
  int messages_create_message(
    int type,
    ffi.Pointer<messages_message_h> msg,
  ) {
    return _messages_create_message(
      type,
      msg,
    );
  }

  late final _messages_create_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<messages_message_h>)>>('messages_create_message');
  late final _messages_create_message = _messages_create_messagePtr
      .asFunction<int Function(int, ffi.Pointer<messages_message_h>)>();

  /// @brief Destroys a message handle and releases all its resources.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle to destroy
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see	messages_create_message()
  int messages_destroy_message(
    messages_message_h msg,
  ) {
    return _messages_destroy_message(
      msg,
    );
  }

  late final _messages_destroy_messagePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(messages_message_h)>>(
          'messages_destroy_message');
  late final _messages_destroy_message = _messages_destroy_messagePtr
      .asFunction<int Function(messages_message_h)>();

  /// @brief Adds the message to message database.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.write
  /// @param[in] service The message service handle
  /// @param[in] msg The message handle
  /// @param[out] msg_id The message ID of added message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OPERATION_FAILED Messaging operation failed
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_create_message()
  int messages_add_message(
    messages_service_h service,
    messages_message_h msg,
    ffi.Pointer<ffi.Int> msg_id,
  ) {
    return _messages_add_message(
      service,
      msg,
      msg_id,
    );
  }

  late final _messages_add_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_service_h, messages_message_h,
              ffi.Pointer<ffi.Int>)>>('messages_add_message');
  late final _messages_add_message = _messages_add_messagePtr.asFunction<
      int Function(
          messages_service_h, messages_message_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the message ID of the message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[out] msg_id The message ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OPERATION_FAILED Messaging operation failed
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_search_message_by_id()
  int messages_get_message_id(
    messages_message_h msg,
    ffi.Pointer<ffi.Int> msg_id,
  ) {
    return _messages_get_message_id(
      msg,
      msg_id,
    );
  }

  late final _messages_get_message_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h,
              ffi.Pointer<ffi.Int>)>>('messages_get_message_id');
  late final _messages_get_message_id = _messages_get_message_idPtr
      .asFunction<int Function(messages_message_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the SIM ID of the sending message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[in] sim_id The SIM ID to send message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OPERATION_FAILED Messaging operation failed
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_get_sim_id()
  int messages_set_sim_id(
    messages_message_h msg,
    int sim_id,
  ) {
    return _messages_set_sim_id(
      msg,
      sim_id,
    );
  }

  late final _messages_set_sim_idPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(messages_message_h, ffi.Int)>>(
      'messages_set_sim_id');
  late final _messages_set_sim_id = _messages_set_sim_idPtr
      .asFunction<int Function(messages_message_h, int)>();

  /// @brief Gets the SIM ID of the message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[out] sim_id The SIM ID of message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OPERATION_FAILED Messaging operation failed
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_set_sim_id()
  int messages_get_sim_id(
    messages_message_h msg,
    ffi.Pointer<ffi.Int> sim_id,
  ) {
    return _messages_get_sim_id(
      msg,
      sim_id,
    );
  }

  late final _messages_get_sim_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h,
              ffi.Pointer<ffi.Int>)>>('messages_get_sim_id');
  late final _messages_get_sim_id = _messages_get_sim_idPtr
      .asFunction<int Function(messages_message_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the message box type of the message.
  /// @since_tizen 3.0
  /// @param[in] msg The message handle
  /// @param[in] mbox The message box type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_set_mbox_type(
    messages_message_h msg,
    int mbox,
  ) {
    return _messages_set_mbox_type(
      msg,
      mbox,
    );
  }

  late final _messages_set_mbox_typePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(messages_message_h, ffi.Int32)>>(
      'messages_set_mbox_type');
  late final _messages_set_mbox_type = _messages_set_mbox_typePtr
      .asFunction<int Function(messages_message_h, int)>();

  /// @brief Gets the message box type of the message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[out] mbox The message box type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_get_mbox_type(
    messages_message_h msg,
    ffi.Pointer<ffi.Int32> mbox,
  ) {
    return _messages_get_mbox_type(
      msg,
      mbox,
    );
  }

  late final _messages_get_mbox_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h,
              ffi.Pointer<ffi.Int32>)>>('messages_get_mbox_type');
  late final _messages_get_mbox_type = _messages_get_mbox_typePtr
      .asFunction<int Function(messages_message_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the destination port of the message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[out] port The destination port of the message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_add_sms_listening_port()
  int messages_get_message_port(
    messages_message_h msg,
    ffi.Pointer<ffi.Int> port,
  ) {
    return _messages_get_message_port(
      msg,
      port,
    );
  }

  late final _messages_get_message_portPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h,
              ffi.Pointer<ffi.Int>)>>('messages_get_message_port');
  late final _messages_get_message_port = _messages_get_message_portPtr
      .asFunction<int Function(messages_message_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the type of the message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[out] type The message type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_get_message_type(
    messages_message_h msg,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _messages_get_message_type(
      msg,
      type,
    );
  }

  late final _messages_get_message_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h,
              ffi.Pointer<ffi.Int32>)>>('messages_get_message_type');
  late final _messages_get_message_type = _messages_get_message_typePtr
      .asFunction<int Function(messages_message_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Adds an recipient's address(phone number) to the message.
  /// @details The maximum number of recipients per message is 10.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[in] address The recipient's address to receive a message \n
  /// The maximum length of @a address is @c 254.
  /// @param[in] type The recipient's type of the @a address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see	messages_get_address()
  /// @see	messages_remove_all_addresses()
  int messages_add_address(
    messages_message_h msg,
    ffi.Pointer<ffi.Char> address,
    int type,
  ) {
    return _messages_add_address(
      msg,
      address,
      type,
    );
  }

  late final _messages_add_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h, ffi.Pointer<ffi.Char>,
              ffi.Int32)>>('messages_add_address');
  late final _messages_add_address = _messages_add_addressPtr.asFunction<
      int Function(messages_message_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Gets the total number of recipients in the message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[out] count The total number of recipients
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see	messages_add_address()
  /// @see	messages_remove_all_addresses()
  int messages_get_address_count(
    messages_message_h msg,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _messages_get_address_count(
      msg,
      count,
    );
  }

  late final _messages_get_address_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h,
              ffi.Pointer<ffi.Int>)>>('messages_get_address_count');
  late final _messages_get_address_count = _messages_get_address_countPtr
      .asFunction<int Function(messages_message_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets a recipient's address with specified index.
  /// @since_tizen 2.3
  /// @remarks You must release @a address using free().
  /// @param[in] msg The message handle
  /// @param[in] index The zero-based index of an address to receive a message
  /// @param[out] address The recipient's address with specified index
  /// @param[out] type The recipient's type of the @a address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see	messages_add_address()
  /// @see	messages_remove_all_addresses()
  int messages_get_address(
    messages_message_h msg,
    int index,
    ffi.Pointer<ffi.Pointer<ffi.Char>> address,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _messages_get_address(
      msg,
      index,
      address,
      type,
    );
  }

  late final _messages_get_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              messages_message_h,
              ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int32>)>>('messages_get_address');
  late final _messages_get_address = _messages_get_addressPtr.asFunction<
      int Function(messages_message_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>,
          ffi.Pointer<ffi.Int32>)>();

  /// @brief Removes all recipients in the message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see	messages_add_address()
  /// @see	messages_get_address()
  int messages_remove_all_addresses(
    messages_message_h msg,
  ) {
    return _messages_remove_all_addresses(
      msg,
    );
  }

  late final _messages_remove_all_addressesPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(messages_message_h)>>(
          'messages_remove_all_addresses');
  late final _messages_remove_all_addresses = _messages_remove_all_addressesPtr
      .asFunction<int Function(messages_message_h)>();

  /// @brief Sets the text of the message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[in] text The text of the message \n
  /// The maximum length of @a text is @c 1530
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see	messages_get_text()
  int messages_set_text(
    messages_message_h msg,
    ffi.Pointer<ffi.Char> text,
  ) {
    return _messages_set_text(
      msg,
      text,
    );
  }

  late final _messages_set_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              messages_message_h, ffi.Pointer<ffi.Char>)>>('messages_set_text');
  late final _messages_set_text = _messages_set_textPtr
      .asFunction<int Function(messages_message_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the text of the message.
  /// @since_tizen 2.3
  /// @remarks You must release @a text using free().
  /// @param[in] msg The message handle
  /// @param[out] text The text of the message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see	messages_set_text()
  int messages_get_text(
    messages_message_h msg,
    ffi.Pointer<ffi.Pointer<ffi.Char>> text,
  ) {
    return _messages_get_text(
      msg,
      text,
    );
  }

  late final _messages_get_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('messages_get_text');
  late final _messages_get_text = _messages_get_textPtr.asFunction<
      int Function(messages_message_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the time of the message.
  /// @since_tizen 3.0
  /// @param[in] msg The message handle
  /// @param[in] time The time of the message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_set_time(
    messages_message_h msg,
    int time,
  ) {
    return _messages_set_time(
      msg,
      time,
    );
  }

  late final _messages_set_timePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(messages_message_h, time_t)>>(
          'messages_set_time');
  late final _messages_set_time =
      _messages_set_timePtr.asFunction<int Function(messages_message_h, int)>();

  /// @brief Gets the time of the message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[out] time The time of the message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_get_time(
    messages_message_h msg,
    ffi.Pointer<time_t> time,
  ) {
    return _messages_get_time(
      msg,
      time,
    );
  }

  late final _messages_get_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              messages_message_h, ffi.Pointer<time_t>)>>('messages_get_time');
  late final _messages_get_time = _messages_get_timePtr
      .asFunction<int Function(messages_message_h, ffi.Pointer<time_t>)>();

  /// @brief Sends the message to all recipients.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.write
  /// @param[in] service The message service handle
  /// @param[in] msg The message handle
  /// @param[in] save_to_sentbox Set to @c true to save the message in the sentbox,
  /// otherwise set to @c false to not save the message in the sentbox
  /// @param[in] callback The callback function
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_SENDING_FAILED Sending message failed
  /// @retval #MESSAGES_ERROR_OPERATION_FAILED Messaging operation failed
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_sent_cb()
  int messages_send_message(
    messages_service_h service,
    messages_message_h msg,
    bool save_to_sentbox,
    messages_sent_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _messages_send_message(
      service,
      msg,
      save_to_sentbox,
      callback,
      user_data,
    );
  }

  late final _messages_send_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              messages_service_h,
              messages_message_h,
              ffi.Bool,
              messages_sent_cb,
              ffi.Pointer<ffi.Void>)>>('messages_send_message');
  late final _messages_send_message = _messages_send_messagePtr.asFunction<
      int Function(messages_service_h, messages_message_h, bool,
          messages_sent_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the message count in the specific message box.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.read
  /// @param[in] service The message service handle
  /// @param[in] mbox The message box type
  /// @param[in] type The message type \n
  /// If @a type is #MESSAGES_TYPE_UNKNOWN, all SMS and MMS messages are counted
  /// @param[out] count The number of messages
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OPERATION_FAILED Messaging operation failed
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_get_message_count(
    messages_service_h service,
    int mbox,
    int type,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _messages_get_message_count(
      service,
      mbox,
      type,
      count,
    );
  }

  late final _messages_get_message_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_service_h, ffi.Int32, ffi.Int32,
              ffi.Pointer<ffi.Int>)>>('messages_get_message_count');
  late final _messages_get_message_count =
      _messages_get_message_countPtr.asFunction<
          int Function(messages_service_h, int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Searches for messages.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.read
  /// @remarks You must release @a message_array using messages_free_message_array().
  /// @param[in] service The message service handle
  /// @param[in] mbox The message box type
  /// @param[in] type The message type \n
  /// If @a type is #MESSAGES_TYPE_UNKNOWN, all SMS and MMS messages are searched
  /// @param[in] keyword The keyword search in the text and subject
  /// @param[in] address The recipient address
  /// @param[in] offset The start position (base @c 0)
  /// @param[in] limit The maximum amount of messages to get \n
  /// In case of @c 0, this method passes to the callback all searched messages
  /// @param[out] message_array The array of the message handle
  /// @param[out] length The number of messages of the @a message_array
  /// @param[out] total The count of the messages that have been retrieved as a result without applying @a limit and @a offset \n
  /// The value can be used to calculate the total number of page views for the searched messages \n
  /// For example, if the count of message search is @c 50 and the limit is @c 20, then using this value, you can notice the total page is @c 3
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGES_ERROR_OPERATION_FAILED Messaging operation failed
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_free_message_array()
  int messages_search_message(
    messages_service_h service,
    int mbox,
    int type,
    ffi.Pointer<ffi.Char> keyword,
    ffi.Pointer<ffi.Char> address,
    int offset,
    int limit,
    ffi.Pointer<ffi.Pointer<messages_message_h>> message_array,
    ffi.Pointer<ffi.Int> length,
    ffi.Pointer<ffi.Int> total,
  ) {
    return _messages_search_message(
      service,
      mbox,
      type,
      keyword,
      address,
      offset,
      limit,
      message_array,
      length,
      total,
    );
  }

  late final _messages_search_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              messages_service_h,
              ffi.Int32,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Int,
              ffi.Pointer<ffi.Pointer<messages_message_h>>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('messages_search_message');
  late final _messages_search_message = _messages_search_messagePtr.asFunction<
      int Function(
          messages_service_h,
          int,
          int,
          ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>,
          int,
          int,
          ffi.Pointer<ffi.Pointer<messages_message_h>>,
          ffi.Pointer<ffi.Int>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Searches a message with the given message ID.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.read
  /// @remarks You must release @a msg using messages_destroy_message().
  /// @param[in] service The message service handle
  /// @param[in] msg_id The message ID
  /// @param[out] msg The message handle that is newly created if successful
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_get_message_id()
  int messages_search_message_by_id(
    messages_service_h service,
    int msg_id,
    ffi.Pointer<messages_message_h> msg,
  ) {
    return _messages_search_message_by_id(
      service,
      msg_id,
      msg,
    );
  }

  late final _messages_search_message_by_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(messages_service_h, ffi.Int,
                  ffi.Pointer<messages_message_h>)>>(
      'messages_search_message_by_id');
  late final _messages_search_message_by_id =
      _messages_search_message_by_idPtr.asFunction<
          int Function(
              messages_service_h, int, ffi.Pointer<messages_message_h>)>();

  /// @brief Frees the message array.
  /// @since_tizen 2.3
  /// @param[in] message_array The array of the message handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_search_message()
  int messages_free_message_array(
    ffi.Pointer<messages_message_h> message_array,
  ) {
    return _messages_free_message_array(
      message_array,
    );
  }

  late final _messages_free_message_arrayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<messages_message_h>)>>('messages_free_message_array');
  late final _messages_free_message_array = _messages_free_message_arrayPtr
      .asFunction<int Function(ffi.Pointer<messages_message_h>)>();

  /// @brief Retrieves the searched messages by invoking the given callback function iteratively.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.read
  /// @param[in] service The message service handle
  /// @param[in] mbox The message box type
  /// @param[in] type The message type \n
  /// If @a type is #MESSAGES_TYPE_UNKNOWN, all SMS and MMS messages are searched
  /// @param[in] keyword The keyword search in the text and subject
  /// @param[in] address The recipient address
  /// @param[in] offset The start position (base 0)
  /// @param[in] limit The maximum amount of messages to get \n
  /// In case of @c 0, this method passes to the callback all searched messages
  /// @param[in] callback The callback function to get a message
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGES_ERROR_OPERATION_FAILED Messaging operation failed
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @post It invokes messages_search_cb().
  /// @see messages_search_cb()
  int messages_foreach_message(
    messages_service_h service,
    int mbox,
    int type,
    ffi.Pointer<ffi.Char> keyword,
    ffi.Pointer<ffi.Char> address,
    int offset,
    int limit,
    messages_search_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _messages_foreach_message(
      service,
      mbox,
      type,
      keyword,
      address,
      offset,
      limit,
      callback,
      user_data,
    );
  }

  late final _messages_foreach_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              messages_service_h,
              ffi.Int32,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Int,
              messages_search_cb,
              ffi.Pointer<ffi.Void>)>>('messages_foreach_message');
  late final _messages_foreach_message =
      _messages_foreach_messagePtr.asFunction<
          int Function(
              messages_service_h,
              int,
              int,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              int,
              int,
              messages_search_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Registers a callback to be invoked when an incoming message is received.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.read
  /// @param[in] service The message service handle
  /// @param[in] callback The callback function
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OPERATION_FAILED Messaging operation failed
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @post It will invoke messages_incoming_cb().
  /// @see messages_unset_message_incoming_cb()
  /// @see messages_incoming_cb()
  int messages_set_message_incoming_cb(
    messages_service_h service,
    messages_incoming_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _messages_set_message_incoming_cb(
      service,
      callback,
      user_data,
    );
  }

  late final _messages_set_message_incoming_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_service_h, messages_incoming_cb,
              ffi.Pointer<ffi.Void>)>>('messages_set_message_incoming_cb');
  late final _messages_set_message_incoming_cb =
      _messages_set_message_incoming_cbPtr.asFunction<
          int Function(messages_service_h, messages_incoming_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.write
  /// @param[in] service The message service handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_set_message_incoming_cb()
  /// @see messages_incoming_cb()
  int messages_unset_message_incoming_cb(
    messages_service_h service,
  ) {
    return _messages_unset_message_incoming_cb(
      service,
    );
  }

  late final _messages_unset_message_incoming_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(messages_service_h)>>(
          'messages_unset_message_incoming_cb');
  late final _messages_unset_message_incoming_cb =
      _messages_unset_message_incoming_cbPtr
          .asFunction<int Function(messages_service_h)>();

  /// @brief Adds an additional listening port for the incoming SMS messages.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.read
  /// @param[in] service The message service handle
  /// @param[in] port The listening port for the SMS messages
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @see messages_set_message_incoming_cb()
  /// @see messages_get_message_port()
  int messages_add_sms_listening_port(
    messages_service_h service,
    int port,
  ) {
    return _messages_add_sms_listening_port(
      service,
      port,
    );
  }

  late final _messages_add_sms_listening_portPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(messages_service_h, ffi.Int)>>(
      'messages_add_sms_listening_port');
  late final _messages_add_sms_listening_port =
      _messages_add_sms_listening_portPtr
          .asFunction<int Function(messages_service_h, int)>();

  /// @brief Sets the subject of the message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[in] subject The subject of the message \n
  /// The maximum length of @a subject is @c 120
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @pre @a msg is created as a #MESSAGES_TYPE_MMS.
  /// @see	messages_mms_get_subject()
  int messages_mms_set_subject(
    messages_message_h msg,
    ffi.Pointer<ffi.Char> subject,
  ) {
    return _messages_mms_set_subject(
      msg,
      subject,
    );
  }

  late final _messages_mms_set_subjectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h,
              ffi.Pointer<ffi.Char>)>>('messages_mms_set_subject');
  late final _messages_mms_set_subject = _messages_mms_set_subjectPtr
      .asFunction<int Function(messages_message_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the subject of the message.
  /// @since_tizen 2.3
  /// @remarks You must release @a subject using free().
  /// @param[in] msg The message handle
  /// @param[out] subject The subject of the message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @pre @a msg is created as a #MESSAGES_TYPE_MMS.
  /// @see	messages_mms_set_subject()
  int messages_mms_get_subject(
    messages_message_h msg,
    ffi.Pointer<ffi.Pointer<ffi.Char>> subject,
  ) {
    return _messages_mms_get_subject(
      msg,
      subject,
    );
  }

  late final _messages_mms_get_subjectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('messages_mms_get_subject');
  late final _messages_mms_get_subject =
      _messages_mms_get_subjectPtr.asFunction<
          int Function(
              messages_message_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Adds the attachment to the MMS message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[in] type The attachment type
  /// @param[in] path The file path to attach \n
  /// The maximum length of @a path is @c 1024
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @pre @a msg is created as a #MESSAGES_TYPE_MMS.
  /// @see	messages_mms_get_attachment()
  /// @see	messages_mms_get_attachment_count()
  /// @see	messages_mms_remove_all_attachments()
  int messages_mms_add_attachment(
    messages_message_h msg,
    int type,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _messages_mms_add_attachment(
      msg,
      type,
      path,
    );
  }

  late final _messages_mms_add_attachmentPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('messages_mms_add_attachment');
  late final _messages_mms_add_attachment =
      _messages_mms_add_attachmentPtr.asFunction<
          int Function(messages_message_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the file path of the attachment with the specified index.
  /// @since_tizen 2.3
  /// @remarks You must release @a path using free().
  /// @param[in] msg The message handle
  /// @param[in] index The zero-based index of the attachment
  /// @param[out] type The attachment type
  /// @param[out] path The file path to attach
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @pre @a msg is created as a #MESSAGES_TYPE_MMS.
  /// @see	messages_mms_add_attachment()
  /// @see	messages_mms_get_attachment_count()
  /// @see	messages_mms_remove_all_attachments()
  int messages_mms_get_attachment(
    messages_message_h msg,
    int index,
    ffi.Pointer<ffi.Int32> type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _messages_mms_get_attachment(
      msg,
      index,
      type,
      path,
    );
  }

  late final _messages_mms_get_attachmentPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(messages_message_h, ffi.Int,
                  ffi.Pointer<ffi.Int32>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'messages_mms_get_attachment');
  late final _messages_mms_get_attachment =
      _messages_mms_get_attachmentPtr.asFunction<
          int Function(messages_message_h, int, ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the attachment with the specified index.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @param[out] count The total number of attachments
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @pre @a msg is created as a #MESSAGES_TYPE_MMS.
  /// @see	messages_mms_add_attachment()
  /// @see	messages_mms_get_attachment()
  /// @see	messages_mms_remove_all_attachments()
  int messages_mms_get_attachment_count(
    messages_message_h msg,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _messages_mms_get_attachment_count(
      msg,
      count,
    );
  }

  late final _messages_mms_get_attachment_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_message_h,
              ffi.Pointer<ffi.Int>)>>('messages_mms_get_attachment_count');
  late final _messages_mms_get_attachment_count =
      _messages_mms_get_attachment_countPtr
          .asFunction<int Function(messages_message_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Removes all attachments to the MMS message.
  /// @since_tizen 2.3
  /// @param[in] msg The message handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  /// @pre @a msg is created as a #MESSAGES_TYPE_MMS.
  /// @see	messages_mms_add_attachment()
  /// @see	messages_mms_get_attachment()
  /// @see	messages_mms_get_attachment_count()
  int messages_mms_remove_all_attachments(
    messages_message_h msg,
  ) {
    return _messages_mms_remove_all_attachments(
      msg,
    );
  }

  late final _messages_mms_remove_all_attachmentsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(messages_message_h)>>(
          'messages_mms_remove_all_attachments');
  late final _messages_mms_remove_all_attachments =
      _messages_mms_remove_all_attachmentsPtr
          .asFunction<int Function(messages_message_h)>();

  /// @brief Registers a callback to be invoked when an WAP Push message is received.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.read
  /// @param[in] service The message service handle
  /// @param[in] app_id The "X-WAP-Application-ID" to indicate a destination WAP Push application ID
  /// @param[in] callback The callback function
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_push_add_incoming_cb(
    messages_service_h service,
    ffi.Pointer<ffi.Char> app_id,
    messages_push_incoming_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _messages_push_add_incoming_cb(
      service,
      app_id,
      callback,
      user_data,
    );
  }

  late final _messages_push_add_incoming_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              messages_service_h,
              ffi.Pointer<ffi.Char>,
              messages_push_incoming_cb,
              ffi.Pointer<ffi.Void>)>>('messages_push_add_incoming_cb');
  late final _messages_push_add_incoming_cb =
      _messages_push_add_incoming_cbPtr.asFunction<
          int Function(messages_service_h, ffi.Pointer<ffi.Char>,
              messages_push_incoming_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the WAP push incoming callback function.
  /// @since_tizen 2.3
  /// @param[in] service The message service handle
  /// @param[in] app_id The "X-WAP-Application-ID" to indicate a destination WAP Push application ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_push_remove_incoming_cb(
    messages_service_h service,
    ffi.Pointer<ffi.Char> app_id,
  ) {
    return _messages_push_remove_incoming_cb(
      service,
      app_id,
    );
  }

  late final _messages_push_remove_incoming_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_service_h,
              ffi.Pointer<ffi.Char>)>>('messages_push_remove_incoming_cb');
  late final _messages_push_remove_incoming_cb =
      _messages_push_remove_incoming_cbPtr.asFunction<
          int Function(messages_service_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Registers an application to the mapping table of the WAP Push service.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.write
  /// @param[in] service The message service handle
  /// @param[in] content_type The MIME content type of the content
  /// @param[in] app_id The "X-WAP-Application-ID" to indicate a destination WAP Push application ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_push_register(
    messages_service_h service,
    ffi.Pointer<ffi.Char> content_type,
    ffi.Pointer<ffi.Char> app_id,
  ) {
    return _messages_push_register(
      service,
      content_type,
      app_id,
    );
  }

  late final _messages_push_registerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_service_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('messages_push_register');
  late final _messages_push_register = _messages_push_registerPtr.asFunction<
      int Function(
          messages_service_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief De-registers an application from the mapping table of the WAP Push service.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.write
  /// @param[in] service The message service handle
  /// @param[in] content_type The MIME content type of the content
  /// @param[in] app_id The "X-WAP-Application-ID" to indicate a destination WAP Push application ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_push_deregister(
    messages_service_h service,
    ffi.Pointer<ffi.Char> content_type,
    ffi.Pointer<ffi.Char> app_id,
  ) {
    return _messages_push_deregister(
      service,
      content_type,
      app_id,
    );
  }

  late final _messages_push_deregisterPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(messages_service_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('messages_push_deregister');
  late final _messages_push_deregister =
      _messages_push_deregisterPtr.asFunction<
          int Function(messages_service_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief Re-registers an application to the mapping table of the WAP Push service.
  /// @since_tizen 2.3
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/message.write
  /// @param[in] service The message service handle
  /// @param[in] content_type An element of the composite key for searching registered entry \n
  /// The MIME content type of the content
  /// @param[in] app_id The composite key for searching mapping information \n
  /// The "X-WAP-Application-ID" to indicate a destination WAP Push application ID
  /// @param[in] dst_content_type The MIME content type of the content
  /// @param[in] dst_app_id The "X-WAP-Application-ID" to indicate a destination WAP Push application ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MESSAGES_ERROR_NONE Successful
  /// @retval #MESSAGES_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MESSAGES_ERROR_PERMISSION_DENIED The application does not have the privilege to call this method
  /// @retval #MESSAGES_ERROR_NOT_SUPPORTED Not supported
  int messages_push_reregister(
    messages_service_h service,
    ffi.Pointer<ffi.Char> content_type,
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Char> dst_content_type,
    ffi.Pointer<ffi.Char> dst_app_id,
  ) {
    return _messages_push_reregister(
      service,
      content_type,
      app_id,
      dst_content_type,
      dst_app_id,
    );
  }

  late final _messages_push_reregisterPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              messages_service_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('messages_push_reregister');
  late final _messages_push_reregister =
      _messages_push_reregisterPtr.asFunction<
          int Function(
              messages_service_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the maximum volume level supported for a particular sound type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]		type The sound type
  /// @param[out]	max	The maximum volume level
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see sound_manager_set_volume()
  /// @see sound_manager_get_volume()
  int sound_manager_get_max_volume(
    int type,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _sound_manager_get_max_volume(
      type,
      max,
    );
  }

  late final _sound_manager_get_max_volumePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ffi.Int>)>>('sound_manager_get_max_volume');
  late final _sound_manager_get_max_volume = _sound_manager_get_max_volumePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the volume level specified for a particular sound type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/volume.set
  /// @param[in]		type The sound type
  /// @param[in]		volume	The volume level to be set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_get_max_volume()
  /// @see sound_manager_get_volume()
  int sound_manager_set_volume(
    int type,
    int volume,
  ) {
    return _sound_manager_set_volume(
      type,
      volume,
    );
  }

  late final _sound_manager_set_volumePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32, ffi.Int)>>(
          'sound_manager_set_volume');
  late final _sound_manager_set_volume =
      _sound_manager_set_volumePtr.asFunction<int Function(int, int)>();

  /// @brief Gets the volume level specified for a particular sound type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]		type The sound type
  /// @param[out]	volume	The current volume level
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_get_max_volume()
  /// @see sound_manager_set_volume()
  int sound_manager_get_volume(
    int type,
    ffi.Pointer<ffi.Int> volume,
  ) {
    return _sound_manager_get_volume(
      type,
      volume,
    );
  }

  late final _sound_manager_get_volumePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Int>)>>('sound_manager_get_volume');
  late final _sound_manager_get_volume = _sound_manager_get_volumePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since 3.0.
  /// @brief Sets the type of the sound being currently played.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]		type The sound type to set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_get_current_sound_type()
  /// @see sound_manager_unset_current_sound_type()
  int sound_manager_set_current_sound_type(
    int type,
  ) {
    return _sound_manager_set_current_sound_type(
      type,
    );
  }

  late final _sound_manager_set_current_sound_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'sound_manager_set_current_sound_type');
  late final _sound_manager_set_current_sound_type =
      _sound_manager_set_current_sound_typePtr.asFunction<int Function(int)>();

  /// @brief Gets the type of the sound being currently played.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out]	type The current sound type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_NO_PLAYING_SOUND No playing sound
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  int sound_manager_get_current_sound_type(
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _sound_manager_get_current_sound_type(
      type,
    );
  }

  late final _sound_manager_get_current_sound_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'sound_manager_get_current_sound_type');
  late final _sound_manager_get_current_sound_type =
      _sound_manager_get_current_sound_typePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since 3.0.
  /// @brief Unsets the type of the sound being currently played.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_set_current_sound_type()
  /// @see sound_manager_get_current_sound_type()
  int sound_manager_unset_current_sound_type() {
    return _sound_manager_unset_current_sound_type();
  }

  late final _sound_manager_unset_current_sound_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'sound_manager_unset_current_sound_type');
  late final _sound_manager_unset_current_sound_type =
      _sound_manager_unset_current_sound_typePtr.asFunction<int Function()>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_add_volume_changed_cb() instead.
  /// @brief Registers a callback function to be invoked when the volume level is changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	callback	Callback function to indicate change in volume
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @post sound_manager_volume_changed_cb() will be invoked.
  /// @see sound_manager_unset_volume_changed_cb()
  /// @see sound_manager_volume_changed_cb()
  int sound_manager_set_volume_changed_cb(
    sound_manager_volume_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sound_manager_set_volume_changed_cb(
      callback,
      user_data,
    );
  }

  late final _sound_manager_set_volume_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_manager_volume_changed_cb,
              ffi.Pointer<ffi.Void>)>>('sound_manager_set_volume_changed_cb');
  late final _sound_manager_set_volume_changed_cb =
      _sound_manager_set_volume_changed_cbPtr.asFunction<
          int Function(
              sound_manager_volume_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_remove_volume_changed_cb() instead.
  /// @brief Unregisters the volume change callback.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @return 0 on success, otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_set_volume_changed_cb()
  int sound_manager_unset_volume_changed_cb() {
    return _sound_manager_unset_volume_changed_cb();
  }

  late final _sound_manager_unset_volume_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'sound_manager_unset_volume_changed_cb');
  late final _sound_manager_unset_volume_changed_cb =
      _sound_manager_unset_volume_changed_cbPtr.asFunction<int Function()>();

  /// @brief Adds a callback function to be invoked when the volume level is changed.
  /// @since_tizen 3.0
  /// @param[in]	callback	Callback function to indicate change in volume
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @param[out]	id	The callback id
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @post sound_manager_volume_changed_cb() will be invoked.
  /// @see sound_manager_remove_volume_changed_cb()
  /// @see sound_manager_volume_changed_cb()
  int sound_manager_add_volume_changed_cb(
    sound_manager_volume_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _sound_manager_add_volume_changed_cb(
      callback,
      user_data,
      id,
    );
  }

  late final _sound_manager_add_volume_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sound_manager_volume_changed_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('sound_manager_add_volume_changed_cb');
  late final _sound_manager_add_volume_changed_cb =
      _sound_manager_add_volume_changed_cbPtr.asFunction<
          int Function(sound_manager_volume_changed_cb, ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Removes the volume change callback.
  /// @since_tizen 3.0
  /// @param[in]	id	The id of the callback to remove
  /// @return 0 on success, otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_add_volume_changed_cb()
  int sound_manager_remove_volume_changed_cb(
    int id,
  ) {
    return _sound_manager_remove_volume_changed_cb(
      id,
    );
  }

  late final _sound_manager_remove_volume_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'sound_manager_remove_volume_changed_cb');
  late final _sound_manager_remove_volume_changed_cb =
      _sound_manager_remove_volume_changed_cbPtr
          .asFunction<int Function(int)>();

  /// @brief Creates a handle for stream information.
  /// @since_tizen 3.0
  ///
  /// @remarks	The registered callback is issued in the internal thread of the sound manager.\n
  /// Do not call this function within sound_stream_focus_state_changed_cb() or sound_stream_focus_state_watch_cb(),\n
  /// otherwise #SOUND_MANAGER_ERROR_INVALID_OPERATION will be returned.\n
  /// To apply the stream policy according to this stream information, this handle should be passed to other APIs\n
  /// related to playback or recording.(e.g. player, wav-player, audio-io, etc.)
  ///
  /// @param[in]	stream_type	The type of stream
  /// @param[in]	callback	The focus state change callback function (optional, this can be NULL)
  /// @param[in]	user_data	The user data to be passed to the callback function (optional, this can be NULL)
  /// @param[out]	stream_info	The handle of stream information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_destroy_stream_information()
  /// @see sound_manager_add_device_for_stream_routing()
  /// @see sound_manager_remove_device_for_stream_routing()
  /// @see sound_manager_remove_all_devices_for_stream_routing()
  /// @see sound_manager_apply_stream_routing()
  /// @see sound_manager_acquire_focus()
  /// @see sound_manager_destroy_focus()
  /// @see sound_manager_get_focus_state()
  int sound_manager_create_stream_information(
    int stream_type,
    sound_stream_focus_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<sound_stream_info_h> stream_info,
  ) {
    return _sound_manager_create_stream_information(
      stream_type,
      callback,
      user_data,
      stream_info,
    );
  }

  late final _sound_manager_create_stream_informationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int32, sound_stream_focus_state_changed_cb,
                  ffi.Pointer<ffi.Void>, ffi.Pointer<sound_stream_info_h>)>>(
      'sound_manager_create_stream_information');
  late final _sound_manager_create_stream_information =
      _sound_manager_create_stream_informationPtr.asFunction<
          int Function(int, sound_stream_focus_state_changed_cb,
              ffi.Pointer<ffi.Void>, ffi.Pointer<sound_stream_info_h>)>();

  /// @brief Destroys the handle for stream information.
  /// @since_tizen 3.0
  ///
  /// @remarks	Do not call this function within sound_stream_focus_state_changed_cb() or sound_stream_focus_state_watch_cb(),\n
  /// otherwise #SOUND_MANAGER_ERROR_INVALID_OPERATION will be returned.
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_add_device_for_stream_routing()
  /// @see sound_manager_remove_device_for_stream_routing()
  /// @see sound_manager_remove_all_devices_for_stream_routing()
  /// @see sound_manager_apply_stream_routing()
  /// @see sound_manager_acquire_focus()
  /// @see sound_manager_destroy_focus()
  /// @see sound_manager_get_focus_state()
  int sound_manager_destroy_stream_information(
    sound_stream_info_h stream_info,
  ) {
    return _sound_manager_destroy_stream_information(
      stream_info,
    );
  }

  late final _sound_manager_destroy_stream_informationPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sound_stream_info_h)>>(
          'sound_manager_destroy_stream_information');
  late final _sound_manager_destroy_stream_information =
      _sound_manager_destroy_stream_informationPtr
          .asFunction<int Function(sound_stream_info_h)>();

  /// @brief Gets the sound type of the stream information.
  /// @since_tizen 3.0
  ///
  /// @remarks	In case of a @a stream_info made with #SOUND_STREAM_TYPE_EMERGENCY, it'll return #SOUND_MANAGER_ERROR_NO_DATA.\n
  /// The reason is that there is no #sound_type_e matched with this @a stream_info.
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @param[out]	sound_type	The sound type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_NO_DATA No data
  /// @pre Call sound_manager_create_stream_information() before calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_set_volume()
  /// @see sound_manager_get_max_volume()
  /// @see sound_manager_get_volume()
  int sound_manager_get_sound_type(
    sound_stream_info_h stream_info,
    ffi.Pointer<ffi.Int32> sound_type,
  ) {
    return _sound_manager_get_sound_type(
      stream_info,
      sound_type,
    );
  }

  late final _sound_manager_get_sound_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_stream_info_h,
              ffi.Pointer<ffi.Int32>)>>('sound_manager_get_sound_type');
  late final _sound_manager_get_sound_type = _sound_manager_get_sound_typePtr
      .asFunction<int Function(sound_stream_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Adds the device to the stream information for the stream routing.
  /// @since_tizen 3.0
  ///
  /// @remarks	Use sound_manager_get_device_list() and sound_manager_get_next_device() to get the device.\n
  /// #SOUND_MANAGER_ERROR_POLICY could be returned according to the stream type of the @a stream_info.\n
  /// The available types of the @a stream_info for this function are #SOUND_STREAM_TYPE_VOIP and #SOUND_STREAM_TYPE_MEDIA_EXTERNAL_ONLY.
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @param[in]	device		The device item from sound_device_list_h
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @pre Call sound_manager_create_stream_information() before calling this function.
  /// @post You can apply this setting by calling sound_manager_apply_stream_routing().
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  /// @see sound_manager_remove_device_for_stream_routing()
  /// @see sound_manager_remove_all_devices_for_stream_routing()
  /// @see sound_manager_apply_stream_routing()
  int sound_manager_add_device_for_stream_routing(
    sound_stream_info_h stream_info,
    sound_device_h device,
  ) {
    return _sound_manager_add_device_for_stream_routing(
      stream_info,
      device,
    );
  }

  late final _sound_manager_add_device_for_stream_routingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_stream_info_h,
              sound_device_h)>>('sound_manager_add_device_for_stream_routing');
  late final _sound_manager_add_device_for_stream_routing =
      _sound_manager_add_device_for_stream_routingPtr
          .asFunction<int Function(sound_stream_info_h, sound_device_h)>();

  /// @brief Removes the device from the stream information for the stream routing.
  /// @since_tizen 3.0
  ///
  /// @remarks	Use sound_manager_get_device_list() and sound_manager_get_next_device() to get the device.\n
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @param[in]	device		The device item from sound_device_list_h
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Call sound_manager_create_stream_information() and sound_manager_add_device_for_stream_routing() before calling this function.
  /// @post You can apply this setting by calling sound_manager_apply_stream_routing().
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  /// @see sound_manager_add_device_for_stream_routing()
  /// @see sound_manager_remove_all_devices_for_stream_routing()
  /// @see sound_manager_apply_stream_routing()
  int sound_manager_remove_device_for_stream_routing(
    sound_stream_info_h stream_info,
    sound_device_h device,
  ) {
    return _sound_manager_remove_device_for_stream_routing(
      stream_info,
      device,
    );
  }

  late final _sound_manager_remove_device_for_stream_routingPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(sound_stream_info_h, sound_device_h)>>(
      'sound_manager_remove_device_for_stream_routing');
  late final _sound_manager_remove_device_for_stream_routing =
      _sound_manager_remove_device_for_stream_routingPtr
          .asFunction<int Function(sound_stream_info_h, sound_device_h)>();

  /// @brief Removes all devices from the stream information for the stream routing.
  /// @since_tizen 4.0
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @pre Call sound_manager_create_stream_information() before calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  /// @see sound_manager_add_device_for_stream_routing()
  /// @see sound_manager_remove_device_for_stream_routing()
  /// @see sound_manager_apply_stream_routing()
  int sound_manager_remove_all_devices_for_stream_routing(
    sound_stream_info_h stream_info,
  ) {
    return _sound_manager_remove_all_devices_for_stream_routing(
      stream_info,
    );
  }

  late final _sound_manager_remove_all_devices_for_stream_routingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sound_stream_info_h)>>(
          'sound_manager_remove_all_devices_for_stream_routing');
  late final _sound_manager_remove_all_devices_for_stream_routing =
      _sound_manager_remove_all_devices_for_stream_routingPtr
          .asFunction<int Function(sound_stream_info_h)>();

  /// @brief Applies the stream routing.
  /// @since_tizen 3.0
  ///
  /// @remarks	If the stream has not been made yet, this setting will be applied when the stream starts to play.\n
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_STATE Invalid state
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @pre Call sound_manager_create_stream_information() and sound_manager_add_device_for_stream_routing() before calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  /// @see sound_manager_add_device_for_stream_routing()
  /// @see sound_manager_remove_device_for_stream_routing()
  /// @see sound_manager_remove_all_devices_for_stream_routing()
  int sound_manager_apply_stream_routing(
    sound_stream_info_h stream_info,
  ) {
    return _sound_manager_apply_stream_routing(
      stream_info,
    );
  }

  late final _sound_manager_apply_stream_routingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sound_stream_info_h)>>(
          'sound_manager_apply_stream_routing');
  late final _sound_manager_apply_stream_routing =
      _sound_manager_apply_stream_routingPtr
          .asFunction<int Function(sound_stream_info_h)>();

  /// @brief Acquires the stream focus.
  /// @since_tizen 3.0
  ///
  /// @remarks	Do not call this function within sound_stream_focus_state_changed_cb() or sound_stream_focus_state_watch_cb(),\n
  /// otherwise #SOUND_MANAGER_ERROR_INVALID_OPERATION will be returned. Since 4.0, it is allowed and does not return the error.
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @param[in]	focus_mask	The focus mask that user wants to acquire
  /// @param[in]	sound_behavior	The requesting sound behavior, values of #sound_behavior_e combined with bitwise 'or'
  /// @param[in]	extra_info	The extra information for this request (optional, this can be NULL)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_INVALID_STATE Invalid state
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @pre Call sound_manager_create_stream_information() with its parameter for sound_stream_focus_state_changed_cb\n
  /// before calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  /// @see sound_manager_acquire_focus_all()
  /// @see sound_manager_release_focus()
  /// @see sound_manager_release_focus_all()
  /// @see sound_manager_get_focus_state()
  int sound_manager_acquire_focus(
    sound_stream_info_h stream_info,
    int focus_mask,
    int sound_behavior,
    ffi.Pointer<ffi.Char> extra_info,
  ) {
    return _sound_manager_acquire_focus(
      stream_info,
      focus_mask,
      sound_behavior,
      extra_info,
    );
  }

  late final _sound_manager_acquire_focusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_stream_info_h, ffi.Int32, ffi.Int,
              ffi.Pointer<ffi.Char>)>>('sound_manager_acquire_focus');
  late final _sound_manager_acquire_focus =
      _sound_manager_acquire_focusPtr.asFunction<
          int Function(sound_stream_info_h, int, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Releases the acquired stream focus.
  /// @since_tizen 3.0
  ///
  /// @remarks	Do not call this function within sound_stream_focus_state_changed_cb() or sound_stream_focus_state_watch_cb(),\n
  /// otherwise #SOUND_MANAGER_ERROR_INVALID_OPERATION will be returned. Since 4.0, it is allowed and does not return the error.
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @param[in]	focus_mask	The focus mask that user wants to release
  /// @param[in]	sound_behavior	The requesting sound behavior, values of #sound_behavior_e combined with bitwise 'or'
  /// @param[in]	extra_info	The extra information for this request (optional, this can be NULL)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_INVALID_STATE Invalid state
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @pre Call sound_manager_create_stream_information() and sound_manager_acquire_focus() before calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  /// @see sound_manager_acquire_focus()
  /// @see sound_manager_acquire_focus_all()
  /// @see sound_manager_release_focus_all()
  /// @see sound_manager_get_focus_state()
  int sound_manager_release_focus(
    sound_stream_info_h stream_info,
    int focus_mask,
    int sound_behavior,
    ffi.Pointer<ffi.Char> extra_info,
  ) {
    return _sound_manager_release_focus(
      stream_info,
      focus_mask,
      sound_behavior,
      extra_info,
    );
  }

  late final _sound_manager_release_focusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_stream_info_h, ffi.Int32, ffi.Int,
              ffi.Pointer<ffi.Char>)>>('sound_manager_release_focus');
  late final _sound_manager_release_focus =
      _sound_manager_release_focusPtr.asFunction<
          int Function(sound_stream_info_h, int, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Acquires all the stream focuses.
  /// @since_tizen 4.0
  ///
  /// @remarks	This function does not return error even though one or all of focuses have already been acquired.\n
  /// Use sound_manager_get_focus_state() to get acquired focus state if it returns #SOUND_MANAGER_ERROR_POLICY.
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @param[in]	sound_behavior	The requesting sound behavior, values of #sound_behavior_e combined with bitwise 'or'
  /// @param[in]	extra_info	The extra information for this request (optional, this can be NULL)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @pre Call sound_manager_create_stream_information() with its parameter for sound_stream_focus_state_changed_cb\n
  /// before calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  /// @see sound_manager_acquire_focus()
  /// @see sound_manager_release_focus()
  /// @see sound_manager_release_focus_all()
  /// @see sound_manager_get_focus_state()
  int sound_manager_acquire_focus_all(
    sound_stream_info_h stream_info,
    int sound_behavior,
    ffi.Pointer<ffi.Char> extra_info,
  ) {
    return _sound_manager_acquire_focus_all(
      stream_info,
      sound_behavior,
      extra_info,
    );
  }

  late final _sound_manager_acquire_focus_allPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_stream_info_h, ffi.Int,
              ffi.Pointer<ffi.Char>)>>('sound_manager_acquire_focus_all');
  late final _sound_manager_acquire_focus_all =
      _sound_manager_acquire_focus_allPtr.asFunction<
          int Function(sound_stream_info_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Releases all the acquired stream focuses.
  /// @since_tizen 4.0
  ///
  /// @remarks	This function does not return error even though one or all of focuses have already been released.
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @param[in]	sound_behavior	The requesting sound behavior, values of #sound_behavior_e combined with bitwise 'or'
  /// @param[in]	extra_info	The extra information for this request (optional, this can be NULL)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @pre Call sound_manager_create_stream_information(), sound_manager_acquire_focus() and sound_manager_acquire_focus_all()\n
  /// before calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  /// @see sound_manager_acquire_focus()
  /// @see sound_manager_acquire_focus_all()
  /// @see sound_manager_release_focus()
  /// @see sound_manager_get_focus_state()
  int sound_manager_release_focus_all(
    sound_stream_info_h stream_info,
    int sound_behavior,
    ffi.Pointer<ffi.Char> extra_info,
  ) {
    return _sound_manager_release_focus_all(
      stream_info,
      sound_behavior,
      extra_info,
    );
  }

  late final _sound_manager_release_focus_allPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_stream_info_h, ffi.Int,
              ffi.Pointer<ffi.Char>)>>('sound_manager_release_focus_all');
  late final _sound_manager_release_focus_all =
      _sound_manager_release_focus_allPtr.asFunction<
          int Function(sound_stream_info_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the state of focus.
  /// @since_tizen 3.0
  /// @param[in]	stream_info	The handle of stream information
  /// @param[out]	state_for_playback	The state of playback focus
  /// @param[out]	state_for_recording	The state of recording focus
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Call sound_manager_create_stream_information() before calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  /// @see sound_manager_acquire_focus()
  /// @see sound_manager_release_focus()
  int sound_manager_get_focus_state(
    sound_stream_info_h stream_info,
    ffi.Pointer<ffi.Int32> state_for_playback,
    ffi.Pointer<ffi.Int32> state_for_recording,
  ) {
    return _sound_manager_get_focus_state(
      stream_info,
      state_for_playback,
      state_for_recording,
    );
  }

  late final _sound_manager_get_focus_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_stream_info_h, ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Int32>)>>('sound_manager_get_focus_state');
  late final _sound_manager_get_focus_state =
      _sound_manager_get_focus_statePtr.asFunction<
          int Function(sound_stream_info_h, ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets auto focus reacquisition property.
  /// @since_tizen 3.0
  ///
  /// @remarks	The focus reacquisition is set as default.
  /// If you don't want to reacquire the focus you've lost automatically, disable the focus reacquisition setting by using this function and vice versa.
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @param[in]	enable	The auto focus reacquisition property to set : (@c true = enable, @c false = disable)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Call sound_manager_create_stream_information() before calling this function.
  /// @see sound_manager_create_stream_information()
  int sound_manager_set_focus_reacquisition(
    sound_stream_info_h stream_info,
    bool enable,
  ) {
    return _sound_manager_set_focus_reacquisition(
      stream_info,
      enable,
    );
  }

  late final _sound_manager_set_focus_reacquisitionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(sound_stream_info_h, ffi.Bool)>>(
      'sound_manager_set_focus_reacquisition');
  late final _sound_manager_set_focus_reacquisition =
      _sound_manager_set_focus_reacquisitionPtr
          .asFunction<int Function(sound_stream_info_h, bool)>();

  /// @brief Gets auto focus reacquisition property.
  /// @since_tizen 3.0
  ///
  /// @remarks	The default value is true.
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @param[out]	enabled	The value of focus auto reacquisition property : (@c true = enabled, @c false = disabled)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Call sound_manager_create_stream_information() before calling this function.
  /// @see sound_manager_create_stream_information()
  int sound_manager_get_focus_reacquisition(
    sound_stream_info_h stream_info,
    ffi.Pointer<ffi.Bool> enabled,
  ) {
    return _sound_manager_get_focus_reacquisition(
      stream_info,
      enabled,
    );
  }

  late final _sound_manager_get_focus_reacquisitionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_stream_info_h,
              ffi.Pointer<ffi.Bool>)>>('sound_manager_get_focus_reacquisition');
  late final _sound_manager_get_focus_reacquisition =
      _sound_manager_get_focus_reacquisitionPtr.asFunction<
          int Function(sound_stream_info_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Delivers focuses to another stream information.
  /// @since_tizen 4.0
  ///
  /// @remarks	This function does not affect any invocation of sound_stream_focus_state_changed_cb() or\n
  /// sound_stream_focus_state_watch_cb(). Do not call this function within sound_stream_focus_state_changed_cb() or\n
  /// sound_stream_focus_state_watch_cb(), otherwise #SOUND_MANAGER_ERROR_INVALID_OPERATION will be returned.
  ///
  /// @param[in]	source	The source handle of stream information which has focuses
  /// @param[in]	destination	The destination handle of stream information which will receive focuses
  /// @param[in]	focus_mask	The focus mask to deliver
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_INVALID_STATE Invalid state
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @pre Call sound_manager_create_stream_information(), sound_manager_acquire_focus() and sound_manager_acquire_focus_all()\n
  /// before calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_acquire_focus()
  /// @see sound_manager_acquire_focus_all()
  int sound_manager_deliver_focus(
    sound_stream_info_h source,
    sound_stream_info_h destination,
    int focus_mask,
  ) {
    return _sound_manager_deliver_focus(
      source,
      destination,
      focus_mask,
    );
  }

  late final _sound_manager_deliver_focusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_stream_info_h, sound_stream_info_h,
              ffi.Int32)>>('sound_manager_deliver_focus');
  late final _sound_manager_deliver_focus =
      _sound_manager_deliver_focusPtr.asFunction<
          int Function(sound_stream_info_h, sound_stream_info_h, int)>();

  /// @brief Checks if the stream information is using the device.
  /// @since_tizen 3.0
  ///
  /// @param[in]	stream_info	The handle of stream information
  /// @param[in]	device	The device item
  /// @param[out]	is_on	Whether the stream info is using the device or not : (@c true = use, @c false = not use)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_get_device_list()
  /// @see sound_manager_get_next_device()
  /// @see sound_manager_get_prev_device()
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_get_device_name()
  /// @see sound_manager_free_device_list()
  int sound_manager_is_stream_on_device(
    sound_stream_info_h stream_info,
    sound_device_h device,
    ffi.Pointer<ffi.Bool> is_on,
  ) {
    return _sound_manager_is_stream_on_device(
      stream_info,
      device,
      is_on,
    );
  }

  late final _sound_manager_is_stream_on_devicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_stream_info_h, sound_device_h,
              ffi.Pointer<ffi.Bool>)>>('sound_manager_is_stream_on_device');
  late final _sound_manager_is_stream_on_device =
      _sound_manager_is_stream_on_devicePtr.asFunction<
          int Function(
              sound_stream_info_h, sound_device_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the current device type for media playback stream.
  /// @since_tizen 3.0
  ///
  /// @param[out]	device_type	The output device type that a media playback stream can go out
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_NO_DATA No data
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_get_device_name()
  int sound_manager_get_current_media_playback_device_type(
    ffi.Pointer<ffi.Int32> device_type,
  ) {
    return _sound_manager_get_current_media_playback_device_type(
      device_type,
    );
  }

  late final _sound_manager_get_current_media_playback_device_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'sound_manager_get_current_media_playback_device_type');
  late final _sound_manager_get_current_media_playback_device_type =
      _sound_manager_get_current_media_playback_device_typePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the reason for the current acquired playback focus.
  /// @since_tizen 3.0
  ///
  /// @remarks	If there is no acquired playback focus in this system, it'll return #SOUND_MANAGER_ERROR_NO_DATA.\n
  /// Do not call this function within sound_stream_focus_state_changed_cb() or sound_stream_focus_state_watch_cb(),\n
  /// otherwise #SOUND_MANAGER_ERROR_INVALID_OPERATION will be returned.\n
  /// The @a extra_info should be released using free().
  ///
  /// @param[out]	acquired_by	The reason for the current acquired playback focus
  /// @param[out]	sound_behavior	The requested sound behavior that should be followed, values of #sound_behavior_e combined with bitwise 'or'
  /// @param[out]	extra_info The extra information of the acquired playback focus (optional, this can be NULL)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_NO_DATA No data
  /// @see sound_manager_get_current_recording_focus()
  int sound_manager_get_current_playback_focus(
    ffi.Pointer<ffi.Int32> acquired_by,
    ffi.Pointer<ffi.Int> sound_behavior,
    ffi.Pointer<ffi.Pointer<ffi.Char>> extra_info,
  ) {
    return _sound_manager_get_current_playback_focus(
      acquired_by,
      sound_behavior,
      extra_info,
    );
  }

  late final _sound_manager_get_current_playback_focusPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Int32>, ffi.Pointer<ffi.Int>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'sound_manager_get_current_playback_focus');
  late final _sound_manager_get_current_playback_focus =
      _sound_manager_get_current_playback_focusPtr.asFunction<
          int Function(ffi.Pointer<ffi.Int32>, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the reason for the current acquired recording focus.
  /// @since_tizen 3.0
  ///
  /// @remarks	If there is no acquired recording focus in this system, it'll return #SOUND_MANAGER_ERROR_NO_DATA.\n
  /// Do not call this function within sound_stream_focus_state_changed_cb() or sound_stream_focus_state_watch_cb(),\n
  /// otherwise #SOUND_MANAGER_ERROR_INVALID_OPERATION will be returned.\n
  /// The @a extra_info should be released using free().
  ///
  /// @param[out]	acquired_by	The reason for the current acquired recording focus
  /// @param[out]	sound_behavior	The requested sound behavior that should be followed, values of #sound_behavior_e combined with bitwise 'or'
  /// @param[out]	extra_info The extra information of the acquired recording focus (optional, this can be NULL)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_NO_DATA No data
  /// @see sound_manager_get_current_playback_focus()
  int sound_manager_get_current_recording_focus(
    ffi.Pointer<ffi.Int32> acquired_by,
    ffi.Pointer<ffi.Int> sound_behavior,
    ffi.Pointer<ffi.Pointer<ffi.Char>> extra_info,
  ) {
    return _sound_manager_get_current_recording_focus(
      acquired_by,
      sound_behavior,
      extra_info,
    );
  }

  late final _sound_manager_get_current_recording_focusPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Int32>, ffi.Pointer<ffi.Int>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'sound_manager_get_current_recording_focus');
  late final _sound_manager_get_current_recording_focus =
      _sound_manager_get_current_recording_focusPtr.asFunction<
          int Function(ffi.Pointer<ffi.Int32>, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Registers the watch callback function to be invoked when the focus state for each sound stream type is changed regardless of the process.
  /// @since_tizen 3.0
  ///
  /// @remarks	The registered callback is invoked by the internal thread of the sound manager.\n
  /// Do not call this function within sound_stream_focus_state_changed_cb() or sound_stream_focus_state_watch_cb(),\n
  /// otherwise #SOUND_MANAGER_ERROR_INVALID_OPERATION will be returned.
  ///
  /// @param[in]	focus_mask	The focus mask that user wants to watch
  /// @param[in]	callback	The focus state change watch callback function
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @param[out]	id		The focus state change watch callback id
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_remove_focus_state_watch_cb()
  int sound_manager_add_focus_state_watch_cb(
    int focus_mask,
    sound_stream_focus_state_watch_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _sound_manager_add_focus_state_watch_cb(
      focus_mask,
      callback,
      user_data,
      id,
    );
  }

  late final _sound_manager_add_focus_state_watch_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              sound_stream_focus_state_watch_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('sound_manager_add_focus_state_watch_cb');
  late final _sound_manager_add_focus_state_watch_cb =
      _sound_manager_add_focus_state_watch_cbPtr.asFunction<
          int Function(int, sound_stream_focus_state_watch_cb,
              ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Int>)>();

  /// @brief Unregisters the focus state change watch callback.
  /// @since_tizen 3.0
  ///
  /// @remarks	Do not call this function within sound_stream_focus_state_changed_cb() or sound_stream_focus_state_watch_cb(),\n
  /// otherwise #SOUND_MANAGER_ERROR_INVALID_OPERATION will be returned.
  ///
  /// @param[in]	id		The focus state change watch callback id
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_add_focus_state_watch_cb()
  int sound_manager_remove_focus_state_watch_cb(
    int id,
  ) {
    return _sound_manager_remove_focus_state_watch_cb(
      id,
    );
  }

  late final _sound_manager_remove_focus_state_watch_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'sound_manager_remove_focus_state_watch_cb');
  late final _sound_manager_remove_focus_state_watch_cb =
      _sound_manager_remove_focus_state_watch_cbPtr
          .asFunction<int Function(int)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Sets the application's sound session type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] type The session type to set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @see sound_manager_get_session_type()
  /// @see sound_manager_set_media_session_option()
  /// @see sound_manager_get_media_session_option()
  /// @see sound_manager_set_media_session_resumption_option()
  /// @see sound_manager_get_media_session_resumption_option()
  /// @see sound_manager_set_voip_session_mode()
  /// @see sound_manager_get_voip_session_mode()
  int sound_manager_set_session_type(
    int type,
  ) {
    return _sound_manager_set_session_type(
      type,
    );
  }

  late final _sound_manager_set_session_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'sound_manager_set_session_type');
  late final _sound_manager_set_session_type =
      _sound_manager_set_session_typePtr.asFunction<int Function(int)>();

  /// @deprecated Deprecated since 3.0.
  /// @brief Gets the application's sound session type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] type The session type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see sound_manager_set_session_type()
  /// @see sound_manager_set_media_session_option()
  /// @see sound_manager_get_media_session_option()
  /// @see sound_manager_set_media_session_resumption_option()
  /// @see sound_manager_get_media_session_resumption_option()
  /// @see sound_manager_set_voip_session_mode()
  /// @see sound_manager_get_voip_session_mode()
  int sound_manager_get_session_type(
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _sound_manager_get_session_type(
      type,
    );
  }

  late final _sound_manager_get_session_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'sound_manager_get_session_type');
  late final _sound_manager_get_session_type =
      _sound_manager_get_session_typePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Sets the media sound session option.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] s_option The session option for starting
  /// @param[in] d_option The session option for during play
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @see sound_manager_set_session_type()
  /// @see sound_manager_get_session_type()
  /// @see sound_manager_get_media_session_option()
  /// @see sound_manager_set_media_session_resumption_option()
  /// @see sound_manager_get_media_session_resumption_option()
  int sound_manager_set_media_session_option(
    int s_option,
    int d_option,
  ) {
    return _sound_manager_set_media_session_option(
      s_option,
      d_option,
    );
  }

  late final _sound_manager_set_media_session_optionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32, ffi.Int32)>>(
          'sound_manager_set_media_session_option');
  late final _sound_manager_set_media_session_option =
      _sound_manager_set_media_session_optionPtr
          .asFunction<int Function(int, int)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Gets the media sound session option.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out] s_option The session option for starting
  /// @param[out] d_option The session option for during play
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @see sound_manager_set_session_type()
  /// @see sound_manager_get_session_type()
  /// @see sound_manager_set_media_session_option()
  /// @see sound_manager_set_media_session_resumption_option()
  /// @see sound_manager_get_media_session_resumption_option()
  int sound_manager_get_media_session_option(
    ffi.Pointer<ffi.Int32> s_option,
    ffi.Pointer<ffi.Int32> d_option,
  ) {
    return _sound_manager_get_media_session_option(
      s_option,
      d_option,
    );
  }

  late final _sound_manager_get_media_session_optionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Int32>, ffi.Pointer<ffi.Int32>)>>(
      'sound_manager_get_media_session_option');
  late final _sound_manager_get_media_session_option =
      _sound_manager_get_media_session_optionPtr.asFunction<
          int Function(ffi.Pointer<ffi.Int32>, ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Sets the media sound session resumption option.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] option The session resumption option
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @see sound_manager_set_session_type()
  /// @see sound_manager_get_session_type()
  /// @see sound_manager_set_media_session_option()
  /// @see sound_manager_get_media_session_option()
  /// @see sound_manager_get_media_session_resumption_option()
  int sound_manager_set_media_session_resumption_option(
    int option,
  ) {
    return _sound_manager_set_media_session_resumption_option(
      option,
    );
  }

  late final _sound_manager_set_media_session_resumption_optionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'sound_manager_set_media_session_resumption_option');
  late final _sound_manager_set_media_session_resumption_option =
      _sound_manager_set_media_session_resumption_optionPtr
          .asFunction<int Function(int)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Gets the media sound session resumption option.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out] option The session resumption option
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @see sound_manager_set_session_type()
  /// @see sound_manager_get_session_type()
  /// @see sound_manager_set_media_session_option()
  /// @see sound_manager_get_media_session_option()
  /// @see sound_manager_set_media_session_resumption_option()
  int sound_manager_get_media_session_resumption_option(
    ffi.Pointer<ffi.Int32> option,
  ) {
    return _sound_manager_get_media_session_resumption_option(
      option,
    );
  }

  late final _sound_manager_get_media_session_resumption_optionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'sound_manager_get_media_session_resumption_option');
  late final _sound_manager_get_media_session_resumption_option =
      _sound_manager_get_media_session_resumption_optionPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Sets the mode of the voip sound session.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mode The voip session mode
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @pre Call sound_manager_set_session_type(#SOUND_SESSION_TYPE_VOIP) before calling this function.
  /// @see sound_manager_set_session_type()
  /// @see sound_manager_get_session_type()
  /// @see sound_manager_get_voip_session_mode()
  int sound_manager_set_voip_session_mode(
    int mode,
  ) {
    return _sound_manager_set_voip_session_mode(
      mode,
    );
  }

  late final _sound_manager_set_voip_session_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'sound_manager_set_voip_session_mode');
  late final _sound_manager_set_voip_session_mode =
      _sound_manager_set_voip_session_modePtr.asFunction<int Function(int)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Gets the mode of the voip sound session.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out] mode The voip session mode
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @pre Call sound_manager_set_session_type(#SOUND_SESSION_TYPE_VOIP) before calling this function.
  /// @see sound_manager_set_session_type()
  /// @see sound_manager_get_session_type()
  /// @see sound_manager_set_voip_session_mode()
  int sound_manager_get_voip_session_mode(
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _sound_manager_get_voip_session_mode(
      mode,
    );
  }

  late final _sound_manager_get_voip_session_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'sound_manager_get_voip_session_mode');
  late final _sound_manager_get_voip_session_mode =
      _sound_manager_get_voip_session_modePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Registers a callback function to be invoked when the sound session being played was interrupted.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	callback	The interrupted callback function
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_POLICY Noncompliance with the sound system policy
  /// @post  sound_session_interrupted_cb() will be invoked.
  /// @see sound_manager_unset_session_interrupted_cb()
  /// @see sound_session_interrupted_cb()
  int sound_manager_set_session_interrupted_cb(
    sound_session_interrupted_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sound_manager_set_session_interrupted_cb(
      callback,
      user_data,
    );
  }

  late final _sound_manager_set_session_interrupted_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  sound_session_interrupted_cb, ffi.Pointer<ffi.Void>)>>(
      'sound_manager_set_session_interrupted_cb');
  late final _sound_manager_set_session_interrupted_cb =
      _sound_manager_set_session_interrupted_cbPtr.asFunction<
          int Function(sound_session_interrupted_cb, ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 3.0.
  /// @brief Unregisters the callback function which is called when the sound session being played is interrupted.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @return 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_set_session_interrupted_cb()
  int sound_manager_unset_session_interrupted_cb() {
    return _sound_manager_unset_session_interrupted_cb();
  }

  late final _sound_manager_unset_session_interrupted_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'sound_manager_unset_session_interrupted_cb');
  late final _sound_manager_unset_session_interrupted_cb =
      _sound_manager_unset_session_interrupted_cbPtr
          .asFunction<int Function()>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_get_device_list() instead.
  /// @brief Gets the list consisting of connected devices.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks	@a Calling this API will deallocate previously obtained list and each item.\n
  /// Use sound_manager_get_next_device() to get the first node of the list.
  ///
  /// @param[in]	device_mask	The mask value
  /// @param[out]	device_list	The list of connected devices
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_NO_DATA No data
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_get_next_device()
  /// @see sound_manager_get_prev_device()
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_get_device_name()
  int sound_manager_get_current_device_list(
    int device_mask,
    ffi.Pointer<sound_device_list_h> device_list,
  ) {
    return _sound_manager_get_current_device_list(
      device_mask,
      device_list,
    );
  }

  late final _sound_manager_get_current_device_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int32, ffi.Pointer<sound_device_list_h>)>>(
      'sound_manager_get_current_device_list');
  late final _sound_manager_get_current_device_list =
      _sound_manager_get_current_device_listPtr
          .asFunction<int Function(int, ffi.Pointer<sound_device_list_h>)>();

  /// @brief Gets the list consisting of connected devices.
  /// @since_tizen 3.0
  ///
  /// @remarks	@a device_list should be freed using sound_manager_free_device_list().\n
  /// Use sound_manager_get_next_device() to get the first node of the list.
  ///
  /// @param[in]	device_mask	The mask values of #sound_device_mask_e combined with bitwise 'or'
  /// @param[out]	device_list	The list of connected devices
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_NO_DATA No data
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_get_next_device()
  /// @see sound_manager_get_prev_device()
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_get_device_name()
  /// @see sound_manager_free_device_list()
  int sound_manager_get_device_list(
    int device_mask,
    ffi.Pointer<sound_device_list_h> device_list,
  ) {
    return _sound_manager_get_device_list(
      device_mask,
      device_list,
    );
  }

  late final _sound_manager_get_device_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<sound_device_list_h>)>>(
      'sound_manager_get_device_list');
  late final _sound_manager_get_device_list = _sound_manager_get_device_listPtr
      .asFunction<int Function(int, ffi.Pointer<sound_device_list_h>)>();

  /// @brief Frees device list and each item of list.
  /// @since_tizen 3.0
  ///
  /// @remarks	This function will deallocate not only device list itself but also each item.
  ///
  /// @param[in]	device_list	The device list got with sound_manager_get_device_list.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  ///
  /// @see sound_manager_get_device_list()
  /// @see sound_manager_get_next_device()
  /// @see sound_manager_get_prev_device()
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_get_device_name()
  int sound_manager_free_device_list(
    sound_device_list_h device_list,
  ) {
    return _sound_manager_free_device_list(
      device_list,
    );
  }

  late final _sound_manager_free_device_listPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sound_device_list_h)>>(
          'sound_manager_free_device_list');
  late final _sound_manager_free_device_list =
      _sound_manager_free_device_listPtr
          .asFunction<int Function(sound_device_list_h)>();

  /// @brief Gets the next item of the device list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	device_list	The list of connected devices
  /// @param[out]	device	The device item
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_NO_DATA No data
  /// @see sound_manager_get_device_list()
  /// @see sound_manager_get_prev_device()
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_get_device_name()
  /// @see sound_manager_free_device_list()
  int sound_manager_get_next_device(
    sound_device_list_h device_list,
    ffi.Pointer<sound_device_h> device,
  ) {
    return _sound_manager_get_next_device(
      device_list,
      device,
    );
  }

  late final _sound_manager_get_next_devicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_device_list_h,
              ffi.Pointer<sound_device_h>)>>('sound_manager_get_next_device');
  late final _sound_manager_get_next_device =
      _sound_manager_get_next_devicePtr.asFunction<
          int Function(sound_device_list_h, ffi.Pointer<sound_device_h>)>();

  /// @brief Gets the previous item of the device list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	device_list	The list of connected devices
  /// @param[out]	device	The device item
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_NO_DATA No data
  /// @see sound_manager_get_device_list()
  /// @see sound_manager_get_next_device()
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_get_device_name()
  /// @see sound_manager_free_device_list()
  int sound_manager_get_prev_device(
    sound_device_list_h device_list,
    ffi.Pointer<sound_device_h> device,
  ) {
    return _sound_manager_get_prev_device(
      device_list,
      device,
    );
  }

  late final _sound_manager_get_prev_devicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_device_list_h,
              ffi.Pointer<sound_device_h>)>>('sound_manager_get_prev_device');
  late final _sound_manager_get_prev_device =
      _sound_manager_get_prev_devicePtr.asFunction<
          int Function(sound_device_list_h, ffi.Pointer<sound_device_h>)>();

  /// @brief Gets the type of the device.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	device	The device item
  /// @param[out]	type	The type of the device
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see sound_manager_get_device_list()
  /// @see sound_manager_get_next_device()
  /// @see sound_manager_get_prev_device()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_get_device_name()
  /// @see sound_manager_free_device_list()
  int sound_manager_get_device_type(
    sound_device_h device,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _sound_manager_get_device_type(
      device,
      type,
    );
  }

  late final _sound_manager_get_device_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_device_h,
              ffi.Pointer<ffi.Int32>)>>('sound_manager_get_device_type');
  late final _sound_manager_get_device_type = _sound_manager_get_device_typePtr
      .asFunction<int Function(sound_device_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the io direction of the device.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	device	The device item
  /// @param[out]	io_direction	The io direction of the device
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see sound_manager_get_device_list()
  /// @see sound_manager_get_next_device()
  /// @see sound_manager_get_prev_device()
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_get_device_name()
  /// @see sound_manager_free_device_list()
  int sound_manager_get_device_io_direction(
    sound_device_h device,
    ffi.Pointer<ffi.Int32> io_direction,
  ) {
    return _sound_manager_get_device_io_direction(
      device,
      io_direction,
    );
  }

  late final _sound_manager_get_device_io_directionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(sound_device_h, ffi.Pointer<ffi.Int32>)>>(
      'sound_manager_get_device_io_direction');
  late final _sound_manager_get_device_io_direction =
      _sound_manager_get_device_io_directionPtr
          .asFunction<int Function(sound_device_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the id of the device.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	device	The device item
  /// @param[out]	id	The id of the device
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see sound_manager_get_device_list()
  /// @see sound_manager_get_next_device()
  /// @see sound_manager_get_prev_device()
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_name()
  /// @see sound_manager_free_device_list()
  int sound_manager_get_device_id(
    sound_device_h device,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _sound_manager_get_device_id(
      device,
      id,
    );
  }

  late final _sound_manager_get_device_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_device_h,
              ffi.Pointer<ffi.Int>)>>('sound_manager_get_device_id');
  late final _sound_manager_get_device_id = _sound_manager_get_device_idPtr
      .asFunction<int Function(sound_device_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the name of the device.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	device	The device item
  /// @param[out]	name	The name of the device
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_get_device_list()
  /// @see sound_manager_get_next_device()
  /// @see sound_manager_get_prev_device()
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_free_device_list()
  int sound_manager_get_device_name(
    sound_device_h device,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _sound_manager_get_device_name(
      device,
      name,
    );
  }

  late final _sound_manager_get_device_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  sound_device_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'sound_manager_get_device_name');
  late final _sound_manager_get_device_name =
      _sound_manager_get_device_namePtr.asFunction<
          int Function(sound_device_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the state of the device.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	device	The device item
  /// @param[out]	state	The state of the device
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see sound_manager_get_device_list()
  /// @see sound_manager_get_next_device()
  /// @see sound_manager_get_prev_device()
  /// @see sound_manager_get_device_type()
  /// @see sound_manager_get_device_io_direction()
  /// @see sound_manager_get_device_id()
  /// @see sound_manager_get_device_name()
  /// @see sound_manager_free_device_list()
  int sound_manager_get_device_state(
    sound_device_h device,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _sound_manager_get_device_state(
      device,
      state,
    );
  }

  late final _sound_manager_get_device_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_device_h,
              ffi.Pointer<ffi.Int32>)>>('sound_manager_get_device_state');
  late final _sound_manager_get_device_state =
      _sound_manager_get_device_statePtr
          .asFunction<int Function(sound_device_h, ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_add_device_connection_changed_cb() instead.
  /// @brief Registers a callback function to be invoked when the state of connection of a sound device was changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks	The initial state of sound devices connected is deactivated.
  ///
  /// @param[in]	device_mask	The mask value
  /// @param[in]	callback	The interrupted callback function
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @post  sound_device_connected_cb() will be invoked.
  /// @see sound_manager_unset_device_connected_cb()
  /// @see sound_device_connected_cb()
  int sound_manager_set_device_connected_cb(
    int device_mask,
    sound_device_connected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sound_manager_set_device_connected_cb(
      device_mask,
      callback,
      user_data,
    );
  }

  late final _sound_manager_set_device_connected_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, sound_device_connected_cb,
              ffi.Pointer<ffi.Void>)>>('sound_manager_set_device_connected_cb');
  late final _sound_manager_set_device_connected_cb =
      _sound_manager_set_device_connected_cbPtr.asFunction<
          int Function(
              int, sound_device_connected_cb, ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_remove_device_connection_changed_cb() instead.
  /// @brief Unregisters the callback function which is called when the state of connection of a sound device was changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_set_device_connected_cb()
  int sound_manager_unset_device_connected_cb() {
    return _sound_manager_unset_device_connected_cb();
  }

  late final _sound_manager_unset_device_connected_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'sound_manager_unset_device_connected_cb');
  late final _sound_manager_unset_device_connected_cb =
      _sound_manager_unset_device_connected_cbPtr.asFunction<int Function()>();

  /// @brief Adds a callback function to be invoked when the connection state of a sound device was changed.
  /// @since_tizen 3.0
  ///
  /// @param[in]	device_mask	Device masks for which changes should be tracked, values of #sound_device_mask_e combined with bitwise 'or'
  /// @param[in]	callback	The device connection state changed callback function
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @param[out]	id	The callback id
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @post  sound_device_connected_cb() will be invoked.
  /// @see sound_manager_remove_device_connection_changed_cb()
  /// @see sound_device_connection_changed_cb()
  int sound_manager_add_device_connection_changed_cb(
    int device_mask,
    sound_device_connection_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _sound_manager_add_device_connection_changed_cb(
      device_mask,
      callback,
      user_data,
      id,
    );
  }

  late final _sound_manager_add_device_connection_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, sound_device_connection_changed_cb,
                  ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Int>)>>(
      'sound_manager_add_device_connection_changed_cb');
  late final _sound_manager_add_device_connection_changed_cb =
      _sound_manager_add_device_connection_changed_cbPtr.asFunction<
          int Function(int, sound_device_connection_changed_cb,
              ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Int>)>();

  /// @brief Removes a callback function invoked when the connection of a sound device was changed.
  /// @since_tizen 3.0
  ///
  /// @param[in]	id	The id of the callback to remove
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_add_device_connection_changed_cb()
  int sound_manager_remove_device_connection_changed_cb(
    int id,
  ) {
    return _sound_manager_remove_device_connection_changed_cb(
      id,
    );
  }

  late final _sound_manager_remove_device_connection_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'sound_manager_remove_device_connection_changed_cb');
  late final _sound_manager_remove_device_connection_changed_cb =
      _sound_manager_remove_device_connection_changed_cbPtr
          .asFunction<int Function(int)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_add_device_state_changed_cb() instead.
  /// @brief Registers a callback function to be invoked when the information of a sound device was changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	device_mask	The mask value
  /// @param[in]	callback	The interrupted callback function
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @post  sound_device_information_changed_cb() will be invoked.
  /// @see sound_manager_unset_device_information_changed_cb()
  /// @see sound_device_information_changed_cb()
  int sound_manager_set_device_information_changed_cb(
    int device_mask,
    sound_device_information_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sound_manager_set_device_information_changed_cb(
      device_mask,
      callback,
      user_data,
    );
  }

  late final _sound_manager_set_device_information_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int32, sound_device_information_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'sound_manager_set_device_information_changed_cb');
  late final _sound_manager_set_device_information_changed_cb =
      _sound_manager_set_device_information_changed_cbPtr.asFunction<
          int Function(int, sound_device_information_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_remove_device_state_changed_cb() instead.
  /// @brief Unregisters the callback function which is called when the information of a sound device was changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_set_device_information_changed_cb()
  int sound_manager_unset_device_information_changed_cb() {
    return _sound_manager_unset_device_information_changed_cb();
  }

  late final _sound_manager_unset_device_information_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'sound_manager_unset_device_information_changed_cb');
  late final _sound_manager_unset_device_information_changed_cb =
      _sound_manager_unset_device_information_changed_cbPtr
          .asFunction<int Function()>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Adds a callback function to be invoked when the state of a sound device was changed.
  /// @since_tizen 3.0
  ///
  /// @param[in]	device_mask	Device masks for which changes should be tracked, values of #sound_device_mask_e combined with bitwise 'or'
  /// @param[in]	callback	The device state changed callback function
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @param[out]	id	The callback id
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @post  sound_device_state_changed_cb() will be invoked.
  /// @see sound_manager_remove_device_state_changed_cb()
  /// @see sound_device_state_connected_cb()
  int sound_manager_add_device_state_changed_cb(
    int device_mask,
    sound_device_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _sound_manager_add_device_state_changed_cb(
      device_mask,
      callback,
      user_data,
      id,
    );
  }

  late final _sound_manager_add_device_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, sound_device_state_changed_cb,
                  ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Int>)>>(
      'sound_manager_add_device_state_changed_cb');
  late final _sound_manager_add_device_state_changed_cb =
      _sound_manager_add_device_state_changed_cbPtr.asFunction<
          int Function(int, sound_device_state_changed_cb,
              ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Removes a callback function invoked when the state of a sound device was changed.
  /// @since_tizen 3.0
  ///
  /// @param[in]	id	The id of the callback to remove
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SOUND_MANAGER_ERROR_NONE Success
  /// @retval #SOUND_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SOUND_MANAGER_ERROR_INTERNAL Internal error inside the sound system
  /// @see sound_manager_add_device_state_changed_cb()
  int sound_manager_remove_device_state_changed_cb(
    int id,
  ) {
    return _sound_manager_remove_device_state_changed_cb(
      id,
    );
  }

  late final _sound_manager_remove_device_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'sound_manager_remove_device_state_changed_cb');
  late final _sound_manager_remove_device_state_changed_cb =
      _sound_manager_remove_device_state_changed_cbPtr
          .asFunction<int Function(int)>();

  /// @brief Creates an audio device instance and returns an input handle to record PCM (pulse-code modulation) data.
  ///
  /// @details This function is used for audio input initialization.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  ///
  /// @remarks @a input must be released using audio_in_destroy().
  ///
  /// @param[in] sample_rate The audio sample rate in 8000[Hz] ~ 48000[Hz]
  /// @param[in] channel The audio channel type (mono or stereo)
  /// @param[in] type The type of audio sample (8- or 16-bit)
  /// @param[out] input An audio input handle is created on success
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #AUDIO_IO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #AUDIO_IO_ERROR_DEVICE_NOT_OPENED Device not opened
  /// @retval #AUDIO_IO_ERROR_SOUND_POLICY Sound policy error
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @post The state will be #AUDIO_IO_STATE_IDLE.\n
  /// audio_in_set_sound_stream_info() is recommended to be called after this API.
  /// @see audio_in_destroy()
  int audio_in_create(
    int sample_rate,
    int channel,
    int type,
    ffi.Pointer<audio_in_h> input,
  ) {
    return _audio_in_create(
      sample_rate,
      channel,
      type,
      input,
    );
  }

  late final _audio_in_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int32, ffi.Int32,
              ffi.Pointer<audio_in_h>)>>('audio_in_create');
  late final _audio_in_create = _audio_in_createPtr
      .asFunction<int Function(int, int, int, ffi.Pointer<audio_in_h>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Creates an audio loopback device instance and returns an input handle to record PCM (pulse-code modulation) data.
  ///
  /// @details This function is used for audio loopback input initialization.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  ///
  /// @remarks @a input must be released using audio_in_destroy().
  ///
  /// @param[in] sample_rate The audio sample rate in 8000[Hz] ~ 48000[Hz]
  /// @param[in] channel The audio channel type, mono, or stereo
  /// @param[in] type The type of audio sample (8- or 16-bit)
  /// @param[out] input An audio input handle will be created, if successful
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #AUDIO_IO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #AUDIO_IO_ERROR_DEVICE_NOT_OPENED Device not opened
  /// @retval #AUDIO_IO_ERROR_SOUND_POLICY Sound policy error
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see audio_in_destroy()
  int audio_in_create_loopback(
    int sample_rate,
    int channel,
    int type,
    ffi.Pointer<audio_in_h> input,
  ) {
    return _audio_in_create_loopback(
      sample_rate,
      channel,
      type,
      input,
    );
  }

  late final _audio_in_create_loopbackPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int32, ffi.Int32,
              ffi.Pointer<audio_in_h>)>>('audio_in_create_loopback');
  late final _audio_in_create_loopback = _audio_in_create_loopbackPtr
      .asFunction<int Function(int, int, int, ffi.Pointer<audio_in_h>)>();

  /// @brief Releases the audio input handle and all its resources associated with an audio stream.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input to destroy
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_DEVICE_NOT_CLOSED Device not closed
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see audio_in_create()
  int audio_in_destroy(
    audio_in_h input,
  ) {
    return _audio_in_destroy(
      input,
    );
  }

  late final _audio_in_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_destroy');
  late final _audio_in_destroy =
      _audio_in_destroyPtr.asFunction<int Function(audio_in_h)>();

  /// @brief Sets the sound stream information to the audio input.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks @a the sound stream information includes audio routing and volume type.
  /// For more details, you can refer to @ref CAPI_MEDIA_SOUND_MANAGER_MODULE
  /// System, Alarm, Notification, Emergency, Voice Information, Ringtone VOIP and Ringtone Call stream types are not supported in this API.
  ///
  /// @param[in] input The handle to the audio input
  /// @param[in] stream_info The handle of stream information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED_TYPE Not supported stream type
  ///
  /// @pre The state should be #AUDIO_IO_STATE_IDLE.\n
  /// Call audio_in_create() before calling this function.
  /// @post Call audio_in_prepare() after calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  int audio_in_set_sound_stream_info(
    audio_in_h input,
    sound_stream_info_h stream_info,
  ) {
    return _audio_in_set_sound_stream_info(
      input,
      stream_info,
    );
  }

  late final _audio_in_set_sound_stream_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_in_h,
              sound_stream_info_h)>>('audio_in_set_sound_stream_info');
  late final _audio_in_set_sound_stream_info =
      _audio_in_set_sound_stream_infoPtr
          .asFunction<int Function(audio_in_h, sound_stream_info_h)>();

  /// @brief Prepares the audio input for reading audio data by starting buffering of audio data from the device.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @retval #AUDIO_IO_ERROR_DEVICE_POLICY_RESTRICTION Device policy restriction
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @post The state will be #AUDIO_IO_STATE_RUNNING.
  /// @see audio_in_unprepare()
  int audio_in_prepare(
    audio_in_h input,
  ) {
    return _audio_in_prepare(
      input,
    );
  }

  late final _audio_in_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_prepare');
  late final _audio_in_prepare =
      _audio_in_preparePtr.asFunction<int Function(audio_in_h)>();

  /// @brief Unprepares the audio input.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @post The state will be #AUDIO_IO_STATE_IDLE.
  /// @see audio_in_prepare()
  int audio_in_unprepare(
    audio_in_h input,
  ) {
    return _audio_in_unprepare(
      input,
    );
  }

  late final _audio_in_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_unprepare');
  late final _audio_in_unprepare =
      _audio_in_unpreparePtr.asFunction<int Function(audio_in_h)>();

  /// @brief Pauses buffering of audio data from the device.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] input The handle to the audio input
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @pre The state should be #AUDIO_IO_STATE_RUNNING.
  /// @post The state will be #AUDIO_IO_STATE_PAUSED.
  /// @see audio_in_resume()
  int audio_in_pause(
    audio_in_h input,
  ) {
    return _audio_in_pause(
      input,
    );
  }

  late final _audio_in_pausePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_pause');
  late final _audio_in_pause =
      _audio_in_pausePtr.asFunction<int Function(audio_in_h)>();

  /// @brief Resumes buffering audio data from the device.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] input The handle to the audio input
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @pre The state should be #AUDIO_IO_STATE_PAUSED.
  /// @post The state will be #AUDIO_IO_STATE_RUNNING.
  /// @see audio_in_pause()
  int audio_in_resume(
    audio_in_h input,
  ) {
    return _audio_in_resume(
      input,
    );
  }

  late final _audio_in_resumePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_resume');
  late final _audio_in_resume =
      _audio_in_resumePtr.asFunction<int Function(audio_in_h)>();

  /// @brief Flushes and discards buffered audio data from the input stream.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @pre The state should be #AUDIO_IO_STATE_RUNNING or #AUDIO_IO_STATE_PAUSED.
  int audio_in_flush(
    audio_in_h input,
  ) {
    return _audio_in_flush(
      input,
    );
  }

  late final _audio_in_flushPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_flush');
  late final _audio_in_flush =
      _audio_in_flushPtr.asFunction<int Function(audio_in_h)>();

  /// @brief Reads audio data from the audio input buffer.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @param[out] buffer The PCM buffer address
  /// @param[in] length The length of the PCM data buffer (in bytes)
  /// @return The number of read bytes on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_BUFFER Invalid buffer pointer
  /// @retval #AUDIO_IO_ERROR_SOUND_POLICY Sound policy error
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre The state should be #AUDIO_IO_STATE_RUNNING.
  int audio_in_read(
    audio_in_h input,
    ffi.Pointer<ffi.Void> buffer,
    int length,
  ) {
    return _audio_in_read(
      input,
      buffer,
      length,
    );
  }

  late final _audio_in_readPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_in_h, ffi.Pointer<ffi.Void>,
              ffi.UnsignedInt)>>('audio_in_read');
  late final _audio_in_read = _audio_in_readPtr
      .asFunction<int Function(audio_in_h, ffi.Pointer<ffi.Void>, int)>();

  /// @brief Gets the size to be allocated for the audio input buffer.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @param[out] size The buffer size (in bytes, the maximum size is 1 MB)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @see audio_in_read()
  int audio_in_get_buffer_size(
    audio_in_h input,
    ffi.Pointer<ffi.Int> size,
  ) {
    return _audio_in_get_buffer_size(
      input,
      size,
    );
  }

  late final _audio_in_get_buffer_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              audio_in_h, ffi.Pointer<ffi.Int>)>>('audio_in_get_buffer_size');
  late final _audio_in_get_buffer_size = _audio_in_get_buffer_sizePtr
      .asFunction<int Function(audio_in_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the sample rate of the audio input data stream.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @param[out] sample_rate The audio sample rate in Hertz (8000 ~ 48000)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  int audio_in_get_sample_rate(
    audio_in_h input,
    ffi.Pointer<ffi.Int> sample_rate,
  ) {
    return _audio_in_get_sample_rate(
      input,
      sample_rate,
    );
  }

  late final _audio_in_get_sample_ratePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              audio_in_h, ffi.Pointer<ffi.Int>)>>('audio_in_get_sample_rate');
  late final _audio_in_get_sample_rate = _audio_in_get_sample_ratePtr
      .asFunction<int Function(audio_in_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the channel type of the audio input data stream.
  ///
  /// @details The audio channel type defines whether the audio is mono or stereo.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @param[out] channel The audio channel type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  int audio_in_get_channel(
    audio_in_h input,
    ffi.Pointer<ffi.Int32> channel,
  ) {
    return _audio_in_get_channel(
      input,
      channel,
    );
  }

  late final _audio_in_get_channelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              audio_in_h, ffi.Pointer<ffi.Int32>)>>('audio_in_get_channel');
  late final _audio_in_get_channel = _audio_in_get_channelPtr
      .asFunction<int Function(audio_in_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the sample audio format (8-bit or 16-bit) of the audio input data stream.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @param[out] type The audio sample type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  int audio_in_get_sample_type(
    audio_in_h input,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _audio_in_get_sample_type(
      input,
      type,
    );
  }

  late final _audio_in_get_sample_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              audio_in_h, ffi.Pointer<ffi.Int32>)>>('audio_in_get_sample_type');
  late final _audio_in_get_sample_type = _audio_in_get_sample_typePtr
      .asFunction<int Function(audio_in_h, ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Registers a callback function to be invoked when the audio input handle is interrupted or the interrupt is completed.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @post audio_io_interrupted_cb() will be invoked.
  ///
  /// @see audio_in_unset_interrupted_cb()
  /// @see audio_io_interrupted_cb()
  int audio_in_set_interrupted_cb(
    audio_in_h input,
    audio_io_interrupted_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _audio_in_set_interrupted_cb(
      input,
      callback,
      user_data,
    );
  }

  late final _audio_in_set_interrupted_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_in_h, audio_io_interrupted_cb,
              ffi.Pointer<ffi.Void>)>>('audio_in_set_interrupted_cb');
  late final _audio_in_set_interrupted_cb =
      _audio_in_set_interrupted_cbPtr.asFunction<
          int Function(
              audio_in_h, audio_io_interrupted_cb, ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 3.0
  /// @brief Unregisters the callback function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see audio_in_set_interrupted_cb()
  int audio_in_unset_interrupted_cb(
    audio_in_h input,
  ) {
    return _audio_in_unset_interrupted_cb(
      input,
    );
  }

  late final _audio_in_unset_interrupted_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_unset_interrupted_cb');
  late final _audio_in_unset_interrupted_cb =
      _audio_in_unset_interrupted_cbPtr.asFunction<int Function(audio_in_h)>();

  /// @deprecated Deprecated since 3.0
  /// @brief Ignores session for input.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  int audio_in_ignore_session(
    audio_in_h input,
  ) {
    return _audio_in_ignore_session(
      input,
    );
  }

  late final _audio_in_ignore_sessionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_ignore_session');
  late final _audio_in_ignore_session =
      _audio_in_ignore_sessionPtr.asFunction<int Function(audio_in_h)>();

  /// @brief Sets an asynchronous(event) callback function to handle recording PCM (pulse-code modulation) data.
  ///
  /// @details @a callback will be called when you can read a PCM data.
  /// It might cause dead lock if change the state of audio handle in callback.
  /// (ex: audio_in_destroy, audio_in_prepare, audio_in_unprepare)
  /// Recommend to use as a VOIP only.
  /// Recommend not to hold callback too long.(it affects latency)
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks @a input must be created using audio_in_create().
  ///
  /// @param[in] input    An audio input handle
  /// @param[in] callback notify stream callback when user can read data (#audio_in_stream_cb)
  /// @param[in] user_data user data to be retrieved when callback is called
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #AUDIO_IO_ERROR_DEVICE_NOT_OPENED Device not opened
  /// @retval #AUDIO_IO_ERROR_SOUND_POLICY Sound policy error
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see audio_out_set_stream_cb()
  int audio_in_set_stream_cb(
    audio_in_h input,
    audio_in_stream_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _audio_in_set_stream_cb(
      input,
      callback,
      user_data,
    );
  }

  late final _audio_in_set_stream_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_in_h, audio_in_stream_cb,
              ffi.Pointer<ffi.Void>)>>('audio_in_set_stream_cb');
  late final _audio_in_set_stream_cb = _audio_in_set_stream_cbPtr.asFunction<
      int Function(audio_in_h, audio_in_stream_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] input The handle to the audio input
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see audio_in_set_interrupted_cb()
  int audio_in_unset_stream_cb(
    audio_in_h input,
  ) {
    return _audio_in_unset_stream_cb(
      input,
    );
  }

  late final _audio_in_unset_stream_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_unset_stream_cb');
  late final _audio_in_unset_stream_cb =
      _audio_in_unset_stream_cbPtr.asFunction<int Function(audio_in_h)>();

  /// @brief peek from audio in buffer
  ///
  /// @details This function works correctly only with read, write callback. Otherwise it won't operate as intended.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks @a Works only in asynchronous(event) mode. This will just retrieve buffer pointer from audio in buffer. Drop after use.
  ///
  /// @param[in] input The handle to the audio input
  /// @param[out] buffer start buffer pointer of peeked audio in data
  /// @param[out] length amount of audio in data to be peeked
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @pre The state should be #AUDIO_IO_STATE_RUNNING.
  /// @see audio_in_drop()
  int audio_in_peek(
    audio_in_h input,
    ffi.Pointer<ffi.Pointer<ffi.Void>> buffer,
    ffi.Pointer<ffi.UnsignedInt> length,
  ) {
    return _audio_in_peek(
      input,
      buffer,
      length,
    );
  }

  late final _audio_in_peekPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_in_h, ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.UnsignedInt>)>>('audio_in_peek');
  late final _audio_in_peek = _audio_in_peekPtr.asFunction<
      int Function(audio_in_h, ffi.Pointer<ffi.Pointer<ffi.Void>>,
          ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief drop peeked audio buffer.
  ///
  /// @details This function works correctly only with read, write callback. Otherwise it won't operate as intended.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks @a Works only in asynchronous(event) mode. This will remove audio in data from actual stream buffer. Use this if peeked data is not needed anymore.
  ///
  /// @param[in] input The handle to the audio input
  /// @return 0 on success, otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @pre The state should be #AUDIO_IO_STATE_RUNNING.
  /// @see audio_in_peek()
  int audio_in_drop(
    audio_in_h input,
  ) {
    return _audio_in_drop(
      input,
    );
  }

  late final _audio_in_dropPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_drop');
  late final _audio_in_drop =
      _audio_in_dropPtr.asFunction<int Function(audio_in_h)>();

  /// @brief Sets the state changed callback function to the audio input handle.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks @a input must be created using audio_in_create().
  ///
  /// @param[in] input    The audio input handle
  /// @param[in] callback the state changed callback called when the state of the handle is changed (#audio_in_state_changed_cb)
  /// @param[in] user_data user data to be retrieved when callback is called
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see audio_in_unset_state_changed_cb()
  int audio_in_set_state_changed_cb(
    audio_in_h input,
    audio_in_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _audio_in_set_state_changed_cb(
      input,
      callback,
      user_data,
    );
  }

  late final _audio_in_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_in_h, audio_in_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('audio_in_set_state_changed_cb');
  late final _audio_in_set_state_changed_cb =
      _audio_in_set_state_changed_cbPtr.asFunction<
          int Function(
              audio_in_h, audio_in_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the state changed callback function of the audio input handle.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] input The handle to the audio input
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see audio_in_set_state_changed_cb()
  int audio_in_unset_state_changed_cb(
    audio_in_h input,
  ) {
    return _audio_in_unset_state_changed_cb(
      input,
    );
  }

  late final _audio_in_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_in_h)>>(
          'audio_in_unset_state_changed_cb');
  late final _audio_in_unset_state_changed_cb =
      _audio_in_unset_state_changed_cbPtr
          .asFunction<int Function(audio_in_h)>();

  /// @deprecated Deprecated since 3.0. Use audio_out_create_new() instead.
  /// @brief Creates an audio device instance and returns an output handle to play PCM (pulse-code modulation) data.
  ///
  /// @details This function is used for audio output initialization.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks @a output must be released by audio_out_destroy().
  ///
  /// @param[in] sample_rate The audio sample rate in 8000[Hz] ~ 48000[Hz]
  /// @param[in] channel The audio channel type (mono or stereo)
  /// @param[in] type The type of audio sample (8-bit or 16-bit)
  /// @param[in] sound_type The type of sound (#sound_type_e)
  /// @param[out] output An audio output handle is created on success
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #AUDIO_IO_ERROR_DEVICE_NOT_OPENED Device not opened
  /// @retval #AUDIO_IO_ERROR_SOUND_POLICY Sound policy error
  ///
  /// @see audio_out_destroy()
  int audio_out_create(
    int sample_rate,
    int channel,
    int type,
    int sound_type,
    ffi.Pointer<audio_out_h> output,
  ) {
    return _audio_out_create(
      sample_rate,
      channel,
      type,
      sound_type,
      output,
    );
  }

  late final _audio_out_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int32, ffi.Int32, ffi.Int32,
              ffi.Pointer<audio_out_h>)>>('audio_out_create');
  late final _audio_out_create = _audio_out_createPtr
      .asFunction<int Function(int, int, int, int, ffi.Pointer<audio_out_h>)>();

  /// @brief Creates an audio device instance and returns an output handle to play PCM (pulse-code modulation) data.
  ///
  /// @details This function is used for audio output initialization.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks @a output must be released by audio_out_destroy().
  /// It is recommended to call audio_out_set_sound_stream_info() after this API.
  ///
  /// @param[in] sample_rate The audio sample rate in 8000[Hz] ~ 48000[Hz]
  /// @param[in] channel The audio channel type (mono or stereo)
  /// @param[in] type The type of audio sample (8-bit or 16-bit)
  /// @param[out] output An audio output handle is created on success
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #AUDIO_IO_ERROR_DEVICE_NOT_OPENED Device not opened
  /// @retval #AUDIO_IO_ERROR_SOUND_POLICY Sound policy error
  ///
  /// @post The state will be #AUDIO_IO_STATE_IDLE.\n
  /// audio_out_set_sound_stream_info() is recommended to be called after this API.
  /// @see audio_out_destroy()
  int audio_out_create_new(
    int sample_rate,
    int channel,
    int type,
    ffi.Pointer<audio_out_h> output,
  ) {
    return _audio_out_create_new(
      sample_rate,
      channel,
      type,
      output,
    );
  }

  late final _audio_out_create_newPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int32, ffi.Int32,
              ffi.Pointer<audio_out_h>)>>('audio_out_create_new');
  late final _audio_out_create_new = _audio_out_create_newPtr
      .asFunction<int Function(int, int, int, ffi.Pointer<audio_out_h>)>();

  /// @brief Releases the audio output handle, along with all its resources.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output to destroy
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #AUDIO_IO_ERROR_DEVICE_NOT_CLOSED Device not closed
  ///
  /// @see audio_out_create()
  int audio_out_destroy(
    audio_out_h output,
  ) {
    return _audio_out_destroy(
      output,
    );
  }

  late final _audio_out_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_destroy');
  late final _audio_out_destroy =
      _audio_out_destroyPtr.asFunction<int Function(audio_out_h)>();

  /// @brief Sets the sound stream information to the audio output.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks @a the sound stream information includes audio routing and volume type.
  /// For more details, you can refer to @ref CAPI_MEDIA_SOUND_MANAGER_MODULE
  /// Voice Recognition and Loopback stream types are not supported in this API.
  ///
  /// @param[in] output The handle to the audio output
  /// @param[in] stream_info The handle of stream information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED Not supported
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  /// @retval #AUDIO_IO_ERROR_NOT_SUPPORTED_TYPE Not supported stream type
  ///
  /// @pre The state should be #AUDIO_IO_STATE_IDLE.\n
  /// Call audio_out_create_new() before calling this function.
  /// @post Call audio_out_prepare() after calling this function.
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  int audio_out_set_sound_stream_info(
    audio_out_h output,
    sound_stream_info_h stream_info,
  ) {
    return _audio_out_set_sound_stream_info(
      output,
      stream_info,
    );
  }

  late final _audio_out_set_sound_stream_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_out_h,
              sound_stream_info_h)>>('audio_out_set_sound_stream_info');
  late final _audio_out_set_sound_stream_info =
      _audio_out_set_sound_stream_infoPtr
          .asFunction<int Function(audio_out_h, sound_stream_info_h)>();

  /// @brief Prepares the audio output for playback, this must be called before audio_out_write().
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @post The state will be #AUDIO_IO_STATE_RUNNING.
  /// @see audio_out_unprepare()
  int audio_out_prepare(
    audio_out_h output,
  ) {
    return _audio_out_prepare(
      output,
    );
  }

  late final _audio_out_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_prepare');
  late final _audio_out_prepare =
      _audio_out_preparePtr.asFunction<int Function(audio_out_h)>();

  /// @brief Unprepares the audio output.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @post The state will be #AUDIO_IO_STATE_IDLE.
  /// @see audio_out_prepare()
  int audio_out_unprepare(
    audio_out_h output,
  ) {
    return _audio_out_unprepare(
      output,
    );
  }

  late final _audio_out_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_unprepare');
  late final _audio_out_unprepare =
      _audio_out_unpreparePtr.asFunction<int Function(audio_out_h)>();

  /// @brief Pauses feeding of audio data to the device.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] output The handle to the audio output
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @pre The state should be #AUDIO_IO_STATE_RUNNING.
  /// @post The state will be #AUDIO_IO_STATE_PAUSED.
  /// @see audio_out_resume()
  int audio_out_pause(
    audio_out_h output,
  ) {
    return _audio_out_pause(
      output,
    );
  }

  late final _audio_out_pausePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_pause');
  late final _audio_out_pause =
      _audio_out_pausePtr.asFunction<int Function(audio_out_h)>();

  /// @brief Resumes feeding of audio data to the device.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] output The handle to the audio output
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @pre The state should be #AUDIO_IO_STATE_PAUSED.
  /// @post The state will be #AUDIO_IO_STATE_RUNNING.
  /// @see audio_out_pause()
  int audio_out_resume(
    audio_out_h output,
  ) {
    return _audio_out_resume(
      output,
    );
  }

  late final _audio_out_resumePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_resume');
  late final _audio_out_resume =
      _audio_out_resumePtr.asFunction<int Function(audio_out_h)>();

  /// @brief Drains buffered audio data from the output stream.
  ///
  /// @details This function waits until drains stream buffer completely. (e.g end of playback)
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @pre The state should be #AUDIO_IO_STATE_RUNNING or #AUDIO_IO_STATE_PAUSED.
  /// @see audio_out_flush()
  int audio_out_drain(
    audio_out_h output,
  ) {
    return _audio_out_drain(
      output,
    );
  }

  late final _audio_out_drainPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_drain');
  late final _audio_out_drain =
      _audio_out_drainPtr.asFunction<int Function(audio_out_h)>();

  /// @brief Flushes and discards buffered audio data from the output stream.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @pre The state should be #AUDIO_IO_STATE_RUNNING or #AUDIO_IO_STATE_PAUSED.
  /// @see audio_out_drain()
  int audio_out_flush(
    audio_out_h output,
  ) {
    return _audio_out_flush(
      output,
    );
  }

  late final _audio_out_flushPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_flush');
  late final _audio_out_flush =
      _audio_out_flushPtr.asFunction<int Function(audio_out_h)>();

  /// @brief Starts writing the audio data to the device.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @param[in,out] buffer The PCM buffer address
  /// @param[in] length The length of the PCM buffer (in bytes)
  /// @return The written data size on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_BUFFER Invalid buffer pointer
  /// @retval #AUDIO_IO_ERROR_SOUND_POLICY Sound policy error
  /// @retval #AUDIO_IO_ERROR_INVALID_STATE Invalid state
  ///
  /// @pre The state should be #AUDIO_IO_STATE_RUNNING.
  int audio_out_write(
    audio_out_h output,
    ffi.Pointer<ffi.Void> buffer,
    int length,
  ) {
    return _audio_out_write(
      output,
      buffer,
      length,
    );
  }

  late final _audio_out_writePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_out_h, ffi.Pointer<ffi.Void>,
              ffi.UnsignedInt)>>('audio_out_write');
  late final _audio_out_write = _audio_out_writePtr
      .asFunction<int Function(audio_out_h, ffi.Pointer<ffi.Void>, int)>();

  /// @brief Gets the size to be allocated for the audio output buffer.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @param[out] size The suggested buffer size (in bytes, the maximum size is 1 MB)
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #AUDIO_IO_ERROR_NONE Successful
  /// @retval  #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see audio_out_write()
  int audio_out_get_buffer_size(
    audio_out_h output,
    ffi.Pointer<ffi.Int> size,
  ) {
    return _audio_out_get_buffer_size(
      output,
      size,
    );
  }

  late final _audio_out_get_buffer_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              audio_out_h, ffi.Pointer<ffi.Int>)>>('audio_out_get_buffer_size');
  late final _audio_out_get_buffer_size = _audio_out_get_buffer_sizePtr
      .asFunction<int Function(audio_out_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the sample rate of the audio output data stream.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @param[out] sample_rate The audio sample rate in Hertz (8000 ~ 48000)
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #AUDIO_IO_ERROR_NONE Successful
  /// @retval  #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_out_get_sample_rate(
    audio_out_h output,
    ffi.Pointer<ffi.Int> sample_rate,
  ) {
    return _audio_out_get_sample_rate(
      output,
      sample_rate,
    );
  }

  late final _audio_out_get_sample_ratePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              audio_out_h, ffi.Pointer<ffi.Int>)>>('audio_out_get_sample_rate');
  late final _audio_out_get_sample_rate = _audio_out_get_sample_ratePtr
      .asFunction<int Function(audio_out_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the channel type of the audio output data stream.
  ///
  /// @details The audio channel type defines whether the audio is mono or stereo.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @param[out] channel The audio channel type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_out_get_channel(
    audio_out_h output,
    ffi.Pointer<ffi.Int32> channel,
  ) {
    return _audio_out_get_channel(
      output,
      channel,
    );
  }

  late final _audio_out_get_channelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              audio_out_h, ffi.Pointer<ffi.Int32>)>>('audio_out_get_channel');
  late final _audio_out_get_channel = _audio_out_get_channelPtr
      .asFunction<int Function(audio_out_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the sample audio format (8-bit or 16-bit) of the audio output data stream.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @param[out] type The audio sample type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_out_get_sample_type(
    audio_out_h output,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _audio_out_get_sample_type(
      output,
      type,
    );
  }

  late final _audio_out_get_sample_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_out_h,
              ffi.Pointer<ffi.Int32>)>>('audio_out_get_sample_type');
  late final _audio_out_get_sample_type = _audio_out_get_sample_typePtr
      .asFunction<int Function(audio_out_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the sound type supported by the audio output device.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @param[out] type The sound type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  int audio_out_get_sound_type(
    audio_out_h output,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _audio_out_get_sound_type(
      output,
      type,
    );
  }

  late final _audio_out_get_sound_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_out_h,
              ffi.Pointer<ffi.Int32>)>>('audio_out_get_sound_type');
  late final _audio_out_get_sound_type = _audio_out_get_sound_typePtr
      .asFunction<int Function(audio_out_h, ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() instead.
  /// @brief Registers a callback function to be invoked when the audio output handle is interrupted or the interrupt is completed.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @post audio_io_interrupted_cb() will be invoked.
  /// @see audio_out_unset_interrupted_cb()
  /// @see audio_io_interrupted_cb()
  int audio_out_set_interrupted_cb(
    audio_out_h output,
    audio_io_interrupted_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _audio_out_set_interrupted_cb(
      output,
      callback,
      user_data,
    );
  }

  late final _audio_out_set_interrupted_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_out_h, audio_io_interrupted_cb,
              ffi.Pointer<ffi.Void>)>>('audio_out_set_interrupted_cb');
  late final _audio_out_set_interrupted_cb =
      _audio_out_set_interrupted_cbPtr.asFunction<
          int Function(
              audio_out_h, audio_io_interrupted_cb, ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 3.0
  /// @brief Unregisters the callback function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see audio_out_set_interrupted_cb()
  int audio_out_unset_interrupted_cb(
    audio_out_h output,
  ) {
    return _audio_out_unset_interrupted_cb(
      output,
    );
  }

  late final _audio_out_unset_interrupted_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_unset_interrupted_cb');
  late final _audio_out_unset_interrupted_cb =
      _audio_out_unset_interrupted_cbPtr
          .asFunction<int Function(audio_out_h)>();

  /// @deprecated Deprecated since 3.0
  /// @brief Ignores session for output.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  int audio_out_ignore_session(
    audio_out_h output,
  ) {
    return _audio_out_ignore_session(
      output,
    );
  }

  late final _audio_out_ignore_sessionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_ignore_session');
  late final _audio_out_ignore_session =
      _audio_out_ignore_sessionPtr.asFunction<int Function(audio_out_h)>();

  /// @brief Sets an asynchronous(event) callback function to handle playing PCM (pulse-code modulation) data.
  ///
  /// @details @a callback will be called when you can write a PCM data.
  /// It might cause dead lock if change the state of audio handle in callback.
  /// (ex: audio_out_destroy, audio_out_prepare, audio_out_unprepare)
  /// Recommend to use as a VOIP only.
  /// Recommend not to hold callback too long.(it affects latency)
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks @a output must be created using audio_out_create().
  ///
  /// @param[in] output   An audio output handle
  /// @param[in] callback notify stream callback when user can write data (#audio_out_stream_cb)
  /// @param[in] user_data user data to be retrieved when callback is called
  /// @return 0 on success, otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #AUDIO_IO_ERROR_DEVICE_NOT_OPENED Device not opened
  /// @retval #AUDIO_IO_ERROR_SOUND_POLICY Sound policy error
  ///
  /// @see audio_out_unset_stream_cb()
  int audio_out_set_stream_cb(
    audio_out_h output,
    audio_out_stream_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _audio_out_set_stream_cb(
      output,
      callback,
      user_data,
    );
  }

  late final _audio_out_set_stream_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_out_h, audio_out_stream_cb,
              ffi.Pointer<ffi.Void>)>>('audio_out_set_stream_cb');
  late final _audio_out_set_stream_cb = _audio_out_set_stream_cbPtr.asFunction<
      int Function(audio_out_h, audio_out_stream_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] output The handle to the audio output
  /// @return 0 on success, otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #AUDIO_IO_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see audio_out_set_stream_cb()
  int audio_out_unset_stream_cb(
    audio_out_h output,
  ) {
    return _audio_out_unset_stream_cb(
      output,
    );
  }

  late final _audio_out_unset_stream_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_unset_stream_cb');
  late final _audio_out_unset_stream_cb =
      _audio_out_unset_stream_cbPtr.asFunction<int Function(audio_out_h)>();

  /// @brief Sets the state changed callback function to the audio output handle.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks @a input must be created using audio_out_create_new().
  ///
  /// @param[in] output    The audio output handle
  /// @param[in] callback the state changed callback called when the state of the handle is changed (#audio_out_state_changed_cb)
  /// @param[in] user_data user data to be retrieved when callback is called
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see audio_out_unset_state_changed_cb()
  int audio_out_set_state_changed_cb(
    audio_out_h output,
    audio_out_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _audio_out_set_state_changed_cb(
      output,
      callback,
      user_data,
    );
  }

  late final _audio_out_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(audio_out_h, audio_out_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('audio_out_set_state_changed_cb');
  late final _audio_out_set_state_changed_cb =
      _audio_out_set_state_changed_cbPtr.asFunction<
          int Function(audio_out_h, audio_out_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the state changed callback function of the audio output handle.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] output The handle to the audio output
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #AUDIO_IO_ERROR_NONE Successful
  /// @retval #AUDIO_IO_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see audio_out_set_state_changed_cb()
  int audio_out_unset_state_changed_cb(
    audio_out_h output,
  ) {
    return _audio_out_unset_state_changed_cb(
      output,
    );
  }

  late final _audio_out_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(audio_out_h)>>(
          'audio_out_unset_state_changed_cb');
  late final _audio_out_unset_state_changed_cb =
      _audio_out_unset_state_changed_cbPtr
          .asFunction<int Function(audio_out_h)>();

  /// @brief Creates a media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @details	It creates media format. and reference count will be set to 1
  /// For destroying media_format_h handle, use media_format_unref().
  /// @param[out] fmt allocated media_format_h
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_ref()
  /// @see media_format_unref()
  int media_format_create(
    ffi.Pointer<media_format_h> fmt,
  ) {
    return _media_format_create(
      fmt,
    );
  }

  late final _media_format_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<media_format_h>)>>(
      'media_format_create');
  late final _media_format_create = _media_format_createPtr
      .asFunction<int Function(ffi.Pointer<media_format_h>)>();

  /// @brief Gets format type of media format.
  /// @since_tizen 3.0
  /// @param[in] fmt The media_format_h to get format type
  /// @param[out] formattype The media_format_type_e, ex) MEDIA_FORMAT_AUDIO
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  int media_format_get_type(
    media_format_h fmt,
    ffi.Pointer<ffi.Int32> formattype,
  ) {
    return _media_format_get_type(
      fmt,
      formattype,
    );
  }

  late final _media_format_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_format_h,
              ffi.Pointer<ffi.Int32>)>>('media_format_get_type');
  late final _media_format_get_type = _media_format_get_typePtr
      .asFunction<int Function(media_format_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets container MIME type of media format.
  /// @since_tizen 3.0
  /// @param[in] fmt The media_format_h to get container mime type
  /// @param[out] mimetype The media_format_mimetype_e, ex) MEDIA_FORMAT_CONTAINER_MP4
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_set_container_mime()
  int media_format_get_container_mime(
    media_format_h fmt,
    ffi.Pointer<ffi.Int32> mimetype,
  ) {
    return _media_format_get_container_mime(
      fmt,
      mimetype,
    );
  }

  late final _media_format_get_container_mimePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_format_h,
              ffi.Pointer<ffi.Int32>)>>('media_format_get_container_mime');
  late final _media_format_get_container_mime =
      _media_format_get_container_mimePtr
          .asFunction<int Function(media_format_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets text track information of media format.
  /// @since_tizen 3.0
  /// @param[in] fmt The media_format_h to get text information
  /// @param[out] mimetype The media_format_mimetype_e, ex) MEDIA_FORMAT_TEXT_MP4
  /// @param[out] type The media_format_text_type_e
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_set_text_mime()
  int media_format_get_text_info(
    media_format_h fmt,
    ffi.Pointer<ffi.Int32> mimetype,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _media_format_get_text_info(
      fmt,
      mimetype,
      type,
    );
  }

  late final _media_format_get_text_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_format_h, ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Int32>)>>('media_format_get_text_info');
  late final _media_format_get_text_info =
      _media_format_get_text_infoPtr.asFunction<
          int Function(media_format_h, ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets video information of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @details   returns mimetype, width, height, average bps, max bps of this media format.
  /// @param[in] fmt media_format_h to get video information
  /// @param[out] mimetype media_format_mimetype_e , ex) MEDIA_FORMAT_H264_HP
  /// @param[out] width width of the video
  /// @param[out] height height of the video
  /// @param[out] avg_bps average bps of the video
  /// @param[out] max_bps max bps of the video
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_set_video_mime()
  /// @see media_format_set_video_width()
  /// @see media_format_set_video_height()
  /// @see media_format_set_video_avg_bps()
  /// @see media_format_set_video_max_bps()
  int media_format_get_video_info(
    media_format_h fmt,
    ffi.Pointer<ffi.Int32> mimetype,
    ffi.Pointer<ffi.Int> width,
    ffi.Pointer<ffi.Int> height,
    ffi.Pointer<ffi.Int> avg_bps,
    ffi.Pointer<ffi.Int> max_bps,
  ) {
    return _media_format_get_video_info(
      fmt,
      mimetype,
      width,
      height,
      avg_bps,
      max_bps,
    );
  }

  late final _media_format_get_video_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_format_h,
              ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('media_format_get_video_info');
  late final _media_format_get_video_info =
      _media_format_get_video_infoPtr.asFunction<
          int Function(
              media_format_h,
              ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets audio information of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @details   returns mimetype, channels, height, samplerate bps, max bps of this media format.
  /// @param[in] fmt media_format_h to get audio information
  /// @param[out] mimetype media_format_mimetype_e , ex) MEDIA_FORMAT_PCM
  /// @param[out] channel channel of the audio
  /// @param[out] samplerate sampling rate of the audio
  /// @param[out] bit bit resolution of the audio
  /// @param[out] avg_bps average bps of the audio
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_set_audio_mime()
  /// @see media_format_set_audio_channel()
  /// @see media_format_set_audio_samplerate()
  /// @see media_format_set_audio_bit()
  /// @see media_format_set_audio_avg_bps()
  int media_format_get_audio_info(
    media_format_h fmt,
    ffi.Pointer<ffi.Int32> mimetype,
    ffi.Pointer<ffi.Int> channel,
    ffi.Pointer<ffi.Int> samplerate,
    ffi.Pointer<ffi.Int> bit,
    ffi.Pointer<ffi.Int> avg_bps,
  ) {
    return _media_format_get_audio_info(
      fmt,
      mimetype,
      channel,
      samplerate,
      bit,
      avg_bps,
    );
  }

  late final _media_format_get_audio_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_format_h,
              ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('media_format_get_audio_info');
  late final _media_format_get_audio_info =
      _media_format_get_audio_infoPtr.asFunction<
          int Function(
              media_format_h,
              ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets audio aac type of media format.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] fmt media_format_h to get audio information
  /// @param[out] is_adts AAC ADTS flag of the audio
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_set_audio_aac_type()
  int media_format_get_audio_aac_type(
    media_format_h fmt,
    ffi.Pointer<ffi.Bool> is_adts,
  ) {
    return _media_format_get_audio_aac_type(
      fmt,
      is_adts,
    );
  }

  late final _media_format_get_audio_aac_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_format_h,
              ffi.Pointer<ffi.Bool>)>>('media_format_get_audio_aac_type');
  late final _media_format_get_audio_aac_type =
      _media_format_get_audio_aac_typePtr
          .asFunction<int Function(media_format_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets audio aac header type of media format.
  /// @since_tizen 3.0
  /// @param[in] fmt The media_format_h to get audio information
  /// @param[out] aac_header_type The media_format_aac_header_type_e, ex) MEDIA_FORMAT_AAC_HEADER_ADTS
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_set_audio_aac_header_type()
  int media_format_get_audio_aac_header_type(
    media_format_h fmt,
    ffi.Pointer<ffi.Int32> aac_header_type,
  ) {
    return _media_format_get_audio_aac_header_type(
      fmt,
      aac_header_type,
    );
  }

  late final _media_format_get_audio_aac_header_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(media_format_h, ffi.Pointer<ffi.Int32>)>>(
      'media_format_get_audio_aac_header_type');
  late final _media_format_get_audio_aac_header_type =
      _media_format_get_audio_aac_header_typePtr
          .asFunction<int Function(media_format_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets video frame rate of media format.
  /// @since_tizen 3.0
  /// @param[in] fmt The media_format_h to get
  /// @param[out] frame_rate The video frame rate
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  int media_format_get_video_frame_rate(
    media_format_h fmt,
    ffi.Pointer<ffi.Int> frame_rate,
  ) {
    return _media_format_get_video_frame_rate(
      fmt,
      frame_rate,
    );
  }

  late final _media_format_get_video_frame_ratePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_format_h,
              ffi.Pointer<ffi.Int>)>>('media_format_get_video_frame_rate');
  late final _media_format_get_video_frame_rate =
      _media_format_get_video_frame_ratePtr
          .asFunction<int Function(media_format_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets container MIME type of media format.
  /// @since_tizen 3.0
  /// @param[in] fmt The media_format_h to set
  /// @param[in] mimetype The media_format_mimetype_e, ex) MEDIA_FORMAT_MP4
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_container_mime()
  int media_format_set_container_mime(
    media_format_h fmt,
    int mimetype,
  ) {
    return _media_format_set_container_mime(
      fmt,
      mimetype,
    );
  }

  late final _media_format_set_container_mimePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int32)>>(
          'media_format_set_container_mime');
  late final _media_format_set_container_mime =
      _media_format_set_container_mimePtr
          .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets text MIME type of media format.
  /// @since_tizen 3.0
  /// @param[in] fmt The media_format_h to set
  /// @param[in] mimetype The media_format_mimetype_e, ex) MEDIA_FORMAT_TEXT*
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_text_info()
  int media_format_set_text_mime(
    media_format_h fmt,
    int mimetype,
  ) {
    return _media_format_set_text_mime(
      fmt,
      mimetype,
    );
  }

  late final _media_format_set_text_mimePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int32)>>(
          'media_format_set_text_mime');
  late final _media_format_set_text_mime = _media_format_set_text_mimePtr
      .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets text type of media format.
  /// @since_tizen 3.0
  /// @param[in] fmt The media_format_h to set
  /// @param[in] type The text type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_text_info()
  int media_format_set_text_type(
    media_format_h fmt,
    int type,
  ) {
    return _media_format_set_text_type(
      fmt,
      type,
    );
  }

  late final _media_format_set_text_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int32)>>(
          'media_format_set_text_type');
  late final _media_format_set_text_type = _media_format_set_text_typePtr
      .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets video MIME type of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt media_format_h to set
  /// @param[in] mimetype media_format_mimetype_e , ex) MEDIA_FORMAT_H264_HP
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_video()
  int media_format_set_video_mime(
    media_format_h fmt,
    int mimetype,
  ) {
    return _media_format_set_video_mime(
      fmt,
      mimetype,
    );
  }

  late final _media_format_set_video_mimePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int32)>>(
          'media_format_set_video_mime');
  late final _media_format_set_video_mime = _media_format_set_video_mimePtr
      .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets video width of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt media_format_h to set
  /// @param[in] width width of the video
  /// @pre must set video MIME type by media_format_set_video_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_video()
  int media_format_set_video_width(
    media_format_h fmt,
    int width,
  ) {
    return _media_format_set_video_width(
      fmt,
      width,
    );
  }

  late final _media_format_set_video_widthPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int)>>(
          'media_format_set_video_width');
  late final _media_format_set_video_width = _media_format_set_video_widthPtr
      .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets video height of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt media_format_h to set
  /// @param[in] height height of the video
  /// @pre must set video MIME type by media_format_set_video_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_video()
  int media_format_set_video_height(
    media_format_h fmt,
    int height,
  ) {
    return _media_format_set_video_height(
      fmt,
      height,
    );
  }

  late final _media_format_set_video_heightPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int)>>(
          'media_format_set_video_height');
  late final _media_format_set_video_height = _media_format_set_video_heightPtr
      .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets video avg_bps of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt media_format_h to set
  /// @param[in] avg_bps average bps of the video
  /// @pre must set video MIME type by media_format_set_video_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_video()
  int media_format_set_video_avg_bps(
    media_format_h fmt,
    int avg_bps,
  ) {
    return _media_format_set_video_avg_bps(
      fmt,
      avg_bps,
    );
  }

  late final _media_format_set_video_avg_bpsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int)>>(
          'media_format_set_video_avg_bps');
  late final _media_format_set_video_avg_bps =
      _media_format_set_video_avg_bpsPtr
          .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets video max_bps of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt media_format_h to set
  /// @param[in] max_bps max bps of the video
  /// @pre must set video MIME type by media_format_set_video_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_video()
  int media_format_set_video_max_bps(
    media_format_h fmt,
    int max_bps,
  ) {
    return _media_format_set_video_max_bps(
      fmt,
      max_bps,
    );
  }

  late final _media_format_set_video_max_bpsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int)>>(
          'media_format_set_video_max_bps');
  late final _media_format_set_video_max_bps =
      _media_format_set_video_max_bpsPtr
          .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets video frame rate of media format.
  /// @since_tizen 3.0
  /// @param[in] fmt The media_format_h to set
  /// @param[in] frame_rate The video frame rate
  /// @pre must set video MIME type by media_format_set_video_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  int media_format_set_video_frame_rate(
    media_format_h fmt,
    int frame_rate,
  ) {
    return _media_format_set_video_frame_rate(
      fmt,
      frame_rate,
    );
  }

  late final _media_format_set_video_frame_ratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int)>>(
          'media_format_set_video_frame_rate');
  late final _media_format_set_video_frame_rate =
      _media_format_set_video_frame_ratePtr
          .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets audio MIME type of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt media_format_h to set audio information
  /// @param[in] mimetype media_format_mimetype_e , ex) MEDIA_FORMAT_PCM
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_audio()
  int media_format_set_audio_mime(
    media_format_h fmt,
    int mimetype,
  ) {
    return _media_format_set_audio_mime(
      fmt,
      mimetype,
    );
  }

  late final _media_format_set_audio_mimePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int32)>>(
          'media_format_set_audio_mime');
  late final _media_format_set_audio_mime = _media_format_set_audio_mimePtr
      .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets audio channel of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt media_format_h to set audio information
  /// @param[in] channel channel of the audio
  /// @pre must set audio MIME type by media_format_set_audio_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_audio()
  int media_format_set_audio_channel(
    media_format_h fmt,
    int channel,
  ) {
    return _media_format_set_audio_channel(
      fmt,
      channel,
    );
  }

  late final _media_format_set_audio_channelPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int)>>(
          'media_format_set_audio_channel');
  late final _media_format_set_audio_channel =
      _media_format_set_audio_channelPtr
          .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets audio samplerate of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt media_format_h to set
  /// @param[in] samplerate sampling rate of the audio
  /// @pre must set audio MIME type by media_format_set_audio_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_audio()
  int media_format_set_audio_samplerate(
    media_format_h fmt,
    int samplerate,
  ) {
    return _media_format_set_audio_samplerate(
      fmt,
      samplerate,
    );
  }

  late final _media_format_set_audio_sampleratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int)>>(
          'media_format_set_audio_samplerate');
  late final _media_format_set_audio_samplerate =
      _media_format_set_audio_sampleratePtr
          .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets audio bit of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @details   Sets audio bit resolution of this media format
  /// @param[in] fmt media_format_h to set
  /// @param[in] bit bit of the audio
  /// @pre must set audio MIME type by media_format_set_audio_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_audio()
  int media_format_set_audio_bit(
    media_format_h fmt,
    int bit,
  ) {
    return _media_format_set_audio_bit(
      fmt,
      bit,
    );
  }

  late final _media_format_set_audio_bitPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int)>>(
          'media_format_set_audio_bit');
  late final _media_format_set_audio_bit = _media_format_set_audio_bitPtr
      .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets audio avg_bps of media format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt media_format_h to set
  /// @param[in] avg_bps avg_bps of the audio
  /// @pre must set audio MIME type by media_format_set_audio_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_audio()
  int media_format_set_audio_avg_bps(
    media_format_h fmt,
    int avg_bps,
  ) {
    return _media_format_set_audio_avg_bps(
      fmt,
      avg_bps,
    );
  }

  late final _media_format_set_audio_avg_bpsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int)>>(
          'media_format_set_audio_avg_bps');
  late final _media_format_set_audio_avg_bps =
      _media_format_set_audio_avg_bpsPtr
          .asFunction<int Function(media_format_h, int)>();

  /// @brief Sets audio aac type of media format.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details   Sets audio aac data type of this media format
  /// @param[in] fmt media_format_h to set
  /// @param[in] is_adts aac adts flag of the audio
  /// @pre must set audio MIME type by media_format_set_audio_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_audio_aac_type()
  int media_format_set_audio_aac_type(
    media_format_h fmt,
    bool is_adts,
  ) {
    return _media_format_set_audio_aac_type(
      fmt,
      is_adts,
    );
  }

  late final _media_format_set_audio_aac_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Bool)>>(
          'media_format_set_audio_aac_type');
  late final _media_format_set_audio_aac_type =
      _media_format_set_audio_aac_typePtr
          .asFunction<int Function(media_format_h, bool)>();

  /// @brief Sets audio aac header type of media format.
  /// @since_tizen 3.0
  /// @param[in] fmt The media_format_h to get audio information
  /// @param[in] aac_header_type The media_format_aac_header_type_e, ex) MEDIA_FORMAT_AAC_HEADER_ADTS
  /// @pre must set audio MIME type by media_format_set_audio_mime()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_get_audio_aac_header_type()
  int media_format_set_audio_aac_header_type(
    media_format_h fmt,
    int aac_header_type,
  ) {
    return _media_format_set_audio_aac_header_type(
      fmt,
      aac_header_type,
    );
  }

  late final _media_format_set_audio_aac_header_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h, ffi.Int32)>>(
          'media_format_set_audio_aac_header_type');
  late final _media_format_set_audio_aac_header_type =
      _media_format_set_audio_aac_header_typePtr
          .asFunction<int Function(media_format_h, int)>();

  /// @brief Increase reference count of media_format_h object.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @details    increase ref_count of media_format_h
  /// @param[in] fmt exist media_format_h
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_unref()
  int media_format_ref(
    media_format_h fmt,
  ) {
    return _media_format_ref(
      fmt,
    );
  }

  late final _media_format_refPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h)>>(
          'media_format_ref');
  late final _media_format_ref =
      _media_format_refPtr.asFunction<int Function(media_format_h)>();

  /// @brief Decrease reference count of media_format_h object.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt exist media_format_h
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_ref()
  int media_format_unref(
    media_format_h fmt,
  ) {
    return _media_format_unref(
      fmt,
    );
  }

  late final _media_format_unrefPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_format_h)>>(
          'media_format_unref');
  late final _media_format_unref =
      _media_format_unrefPtr.asFunction<int Function(media_format_h)>();

  /// @brief Check whether the media_format_h is writable or not.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] fmt exist media_format_h
  /// @param[out] is_writable if ref_count is 1, return true. if not, return false
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  int media_format_is_writable(
    media_format_h fmt,
    ffi.Pointer<ffi.Bool> is_writable,
  ) {
    return _media_format_is_writable(
      fmt,
      is_writable,
    );
  }

  late final _media_format_is_writablePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_format_h,
              ffi.Pointer<ffi.Bool>)>>('media_format_is_writable');
  late final _media_format_is_writable = _media_format_is_writablePtr
      .asFunction<int Function(media_format_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Returns a writable copy of media_format_h.
  /// @details If there is only one reference count on fmt, the caller must be the owner,
  /// and so this function will return the object unchanged.
  /// while, if there is more than one reference count on the object, a new object will be returned.
  /// The caller will own a reference to the returned object.
  /// In a nutshell, this function unrefs the fmt and refs the out_fmt returned.
  /// Don't access fmt after calling this function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If a new object is returned, it will not have its own copy of extra data.
  /// The new object's extra data object will be the original object's extra data.
  /// @param[in] fmt exist media_format_h , don't access it after calling this function
  /// @param[out] out_fmt new copied media_format_h, the caller is owner of this object
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_FORMAT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_OPERATION Invalid operation
  int media_format_make_writable(
    media_format_h fmt,
    ffi.Pointer<media_format_h> out_fmt,
  ) {
    return _media_format_make_writable(
      fmt,
      out_fmt,
    );
  }

  late final _media_format_make_writablePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_format_h,
              ffi.Pointer<media_format_h>)>>('media_format_make_writable');
  late final _media_format_make_writable = _media_format_make_writablePtr
      .asFunction<int Function(media_format_h, ffi.Pointer<media_format_h>)>();

  /// @brief Sets extra data of media format.
  /// @details	The user can set data that media format does not support.
  /// @since_tizen 4.0
  /// @remarks The application is responsible for freeing @a extra_data.
  /// For description of extra data behavior upon making an object writable,
  /// see the description of media_format_make_writable().
  /// @param[in] fmt   The media format handle
  /// @param[in] extra_data  The extra data to set
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see media_format_get_extra()
  int media_format_set_extra(
    media_format_h fmt,
    ffi.Pointer<ffi.Void> extra_data,
  ) {
    return _media_format_set_extra(
      fmt,
      extra_data,
    );
  }

  late final _media_format_set_extraPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_format_h,
              ffi.Pointer<ffi.Void>)>>('media_format_set_extra');
  late final _media_format_set_extra = _media_format_set_extraPtr
      .asFunction<int Function(media_format_h, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets extra data of media format.
  /// @details	The user can get extra data which user sets value via media_format_set_extra().
  /// @since_tizen 4.0
  /// @remarks The application is responsible for freeing @a extra_data.
  /// For description of extra data behavior upon making an object writable,
  /// see the description of media_format_make_writable().
  /// @param[in]  fmt   The media format handle
  /// @param[out] extra_data    The extra data to get
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_FORMAT_ERROR_NONE Successful
  /// @retval #MEDIA_FORMAT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see media_format_set_extra()
  int media_format_get_extra(
    media_format_h fmt,
    ffi.Pointer<ffi.Pointer<ffi.Void>> extra_data,
  ) {
    return _media_format_get_extra(
      fmt,
      extra_data,
    );
  }

  late final _media_format_get_extraPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_format_h,
              ffi.Pointer<ffi.Pointer<ffi.Void>>)>>('media_format_get_extra');
  late final _media_format_get_extra = _media_format_get_extraPtr.asFunction<
      int Function(media_format_h, ffi.Pointer<ffi.Pointer<ffi.Void>>)>();

  /// @brief Queries surface format list and number of format supported by the system.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release the formats using free().
  ///
  /// @param[out] formats  The format array which the system can support \n
  /// This pointer has to be freed by user.
  /// @param[out] num      The number of formats
  ///
  /// @return  #TBM_SURFACE_ERROR_NONE if this function succeeds,
  /// otherwise an error status value
  ///
  /// @retval #TBM_SURFACE_ERROR_NONE               Success
  /// @retval #TBM_SURFACE_ERROR_INVALID_OPERATION  Invalid operation
  ///
  /// @par Example
  /// @code
  /// #include <tbm_surface.h>
  ///
  /// uint32_t *formats;
  /// uint32_t format_num;
  /// int ret, i;
  /// tbm_surface_error_e tse;
  ///
  /// tse = tbm_surface_query_formats (&formats, &format_num))
  ///
  /// for( i = 0 ; i < format_num ; i++)
  /// {
  /// if (formats[i] == TBM_FORMAT_RGB332)
  /// {
  /// ....
  ///
  /// free (formats);
  /// @endcode
  int tbm_surface_query_formats(
    ffi.Pointer<ffi.Pointer<ffi.Uint32>> formats,
    ffi.Pointer<ffi.Uint32> num,
  ) {
    return _tbm_surface_query_formats(
      formats,
      num,
    );
  }

  late final _tbm_surface_query_formatsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Pointer<ffi.Uint32>>,
              ffi.Pointer<ffi.Uint32>)>>('tbm_surface_query_formats');
  late final _tbm_surface_query_formats =
      _tbm_surface_query_formatsPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Pointer<ffi.Uint32>>, ffi.Pointer<ffi.Uint32>)>();

  /// @brief Creates the tbm_surface.
  /// @details This function creates the tbm_surface with the given width, height, and format.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remark The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  ///
  /// @param[in] width   The width of surface
  /// @param[in] height  The height of surface
  /// @param[in] format  The format of surface
  ///
  /// @return   #tbm_surface_h on success,
  /// otherwise @c NULL
  ///
  /// @retval #tbm_surface_h  The TBM surface handle
  ///
  /// @exception #TBM_SURFACE_ERROR_NONE               Success
  /// @exception #TBM_SURFACE_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @exception #TBM_SURFACE_ERROR_INVALID_OPERATION  Invalid operation
  ///
  /// @see tbm_surface_destroy()
  ///
  /// @par Example
  /// @code
  /// #include <tbm_surface.h>
  ///
  /// tbm_surface_h surface;
  ///
  /// surface = tbm_surface_create (128, 128, TBM_FORMAT_RGB332);
  ///
  /// ...
  ///
  /// tbm_surface_destroy (surface);
  /// @endcode
  tbm_surface_h tbm_surface_create(
    int width,
    int height,
    int format,
  ) {
    return _tbm_surface_create(
      width,
      height,
      format,
    );
  }

  late final _tbm_surface_createPtr = _lookup<
      ffi.NativeFunction<
          tbm_surface_h Function(
              ffi.Int, ffi.Int, tbm_format)>>('tbm_surface_create');
  late final _tbm_surface_create = _tbm_surface_createPtr
      .asFunction<tbm_surface_h Function(int, int, int)>();

  /// @brief Destroys the tbm_surface.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] surface  The #tbm_surface_h
  ///
  /// @return  #TBM_SURFACE_ERROR_NONE on success,
  /// otherwise an error status value
  ///
  /// @retval #TBM_SURFACE_ERROR_NONE               Success
  /// @retval #TBM_SURFACE_ERROR_INVALID_PARAMETER  Invalid parameter
  ///
  /// @see tbm_surface_create()
  ///
  /// @par Example
  /// @code
  /// #include <tbm_surface.h>
  ///
  /// tbm_surface_h surface;
  ///
  /// surface = tbm_surface_create (128, 128, TBM_FORMAT_RGB332);
  ///
  /// ...
  ///
  /// tbm_surface_destroy (surface);
  /// @endcode
  int tbm_surface_destroy(
    tbm_surface_h surface,
  ) {
    return _tbm_surface_destroy(
      surface,
    );
  }

  late final _tbm_surface_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tbm_surface_h)>>(
          'tbm_surface_destroy');
  late final _tbm_surface_destroy =
      _tbm_surface_destroyPtr.asFunction<int Function(tbm_surface_h)>();

  /// @brief Maps the tbm_surface according to the access option.
  /// @details After mapping tbm_surface, the information of tbm_surface is assigned in #tbm_surface_info_s struct. \n
  /// The information of tbm_surface has width, height, format, bpp, size, number of planes and information of planes. \n
  /// The information of planes has stride, offset, size and pointer of plane. \n
  /// #TBM_SURF_OPTION_READ indicates access option to read. \n
  /// #TBM_SURF_OPTION_WRITE indicates access option to write.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  surface  The #tbm_surface_h
  /// @param[in]  opt      The option to access the tbm_surface
  /// @param[out] info     The information of the tbm_surface
  ///
  /// @return  #TBM_SURFACE_ERROR_NONE on success,
  /// otherwise an error status value
  ///
  /// @retval #TBM_SURFACE_ERROR_NONE               Success
  /// @retval #TBM_SURFACE_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #TBM_SURFACE_ERROR_INVALID_OPERATION  Invalid operation
  ///
  /// @see tbm_surface_unmap();
  ///
  /// @par Example
  /// @code
  /// #include <tbm_surface.h>
  ///
  /// tbm_surface_h surface;
  /// tbm_surface_info_s info;
  /// int ret;
  ///
  /// surface = tbm_surface_create (128, 128, TBM_FORMAT_RGB332);
  /// ret = tbm_surface_map (surface, TBM_SURF_OPTION_WRITE|TBM_SURF_OPTION_READ, &info);
  ///
  /// ...
  ///
  /// tbm_surface_unmap (surface);
  /// tbm_surface_destroy (surface);
  /// @endcode
  int tbm_surface_map(
    tbm_surface_h surface,
    int opt,
    ffi.Pointer<tbm_surface_info_s> info,
  ) {
    return _tbm_surface_map(
      surface,
      opt,
      info,
    );
  }

  late final _tbm_surface_mapPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tbm_surface_h, ffi.Int,
              ffi.Pointer<tbm_surface_info_s>)>>('tbm_surface_map');
  late final _tbm_surface_map = _tbm_surface_mapPtr.asFunction<
      int Function(tbm_surface_h, int, ffi.Pointer<tbm_surface_info_s>)>();

  /// @brief Unmaps the tbm_surface.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] surface  The #tbm_surface_h
  ///
  /// @return  #TBM_SURFACE_ERROR_NONE on success,
  /// otherwise an error status value
  ///
  /// @retval #TBM_SURFACE_ERROR_NONE               Success
  /// @retval #TBM_SURFACE_ERROR_INVALID_PARAMETER  Invalid parameter
  ///
  /// @see tbm_surface_map()
  ///
  /// @par Example
  /// @code
  /// #include <tbm_surface.h>
  ///
  /// tbm_surface_h surface;
  /// tbm_surface_info_s info;
  /// int ret;
  ///
  /// surface = tbm_surface_create (128, 128, TBM_FORMAT_RGB332);
  /// ret = tbm_surface_map (surface, TBM_SURF_OPTION_WRITE|TBM_SURF_OPTION_READ, &info);
  ///
  /// ...
  ///
  /// tbm_surface_unmap (surface);
  /// tbm_surface_destroy (surface);
  /// @endcode
  int tbm_surface_unmap(
    tbm_surface_h surface,
  ) {
    return _tbm_surface_unmap(
      surface,
    );
  }

  late final _tbm_surface_unmapPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tbm_surface_h)>>(
          'tbm_surface_unmap');
  late final _tbm_surface_unmap =
      _tbm_surface_unmapPtr.asFunction<int Function(tbm_surface_h)>();

  /// @brief Gets the information of the tbm_surface.
  /// @details The information of tbm_surface is assigned in #tbm_surface_info_s struct. \n
  /// The information of tbm_surface has width, height, format, bpp, size, number of planes and information of planes. \n
  /// The information of planes has stride, offset, size and pointer of plane.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   surface  The #tbm_surface_h
  /// @param[out]  info     The information of the tbm_surface
  ///
  /// @return  #TBM_SURFACE_ERROR_NONE on success,
  /// otherwise an error status value
  ///
  /// @retval #TBM_SURFACE_ERROR_NONE               Success
  /// @retval #TBM_SURFACE_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #TBM_SURFACE_ERROR_INVALID_OPERATION  Invalid operation
  ///
  /// @see tbm_surface_map()
  ///
  /// @par Example
  /// @code
  /// #include <tbm_surface.h>
  ///
  /// tbm_surface_h surface;
  /// tbm_surface_info_s info;
  /// int ret;
  ///
  /// surface = tbm_surface_create (128, 128, TBM_FORMAT_RGB332);
  /// ret = tbm_surface_get_info (surface, &info);
  ///
  /// ...
  ///
  /// tbm_surface_destroy (surface);
  /// @endcode
  int tbm_surface_get_info(
    tbm_surface_h surface,
    ffi.Pointer<tbm_surface_info_s> info,
  ) {
    return _tbm_surface_get_info(
      surface,
      info,
    );
  }

  late final _tbm_surface_get_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tbm_surface_h,
              ffi.Pointer<tbm_surface_info_s>)>>('tbm_surface_get_info');
  late final _tbm_surface_get_info = _tbm_surface_get_infoPtr.asFunction<
      int Function(tbm_surface_h, ffi.Pointer<tbm_surface_info_s>)>();

  /// @brief Gets the width of the tbm_surface.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] surface  The #tbm_surface_h
  ///
  /// @return  The width of the tbm_surface on success,
  /// otherwise an error status value
  ///
  /// @retval #TBM_SURFACE_ERROR_INVALID_PARAMETER  Invalid parameter
  ///
  /// @par Example
  /// @code
  /// #include <tbm_surface.h>
  ///
  /// tbm_surface_h surface;
  /// int width;
  ///
  /// surface = tbm_surface_create (128, 128, TBM_FORMAT_RGB332);
  ///
  /// ...
  ///
  /// width = tbm_surface_get_width (surface);
  ///
  /// ...
  ///
  /// tbm_surface_destroy (surface);
  /// @endcode
  int tbm_surface_get_width(
    tbm_surface_h surface,
  ) {
    return _tbm_surface_get_width(
      surface,
    );
  }

  late final _tbm_surface_get_widthPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tbm_surface_h)>>(
          'tbm_surface_get_width');
  late final _tbm_surface_get_width =
      _tbm_surface_get_widthPtr.asFunction<int Function(tbm_surface_h)>();

  /// @brief Gets the height of the tbm_surface.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] surface  The #tbm_surface_h
  ///
  /// @return  The height of the tbm_surface if this function succeeds,
  /// otherwise an error status value
  ///
  /// @retval #TBM_SURFACE_ERROR_INVALID_PARAMETER  Invalid parameter
  ///
  /// @par Example
  /// @code
  /// #include <tbm_surface.h>
  ///
  /// tbm_surface_h surface;
  /// int height;
  ///
  /// surface = tbm_surface_create (128, 128, TBM_FORMAT_RGB332);
  ///
  /// ...
  ///
  /// height = tbm_surface_get_height (surface);
  ///
  /// ...
  ///
  /// tbm_surface_destroy (surface);
  /// @endcode
  int tbm_surface_get_height(
    tbm_surface_h surface,
  ) {
    return _tbm_surface_get_height(
      surface,
    );
  }

  late final _tbm_surface_get_heightPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tbm_surface_h)>>(
          'tbm_surface_get_height');
  late final _tbm_surface_get_height =
      _tbm_surface_get_heightPtr.asFunction<int Function(tbm_surface_h)>();

  /// @brief Gets the format of the tbm_surface.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remark The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  ///
  /// @param[in] surface  The #tbm_surface_h
  ///
  /// @return  The format of the tbm_surface on success,
  /// otherwise @c 0 on failure
  ///
  /// @retval #tbm_format  The format of surface
  ///
  /// @exception #TBM_SURFACE_ERROR_NONE               Success
  /// @exception #TBM_SURFACE_ERROR_INVALID_PARAMETER  Invalid parameter
  ///
  /// @par Example
  /// @code
  /// #include <tbm_surface.h>
  ///
  /// tbm_surface_s surface;
  /// tbm_format format;
  ///
  /// surface = tbm_surface_create (128, 128, TBM_FORMAT_RGB332);
  ///
  /// ...
  ///
  /// format = tbm_surface_get_format (surface);
  ///
  /// ...
  ///
  /// tbm_surface_destroy (surface);
  /// @endcode
  int tbm_surface_get_format(
    tbm_surface_h surface,
  ) {
    return _tbm_surface_get_format(
      surface,
    );
  }

  late final _tbm_surface_get_formatPtr =
      _lookup<ffi.NativeFunction<tbm_format Function(tbm_surface_h)>>(
          'tbm_surface_get_format');
  late final _tbm_surface_get_format =
      _tbm_surface_get_formatPtr.asFunction<int Function(tbm_surface_h)>();

  /// @brief    Creates a media packet handle and allocates buffer.
  /// @details  The buffer will be allocated to heap or tbm_surface.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks The @c packet must be released by using media_packet_destroy().
  /// @param[in]  fmt       The allocated #media_format_h by caller
  /// @param[in]  fcb       The media_packet_finalize_cb() to register
  /// @param[in]  fcb_data  The user data to be passed to the media_packet_finalize_cb() function
  /// @param[out] packet    A new handle for media packet
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Must have media_format_h instance by media_format_create()
  /// @post Must do media_format_unref()
  ///
  /// @see media_packet_destroy()
  /// @see media_packet_finalize_cb()
  /// @see media_format_unref()
  /// @par Example
  /// @code
  /// #include <media_packet.h>
  ///
  /// {
  /// media_format_h fmt;
  /// media_packet_h packet;
  ///
  /// media_format_create(&fmt);
  /// media_format_set_video_mime(fmt, MEDIA_FORMAT_H264_HP);
  /// media_format_set_video_width(fmt, 640);
  /// media_format_set_video_height(fmt, 480);
  /// media_format_set_video_avg_bps(fmt, 10000000);
  /// media_format_set_video_max_bps(fmt, 15000000);
  ///
  /// media_packet_create_alloc (fmt, _finalize_callback, fcb_data, &packet);
  /// media_format_unref(fmt);
  ///
  /// ...
  /// media_packet_destroy(packet);
  /// }
  ///
  /// int _finalize_callback(media_packet_h packet, int err, void* userdata)
  /// {
  /// ...
  /// return MEDIA_PACKET_FINALIZE;
  /// }
  ///
  /// @endcode
  int media_packet_create_alloc(
    media_format_h fmt,
    media_packet_finalize_cb fcb,
    ffi.Pointer<ffi.Void> fcb_data,
    ffi.Pointer<media_packet_h> packet,
  ) {
    return _media_packet_create_alloc(
      fmt,
      fcb,
      fcb_data,
      packet,
    );
  }

  late final _media_packet_create_allocPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_format_h,
              media_packet_finalize_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<media_packet_h>)>>('media_packet_create_alloc');
  late final _media_packet_create_alloc =
      _media_packet_create_allocPtr.asFunction<
          int Function(media_format_h, media_packet_finalize_cb,
              ffi.Pointer<ffi.Void>, ffi.Pointer<media_packet_h>)>();

  /// @brief    Creates a media packet handle.
  /// @details  It creates only media packet handle without allocated buffer.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks The @c packet must be released by using media_packet_destroy().
  /// @param[in] fmt       The allocated #media_format_h by caller
  /// @param[in] fcb       The media_packet_finalize_cb() to register
  /// @param[in] fcb_data  The user data to be passed to the media_packet_finalize_cb() function
  /// @param[out] packet   A new handle for media packet
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Must have media_format_h instance by media_format_create()
  /// @post Must do media_format_unref()
  ///
  /// @see media_packet_destroy()
  /// @see media_packet_finalize_cb()
  /// @see media_format_unref()
  /// @par Example
  /// @code
  /// #include <media_packet.h>
  ///
  /// {
  /// media_format_h fmt;
  /// media_packet_h packet;
  ///
  /// media_format_create(&fmt);
  /// media_format_set_video_mime(fmt, MEDIA_FORMAT_H264_HP);
  /// media_format_set_video_width(fmt, 640);
  /// media_format_set_video_height(fmt, 480);
  /// media_format_set_video_avg_bps(fmt, 10000000);
  /// media_format_set_video_max_bps(fmt, 15000000);
  ///
  /// media_packet_create (fmt, _finalize_callback, fcb_data, &packet);
  /// media_format_unref(fmt);
  ///
  /// ...
  /// media_packet_destroy(packet);
  /// }
  ///
  /// int _finalize_callback(media_packet_h packet, int err, void* userdata)
  /// {
  /// ...
  /// return MEDIA_PACKET_FINALIZE;
  /// }
  ///
  /// @endcode
  int media_packet_create(
    media_format_h fmt,
    media_packet_finalize_cb fcb,
    ffi.Pointer<ffi.Void> fcb_data,
    ffi.Pointer<media_packet_h> packet,
  ) {
    return _media_packet_create(
      fmt,
      fcb,
      fcb_data,
      packet,
    );
  }

  late final _media_packet_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_format_h,
              media_packet_finalize_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<media_packet_h>)>>('media_packet_create');
  late final _media_packet_create = _media_packet_createPtr.asFunction<
      int Function(media_format_h, media_packet_finalize_cb,
          ffi.Pointer<ffi.Void>, ffi.Pointer<media_packet_h>)>();

  /// @brief    Copies a media packet handle.
  /// @details  It re-creates only media packet handle with exist media packet handle.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks The @c new_packet must be released by using media_packet_destroy().
  /// @param[in]   org_packet   The existing media packet handle
  /// @param[in]   fcb          The media_packet_finalize_cb() to register
  /// @param[in]   fcb_data     The user data to be passed to the media_packet_finalize_cb() function
  /// @param[out]  new_packet   A new handle for media packet
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_packet_destroy()
  /// @see media_packet_finalize_cb()
  int media_packet_copy(
    media_packet_h org_packet,
    media_packet_finalize_cb fcb,
    ffi.Pointer<ffi.Void> fcb_data,
    ffi.Pointer<media_packet_h> new_packet,
  ) {
    return _media_packet_copy(
      org_packet,
      fcb,
      fcb_data,
      new_packet,
    );
  }

  late final _media_packet_copyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_packet_h,
              media_packet_finalize_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<media_packet_h>)>>('media_packet_copy');
  late final _media_packet_copy = _media_packet_copyPtr.asFunction<
      int Function(media_packet_h, media_packet_finalize_cb,
          ffi.Pointer<ffi.Void>, ffi.Pointer<media_packet_h>)>();

  /// @brief    Allocates buffer with media packet handle.
  /// @details  Before using media_packet_alloc(), media packet handle must be exist.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] packet   The existing media packet handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_packet_create()
  /// @see media_packet_destroy()
  int media_packet_alloc(
    media_packet_h packet,
  ) {
    return _media_packet_alloc(
      packet,
    );
  }

  late final _media_packet_allocPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_h)>>(
          'media_packet_alloc');
  late final _media_packet_alloc =
      _media_packet_allocPtr.asFunction<int Function(media_packet_h)>();

  /// @brief    Creates media packet handle and allocates buffer with #tbm_surface_h.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks The @c packet must be released by using media_packet_destroy().
  /// @param[in]   fmt       The allocated #media_format_h by caller
  /// @param[in]   surface   The #tbm_surface_h by caller
  /// @param[in]   fcb       The media_packet_finalize_cb() to register
  /// @param[in]   fcb_data  The user data to be passed to the media_packet_finalize_cb() function
  /// @param[out]  packet  A new handle for media packet
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Must have media_format_h instance by media_format_create()
  /// @post Must do media_format_unref()
  ///
  /// @see media_packet_destroy()
  /// @see media_packet_finalize_cb()
  /// @see media_format_unref()
  /// @par Example
  /// @code
  /// #include <media_packet.h>
  ///
  /// {
  /// media_format_h fmt;
  /// media_packet_h packet;
  ///
  /// media_format_create(&fmt);
  /// media_format_set_video_mime(fmt, MEDIA_FORMAT_H264_HP);
  /// media_format_set_video_width(fmt, 640);
  /// media_format_set_video_height(fmt, 480);
  /// media_format_set_video_avg_bps(fmt, 10000000);
  /// media_format_set_video_max_bps(fmt, 15000000);
  ///
  /// media_packet_create_from_tbm_surface (fmt, surface, _finalize_callback, fcb_data, &packet);
  /// media_format_unref(fmt);
  ///
  /// ...
  /// media_pacekt_destory(packet);
  /// }
  ///
  /// int _finalize_callback(media_packet_h packet, int err, void* userdata)
  /// {
  /// ...
  /// return MEDIA_PACKET_FINALIZE;
  /// }
  ///
  /// @endcode
  int media_packet_create_from_tbm_surface(
    media_format_h fmt,
    tbm_surface_h surface,
    media_packet_finalize_cb fcb,
    ffi.Pointer<ffi.Void> fcb_data,
    ffi.Pointer<media_packet_h> packet,
  ) {
    return _media_packet_create_from_tbm_surface(
      fmt,
      surface,
      fcb,
      fcb_data,
      packet,
    );
  }

  late final _media_packet_create_from_tbm_surfacePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_format_h,
                  tbm_surface_h,
                  media_packet_finalize_cb,
                  ffi.Pointer<ffi.Void>,
                  ffi.Pointer<media_packet_h>)>>(
      'media_packet_create_from_tbm_surface');
  late final _media_packet_create_from_tbm_surface =
      _media_packet_create_from_tbm_surfacePtr.asFunction<
          int Function(media_format_h, tbm_surface_h, media_packet_finalize_cb,
              ffi.Pointer<ffi.Void>, ffi.Pointer<media_packet_h>)>();

  /// @brief    Creates media packet handle with already allocated external buffer.
  /// @details It does not support video's #MEDIA_FORMAT_RAW type.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks The @c packet must be released by using media_packet_destroy().
  /// @param[in]   fmt       The allocated #media_format_h by caller
  /// @param[in]   mem_ptr   The memory pointer which is created by external module
  /// @param[in]   size      The buffer size value to set
  /// @param[in]   fcb       The media_packet_finalize_cb() to register
  /// @param[in]   fcb_data  The user data to be passed to the media_packet_finalize_cb() function
  /// @param[out]  packet  A new handle for media packet
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Must have media_format_h instance by media_format_create()
  /// @post Must do media_format_unref()
  ///
  /// @see media_packet_destroy()
  /// @see media_packet_finalize_cb()
  /// @see media_format_unref()
  /// @par Example
  /// @code
  /// #include <media_packet.h>
  ///
  /// {
  /// media_format_h fmt;
  /// media_packet_h packet;
  ///
  /// media_format_create(&fmt);
  /// media_format_set_video_mime(fmt, MEDIA_FORMAT_H264_HP);
  /// media_format_set_video_width(fmt, 640);
  /// media_format_set_video_height(fmt, 480);
  /// media_format_set_video_avg_bps(fmt, 10000000);
  /// media_format_set_video_max_bps(fmt, 15000000);
  ///
  /// media_packet_create_from_external_memory (fmt, mem_ptr, size,  _finalize_callback, fcb_data, &packet);
  /// media_format_unref(fmt);
  ///
  /// ...
  /// media_packet_destroy(packet);
  /// }
  ///
  /// int _finalize_callback(media_packet_h packet, int err, void* userdata)
  /// {
  /// ...
  /// return MEDIA_PACKET_FINALIZE;
  /// }
  ///
  /// @endcode
  int media_packet_create_from_external_memory(
    media_format_h fmt,
    ffi.Pointer<ffi.Void> mem_ptr,
    int size,
    media_packet_finalize_cb fcb,
    ffi.Pointer<ffi.Void> fcb_data,
    ffi.Pointer<media_packet_h> packet,
  ) {
    return _media_packet_create_from_external_memory(
      fmt,
      mem_ptr,
      size,
      fcb,
      fcb_data,
      packet,
    );
  }

  late final _media_packet_create_from_external_memoryPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_format_h,
                  ffi.Pointer<ffi.Void>,
                  ffi.Uint64,
                  media_packet_finalize_cb,
                  ffi.Pointer<ffi.Void>,
                  ffi.Pointer<media_packet_h>)>>(
      'media_packet_create_from_external_memory');
  late final _media_packet_create_from_external_memory =
      _media_packet_create_from_external_memoryPtr.asFunction<
          int Function(
              media_format_h,
              ffi.Pointer<ffi.Void>,
              int,
              media_packet_finalize_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<media_packet_h>)>();

  /// @brief Gets #media_format_h of media packet
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] fmt      The media format of media packet
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_format_unref()
  /// @par Example
  /// @code
  /// #include <media_packet.h>
  ///
  /// {
  /// media_format_h* fmt;
  ///
  /// media_packet_get_format (pakcet, &fmt);
  /// ..
  ///
  /// media_format_unref(fmt);
  /// ...
  /// }
  ///
  /// @endcode
  int media_packet_get_format(
    media_packet_h packet,
    ffi.Pointer<media_format_h> fmt,
  ) {
    return _media_packet_get_format(
      packet,
      fmt,
    );
  }

  late final _media_packet_get_formatPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<media_format_h>)>>('media_packet_get_format');
  late final _media_packet_get_format = _media_packet_get_formatPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<media_format_h>)>();

  /// @brief Sets #media_format_h of media packet
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] packet   The media packet handle
  /// @param[in] fmt      The #media_format_h to set
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see media_format_unref()
  /// @par Example
  /// @code
  /// #include <media_packet.h>
  ///
  /// {
  /// media_format_h fmt;
  ///
  /// media_packet_set_format (pakcet, fmt);
  /// ..
  ///
  /// media_format_unref(fmt);
  /// ...
  /// }
  ///
  /// @endcode
  int media_packet_set_format(
    media_packet_h packet,
    media_format_h fmt,
  ) {
    return _media_packet_set_format(
      packet,
      fmt,
    );
  }

  late final _media_packet_set_formatPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(media_packet_h, media_format_h)>>(
      'media_packet_set_format');
  late final _media_packet_set_format = _media_packet_set_formatPtr
      .asFunction<int Function(media_packet_h, media_format_h)>();

  /// @brief Sets PTS of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] packet   The media packet handle
  /// @param[in] pts      The PTS value to set
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_set_pts(
    media_packet_h packet,
    int pts,
  ) {
    return _media_packet_set_pts(
      packet,
      pts,
    );
  }

  late final _media_packet_set_ptsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_h, ffi.Uint64)>>(
          'media_packet_set_pts');
  late final _media_packet_set_pts =
      _media_packet_set_ptsPtr.asFunction<int Function(media_packet_h, int)>();

  /// @brief Sets DTS of media packet handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[in]  dts      The DTS value to set
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_set_dts(
    media_packet_h packet,
    int dts,
  ) {
    return _media_packet_set_dts(
      packet,
      dts,
    );
  }

  late final _media_packet_set_dtsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_h, ffi.Uint64)>>(
          'media_packet_set_dts');
  late final _media_packet_set_dts =
      _media_packet_set_dtsPtr.asFunction<int Function(media_packet_h, int)>();

  /// @brief Sets PTS of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] packet    The media packet handle
  /// @param[in] duration  The duration value to set
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_set_duration(
    media_packet_h packet,
    int duration,
  ) {
    return _media_packet_set_duration(
      packet,
      duration,
    );
  }

  late final _media_packet_set_durationPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_h, ffi.Uint64)>>(
          'media_packet_set_duration');
  late final _media_packet_set_duration = _media_packet_set_durationPtr
      .asFunction<int Function(media_packet_h, int)>();

  /// @brief Sets buffer size of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] size     The buffer size value to set
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_set_buffer_size(
    media_packet_h packet,
    int size,
  ) {
    return _media_packet_set_buffer_size(
      packet,
      size,
    );
  }

  late final _media_packet_set_buffer_sizePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_h, ffi.Uint64)>>(
          'media_packet_set_buffer_size');
  late final _media_packet_set_buffer_size = _media_packet_set_buffer_sizePtr
      .asFunction<int Function(media_packet_h, int)>();

  /// @brief Gets PTS of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] pts      The PTS value to get
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  int media_packet_get_pts(
    media_packet_h packet,
    ffi.Pointer<ffi.Uint64> pts,
  ) {
    return _media_packet_get_pts(
      packet,
      pts,
    );
  }

  late final _media_packet_get_ptsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Uint64>)>>('media_packet_get_pts');
  late final _media_packet_get_pts = _media_packet_get_ptsPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Uint64>)>();

  /// @brief Gets DTS of media packet
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] dts      The DTS value to get
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_dts(
    media_packet_h packet,
    ffi.Pointer<ffi.Uint64> dts,
  ) {
    return _media_packet_get_dts(
      packet,
      dts,
    );
  }

  late final _media_packet_get_dtsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Uint64>)>>('media_packet_get_dts');
  late final _media_packet_get_dts = _media_packet_get_dtsPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Uint64>)>();

  /// @brief Gets duration of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet    The media packet handle
  /// @param[out] duration  The duration value to get
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_duration(
    media_packet_h packet,
    ffi.Pointer<ffi.Uint64> duration,
  ) {
    return _media_packet_get_duration(
      packet,
      duration,
    );
  }

  late final _media_packet_get_durationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Uint64>)>>('media_packet_get_duration');
  late final _media_packet_get_duration = _media_packet_get_durationPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Uint64>)>();

  /// @brief Gets buffer size of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] size     The buffer size value to get
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_buffer_size(
    media_packet_h packet,
    ffi.Pointer<ffi.Uint64> size,
  ) {
    return _media_packet_get_buffer_size(
      packet,
      size,
    );
  }

  late final _media_packet_get_buffer_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Uint64>)>>('media_packet_get_buffer_size');
  late final _media_packet_get_buffer_size = _media_packet_get_buffer_sizePtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Uint64>)>();

  /// @brief Gets buffer data pointer of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] data     The allocated buffer data pointer
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_buffer_data_ptr(
    media_packet_h packet,
    ffi.Pointer<ffi.Pointer<ffi.Void>> data,
  ) {
    return _media_packet_get_buffer_data_ptr(
      packet,
      data,
    );
  }

  late final _media_packet_get_buffer_data_ptrPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_packet_h, ffi.Pointer<ffi.Pointer<ffi.Void>>)>>(
      'media_packet_get_buffer_data_ptr');
  late final _media_packet_get_buffer_data_ptr =
      _media_packet_get_buffer_data_ptrPtr.asFunction<
          int Function(media_packet_h, ffi.Pointer<ffi.Pointer<ffi.Void>>)>();

  /// @brief Gets TBM surface data of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] surface  The tbm_surface data pointer
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_tbm_surface(
    media_packet_h packet,
    ffi.Pointer<tbm_surface_h> surface,
  ) {
    return _media_packet_get_tbm_surface(
      packet,
      surface,
    );
  }

  late final _media_packet_get_tbm_surfacePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<tbm_surface_h>)>>('media_packet_get_tbm_surface');
  late final _media_packet_get_tbm_surface = _media_packet_get_tbm_surfacePtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<tbm_surface_h>)>();

  /// @brief Sets extra data of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] packet   The media packet handle
  /// @param[in] extra    The extra data to set
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_set_extra(
    media_packet_h packet,
    ffi.Pointer<ffi.Void> extra,
  ) {
    return _media_packet_set_extra(
      packet,
      extra,
    );
  }

  late final _media_packet_set_extraPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Void>)>>('media_packet_set_extra');
  late final _media_packet_set_extra = _media_packet_set_extraPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets extra data of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] extra    The extra data to get
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_extra(
    media_packet_h packet,
    ffi.Pointer<ffi.Pointer<ffi.Void>> extra,
  ) {
    return _media_packet_get_extra(
      packet,
      extra,
    );
  }

  late final _media_packet_get_extraPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Pointer<ffi.Void>>)>>('media_packet_get_extra');
  late final _media_packet_get_extra = _media_packet_get_extraPtr.asFunction<
      int Function(media_packet_h, ffi.Pointer<ffi.Pointer<ffi.Void>>)>();

  /// @brief Checks whether the given media packet is for video.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] is_video @c true if the given media packet is for video,
  /// otherwise @c false if the given media packet is not for video
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_format_mimetype_e
  /// @see media_format_type_e
  int media_packet_is_video(
    media_packet_h packet,
    ffi.Pointer<ffi.Bool> is_video,
  ) {
    return _media_packet_is_video(
      packet,
      is_video,
    );
  }

  late final _media_packet_is_videoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_packet_h, ffi.Pointer<ffi.Bool>)>>('media_packet_is_video');
  late final _media_packet_is_video = _media_packet_is_videoPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the given media packet is for audio.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet    The media packet handle
  /// @param[out] is_audio  @c true if the given media packet is for audio,
  /// otherwise @c false if the given media packet is not for audio
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_mimetype_e
  /// @see media_format_type_e
  int media_packet_is_audio(
    media_packet_h packet,
    ffi.Pointer<ffi.Bool> is_audio,
  ) {
    return _media_packet_is_audio(
      packet,
      is_audio,
    );
  }

  late final _media_packet_is_audioPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_packet_h, ffi.Pointer<ffi.Bool>)>>('media_packet_is_audio');
  late final _media_packet_is_audio = _media_packet_is_audioPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the given media packet is for text.
  /// @since_tizen 3.0
  ///
  /// @param[in]  packet    The media packet handle
  /// @param[out] is_text  @c true if the given media packet is for text,
  /// otherwise @c false if the given media packet is not for text
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_format_mimetype_e
  /// @see media_format_type_e
  int media_packet_is_text(
    media_packet_h packet,
    ffi.Pointer<ffi.Bool> is_text,
  ) {
    return _media_packet_is_text(
      packet,
      is_text,
    );
  }

  late final _media_packet_is_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_packet_h, ffi.Pointer<ffi.Bool>)>>('media_packet_is_text');
  late final _media_packet_is_text = _media_packet_is_textPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the given media packet is encoded type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet      The media packet handle
  /// @param[out] is_encoded  @c true if the given media packet is encoded,
  /// otherwise @c false if the given media packet is not encoded
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_format_mimetype_e
  /// @see media_format_data_type_e
  int media_packet_is_encoded(
    media_packet_h packet,
    ffi.Pointer<ffi.Bool> is_encoded,
  ) {
    return _media_packet_is_encoded(
      packet,
      is_encoded,
    );
  }

  late final _media_packet_is_encodedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Bool>)>>('media_packet_is_encoded');
  late final _media_packet_is_encoded = _media_packet_is_encodedPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the given media packet is raw type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] is_raw   @c true if the given media packet is for raw video,
  /// otherwise @c false if the given media packet is not for raw video
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_format_mimetype_e
  /// @see media_format_data_type_e
  int media_packet_is_raw(
    media_packet_h packet,
    ffi.Pointer<ffi.Bool> is_raw,
  ) {
    return _media_packet_is_raw(
      packet,
      is_raw,
    );
  }

  late final _media_packet_is_rawPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_packet_h, ffi.Pointer<ffi.Bool>)>>('media_packet_is_raw');
  late final _media_packet_is_raw = _media_packet_is_rawPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets #media_buffer_flags_e of media packet.
  /// @since_tizen 3.0
  ///
  /// @param[in] packet    The media packet handle
  /// @param[out] flags    The media_buffer_flags_e of media packet to get
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_buffer_flags_e
  /// @see media_packet_unset_flags()
  int media_packet_get_flags(
    media_packet_h packet,
    ffi.Pointer<ffi.Int32> flags,
  ) {
    return _media_packet_get_flags(
      packet,
      flags,
    );
  }

  late final _media_packet_get_flagsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Int32>)>>('media_packet_get_flags');
  late final _media_packet_get_flags = _media_packet_get_flagsPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets #media_buffer_flags_e of media packet.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] packet    The media packet handle
  /// @param[in] flags    The media_buffer_flags_e of media packet to set
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_buffer_flags_e
  /// @see media_packet_unset_flags()
  int media_packet_set_flags(
    media_packet_h packet,
    int flags,
  ) {
    return _media_packet_set_flags(
      packet,
      flags,
    );
  }

  late final _media_packet_set_flagsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_h, ffi.Int32)>>(
          'media_packet_set_flags');
  late final _media_packet_set_flags = _media_packet_set_flagsPtr
      .asFunction<int Function(media_packet_h, int)>();

  /// @brief Unsets media_buffer_flags_e of media packet
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] packet   The media packet handle
  /// @param[in] flags    The media_buffer_flags_e of media packet to unset
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_buffer_flags_e
  /// @see media_packet_set_flags()
  int media_packet_unset_flags(
    media_packet_h packet,
    int flags,
  ) {
    return _media_packet_unset_flags(
      packet,
      flags,
    );
  }

  late final _media_packet_unset_flagsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_h, ffi.Int32)>>(
          'media_packet_unset_flags');
  late final _media_packet_unset_flags = _media_packet_unset_flagsPtr
      .asFunction<int Function(media_packet_h, int)>();

  /// @brief Checks whether the given media packet is codec data.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] packet            The media packet handle
  /// @param[out] is_codec_config  @c true if the given media packet is for codec data,
  /// otherwise @c false if the given media packet is not for codec data
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_format_mimetype_e
  /// @see media_format_data_type_e
  int media_packet_is_codec_config(
    media_packet_h packet,
    ffi.Pointer<ffi.Bool> is_codec_config,
  ) {
    return _media_packet_is_codec_config(
      packet,
      is_codec_config,
    );
  }

  late final _media_packet_is_codec_configPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Bool>)>>('media_packet_is_codec_config');
  late final _media_packet_is_codec_config = _media_packet_is_codec_configPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the given media packet is eos.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] packet   The media packet handle
  /// @param[out] is_eos  @c true if the given media packet is for eos,
  /// otherwise @c false if the given media packet is not for eos
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_format_mimetype_e
  /// @see media_format_data_type_e
  int media_packet_is_end_of_stream(
    media_packet_h packet,
    ffi.Pointer<ffi.Bool> is_eos,
  ) {
    return _media_packet_is_end_of_stream(
      packet,
      is_eos,
    );
  }

  late final _media_packet_is_end_of_streamPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Bool>)>>('media_packet_is_end_of_stream');
  late final _media_packet_is_end_of_stream = _media_packet_is_end_of_streamPtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the given media packet is sync frame.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] is_sync  @c true if the given media packet is for sync frame,
  /// otherwise @c false if the given media packet is not for sync frame
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_format_mimetype_e
  /// @see media_format_data_type_e
  int media_packet_is_sync_frame(
    media_packet_h packet,
    ffi.Pointer<ffi.Bool> is_sync,
  ) {
    return _media_packet_is_sync_frame(
      packet,
      is_sync,
    );
  }

  late final _media_packet_is_sync_framePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Bool>)>>('media_packet_is_sync_frame');
  late final _media_packet_is_sync_frame = _media_packet_is_sync_framePtr
      .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the allocated buffer is tbm surface or not.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] has_tbm_surface  @c true if the given media packet's allocated buffer is tbm surface,
  /// otherwise @c false if the given media packet's allocated buffer is not tbm surface
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_has_tbm_surface_buffer(
    media_packet_h packet,
    ffi.Pointer<ffi.Bool> has_tbm_surface,
  ) {
    return _media_packet_has_tbm_surface_buffer(
      packet,
      has_tbm_surface,
    );
  }

  late final _media_packet_has_tbm_surface_bufferPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h,
              ffi.Pointer<ffi.Bool>)>>('media_packet_has_tbm_surface_buffer');
  late final _media_packet_has_tbm_surface_buffer =
      _media_packet_has_tbm_surface_bufferPtr
          .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the number of planes from tbm surface in the given media packet.
  /// @details Use only if the media_format_h is #MEDIA_FORMAT_RAW and #MEDIA_FORMAT_VIDEO.
  /// It means that media_packet_h's buffer is allocated on tbm_surface.
  /// If not sure of that, use media_packet_is_video() and media_packet_is_raw() or media_packet_has_tbm_surface_buffer().
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[out] num  The number of planes from tbm_surface
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_number_of_video_planes(
    media_packet_h packet,
    ffi.Pointer<ffi.Uint32> num,
  ) {
    return _media_packet_get_number_of_video_planes(
      packet,
      num,
    );
  }

  late final _media_packet_get_number_of_video_planesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(media_packet_h, ffi.Pointer<ffi.Uint32>)>>(
      'media_packet_get_number_of_video_planes');
  late final _media_packet_get_number_of_video_planes =
      _media_packet_get_number_of_video_planesPtr
          .asFunction<int Function(media_packet_h, ffi.Pointer<ffi.Uint32>)>();

  /// @brief Gets stride width from tbm surface in the given media packet.
  /// @details Use only if the media_format_h is #MEDIA_FORMAT_RAW and #MEDIA_FORMAT_VIDEO.
  /// It means that media_packet_h's buffer is allocated on tbm_surface.
  /// If not sure of that, use media_packet_is_video() and media_packet_is_raw() or media_packet_has_tbm_surface_buffer().
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[in]  plane_idx   The plane index value
  /// @param[out] stride_width  the stride value from tbm_surface
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_video_stride_width(
    media_packet_h packet,
    int plane_idx,
    ffi.Pointer<ffi.Int> stride_width,
  ) {
    return _media_packet_get_video_stride_width(
      packet,
      plane_idx,
      stride_width,
    );
  }

  late final _media_packet_get_video_stride_widthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('media_packet_get_video_stride_width');
  late final _media_packet_get_video_stride_width =
      _media_packet_get_video_stride_widthPtr.asFunction<
          int Function(media_packet_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets stride height from tbm surface in the given media packet.
  /// @details Use only if the media_format_h is #MEDIA_FORMAT_RAW and #MEDIA_FORMAT_VIDEO.
  /// It means that media_packet_h's buffer is allocated on tbm_surface.
  /// If not sure of that, use media_packet_is_video() and media_packet_is_raw() or media_packet_has_tbm_surface_buffer().
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in]  packet   The media packet handle
  /// @param[in]  plane_idx   The plane index value
  /// @param[out] stride_height  The stride height value from tbm_surface
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_video_stride_height(
    media_packet_h packet,
    int plane_idx,
    ffi.Pointer<ffi.Int> stride_height,
  ) {
    return _media_packet_get_video_stride_height(
      packet,
      plane_idx,
      stride_height,
    );
  }

  late final _media_packet_get_video_stride_heightPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('media_packet_get_video_stride_height');
  late final _media_packet_get_video_stride_height =
      _media_packet_get_video_stride_heightPtr.asFunction<
          int Function(media_packet_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets plane data pointer from tbm surface in the given media packet.
  /// @details Use only if the media_format_h is #MEDIA_FORMAT_RAW and #MEDIA_FORMAT_VIDEO.
  /// It means that media_packet_h's buffer is allocated on tbm_surface.
  /// If not sure of that, use media_packet_is_video() and media_packet_is_raw() or media_packet_has_tbm_surface_buffer().
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks The @c plane_data_ptr must not be released by using free(). Note that It is released by media_packet_destory() or tbm_surface_destroy().
  /// @param[in]  packet   The media packet handle
  /// @param[in]  plane_idx   The plane index value
  /// @param[out] plane_data_ptr  The plane data pointer from tbm_surface
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_video_plane_data_ptr(
    media_packet_h packet,
    int plane_idx,
    ffi.Pointer<ffi.Pointer<ffi.Void>> plane_data_ptr,
  ) {
    return _media_packet_get_video_plane_data_ptr(
      packet,
      plane_idx,
      plane_data_ptr,
    );
  }

  late final _media_packet_get_video_plane_data_ptrPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(media_packet_h, ffi.Int,
                  ffi.Pointer<ffi.Pointer<ffi.Void>>)>>(
      'media_packet_get_video_plane_data_ptr');
  late final _media_packet_get_video_plane_data_ptr =
      _media_packet_get_video_plane_data_ptrPtr.asFunction<
          int Function(
              media_packet_h, int, ffi.Pointer<ffi.Pointer<ffi.Void>>)>();

  /// @brief Gets codec data and the codec data size of media packet.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] packet   The media packet handle
  /// @param[out] codec_data    The codec data to get
  /// @param[out] codec_data_size    The codec data size to get
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  int media_packet_get_codec_data(
    media_packet_h packet,
    ffi.Pointer<ffi.Pointer<ffi.Void>> codec_data,
    ffi.Pointer<ffi.UnsignedInt> codec_data_size,
  ) {
    return _media_packet_get_codec_data(
      packet,
      codec_data,
      codec_data_size,
    );
  }

  late final _media_packet_get_codec_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_h, ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.UnsignedInt>)>>('media_packet_get_codec_data');
  late final _media_packet_get_codec_data =
      _media_packet_get_codec_dataPtr.asFunction<
          int Function(media_packet_h, ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Destroys the media packet handle.
  /// @details  The registered finalize_callback() function will be invoked to destroy the media packet handle.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] packet  The handle to media packet to be destroyed
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE              Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see media_packet_create_alloc()
  /// @see media_packet_create()
  /// @see media_packet_copy()
  /// @see media_packet_create_from_tbm_surface()
  /// @see media_packet_create_from_external_memory()
  int media_packet_destroy(
    media_packet_h packet,
  ) {
    return _media_packet_destroy(
      packet,
    );
  }

  late final _media_packet_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_h)>>(
          'media_packet_destroy');
  late final _media_packet_destroy =
      _media_packet_destroyPtr.asFunction<int Function(media_packet_h)>();

  /// @brief Creates a new camera handle for controlling a camera.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Multiple handles on a context at the same time are allowed to be created. However,
  /// camera cannot guarantee proper operation because of limited resources, such as
  /// camera device, audio device, and display device.\n.
  /// A @a camera must be released using camera_destroy().
  /// @remarks The privilege %http://tizen.org/privilege/camera is not required since 4.0,\n
  /// but it is required in all earlier versions.
  /// @param[in] device The hardware camera to access
  /// @param[out] camera A newly returned handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CAMERA_ERROR_SOUND_POLICY Sound policy error
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @post If it succeeds, the camera state will be #CAMERA_STATE_CREATED.
  ///
  /// @see camera_destroy()
  int camera_create(
    int device,
    ffi.Pointer<camera_h> camera,
  ) {
    return _camera_create(
      device,
      camera,
    );
  }

  late final _camera_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Pointer<camera_h>)>>('camera_create');
  late final _camera_create =
      _camera_createPtr.asFunction<int Function(int, ffi.Pointer<camera_h>)>();

  /// @brief Changes the camera device.
  ///
  /// @since_tizen 3.0
  /// @remarks This function can be used to change camera device simply without camera_destroy() and camera_create().\n
  /// If display reuse hint is set by camera_set_display_reuse_hint() before stopping the preview,\n
  /// display handle will be reused and last frame on display can be kept even though camera device is changed.
  /// @param[in] camera The handle to the camera
  /// @param[in] device The hardware camera to access
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre    The camera state must be set to #CAMERA_STATE_CREATED.
  /// @post   If it succeeds, the camera attributes and settings will be reset.
  ///
  /// @see camera_set_display_reuse_hint()
  /// @see camera_get_display_reuse_hint()
  int camera_change_device(
    camera_h camera,
    int device,
  ) {
    return _camera_change_device(
      camera,
      device,
    );
  }

  late final _camera_change_devicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_change_device');
  late final _camera_change_device =
      _camera_change_devicePtr.asFunction<int Function(camera_h, int)>();

  /// @brief Destroys the camera handle and releases all its resources.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @see camera_create()
  int camera_destroy(
    camera_h camera,
  ) {
    return _camera_destroy(
      camera,
    );
  }

  late final _camera_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>('camera_destroy');
  late final _camera_destroy =
      _camera_destroyPtr.asFunction<int Function(camera_h)>();

  /// @brief Starts capturing and drawing preview frames on the screen.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/camera
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_SOUND_POLICY Sound policy error
  /// @retval #CAMERA_ERROR_RESOURCE_CONFLICT Resource conflict error
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_DEVICE_BUSY The device is being used in another application or is performing other operations
  /// @retval #CAMERA_ERROR_DEVICE_NOT_FOUND No camera device
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre    The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_CAPTURED.\n
  /// You must set the display handle. \n
  /// If needed, modify preview FPS(camera_attr_set_preview_fps()),
  /// preview resolution(camera_set_preview_resolution()), or preview format(camera_set_preview_format()).
  /// @post   If it succeeds, the camera state will be #CAMERA_STATE_PREVIEW.\n
  /// camera_preview_cb() will be called when preview image data becomes available.
  ///
  /// @see	camera_stop_preview()
  /// @see camera_set_display()
  /// @see camera_set_preview_cb()
  /// @see camera_set_media_packet_preview_cb()
  /// @see camera_foreach_supported_preview_resolution()
  /// @see camera_set_preview_resolution()
  /// @see camera_get_preview_resolution()
  /// @see camera_foreach_supported_preview_format()
  /// @see camera_set_preview_format()
  /// @see camera_get_preview_format()
  /// @see camera_attr_foreach_supported_fps()
  /// @see camera_attr_set_preview_fps()
  /// @see camera_attr_get_preview_fps()
  int camera_start_preview(
    camera_h camera,
  ) {
    return _camera_start_preview(
      camera,
    );
  }

  late final _camera_start_previewPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_start_preview');
  late final _camera_start_preview =
      _camera_start_previewPtr.asFunction<int Function(camera_h)>();

  /// @brief Stops capturing and drawing preview frames.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/camera
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_PREVIEW.
  /// @post The camera state will be #CAMERA_STATE_CREATED.
  /// @see	camera_start_preview()
  /// @see	camera_unset_preview_cb()
  /// @see	camera_unset_media_packet_preview_cb()
  int camera_stop_preview(
    camera_h camera,
  ) {
    return _camera_stop_preview(
      camera,
    );
  }

  late final _camera_stop_previewPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_stop_preview');
  late final _camera_stop_preview =
      _camera_stop_previewPtr.asFunction<int Function(camera_h)>();

  /// @brief Starts capturing of still images.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/camera
  /// @remarks This function causes the transition of the camera state from #CAMERA_STATE_CAPTURING to #CAMERA_STATE_CAPTURED automatically\n
  /// and the corresponding callback function camera_capturing_cb() and camera_capture_completed_cb() will be invoked\n
  /// The captured image will be delivered through camera_capturing_cb().\n
  /// camera_capture_completed_cb() callback notifies about completion of camera_capturing_cb(). \n
  /// The camera's preview should be restarted by calling camera_start_preview().
  /// @param[in] camera The handle to the camera
  /// @param[in] capturing_cb The callback for capturing data
  /// @param[in] completed_cb The callback for notification of completion
  /// @param[in] user_data The user data
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_PREVIEW. \n
  /// If needed, modify capture resolution(camera_set_capture_resolution()),
  /// capture format(camera_set_capture_format()), or image quality(camera_attr_set_image_quality()).
  /// @post If it succeeds the camera state will be #CAMERA_STATE_CAPTURED.
  ///
  /// @see camera_start_preview()
  /// @see camera_start_continuous_capture();
  /// @see camera_foreach_supported_capture_resolution()
  /// @see camera_set_capture_resolution()
  /// @see camera_get_capture_resolution()
  /// @see camera_foreach_supported_capture_format()
  /// @see camera_set_capture_format()
  /// @see camera_get_capture_format()
  /// @see camera_attr_set_image_quality()
  /// @see camera_attr_get_image_quality()
  int camera_start_capture(
    camera_h camera,
    camera_capturing_cb capturing_cb,
    camera_capture_completed_cb completed_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_start_capture(
      camera,
      capturing_cb,
      completed_cb,
      user_data,
    );
  }

  late final _camera_start_capturePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h,
              camera_capturing_cb,
              camera_capture_completed_cb,
              ffi.Pointer<ffi.Void>)>>('camera_start_capture');
  late final _camera_start_capture = _camera_start_capturePtr.asFunction<
      int Function(camera_h, camera_capturing_cb, camera_capture_completed_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Starts continuously capturing still images.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/camera
  /// @remarks If this is not supported zero shutter lag occurs. The capture resolution could be changed to the preview resolution.\n
  /// This function causes the transition of the camera state from #CAMERA_STATE_CAPTURING to #CAMERA_STATE_CAPTURED automatically\n
  /// and the corresponding callback function camera_capturing_cb() and camera_capture_completed_cb() will be invoked\n
  /// Each Captured image will be delivered through camera_capturing_cb().\n
  /// The camera_capture_completed_cb() callback notifies about the completion of an entire capture.\n
  /// The camera's preview should be restarted by calling camera_start_preview().\n.
  /// @param[in] camera The handle to the camera
  /// @param[in] count The number of still images
  /// @param[in] interval The interval of the capture (millisecond)
  /// @param[in] capturing_cb The callback for capturing data
  /// @param[in] completed_cb The callback for notification of completion
  /// @param[in] user_data The user data
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post   If it succeeds the camera state will be #CAMERA_STATE_CAPTURED.
  ///
  /// @see camera_start_preview()
  /// @see camera_start_capture();
  /// @see camera_stop_continuous_capture()
  /// @see camera_is_supported_zero_shutter_lag()
  int camera_start_continuous_capture(
    camera_h camera,
    int count,
    int interval,
    camera_capturing_cb capturing_cb,
    camera_capture_completed_cb completed_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_start_continuous_capture(
      camera,
      count,
      interval,
      capturing_cb,
      completed_cb,
      user_data,
    );
  }

  late final _camera_start_continuous_capturePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h,
              ffi.Int,
              ffi.Int,
              camera_capturing_cb,
              camera_capture_completed_cb,
              ffi.Pointer<ffi.Void>)>>('camera_start_continuous_capture');
  late final _camera_start_continuous_capture =
      _camera_start_continuous_capturePtr.asFunction<
          int Function(camera_h, int, int, camera_capturing_cb,
              camera_capture_completed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Aborts continuous capturing.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/camera
  /// @remarks The camera state will be changed to #CAMERA_STATE_CAPTURED.
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_PREVIEW.
  ///
  /// @see camera_start_continuous_capture()
  int camera_stop_continuous_capture(
    camera_h camera,
  ) {
    return _camera_stop_continuous_capture(
      camera,
    );
  }

  late final _camera_stop_continuous_capturePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_stop_continuous_capture');
  late final _camera_stop_continuous_capture =
      _camera_stop_continuous_capturePtr.asFunction<int Function(camera_h)>();

  /// @brief Gets the state of the camera.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] state The current state of the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_create()
  /// @see camera_start_preview()
  /// @see camera_stop_preview()
  /// @see camera_start_capture()
  int camera_get_state(
    camera_h camera,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _camera_get_state(
      camera,
      state,
    );
  }

  late final _camera_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_get_state');
  late final _camera_get_state = _camera_get_statePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Starts camera auto-focusing, asynchronously.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/camera
  /// @remarks If continuous status is @c true, the camera continuously tries to focus.
  /// @param[in] camera The handle to the camera
  /// @param[in] continuous The status of continuous focusing
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_PREVIEW.
  /// @post The camera focus state will be #CAMERA_FOCUS_STATE_ONGOING.
  ///
  /// @see camera_cancel_focusing()
  /// @see camera_set_focus_changed_cb()
  /// @see camera_focus_changed_cb()
  /// @see camera_attr_set_af_mode()
  int camera_start_focusing(
    camera_h camera,
    bool continuous,
  ) {
    return _camera_start_focusing(
      camera,
      continuous,
    );
  }

  late final _camera_start_focusingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Bool)>>(
          'camera_start_focusing');
  late final _camera_start_focusing =
      _camera_start_focusingPtr.asFunction<int Function(camera_h, bool)>();

  /// @brief Stops camera auto focusing.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/camera
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_PREVIEW.
  ///
  /// @see camera_start_focusing()
  /// @see	camera_focus_changed_cb()
  int camera_cancel_focusing(
    camera_h camera,
  ) {
    return _camera_cancel_focusing(
      camera,
    );
  }

  late final _camera_cancel_focusingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_cancel_focusing');
  late final _camera_cancel_focusing =
      _camera_cancel_focusingPtr.asFunction<int Function(camera_h)>();

  /// @brief Sets the display handle to show preview images.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This function must be called before previewing (see camera_start_preview()).
  /// In Custom ROI display mode, camera_attr_set_display_roi_area() function must be called before calling this function.
  /// @param[in] camera The handle to the camera
  /// @param[in] type The display type
  /// @param[in] display The display handle from #GET_DISPLAY
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED.
  ///
  /// @see camera_start_preview()
  /// @see #GET_DISPLAY
  int camera_set_display(
    camera_h camera,
    int type,
    camera_display_h display,
  ) {
    return _camera_set_display(
      camera,
      type,
      display,
    );
  }

  late final _camera_set_displayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Int32, camera_display_h)>>('camera_set_display');
  late final _camera_set_display = _camera_set_displayPtr
      .asFunction<int Function(camera_h, int, camera_display_h)>();

  /// @brief Sets the resolution of the preview.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This function should be called before previewing (camera_start_preview()).
  /// @param[in] camera The handle to the camera
  /// @param[in] width The preview width
  /// @param[in] height The preview height
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  ///
  /// @see camera_start_preview()
  /// @see	camera_get_preview_resolution()
  /// @see	camera_foreach_supported_preview_resolution()
  int camera_set_preview_resolution(
    camera_h camera,
    int width,
    int height,
  ) {
    return _camera_set_preview_resolution(
      camera,
      width,
      height,
    );
  }

  late final _camera_set_preview_resolutionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int, ffi.Int)>>(
          'camera_set_preview_resolution');
  late final _camera_set_preview_resolution = _camera_set_preview_resolutionPtr
      .asFunction<int Function(camera_h, int, int)>();

  /// @brief Gets the resolution of the preview.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] width The preview width
  /// @param[out] height The preview height
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_set_preview_resolution()
  /// @see	camera_foreach_supported_preview_resolution()
  int camera_get_preview_resolution(
    camera_h camera,
    ffi.Pointer<ffi.Int> width,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _camera_get_preview_resolution(
      camera,
      width,
      height,
    );
  }

  late final _camera_get_preview_resolutionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('camera_get_preview_resolution');
  late final _camera_get_preview_resolution =
      _camera_get_preview_resolutionPtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the recommended preview resolution.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Depending on the capture resolution aspect ratio and display resolution, the recommended preview resolution is determined.
  /// @param[in] camera The handle to the camera
  /// @param[out] width The preview width
  /// @param[out] height The preview height
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_set_preview_resolution()
  /// @see	camera_foreach_supported_preview_resolution()
  int camera_get_recommended_preview_resolution(
    camera_h camera,
    ffi.Pointer<ffi.Int> width,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _camera_get_recommended_preview_resolution(
      camera,
      width,
      height,
    );
  }

  late final _camera_get_recommended_preview_resolutionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>>(
      'camera_get_recommended_preview_resolution');
  late final _camera_get_recommended_preview_resolution =
      _camera_get_recommended_preview_resolutionPtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Starts face detection.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/camera
  /// @remarks This should be called after the preview is started.\n
  /// This callback will be invoked when the face is detected in the preview frame.\n
  /// Internally it starts continuous focus and focusing on the detected face.\n
  /// When face detection is running, the camera_start_focusing(), camera_cancel_focusing(), camera_attr_set_af_mode(), camera_attr_set_af_area(), camera_attr_set_exposure_mode(), and camera_attr_set_whitebalance() settings are ignored.\n
  /// If camera_stop_preview() is invoked, face detection is stopped and then preview is resumed using camera_start_preview(), this method should be called again to resume face detection.
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback to notify face detection
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Not preview state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Not supported this feature
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be #CAMERA_STATE_PREVIEW.
  ///
  /// @see camera_stop_face_detection()
  /// @see camera_face_detected_cb()
  /// @see camera_is_supported_face_detection()
  int camera_start_face_detection(
    camera_h camera,
    camera_face_detected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_start_face_detection(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_start_face_detectionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_face_detected_cb,
              ffi.Pointer<ffi.Void>)>>('camera_start_face_detection');
  late final _camera_start_face_detection =
      _camera_start_face_detectionPtr.asFunction<
          int Function(
              camera_h, camera_face_detected_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Stops face detection.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/camera
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre This should be called after face detection is started.
  ///
  /// @see camera_start_face_detection()
  /// @see camera_is_supported_face_detection()
  int camera_stop_face_detection(
    camera_h camera,
  ) {
    return _camera_stop_face_detection(
      camera,
    );
  }

  late final _camera_stop_face_detectionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_stop_face_detection');
  late final _camera_stop_face_detection =
      _camera_stop_face_detectionPtr.asFunction<int Function(camera_h)>();

  /// @brief Gets continuous capture feature's supported state.
  /// @ingroup CAPI_MEDIA_CAMERA_CAPABILITY_MODULE
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] camera The handle to the camera
  /// @return @c true on supported, otherwise false
  /// @exception #CAMERA_ERROR_NONE Successful
  /// @exception #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @exception #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  bool camera_is_supported_continuous_capture(
    camera_h camera,
  ) {
    return _camera_is_supported_continuous_capture(
      camera,
    );
  }

  late final _camera_is_supported_continuous_capturePtr =
      _lookup<ffi.NativeFunction<ffi.Bool Function(camera_h)>>(
          'camera_is_supported_continuous_capture');
  late final _camera_is_supported_continuous_capture =
      _camera_is_supported_continuous_capturePtr
          .asFunction<bool Function(camera_h)>();

  /// @brief Retrieves all supported camera preview resolutions by invoking the callback function once for each supported camera preview resolution.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to be invoked
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_supported_preview_resolution_cb() repeatedly to retrieve each supported preview resolution.
  ///
  /// @see	camera_set_preview_resolution()
  /// @see	camera_get_preview_resolution()
  /// @see	camera_supported_preview_resolution_cb()
  int camera_foreach_supported_preview_resolution(
    camera_h camera,
    camera_supported_preview_resolution_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_foreach_supported_preview_resolution(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_foreach_supported_preview_resolutionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_supported_preview_resolution_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_foreach_supported_preview_resolution');
  late final _camera_foreach_supported_preview_resolution =
      _camera_foreach_supported_preview_resolutionPtr.asFunction<
          int Function(camera_h, camera_supported_preview_resolution_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_MEDIA_CAMERA_DISPLAY_MODULE
  /// @brief Sets the display rotation.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This function should be called before previewing (see camera_start_preview())
  /// @param[in] camera The handle to the camera
  /// @param[in] rotation The display rotation
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Display type is incorrect
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_start_preview()
  /// @see	camera_get_display_rotation()
  int camera_set_display_rotation(
    camera_h camera,
    int rotation,
  ) {
    return _camera_set_display_rotation(
      camera,
      rotation,
    );
  }

  late final _camera_set_display_rotationPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_set_display_rotation');
  late final _camera_set_display_rotation =
      _camera_set_display_rotationPtr.asFunction<int Function(camera_h, int)>();

  /// @ingroup CAPI_MEDIA_CAMERA_DISPLAY_MODULE
  /// @brief Gets the display rotation.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] rotation The display rotation
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_display_rotation()
  int camera_get_display_rotation(
    camera_h camera,
    ffi.Pointer<ffi.Int32> rotation,
  ) {
    return _camera_get_display_rotation(
      camera,
      rotation,
    );
  }

  late final _camera_get_display_rotationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Int32>)>>('camera_get_display_rotation');
  late final _camera_get_display_rotation = _camera_get_display_rotationPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_MEDIA_CAMERA_DISPLAY_MODULE
  /// @brief Sets the display flip.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] flip The display flip
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Display type is incorrect
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_get_display_flip()
  int camera_set_display_flip(
    camera_h camera,
    int flip,
  ) {
    return _camera_set_display_flip(
      camera,
      flip,
    );
  }

  late final _camera_set_display_flipPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_set_display_flip');
  late final _camera_set_display_flip =
      _camera_set_display_flipPtr.asFunction<int Function(camera_h, int)>();

  /// @ingroup CAPI_MEDIA_CAMERA_DISPLAY_MODULE
  /// @brief Gets the display flip.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] flip The display flip
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_display_flip()
  int camera_get_display_flip(
    camera_h camera,
    ffi.Pointer<ffi.Int32> flip,
  ) {
    return _camera_get_display_flip(
      camera,
      flip,
    );
  }

  late final _camera_get_display_flipPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_get_display_flip');
  late final _camera_get_display_flip = _camera_get_display_flipPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_MEDIA_CAMERA_DISPLAY_MODULE
  /// @brief Sets the visible property for display.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] visible The display visibility property
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_is_display_visible()
  int camera_set_display_visible(
    camera_h camera,
    bool visible,
  ) {
    return _camera_set_display_visible(
      camera,
      visible,
    );
  }

  late final _camera_set_display_visiblePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Bool)>>(
          'camera_set_display_visible');
  late final _camera_set_display_visible =
      _camera_set_display_visiblePtr.asFunction<int Function(camera_h, bool)>();

  /// @ingroup CAPI_MEDIA_CAMERA_DISPLAY_MODULE
  /// @brief Gets the visible property of display.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] visible @c true if camera display is visible, otherwise @c false
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_display_visible()
  int camera_is_display_visible(
    camera_h camera,
    ffi.Pointer<ffi.Bool> visible,
  ) {
    return _camera_is_display_visible(
      camera,
      visible,
    );
  }

  late final _camera_is_display_visiblePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Bool>)>>('camera_is_display_visible');
  late final _camera_is_display_visible = _camera_is_display_visiblePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Bool>)>();

  /// @ingroup CAPI_MEDIA_CAMERA_DISPLAY_MODULE
  /// @brief Sets the display mode.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] mode The display mode
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_get_display_mode()
  int camera_set_display_mode(
    camera_h camera,
    int mode,
  ) {
    return _camera_set_display_mode(
      camera,
      mode,
    );
  }

  late final _camera_set_display_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_set_display_mode');
  late final _camera_set_display_mode =
      _camera_set_display_modePtr.asFunction<int Function(camera_h, int)>();

  /// @ingroup CAPI_MEDIA_CAMERA_DISPLAY_MODULE
  /// @brief Gets the display mode.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] mode The display mode
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_display_mode()
  int camera_get_display_mode(
    camera_h camera,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _camera_get_display_mode(
      camera,
      mode,
    );
  }

  late final _camera_get_display_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_get_display_mode');
  late final _camera_get_display_mode = _camera_get_display_modePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the hint for display reuse.
  /// @since_tizen 3.0
  /// @details If the hint is set to true, the display will be reused when the camera device is changed with camera_change_device().
  /// @remarks If the current display type is #CAMERA_DISPLAY_TYPE_NONE, this function will return #CAMERA_ERROR_INVALID_OPERATION.
  /// @param[in] camera The handle to the camera
  /// @param[in] hint The hint for display reuse; true - reuse the display, false - do not reuse
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre    The camera state must be set to #CAMERA_STATE_PREVIEW.
  /// @see camera_get_display_reuse_hint()
  /// @see camera_change_device()
  int camera_set_display_reuse_hint(
    camera_h camera,
    bool hint,
  ) {
    return _camera_set_display_reuse_hint(
      camera,
      hint,
    );
  }

  late final _camera_set_display_reuse_hintPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Bool)>>(
          'camera_set_display_reuse_hint');
  late final _camera_set_display_reuse_hint = _camera_set_display_reuse_hintPtr
      .asFunction<int Function(camera_h, bool)>();

  /// @brief Gets the hint for display reuse.
  /// @since_tizen 3.0
  /// @remarks If the current display type is #CAMERA_DISPLAY_TYPE_NONE, this function will return #CAMERA_ERROR_INVALID_OPERATION.
  /// @param[in] camera The handle to the camera
  /// @param[out] hint The hint for display reuse; true - reuse the display, false - do not reuse
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_get_display_reuse_hint()
  /// @see camera_change_device()
  int camera_get_display_reuse_hint(
    camera_h camera,
    ffi.Pointer<ffi.Bool> hint,
  ) {
    return _camera_get_display_reuse_hint(
      camera,
      hint,
    );
  }

  late final _camera_get_display_reuse_hintPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Bool>)>>('camera_get_display_reuse_hint');
  late final _camera_get_display_reuse_hint = _camera_get_display_reuse_hintPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the resolution of the captured image.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] width The capture width
  /// @param[in] height The capture height
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_start_capture()
  /// @see	camera_get_capture_resolution()
  /// @see	camera_foreach_supported_capture_resolution()
  int camera_set_capture_resolution(
    camera_h camera,
    int width,
    int height,
  ) {
    return _camera_set_capture_resolution(
      camera,
      width,
      height,
    );
  }

  late final _camera_set_capture_resolutionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int, ffi.Int)>>(
          'camera_set_capture_resolution');
  late final _camera_set_capture_resolution = _camera_set_capture_resolutionPtr
      .asFunction<int Function(camera_h, int, int)>();

  /// @brief Gets the resolution of the captured image.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] width The capture width
  /// @param[out] height The capture height
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_capture_resolution()
  /// @see camera_foreach_supported_capture_resolution()
  int camera_get_capture_resolution(
    camera_h camera,
    ffi.Pointer<ffi.Int> width,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _camera_get_capture_resolution(
      camera,
      width,
      height,
    );
  }

  late final _camera_get_capture_resolutionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('camera_get_capture_resolution');
  late final _camera_get_capture_resolution =
      _camera_get_capture_resolutionPtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Retrieves all supported camera captured resolutions by invoking the callback function once for each supported camera capture resolution.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_supported_capture_resolution_cb() repeatedly to retrieve each supported capture resolution.
  /// @see camera_set_capture_resolution()
  /// @see camera_get_capture_resolution()
  /// @see	camera_supported_capture_resolution_cb()
  int camera_foreach_supported_capture_resolution(
    camera_h camera,
    camera_supported_capture_resolution_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_foreach_supported_capture_resolution(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_foreach_supported_capture_resolutionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_supported_capture_resolution_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_foreach_supported_capture_resolution');
  late final _camera_foreach_supported_capture_resolution =
      _camera_foreach_supported_capture_resolutionPtr.asFunction<
          int Function(camera_h, camera_supported_capture_resolution_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the format of an image to be captured.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This function should be called before capturing (see camera_start_capture()).
  /// @param[in] camera The handle to the camera
  /// @param[out] format The format of the image to be captured
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre	The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_start_capture()
  /// @see	camera_get_capture_format()
  /// @see	camera_foreach_supported_capture_format()
  int camera_set_capture_format(
    camera_h camera,
    int format,
  ) {
    return _camera_set_capture_format(
      camera,
      format,
    );
  }

  late final _camera_set_capture_formatPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_set_capture_format');
  late final _camera_set_capture_format =
      _camera_set_capture_formatPtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the format of the image to be captured.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] format The format of the image to be captured
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_set_capture_format()
  /// @see	camera_foreach_supported_capture_format()
  int camera_get_capture_format(
    camera_h camera,
    ffi.Pointer<ffi.Int32> format,
  ) {
    return _camera_get_capture_format(
      camera,
      format,
    );
  }

  late final _camera_get_capture_formatPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_get_capture_format');
  late final _camera_get_capture_format = _camera_get_capture_formatPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported camera capture formats by invoking the callback function once for each supported camera capture format.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to be invoked
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_supported_capture_format_cb() repeatedly to retrieve each supported capture format.
  /// @see	camera_set_capture_format()
  /// @see	camera_get_capture_format()
  /// @see	camera_supported_capture_format_cb()
  int camera_foreach_supported_capture_format(
    camera_h camera,
    camera_supported_capture_format_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_foreach_supported_capture_format(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_foreach_supported_capture_formatPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_supported_capture_format_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_foreach_supported_capture_format');
  late final _camera_foreach_supported_capture_format =
      _camera_foreach_supported_capture_formatPtr.asFunction<
          int Function(camera_h, camera_supported_capture_format_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the preview data format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This function should be called before previewing (see camera_start_preview()).
  /// @param[in] camera The handle to the camera
  /// @param[in] format The preview data format
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED.
  /// @see camera_start_preview()
  /// @see	camera_get_preview_format()
  /// @see	camera_foreach_supported_preview_format()
  int camera_set_preview_format(
    camera_h camera,
    int format,
  ) {
    return _camera_set_preview_format(
      camera,
      format,
    );
  }

  late final _camera_set_preview_formatPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_set_preview_format');
  late final _camera_set_preview_format =
      _camera_set_preview_formatPtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the format of the preview stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] format The preview data format
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_set_preview_format()
  /// @see	camera_foreach_supported_preview_format()
  int camera_get_preview_format(
    camera_h camera,
    ffi.Pointer<ffi.Int32> format,
  ) {
    return _camera_get_preview_format(
      camera,
      format,
    );
  }

  late final _camera_get_preview_formatPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_get_preview_format');
  late final _camera_get_preview_format = _camera_get_preview_formatPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the facing direction of camera module.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[out] facing_direction The facing direction of camera module
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  int camera_get_facing_direction(
    camera_h camera,
    ffi.Pointer<ffi.Int32> facing_direction,
  ) {
    return _camera_get_facing_direction(
      camera,
      facing_direction,
    );
  }

  late final _camera_get_facing_directionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Int32>)>>('camera_get_facing_direction');
  late final _camera_get_facing_direction = _camera_get_facing_directionPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the camera's flash state.
  /// @since_tizen 3.0
  /// @param[in] device The hardware camera to access
  /// @param[out] state The current flash state
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @see camera_attr_set_flash_mode()
  /// @see camera_attr_get_flash_mode()
  int camera_get_flash_state(
    int device,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _camera_get_flash_state(
      device,
      state,
    );
  }

  late final _camera_get_flash_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Int32>)>>('camera_get_flash_state');
  late final _camera_get_flash_state = _camera_get_flash_statePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported camera preview formats by invoking the callback function once for each supported camera preview format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to be invoked
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_supported_preview_format_cb() repeatedly to retrieve each supported preview format.
  /// @see	camera_set_preview_format()
  /// @see	camera_get_preview_format()
  /// @see	camera_supported_preview_format_cb()
  int camera_foreach_supported_preview_format(
    camera_h camera,
    camera_supported_preview_format_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_foreach_supported_preview_format(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_foreach_supported_preview_formatPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_supported_preview_format_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_foreach_supported_preview_format');
  late final _camera_foreach_supported_preview_format =
      _camera_foreach_supported_preview_formatPtr.asFunction<
          int Function(camera_h, camera_supported_preview_format_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_MEDIA_CAMERA_CAPABILITY_MODULE
  /// @brief Gets the face detection feature's supported state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] camera The handle to the camera
  /// @return @c true if supported, otherwise @c false
  /// @see camera_start_face_detection()
  /// @see camera_stop_face_detection()
  /// @exception #CAMERA_ERROR_NONE Successful
  /// @exception #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @exception #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  bool camera_is_supported_face_detection(
    camera_h camera,
  ) {
    return _camera_is_supported_face_detection(
      camera,
    );
  }

  late final _camera_is_supported_face_detectionPtr =
      _lookup<ffi.NativeFunction<ffi.Bool Function(camera_h)>>(
          'camera_is_supported_face_detection');
  late final _camera_is_supported_face_detection =
      _camera_is_supported_face_detectionPtr
          .asFunction<bool Function(camera_h)>();

  /// @brief Gets the zero shutter lag feature's supported state.
  /// @ingroup CAPI_MEDIA_CAMERA_CAPABILITY_MODULE
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If supporting zero shutter lag, continuous shot can be done with full capture size. \n
  /// The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] camera The handle to the camera
  /// @return @c true if supported, otherwise @c false
  /// @exception #CAMERA_ERROR_NONE Successful
  /// @exception #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @exception #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  bool camera_is_supported_zero_shutter_lag(
    camera_h camera,
  ) {
    return _camera_is_supported_zero_shutter_lag(
      camera,
    );
  }

  late final _camera_is_supported_zero_shutter_lagPtr =
      _lookup<ffi.NativeFunction<ffi.Bool Function(camera_h)>>(
          'camera_is_supported_zero_shutter_lag');
  late final _camera_is_supported_zero_shutter_lag =
      _camera_is_supported_zero_shutter_lagPtr
          .asFunction<bool Function(camera_h)>();

  /// @ingroup CAPI_MEDIA_CAMERA_CAPABILITY_MODULE
  /// @brief Gets the camera device count.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If the device supports primary and secondary camera, this returns @c 2. If @c 1 is returned, the device only supports primary camera.
  /// @param[in] camera The handle to the camera
  /// @param[out] device_count The device count
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  int camera_get_device_count(
    camera_h camera,
    ffi.Pointer<ffi.Int> device_count,
  ) {
    return _camera_get_device_count(
      camera,
      device_count,
    );
  }

  late final _camera_get_device_countPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_get_device_count');
  late final _camera_get_device_count = _camera_get_device_countPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the media packet preview callback feature's supported state.
  /// @ingroup CAPI_MEDIA_CAMERA_CAPABILITY_MODULE
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] camera The handle to the camera
  /// @return @c true if supported, otherwise @c false
  /// @exception #CAMERA_ERROR_NONE Successful
  /// @exception #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @exception #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  bool camera_is_supported_media_packet_preview_cb(
    camera_h camera,
  ) {
    return _camera_is_supported_media_packet_preview_cb(
      camera,
    );
  }

  late final _camera_is_supported_media_packet_preview_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Bool Function(camera_h)>>(
          'camera_is_supported_media_packet_preview_cb');
  late final _camera_is_supported_media_packet_preview_cb =
      _camera_is_supported_media_packet_preview_cbPtr
          .asFunction<bool Function(camera_h)>();

  /// @brief Registers a callback function to be called once per frame when previewing.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This callback does not work in the video recorder mode.\n
  /// Before 4.0, the only allowed state for calling this function was #CAMERA_STATE_CREATED.\n
  /// Since 4.0, #CAMERA_STATE_PREVIEW has been added as an allowed state,\n
  /// so that this function could be called before previewing or even while previewing.\n
  /// A registered callback is called on the internal thread of the camera.\n
  /// A video frame can be retrieved using a registered callback,\n
  /// and the buffer is only available in a registered callback.\n
  /// Since tizen 3.0, if you change the buffer in a registered callback,\n
  /// it could not be displayed on the device in case of copied buffer.\n
  /// and if camera_is_supported_media_packet_preview_cb() returns false,\n
  /// it's copied buffer case.
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to be registered
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre	Before 4.0 : The camera state must be set to #CAMERA_STATE_CREATED.\n
  /// Since  4.0 : The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see	camera_start_preview()
  /// @see	camera_unset_preview_cb()
  /// @see	camera_preview_cb()
  int camera_set_preview_cb(
    camera_h camera,
    camera_preview_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_set_preview_cb(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_set_preview_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_preview_cb,
              ffi.Pointer<ffi.Void>)>>('camera_set_preview_cb');
  late final _camera_set_preview_cb = _camera_set_preview_cbPtr.asFunction<
      int Function(camera_h, camera_preview_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_preview_cb()
  int camera_unset_preview_cb(
    camera_h camera,
  ) {
    return _camera_unset_preview_cb(
      camera,
    );
  }

  late final _camera_unset_preview_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_unset_preview_cb');
  late final _camera_unset_preview_cb =
      _camera_unset_preview_cbPtr.asFunction<int Function(camera_h)>();

  /// @brief Registers a media packet callback function to be called once per frame when previewing.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This callback does not work in video recorder mode.\n
  /// This function should be called before previewing (see camera_start_preview())\n
  /// A registered callback is called on the internal thread of the camera.\n
  /// A video frame can be retrieved using a registered callback as a media packet.\n
  /// The callback function holds the same buffer that will be drawn on the display device.\n
  /// So if you change the media packet in a registered callback, it will be displayed on the device\n
  /// and the media packet is available until it's destroyed by media_packet_destroy().
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to be registered
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre	The camera's state should be #CAMERA_STATE_CREATED.
  /// @see	camera_start_preview()
  /// @see	camera_unset_media_packet_preview_cb()
  /// @see	camera_media_packet_preview_cb()
  int camera_set_media_packet_preview_cb(
    camera_h camera,
    camera_media_packet_preview_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_set_media_packet_preview_cb(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_set_media_packet_preview_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_media_packet_preview_cb,
              ffi.Pointer<ffi.Void>)>>('camera_set_media_packet_preview_cb');
  late final _camera_set_media_packet_preview_cb =
      _camera_set_media_packet_preview_cbPtr.asFunction<
          int Function(camera_h, camera_media_packet_preview_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the media packet callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_set_media_packet_preview_cb()
  int camera_unset_media_packet_preview_cb(
    camera_h camera,
  ) {
    return _camera_unset_media_packet_preview_cb(
      camera,
    );
  }

  late final _camera_unset_media_packet_preview_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_unset_media_packet_preview_cb');
  late final _camera_unset_media_packet_preview_cb =
      _camera_unset_media_packet_preview_cbPtr
          .asFunction<int Function(camera_h)>();

  /// @brief Registers a callback function to be called when the camera state changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function will invoke camera_state_changed_cb() when the camera state changes.
  /// @see camera_unset_state_changed_cb()
  /// @see	camera_state_changed_cb()
  int camera_set_state_changed_cb(
    camera_h camera,
    camera_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_set_state_changed_cb(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('camera_set_state_changed_cb');
  late final _camera_set_state_changed_cb =
      _camera_set_state_changed_cbPtr.asFunction<
          int Function(
              camera_h, camera_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_state_changed_cb()
  int camera_unset_state_changed_cb(
    camera_h camera,
  ) {
    return _camera_unset_state_changed_cb(
      camera,
    );
  }

  late final _camera_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_unset_state_changed_cb');
  late final _camera_unset_state_changed_cb =
      _camera_unset_state_changed_cbPtr.asFunction<int Function(camera_h)>();

  /// @brief Registers a callback function to be called when the camera is interrupted by policy.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_unset_interrupted_cb()
  /// @see	camera_interrupted_cb()
  int camera_set_interrupted_cb(
    camera_h camera,
    camera_interrupted_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_set_interrupted_cb(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_set_interrupted_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_interrupted_cb,
              ffi.Pointer<ffi.Void>)>>('camera_set_interrupted_cb');
  late final _camera_set_interrupted_cb =
      _camera_set_interrupted_cbPtr.asFunction<
          int Function(
              camera_h, camera_interrupted_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_interrupted_cb()
  int camera_unset_interrupted_cb(
    camera_h camera,
  ) {
    return _camera_unset_interrupted_cb(
      camera,
    );
  }

  late final _camera_unset_interrupted_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_unset_interrupted_cb');
  late final _camera_unset_interrupted_cb =
      _camera_unset_interrupted_cbPtr.asFunction<int Function(camera_h)>();

  /// @brief Registers a callback function to be called when the camera interrupt is started by policy.
  /// @since_tizen 4.0
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see camera_unset_interrupt_started_cb()
  /// @see camera_interrupt_started_cb()
  int camera_set_interrupt_started_cb(
    camera_h camera,
    camera_interrupt_started_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_set_interrupt_started_cb(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_set_interrupt_started_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_interrupt_started_cb,
              ffi.Pointer<ffi.Void>)>>('camera_set_interrupt_started_cb');
  late final _camera_set_interrupt_started_cb =
      _camera_set_interrupt_started_cbPtr.asFunction<
          int Function(
              camera_h, camera_interrupt_started_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 4.0
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see camera_set_interrupt_started_cb()
  int camera_unset_interrupt_started_cb(
    camera_h camera,
  ) {
    return _camera_unset_interrupt_started_cb(
      camera,
    );
  }

  late final _camera_unset_interrupt_started_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_unset_interrupt_started_cb');
  late final _camera_unset_interrupt_started_cb =
      _camera_unset_interrupt_started_cbPtr
          .asFunction<int Function(camera_h)>();

  /// @brief Registers a callback function to be called when the auto-focus state changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function will invoke camera_focus_changed_cb() when the auto-focus state changes.
  /// @see	camera_start_focusing()
  /// @see	camera_cancel_focusing()
  /// @see	camera_unset_focus_changed_cb()
  /// @see	camera_focus_changed_cb()
  int camera_set_focus_changed_cb(
    camera_h camera,
    camera_focus_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_set_focus_changed_cb(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_set_focus_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_focus_changed_cb,
              ffi.Pointer<ffi.Void>)>>('camera_set_focus_changed_cb');
  late final _camera_set_focus_changed_cb =
      _camera_set_focus_changed_cbPtr.asFunction<
          int Function(
              camera_h, camera_focus_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_focus_changed_cb()
  int camera_unset_focus_changed_cb(
    camera_h camera,
  ) {
    return _camera_unset_focus_changed_cb(
      camera,
    );
  }

  late final _camera_unset_focus_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_unset_focus_changed_cb');
  late final _camera_unset_focus_changed_cb =
      _camera_unset_focus_changed_cbPtr.asFunction<int Function(camera_h)>();

  /// @brief Registers a callback function to be called when an asynchronous operation error occurs.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This callback informs about a critical error situation.\n
  /// When this callback is invoked, the user should release the resource and terminate the application.\n
  /// In case of errors, one of the following codes will occur:\n
  /// #CAMERA_ERROR_DEVICE,\n
  /// #CAMERA_ERROR_INVALID_OPERATION,\n
  /// #CAMERA_ERROR_OUT_OF_MEMORY.
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function will invoke camera_error_cb() when an asynchronous operation error occurs.
  ///
  /// @see camera_unset_error_cb()
  /// @see	camera_error_cb()
  int camera_set_error_cb(
    camera_h camera,
    camera_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_set_error_cb(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_error_cb,
              ffi.Pointer<ffi.Void>)>>('camera_set_error_cb');
  late final _camera_set_error_cb = _camera_set_error_cbPtr.asFunction<
      int Function(camera_h, camera_error_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_error_cb()
  int camera_unset_error_cb(
    camera_h camera,
  ) {
    return _camera_unset_error_cb(
      camera,
    );
  }

  late final _camera_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_unset_error_cb');
  late final _camera_unset_error_cb =
      _camera_unset_error_cbPtr.asFunction<int Function(camera_h)>();

  /// @brief Gets the state of camera device.
  /// @since_tizen 3.0
  /// @param[in] device The hardware camera type
  /// @param[out] state The current state of the device
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  int camera_get_device_state(
    int device,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _camera_get_device_state(
      device,
      state,
    );
  }

  late final _camera_get_device_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Int32>)>>('camera_get_device_state');
  late final _camera_get_device_state = _camera_get_device_statePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Registers a callback function to be called when the camera device state changes.
  /// @since_tizen 3.0
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @param[out] cb_id The id of registered callback
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @post This function will invoke camera_device_state_changed_cb() when the camera device's state changes.
  /// @see camera_remove_device_state_changed_cb()
  /// @see camera_device_state_changed_cb()
  int camera_add_device_state_changed_cb(
    camera_device_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> cb_id,
  ) {
    return _camera_add_device_state_changed_cb(
      callback,
      user_data,
      cb_id,
    );
  }

  late final _camera_add_device_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_device_state_changed_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('camera_add_device_state_changed_cb');
  late final _camera_add_device_state_changed_cb =
      _camera_add_device_state_changed_cbPtr.asFunction<
          int Function(camera_device_state_changed_cb, ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 3.0
  /// @param[in] cb_id The id of registered callback
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @see camera_add_device_state_changed_cb()
  int camera_remove_device_state_changed_cb(
    int cb_id,
  ) {
    return _camera_remove_device_state_changed_cb(
      cb_id,
    );
  }

  late final _camera_remove_device_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'camera_remove_device_state_changed_cb');
  late final _camera_remove_device_state_changed_cb =
      _camera_remove_device_state_changed_cbPtr.asFunction<int Function(int)>();

  /// @brief Sets the preview frame rate.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This function should be called before previewing (see camera_start_preview()).
  /// @param[in] camera The handle to the camera
  /// @param[in] fps The frame rate
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED.
  /// @see camera_start_preview()
  /// @see	camera_attr_get_preview_fps()
  /// @see	camera_attr_foreach_supported_fps()
  int camera_attr_set_preview_fps(
    camera_h camera,
    int fps,
  ) {
    return _camera_attr_set_preview_fps(
      camera,
      fps,
    );
  }

  late final _camera_attr_set_preview_fpsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_preview_fps');
  late final _camera_attr_set_preview_fps =
      _camera_attr_set_preview_fpsPtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the frames per second of a preview video stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] fps The frames per second of the preview video stream
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_attr_set_preview_fps()
  /// @see	camera_attr_foreach_supported_fps()
  int camera_attr_get_preview_fps(
    camera_h camera,
    ffi.Pointer<ffi.Int32> fps,
  ) {
    return _camera_attr_get_preview_fps(
      camera,
      fps,
    );
  }

  late final _camera_attr_get_preview_fpsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Int32>)>>('camera_attr_get_preview_fps');
  late final _camera_attr_get_preview_fps = _camera_attr_get_preview_fpsPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported FPS modes by invoking the callback function once for each supported FPS mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_fps_cb() repeatedly to get each supported FPS mode.
  /// @see	camera_attr_set_preview_fps()
  /// @see	camera_attr_get_preview_fps()
  /// @see	camera_attr_supported_fps_cb()
  int camera_attr_foreach_supported_fps(
    camera_h camera,
    camera_attr_supported_fps_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_fps(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_fpsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_attr_supported_fps_cb,
              ffi.Pointer<ffi.Void>)>>('camera_attr_foreach_supported_fps');
  late final _camera_attr_foreach_supported_fps =
      _camera_attr_foreach_supported_fpsPtr.asFunction<
          int Function(
              camera_h, camera_attr_supported_fps_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves all supported FPS modes by invoking the callback function once for each supported FPS mode.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] width Required preview resolution's width
  /// @param[in] height Required preview resolution's height
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_fps_cb() repeatedly to get each supported FPS mode.
  /// @see	camera_attr_set_preview_fps()
  /// @see	camera_attr_get_preview_fps()
  /// @see	camera_attr_supported_fps_cb()
  int camera_attr_foreach_supported_fps_by_resolution(
    camera_h camera,
    int width,
    int height,
    camera_attr_supported_fps_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_fps_by_resolution(
      camera,
      width,
      height,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_fps_by_resolutionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, ffi.Int, ffi.Int,
                  camera_attr_supported_fps_cb, ffi.Pointer<ffi.Void>)>>(
      'camera_attr_foreach_supported_fps_by_resolution');
  late final _camera_attr_foreach_supported_fps_by_resolution =
      _camera_attr_foreach_supported_fps_by_resolutionPtr.asFunction<
          int Function(camera_h, int, int, camera_attr_supported_fps_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets quality of the image.
  /// @details The range for image quality is 1 to 100. If @a quality is out of range, #CAMERA_ERROR_INVALID_PARAMETER error occurred.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] quality The quality of image (1 ~ 100)
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_start_preview()
  /// @see	camera_attr_get_image_quality()
  int camera_attr_set_image_quality(
    camera_h camera,
    int quality,
  ) {
    return _camera_attr_set_image_quality(
      camera,
      quality,
    );
  }

  late final _camera_attr_set_image_qualityPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int)>>(
          'camera_attr_set_image_quality');
  late final _camera_attr_set_image_quality = _camera_attr_set_image_qualityPtr
      .asFunction<int Function(camera_h, int)>();

  /// @brief Gets the quality of a still image, which is captured.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] quality The quality of the image(1 ~ 100)
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_image_quality()
  int camera_attr_get_image_quality(
    camera_h camera,
    ffi.Pointer<ffi.Int> quality,
  ) {
    return _camera_attr_get_image_quality(
      camera,
      quality,
    );
  }

  late final _camera_attr_get_image_qualityPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_attr_get_image_quality');
  late final _camera_attr_get_image_quality = _camera_attr_get_image_qualityPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the bit rate of encoded preview.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[out] bitrate The bit rate of encoded preview
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_encoded_preview_bitrate()
  int camera_attr_get_encoded_preview_bitrate(
    camera_h camera,
    ffi.Pointer<ffi.Int> bitrate,
  ) {
    return _camera_attr_get_encoded_preview_bitrate(
      camera,
      bitrate,
    );
  }

  late final _camera_attr_get_encoded_preview_bitratePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_attr_get_encoded_preview_bitrate');
  late final _camera_attr_get_encoded_preview_bitrate =
      _camera_attr_get_encoded_preview_bitratePtr
          .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the bit rate of encoded preview.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[in] bitrate The bit rate of encoded preview
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_get_encoded_preview_bitrate()
  int camera_attr_set_encoded_preview_bitrate(
    camera_h camera,
    int bitrate,
  ) {
    return _camera_attr_set_encoded_preview_bitrate(
      camera,
      bitrate,
    );
  }

  late final _camera_attr_set_encoded_preview_bitratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int)>>(
          'camera_attr_set_encoded_preview_bitrate');
  late final _camera_attr_set_encoded_preview_bitrate =
      _camera_attr_set_encoded_preview_bitratePtr
          .asFunction<int Function(camera_h, int)>();

  /// @brief Gets the GOP(Group Of Pictures) interval of encoded preview.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[out] interval the GOP interval of encoded preview (millisecond)
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_get_encoded_preview_gop_interval()
  int camera_attr_get_encoded_preview_gop_interval(
    camera_h camera,
    ffi.Pointer<ffi.Int> interval,
  ) {
    return _camera_attr_get_encoded_preview_gop_interval(
      camera,
      interval,
    );
  }

  late final _camera_attr_get_encoded_preview_gop_intervalPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_attr_get_encoded_preview_gop_interval');
  late final _camera_attr_get_encoded_preview_gop_interval =
      _camera_attr_get_encoded_preview_gop_intervalPtr
          .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the GOP(Group Of Pictures) interval of encoded preview.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[in] interval the GOP interval of encoded preview (millisecond)
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_encoded_preview_gop_interval()
  int camera_attr_set_encoded_preview_gop_interval(
    camera_h camera,
    int interval,
  ) {
    return _camera_attr_set_encoded_preview_gop_interval(
      camera,
      interval,
    );
  }

  late final _camera_attr_set_encoded_preview_gop_intervalPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int)>>(
          'camera_attr_set_encoded_preview_gop_interval');
  late final _camera_attr_set_encoded_preview_gop_interval =
      _camera_attr_set_encoded_preview_gop_intervalPtr
          .asFunction<int Function(camera_h, int)>();

  /// @brief Sets the zoom level.
  /// @details The range for the zoom level is received from camera_attr_get_zoom_range(). If @a zoom is out of range, the #CAMERA_ERROR_INVALID_PARAMETER error occurs.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] zoom The zoom level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_get_zoom()
  /// @see camera_attr_get_zoom_range()
  int camera_attr_set_zoom(
    camera_h camera,
    int zoom,
  ) {
    return _camera_attr_set_zoom(
      camera,
      zoom,
    );
  }

  late final _camera_attr_set_zoomPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int)>>(
          'camera_attr_set_zoom');
  late final _camera_attr_set_zoom =
      _camera_attr_set_zoomPtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the zoom level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] zoom The zoom level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_zoom()
  /// @see camera_attr_get_zoom_range()
  int camera_attr_get_zoom(
    camera_h camera,
    ffi.Pointer<ffi.Int> zoom,
  ) {
    return _camera_attr_get_zoom(
      camera,
      zoom,
    );
  }

  late final _camera_attr_get_zoomPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_attr_get_zoom');
  late final _camera_attr_get_zoom = _camera_attr_get_zoomPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the available zoom level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If the min value is greater than the max value, it means that this feature is not supported.
  /// @param[in] camera The handle to the camera
  /// @param[out] min The minimum zoom level
  /// @param[out] max The maximum zoom level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_zoom()
  /// @see camera_attr_get_zoom()
  int camera_attr_get_zoom_range(
    camera_h camera,
    ffi.Pointer<ffi.Int> min,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _camera_attr_get_zoom_range(
      camera,
      min,
      max,
    );
  }

  late final _camera_attr_get_zoom_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('camera_attr_get_zoom_range');
  late final _camera_attr_get_zoom_range =
      _camera_attr_get_zoom_rangePtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the auto focus mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] mode The auto focus mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see	camera_attr_get_af_mode()
  /// @see	camera_attr_foreach_supported_af_mode()
  /// @see	#camera_attr_af_mode_e
  int camera_attr_set_af_mode(
    camera_h camera,
    int mode,
  ) {
    return _camera_attr_set_af_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_set_af_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_af_mode');
  late final _camera_attr_set_af_mode =
      _camera_attr_set_af_modePtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the auto focus mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] mode The auto focus mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_foreach_supported_af_mode()
  /// @see camera_attr_set_af_mode()
  /// @see	#camera_attr_af_mode_e
  int camera_attr_get_af_mode(
    camera_h camera,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _camera_attr_get_af_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_get_af_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_attr_get_af_mode');
  late final _camera_attr_get_af_mode = _camera_attr_get_af_modePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets auto focus area.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This API is invalid in the #CAMERA_ATTR_AF_NONE mode.\n
  /// The coordinates are mapped to preview area.
  /// @param[in] camera The handle to the camera
  /// @param[in] x The x coordinates of the focus area
  /// @param[in] y The y coordinates of the focus area
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_set_af_mode()
  /// @see camera_attr_clear_af_area()
  int camera_attr_set_af_area(
    camera_h camera,
    int x,
    int y,
  ) {
    return _camera_attr_set_af_area(
      camera,
      x,
      y,
    );
  }

  late final _camera_attr_set_af_areaPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int, ffi.Int)>>(
          'camera_attr_set_af_area');
  late final _camera_attr_set_af_area = _camera_attr_set_af_areaPtr
      .asFunction<int Function(camera_h, int, int)>();

  /// @brief Clears the auto focus area.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The focusing area is set to the center.
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_af_mode()
  /// @see camera_attr_set_af_area()
  int camera_attr_clear_af_area(
    camera_h camera,
  ) {
    return _camera_attr_clear_af_area(
      camera,
    );
  }

  late final _camera_attr_clear_af_areaPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_attr_clear_af_area');
  late final _camera_attr_clear_af_area =
      _camera_attr_clear_af_areaPtr.asFunction<int Function(camera_h)>();

  /// @brief Retrieves all supported auto focus modes by invoking the callback function once for each supported auto focus mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_af_mode_cb() to get all the supported auto focus modes.
  /// @see camera_attr_set_af_mode()
  /// @see camera_attr_get_af_mode()
  /// @see	camera_attr_supported_af_mode_cb()
  int camera_attr_foreach_supported_af_mode(
    camera_h camera,
    camera_attr_supported_af_mode_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_af_mode(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_af_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_attr_supported_af_mode_cb,
              ffi.Pointer<ffi.Void>)>>('camera_attr_foreach_supported_af_mode');
  late final _camera_attr_foreach_supported_af_mode =
      _camera_attr_foreach_supported_af_modePtr.asFunction<
          int Function(camera_h, camera_attr_supported_af_mode_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the exposure mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] mode The exposure mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_get_exposure_mode()
  /// @see camera_attr_foreach_supported_exposure_mode()
  int camera_attr_set_exposure_mode(
    camera_h camera,
    int mode,
  ) {
    return _camera_attr_set_exposure_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_set_exposure_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_exposure_mode');
  late final _camera_attr_set_exposure_mode = _camera_attr_set_exposure_modePtr
      .asFunction<int Function(camera_h, int)>();

  /// @brief Gets the exposure mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] mode The exposure mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_exposure_mode()
  /// @see camera_attr_foreach_supported_exposure_mode()
  int camera_attr_get_exposure_mode(
    camera_h camera,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _camera_attr_get_exposure_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_get_exposure_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Int32>)>>('camera_attr_get_exposure_mode');
  late final _camera_attr_get_exposure_mode = _camera_attr_get_exposure_modePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported exposure modes by invoking the callback function once for each supported exposure mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_exposure_mode_cb() to get all the supported exposure modes.
  /// @see camera_attr_set_exposure_mode()
  /// @see camera_attr_get_exposure_mode()
  /// @see	camera_attr_supported_exposure_mode_cb()
  int camera_attr_foreach_supported_exposure_mode(
    camera_h camera,
    camera_attr_supported_exposure_mode_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_exposure_mode(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_exposure_modePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_attr_supported_exposure_mode_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_attr_foreach_supported_exposure_mode');
  late final _camera_attr_foreach_supported_exposure_mode =
      _camera_attr_foreach_supported_exposure_modePtr.asFunction<
          int Function(camera_h, camera_attr_supported_exposure_mode_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the exposure value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] value The exposure value
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_attr_get_exposure()
  int camera_attr_set_exposure(
    camera_h camera,
    int value,
  ) {
    return _camera_attr_set_exposure(
      camera,
      value,
    );
  }

  late final _camera_attr_set_exposurePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int)>>(
          'camera_attr_set_exposure');
  late final _camera_attr_set_exposure =
      _camera_attr_set_exposurePtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the exposure value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] value The exposure value
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_attr_set_exposure()
  int camera_attr_get_exposure(
    camera_h camera,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _camera_attr_get_exposure(
      camera,
      value,
    );
  }

  late final _camera_attr_get_exposurePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_attr_get_exposure');
  late final _camera_attr_get_exposure = _camera_attr_get_exposurePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the available exposure value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If the min value is greater than the max value, it means that this feature is not supported.
  /// @param[in] camera The handle to the camera
  /// @param[out] min The minimum exposure value
  /// @param[out] max The maximum exposure value
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_attr_set_exposure()
  int camera_attr_get_exposure_range(
    camera_h camera,
    ffi.Pointer<ffi.Int> min,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _camera_attr_get_exposure_range(
      camera,
      min,
      max,
    );
  }

  late final _camera_attr_get_exposure_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('camera_attr_get_exposure_range');
  late final _camera_attr_get_exposure_range =
      _camera_attr_get_exposure_rangePtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the ISO level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] iso The ISO level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see	camera_attr_get_iso()
  /// @see camera_attr_foreach_supported_iso()
  int camera_attr_set_iso(
    camera_h camera,
    int iso,
  ) {
    return _camera_attr_set_iso(
      camera,
      iso,
    );
  }

  late final _camera_attr_set_isoPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_iso');
  late final _camera_attr_set_iso =
      _camera_attr_set_isoPtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the ISO level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] iso The ISO level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_attr_set_iso()
  /// @see camera_attr_foreach_supported_iso()
  int camera_attr_get_iso(
    camera_h camera,
    ffi.Pointer<ffi.Int32> iso,
  ) {
    return _camera_attr_get_iso(
      camera,
      iso,
    );
  }

  late final _camera_attr_get_isoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_attr_get_iso');
  late final _camera_attr_get_iso = _camera_attr_get_isoPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported ISO levels by invoking the callback function once for each supported ISO level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to be invoked
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_iso_cb() to get all the supported ISO levels.
  /// @see	camera_attr_set_iso()
  /// @see camera_attr_get_iso()
  /// @see	camera_attr_supported_iso_cb()
  int camera_attr_foreach_supported_iso(
    camera_h camera,
    camera_attr_supported_iso_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_iso(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_isoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_attr_supported_iso_cb,
              ffi.Pointer<ffi.Void>)>>('camera_attr_foreach_supported_iso');
  late final _camera_attr_foreach_supported_iso =
      _camera_attr_foreach_supported_isoPtr.asFunction<
          int Function(
              camera_h, camera_attr_supported_iso_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the theater mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If you want to display the preview image on the external display with the full screen mode, use this function.
  /// @param[in] camera The handle to the camera
  /// @param[in] mode The mode to change
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre	This function is valid only when the external display is connected.
  /// @see	camera_attr_get_theater_mode()
  int camera_attr_set_theater_mode(
    camera_h camera,
    int mode,
  ) {
    return _camera_attr_set_theater_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_set_theater_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_theater_mode');
  late final _camera_attr_set_theater_mode = _camera_attr_set_theater_modePtr
      .asFunction<int Function(camera_h, int)>();

  /// @brief Gets the theater mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] mode Current theater mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_attr_get_theater_mode()
  int camera_attr_get_theater_mode(
    camera_h camera,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _camera_attr_get_theater_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_get_theater_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Int32>)>>('camera_attr_get_theater_mode');
  late final _camera_attr_get_theater_mode = _camera_attr_get_theater_modePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported theater modes by invoking callback function once for each supported theater modes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_theater_mode_cb() to get all supported theater modes.
  /// @see camera_attr_set_theater_mode()
  /// @see camera_attr_get_theater_mode()
  /// @see	camera_attr_supported_theater_mode_cb()
  int camera_attr_foreach_supported_theater_mode(
    camera_h camera,
    camera_attr_supported_theater_mode_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_theater_mode(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_theater_modePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_attr_supported_theater_mode_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_attr_foreach_supported_theater_mode');
  late final _camera_attr_foreach_supported_theater_mode =
      _camera_attr_foreach_supported_theater_modePtr.asFunction<
          int Function(camera_h, camera_attr_supported_theater_mode_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the brightness level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If the min value is greater than the max value from camera_attr_get_brightness_range(), \n
  /// it means that this feature is not supported.
  /// @param[in] camera The handle to the camera
  /// @param[in] level The brightness level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_get_brightness()
  /// @see camera_attr_get_brightness_range()
  int camera_attr_set_brightness(
    camera_h camera,
    int level,
  ) {
    return _camera_attr_set_brightness(
      camera,
      level,
    );
  }

  late final _camera_attr_set_brightnessPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int)>>(
          'camera_attr_set_brightness');
  late final _camera_attr_set_brightness =
      _camera_attr_set_brightnessPtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the brightness level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] level The brightness level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_brightness()
  /// @see camera_attr_get_brightness_range()
  int camera_attr_get_brightness(
    camera_h camera,
    ffi.Pointer<ffi.Int> level,
  ) {
    return _camera_attr_get_brightness(
      camera,
      level,
    );
  }

  late final _camera_attr_get_brightnessPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_attr_get_brightness');
  late final _camera_attr_get_brightness = _camera_attr_get_brightnessPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the available brightness level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If the min value is greater than the max value, it means that this feature is not supported.
  /// @param[in] camera The handle to the camera
  /// @param[out] min The minimum brightness level
  /// @param[out] max The maximum brightness level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_brightness()
  /// @see camera_attr_get_brightness()
  int camera_attr_get_brightness_range(
    camera_h camera,
    ffi.Pointer<ffi.Int> min,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _camera_attr_get_brightness_range(
      camera,
      min,
      max,
    );
  }

  late final _camera_attr_get_brightness_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('camera_attr_get_brightness_range');
  late final _camera_attr_get_brightness_range =
      _camera_attr_get_brightness_rangePtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the contrast level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] level The contrast level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_get_contrast()
  /// @see camera_attr_get_contrast_range()
  int camera_attr_set_contrast(
    camera_h camera,
    int level,
  ) {
    return _camera_attr_set_contrast(
      camera,
      level,
    );
  }

  late final _camera_attr_set_contrastPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int)>>(
          'camera_attr_set_contrast');
  late final _camera_attr_set_contrast =
      _camera_attr_set_contrastPtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the contrast level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] level The contrast level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_contrast()
  /// @see camera_attr_get_contrast_range()
  int camera_attr_get_contrast(
    camera_h camera,
    ffi.Pointer<ffi.Int> level,
  ) {
    return _camera_attr_get_contrast(
      camera,
      level,
    );
  }

  late final _camera_attr_get_contrastPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_attr_get_contrast');
  late final _camera_attr_get_contrast = _camera_attr_get_contrastPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the available contrast level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If the min value is greater than the max value, it means that this feature is not supported.
  /// @param[in] camera The handle to the camera
  /// @param[out] min The minimum contrast level
  /// @param[out] max The maximum contrast level
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_contrast()
  /// @see camera_attr_get_contrast()
  int camera_attr_get_contrast_range(
    camera_h camera,
    ffi.Pointer<ffi.Int> min,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _camera_attr_get_contrast_range(
      camera,
      min,
      max,
    );
  }

  late final _camera_attr_get_contrast_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('camera_attr_get_contrast_range');
  late final _camera_attr_get_contrast_range =
      _camera_attr_get_contrast_rangePtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the white balance mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] whitebalance The white balance mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_foreach_supported_whitebalance()
  /// @see camera_attr_get_whitebalance()
  int camera_attr_set_whitebalance(
    camera_h camera,
    int whitebalance,
  ) {
    return _camera_attr_set_whitebalance(
      camera,
      whitebalance,
    );
  }

  late final _camera_attr_set_whitebalancePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_whitebalance');
  late final _camera_attr_set_whitebalance = _camera_attr_set_whitebalancePtr
      .asFunction<int Function(camera_h, int)>();

  /// @brief Gets the white balance mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] whitebalance The white balance mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_foreach_supported_whitebalance()
  /// @see camera_attr_set_whitebalance()
  int camera_attr_get_whitebalance(
    camera_h camera,
    ffi.Pointer<ffi.Int32> whitebalance,
  ) {
    return _camera_attr_get_whitebalance(
      camera,
      whitebalance,
    );
  }

  late final _camera_attr_get_whitebalancePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Int32>)>>('camera_attr_get_whitebalance');
  late final _camera_attr_get_whitebalance = _camera_attr_get_whitebalancePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported white balances by invoking the callback function once for each supported white balance.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_whitebalance_cb() to get all the supported white balances.
  /// @see camera_attr_set_whitebalance()
  /// @see camera_attr_get_whitebalance()
  /// @see	camera_attr_supported_whitebalance_cb()
  int camera_attr_foreach_supported_whitebalance(
    camera_h camera,
    camera_attr_supported_whitebalance_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_whitebalance(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_whitebalancePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_attr_supported_whitebalance_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_attr_foreach_supported_whitebalance');
  late final _camera_attr_foreach_supported_whitebalance =
      _camera_attr_foreach_supported_whitebalancePtr.asFunction<
          int Function(camera_h, camera_attr_supported_whitebalance_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the camera effect mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] effect The camera effect mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_foreach_supported_effect()
  /// @see camera_attr_get_effect()
  int camera_attr_set_effect(
    camera_h camera,
    int effect,
  ) {
    return _camera_attr_set_effect(
      camera,
      effect,
    );
  }

  late final _camera_attr_set_effectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_effect');
  late final _camera_attr_set_effect =
      _camera_attr_set_effectPtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the camera effect mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] effect The camera effect mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_foreach_supported_effect()
  /// @see camera_attr_set_effect()
  int camera_attr_get_effect(
    camera_h camera,
    ffi.Pointer<ffi.Int32> effect,
  ) {
    return _camera_attr_get_effect(
      camera,
      effect,
    );
  }

  late final _camera_attr_get_effectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_attr_get_effect');
  late final _camera_attr_get_effect = _camera_attr_get_effectPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported effect modes by invoking the callback function once for each supported effect mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_effect_cb() to get all the supported effect modes.
  /// @see camera_attr_set_effect()
  /// @see camera_attr_get_effect()
  /// @see	camera_attr_supported_effect_cb()
  int camera_attr_foreach_supported_effect(
    camera_h camera,
    camera_attr_supported_effect_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_effect(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_effectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, camera_attr_supported_effect_cb,
              ffi.Pointer<ffi.Void>)>>('camera_attr_foreach_supported_effect');
  late final _camera_attr_foreach_supported_effect =
      _camera_attr_foreach_supported_effectPtr.asFunction<
          int Function(camera_h, camera_attr_supported_effect_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the scene mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] mode The scene mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_foreach_supported_scene_mode()
  /// @see camera_attr_get_scene_mode()
  int camera_attr_set_scene_mode(
    camera_h camera,
    int mode,
  ) {
    return _camera_attr_set_scene_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_set_scene_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_scene_mode');
  late final _camera_attr_set_scene_mode =
      _camera_attr_set_scene_modePtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the scene mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] mode The scene mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_attr_foreach_supported_scene_mode()
  /// @see camera_attr_set_scene_mode()
  int camera_attr_get_scene_mode(
    camera_h camera,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _camera_attr_get_scene_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_get_scene_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_attr_get_scene_mode');
  late final _camera_attr_get_scene_mode = _camera_attr_get_scene_modePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported scene modes by invoking the callback function once for each supported scene mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_scene_mode_cb() to get all the supported scene modes.
  /// @see	camera_attr_set_scene_mode()
  /// @see camera_attr_get_scene_mode()
  /// @see camera_attr_supported_scene_mode_cb()
  int camera_attr_foreach_supported_scene_mode(
    camera_h camera,
    camera_attr_supported_scene_mode_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_scene_mode(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_scene_modePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_attr_supported_scene_mode_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_attr_foreach_supported_scene_mode');
  late final _camera_attr_foreach_supported_scene_mode =
      _camera_attr_foreach_supported_scene_modePtr.asFunction<
          int Function(camera_h, camera_attr_supported_scene_mode_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Enables to write EXIF(Exchangeable image file format) tags in a JPEG file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] enable If @c true writing EXIF tags in a JPEG file is enabled, otherwise @c false
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see         camera_attr_is_enabled_tag()
  int camera_attr_enable_tag(
    camera_h camera,
    bool enable,
  ) {
    return _camera_attr_enable_tag(
      camera,
      enable,
    );
  }

  late final _camera_attr_enable_tagPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Bool)>>(
          'camera_attr_enable_tag');
  late final _camera_attr_enable_tag =
      _camera_attr_enable_tagPtr.asFunction<int Function(camera_h, bool)>();

  /// @brief Gets the value that indicates whether writing EXIF(Exchangeable image file format) tags in a JPEG file is enabled.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] enabled  If @c true camera information is enabled, otherwise @c false
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see         camera_attr_enable_tag()
  int camera_attr_is_enabled_tag(
    camera_h camera,
    ffi.Pointer<ffi.Bool> enabled,
  ) {
    return _camera_attr_is_enabled_tag(
      camera,
      enabled,
    );
  }

  late final _camera_attr_is_enabled_tagPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Bool>)>>('camera_attr_is_enabled_tag');
  late final _camera_attr_is_enabled_tag = _camera_attr_is_enabled_tagPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the camera image description in the EXIF(Exchangeable image file format) tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] description The string with description
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_get_tag_image_description()
  int camera_attr_set_tag_image_description(
    camera_h camera,
    ffi.Pointer<ffi.Char> description,
  ) {
    return _camera_attr_set_tag_image_description(
      camera,
      description,
    );
  }

  late final _camera_attr_set_tag_image_descriptionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Char>)>>('camera_attr_set_tag_image_description');
  late final _camera_attr_set_tag_image_description =
      _camera_attr_set_tag_image_descriptionPtr
          .asFunction<int Function(camera_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the camera image description in EXIF(Exchangeable image file format) tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a description using free().
  /// @param[in] camera The handle to the camera
  /// @param[out] description A pointer to a string
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_tag_image_description()
  int camera_attr_get_tag_image_description(
    camera_h camera,
    ffi.Pointer<ffi.Pointer<ffi.Char>> description,
  ) {
    return _camera_attr_get_tag_image_description(
      camera,
      description,
    );
  }

  late final _camera_attr_get_tag_image_descriptionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'camera_attr_get_tag_image_description');
  late final _camera_attr_get_tag_image_description =
      _camera_attr_get_tag_image_descriptionPtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the camera orientation in the EXIF(Exchangeable image file format) tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] orientation The camera orientation
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_attr_get_tag_orientation()
  int camera_attr_set_tag_orientation(
    camera_h camera,
    int orientation,
  ) {
    return _camera_attr_set_tag_orientation(
      camera,
      orientation,
    );
  }

  late final _camera_attr_set_tag_orientationPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_tag_orientation');
  late final _camera_attr_set_tag_orientation =
      _camera_attr_set_tag_orientationPtr
          .asFunction<int Function(camera_h, int)>();

  /// @brief Gets the camera orientation in the EXIF(Exchangeable image file format) tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] orientation The camera orientation
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	camera_attr_set_tag_orientation()
  int camera_attr_get_tag_orientation(
    camera_h camera,
    ffi.Pointer<ffi.Int32> orientation,
  ) {
    return _camera_attr_get_tag_orientation(
      camera,
      orientation,
    );
  }

  late final _camera_attr_get_tag_orientationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Int32>)>>('camera_attr_get_tag_orientation');
  late final _camera_attr_get_tag_orientation =
      _camera_attr_get_tag_orientationPtr
          .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the software information in the EXIF(Exchangeable image file format) tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] software The software information tag
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_get_tag_software()
  int camera_attr_set_tag_software(
    camera_h camera,
    ffi.Pointer<ffi.Char> software,
  ) {
    return _camera_attr_set_tag_software(
      camera,
      software,
    );
  }

  late final _camera_attr_set_tag_softwarePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Char>)>>('camera_attr_set_tag_software');
  late final _camera_attr_set_tag_software = _camera_attr_set_tag_softwarePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the software information in the EXIF(Exchangeable image file format) tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a software using free().
  /// @param[in] camera The handle to the camera
  /// @param[out] software A pointer to a string
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_tag_software()
  int camera_attr_get_tag_software(
    camera_h camera,
    ffi.Pointer<ffi.Pointer<ffi.Char>> software,
  ) {
    return _camera_attr_get_tag_software(
      camera,
      software,
    );
  }

  late final _camera_attr_get_tag_softwarePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'camera_attr_get_tag_software');
  late final _camera_attr_get_tag_software = _camera_attr_get_tag_softwarePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the geotag(GPS data) in the EXIF(Exchangeable image file format) tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] latitude The latitude data
  /// @param[in] longitude The longitude data
  /// @param[in] altitude The altitude data
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_get_geotag()
  /// @see camera_attr_remove_geotag()
  int camera_attr_set_geotag(
    camera_h camera,
    double latitude,
    double longitude,
    double altitude,
  ) {
    return _camera_attr_set_geotag(
      camera,
      latitude,
      longitude,
      altitude,
    );
  }

  late final _camera_attr_set_geotagPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, ffi.Double, ffi.Double,
              ffi.Double)>>('camera_attr_set_geotag');
  late final _camera_attr_set_geotag = _camera_attr_set_geotagPtr
      .asFunction<int Function(camera_h, double, double, double)>();

  /// @brief Gets the geotag(GPS data) in the EXIF(Exchangeable image file format) tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] latitude The latitude data
  /// @param[out] longitude The longitude data
  /// @param[out] altitude The altitude data
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_geotag()
  /// @see camera_attr_remove_geotag()
  int camera_attr_get_geotag(
    camera_h camera,
    ffi.Pointer<ffi.Double> latitude,
    ffi.Pointer<ffi.Double> longitude,
    ffi.Pointer<ffi.Double> altitude,
  ) {
    return _camera_attr_get_geotag(
      camera,
      latitude,
      longitude,
      altitude,
    );
  }

  late final _camera_attr_get_geotagPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h,
              ffi.Pointer<ffi.Double>,
              ffi.Pointer<ffi.Double>,
              ffi.Pointer<ffi.Double>)>>('camera_attr_get_geotag');
  late final _camera_attr_get_geotag = _camera_attr_get_geotagPtr.asFunction<
      int Function(camera_h, ffi.Pointer<ffi.Double>, ffi.Pointer<ffi.Double>,
          ffi.Pointer<ffi.Double>)>();

  /// @brief Removes the geotag(GPS data) in the EXIF(Exchangeable image file format) tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_set_geotag()
  /// @see camera_attr_get_geotag()
  int camera_attr_remove_geotag(
    camera_h camera,
  ) {
    return _camera_attr_remove_geotag(
      camera,
    );
  }

  late final _camera_attr_remove_geotagPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_attr_remove_geotag');
  late final _camera_attr_remove_geotag =
      _camera_attr_remove_geotagPtr.asFunction<int Function(camera_h)>();

  /// @brief Sets the camera's flash mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, while setting the flash mode, if the flash was preempted by other APIs,\n
  /// then this function returns #CAMERA_ERROR_DEVICE_BUSY error.
  /// @param[in] camera The handle to the camera
  /// @param[in] mode The flash mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @retval #CAMERA_ERROR_DEVICE_BUSY The flash was preempted by other API
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see	camera_attr_foreach_supported_flash_mode()
  /// @see camera_attr_get_flash_mode()
  int camera_attr_set_flash_mode(
    camera_h camera,
    int mode,
  ) {
    return _camera_attr_set_flash_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_set_flash_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_flash_mode');
  late final _camera_attr_set_flash_mode =
      _camera_attr_set_flash_modePtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the camera's flash mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] mode The flash mode
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_foreach_supported_flash_mode()
  /// @see camera_attr_set_flash_mode()
  int camera_attr_get_flash_mode(
    camera_h camera,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _camera_attr_get_flash_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_get_flash_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_attr_get_flash_mode');
  late final _camera_attr_get_flash_mode = _camera_attr_get_flash_modePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported flash modes by invoking the callback function once for each supported flash mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data passed to the callback registration function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_flash_mode_cb() to get all supported flash modes.
  /// @see	camera_attr_set_flash_mode()
  /// @see camera_attr_get_flash_mode()
  /// @see	camera_attr_supported_flash_mode_cb()
  int camera_attr_foreach_supported_flash_mode(
    camera_h camera,
    camera_attr_supported_flash_mode_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_flash_mode(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_flash_modePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_attr_supported_flash_mode_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_attr_foreach_supported_flash_mode');
  late final _camera_attr_foreach_supported_flash_mode =
      _camera_attr_foreach_supported_flash_modePtr.asFunction<
          int Function(camera_h, camera_attr_supported_flash_mode_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the camera len's orientation angle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] angle The orientation angle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_set_display_rotation()
  int camera_attr_get_lens_orientation(
    camera_h camera,
    ffi.Pointer<ffi.Int> angle,
  ) {
    return _camera_attr_get_lens_orientation(
      camera,
      angle,
    );
  }

  late final _camera_attr_get_lens_orientationPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_attr_get_lens_orientation');
  late final _camera_attr_get_lens_orientation =
      _camera_attr_get_lens_orientationPtr
          .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the stream rotation.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] rotation The stream rotation
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre	The camera state must be set to #CAMERA_STATE_CREATED.
  /// @see camera_attr_get_stream_rotation()
  int camera_attr_set_stream_rotation(
    camera_h camera,
    int rotation,
  ) {
    return _camera_attr_set_stream_rotation(
      camera,
      rotation,
    );
  }

  late final _camera_attr_set_stream_rotationPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_stream_rotation');
  late final _camera_attr_set_stream_rotation =
      _camera_attr_set_stream_rotationPtr
          .asFunction<int Function(camera_h, int)>();

  /// @brief Gets the stream rotation.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] rotation	The stream rotation
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre	The camera state must be set to #CAMERA_STATE_CREATED.
  /// @see camera_attr_set_stream_rotation()
  int camera_attr_get_stream_rotation(
    camera_h camera,
    ffi.Pointer<ffi.Int32> rotation,
  ) {
    return _camera_attr_get_stream_rotation(
      camera,
      rotation,
    );
  }

  late final _camera_attr_get_stream_rotationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Int32>)>>('camera_attr_get_stream_rotation');
  late final _camera_attr_get_stream_rotation =
      _camera_attr_get_stream_rotationPtr
          .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported stream rotation modes by invoking callback function once for each supported stream rotation mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_stream_rotation_cb() to get all supported stream rotation mode.
  /// @see camera_attr_set_stream_rotation()
  /// @see camera_attr_get_stream_rotation()
  /// @see camera_attr_supported_stream_rotation_cb()
  int camera_attr_foreach_supported_stream_rotation(
    camera_h camera,
    camera_attr_supported_stream_rotation_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_stream_rotation(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_stream_rotationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  camera_h,
                  camera_attr_supported_stream_rotation_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_attr_foreach_supported_stream_rotation');
  late final _camera_attr_foreach_supported_stream_rotation =
      _camera_attr_foreach_supported_stream_rotationPtr.asFunction<
          int Function(camera_h, camera_attr_supported_stream_rotation_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the stream flip.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] flip The stream flip
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre	The camera state must be set to #CAMERA_STATE_CREATED.
  /// @see camera_attr_set_stream_rotation()
  int camera_attr_set_stream_flip(
    camera_h camera,
    int flip,
  ) {
    return _camera_attr_set_stream_flip(
      camera,
      flip,
    );
  }

  late final _camera_attr_set_stream_flipPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_stream_flip');
  late final _camera_attr_set_stream_flip =
      _camera_attr_set_stream_flipPtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the stream flip.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] flip  The stream flip
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre	The camera state must be set to #CAMERA_STATE_CREATED.
  /// @see camera_attr_set_stream_rotation()
  int camera_attr_get_stream_flip(
    camera_h camera,
    ffi.Pointer<ffi.Int32> flip,
  ) {
    return _camera_attr_get_stream_flip(
      camera,
      flip,
    );
  }

  late final _camera_attr_get_stream_flipPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Int32>)>>('camera_attr_get_stream_flip');
  late final _camera_attr_get_stream_flip = _camera_attr_get_stream_flipPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported stream flip modes by invoking callback function once for each supported stream flip mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_stream_flip_cb() to get all supported stream flip mode.
  /// @see camera_attr_set_stream_flip()
  /// @see camera_attr_get_stream_flip()
  /// @see camera_attr_supported_stream_flip_cb()
  int camera_attr_foreach_supported_stream_flip(
    camera_h camera,
    camera_attr_supported_stream_flip_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_stream_flip(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_stream_flipPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_attr_supported_stream_flip_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_attr_foreach_supported_stream_flip');
  late final _camera_attr_foreach_supported_stream_flip =
      _camera_attr_foreach_supported_stream_flipPtr.asFunction<
          int Function(camera_h, camera_attr_supported_stream_flip_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the mode of HDR(High dynamic range) capture.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Taking multiple pictures at different exposure levels and intelligently stitching them together so that we eventually arrive at a picture that is representative in both dark and bright areas.\n
  /// If this attribute is set to @c true. camera_attr_hdr_progress_cb() is invoked during capture.\n
  /// If you set #CAMERA_ATTR_HDR_MODE_KEEP_ORIGINAL, the capturing callback is invoked twice. The first callback is delivering origin image data. The second callback is delivering improved image data.
  /// @param[in] camera The handle to the camera
  /// @param[in] mode The mode of HDR capture
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_get_hdr_mode()
  /// @see camera_attr_set_hdr_capture_progress_cb()
  /// @see camera_attr_unset_hdr_capture_progress_cb()
  /// @see camera_attr_is_supported_hdr_capture()
  int camera_attr_set_hdr_mode(
    camera_h camera,
    int mode,
  ) {
    return _camera_attr_set_hdr_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_set_hdr_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_hdr_mode');
  late final _camera_attr_set_hdr_mode =
      _camera_attr_set_hdr_modePtr.asFunction<int Function(camera_h, int)>();

  /// @brief Gets the mode of HDR(High dynamic range) capture.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] mode The mode of HDR capture
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_hdr_mode()
  /// @see camera_attr_set_hdr_capture_progress_cb()
  /// @see camera_attr_unset_hdr_capture_progress_cb()
  /// @see camera_attr_is_supported_hdr_capture()
  int camera_attr_get_hdr_mode(
    camera_h camera,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _camera_attr_get_hdr_mode(
      camera,
      mode,
    );
  }

  late final _camera_attr_get_hdr_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h, ffi.Pointer<ffi.Int32>)>>('camera_attr_get_hdr_mode');
  late final _camera_attr_get_hdr_mode = _camera_attr_get_hdr_modePtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Registers a callback function to be called when HDR capture is progressing.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This callback notifies progress of the HDR process.
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data passed to the callback registration function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_hdr_mode()
  /// @see camera_attr_get_hdr_mode()
  /// @see camera_attr_unset_hdr_capture_progress_cb()
  /// @see camera_attr_is_supported_hdr_capture()
  int camera_attr_set_hdr_capture_progress_cb(
    camera_h camera,
    camera_attr_hdr_progress_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_set_hdr_capture_progress_cb(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_set_hdr_capture_progress_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_attr_hdr_progress_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_attr_set_hdr_capture_progress_cb');
  late final _camera_attr_set_hdr_capture_progress_cb =
      _camera_attr_set_hdr_capture_progress_cbPtr.asFunction<
          int Function(
              camera_h, camera_attr_hdr_progress_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_hdr_mode()
  /// @see camera_attr_get_hdr_mode()
  /// @see camera_attr_set_hdr_capture_progress_cb()
  /// @see camera_attr_is_supported_hdr_capture()
  int camera_attr_unset_hdr_capture_progress_cb(
    camera_h camera,
  ) {
    return _camera_attr_unset_hdr_capture_progress_cb(
      camera,
    );
  }

  late final _camera_attr_unset_hdr_capture_progress_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h)>>(
          'camera_attr_unset_hdr_capture_progress_cb');
  late final _camera_attr_unset_hdr_capture_progress_cb =
      _camera_attr_unset_hdr_capture_progress_cbPtr
          .asFunction<int Function(camera_h)>();

  /// @ingroup CAPI_MEDIA_CAMERA_CAPABILITY_MODULE
  /// @brief Gets the support state of HDR capture.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] camera The handle to the camera
  /// @return @c true if supported, otherwise @c false
  /// @exception #CAMERA_ERROR_NONE Successful
  /// @exception #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @exception #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @see camera_attr_set_hdr_mode()
  /// @see camera_attr_get_hdr_mode()
  /// @see camera_attr_set_hdr_capture_progress_cb()
  /// @see camera_attr_unset_hdr_capture_progress_cb()
  bool camera_attr_is_supported_hdr_capture(
    camera_h camera,
  ) {
    return _camera_attr_is_supported_hdr_capture(
      camera,
    );
  }

  late final _camera_attr_is_supported_hdr_capturePtr =
      _lookup<ffi.NativeFunction<ffi.Bool Function(camera_h)>>(
          'camera_attr_is_supported_hdr_capture');
  late final _camera_attr_is_supported_hdr_capture =
      _camera_attr_is_supported_hdr_capturePtr
          .asFunction<bool Function(camera_h)>();

  /// @brief Enables/Disables the anti-shake feature.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This feature is used for image capture.
  /// @param[in] camera The handle to the camera
  /// @param[in] enable If @c true the anti-shake feature is enabled, otherwise @c false
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_is_enabled_anti_shake()
  /// @see camera_attr_is_supported_anti_shake()
  int camera_attr_enable_anti_shake(
    camera_h camera,
    bool enable,
  ) {
    return _camera_attr_enable_anti_shake(
      camera,
      enable,
    );
  }

  late final _camera_attr_enable_anti_shakePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Bool)>>(
          'camera_attr_enable_anti_shake');
  late final _camera_attr_enable_anti_shake = _camera_attr_enable_anti_shakePtr
      .asFunction<int Function(camera_h, bool)>();

  /// @brief Gets the state of the anti-shake feature.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] enabled The state of anti-shake
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_enable_anti_shake()
  /// @see camera_attr_is_supported_anti_shake()
  int camera_attr_is_enabled_anti_shake(
    camera_h camera,
    ffi.Pointer<ffi.Bool> enabled,
  ) {
    return _camera_attr_is_enabled_anti_shake(
      camera,
      enabled,
    );
  }

  late final _camera_attr_is_enabled_anti_shakePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Bool>)>>('camera_attr_is_enabled_anti_shake');
  late final _camera_attr_is_enabled_anti_shake =
      _camera_attr_is_enabled_anti_shakePtr
          .asFunction<int Function(camera_h, ffi.Pointer<ffi.Bool>)>();

  /// @ingroup CAPI_MEDIA_CAMERA_CAPABILITY_MODULE
  /// @brief Gets the support state of the anti-shake feature.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] camera The handle to the camera
  /// @return @c true if supported, otherwise @c false
  /// @exception #CAMERA_ERROR_NONE Successful
  /// @exception #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @exception #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @see camera_attr_enable_anti_shake()
  /// @see camera_attr_is_enabled_anti_shake()
  bool camera_attr_is_supported_anti_shake(
    camera_h camera,
  ) {
    return _camera_attr_is_supported_anti_shake(
      camera,
    );
  }

  late final _camera_attr_is_supported_anti_shakePtr =
      _lookup<ffi.NativeFunction<ffi.Bool Function(camera_h)>>(
          'camera_attr_is_supported_anti_shake');
  late final _camera_attr_is_supported_anti_shake =
      _camera_attr_is_supported_anti_shakePtr
          .asFunction<bool Function(camera_h)>();

  /// @brief Enables/Disables the video stabilization feature.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If video stabilization is enabled, zero shutter lag is disabled.\n
  /// This feature is used to record a video.
  /// @param[in] camera The handle to the camera
  /// @param[in] enable If @c true video stabilization is enabled, otherwise @c false
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_is_enabled_video_stabilization()
  /// @see camera_attr_is_supported_video_stabilization()
  int camera_attr_enable_video_stabilization(
    camera_h camera,
    bool enable,
  ) {
    return _camera_attr_enable_video_stabilization(
      camera,
      enable,
    );
  }

  late final _camera_attr_enable_video_stabilizationPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Bool)>>(
          'camera_attr_enable_video_stabilization');
  late final _camera_attr_enable_video_stabilization =
      _camera_attr_enable_video_stabilizationPtr
          .asFunction<int Function(camera_h, bool)>();

  /// @brief Gets the state of the video stabilization feature.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] enabled The state of video stabilization
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_enable_video_stabilization()
  /// @see camera_attr_is_supported_video_stabilization()
  int camera_attr_is_enabled_video_stabilization(
    camera_h camera,
    ffi.Pointer<ffi.Bool> enabled,
  ) {
    return _camera_attr_is_enabled_video_stabilization(
      camera,
      enabled,
    );
  }

  late final _camera_attr_is_enabled_video_stabilizationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, ffi.Pointer<ffi.Bool>)>>(
      'camera_attr_is_enabled_video_stabilization');
  late final _camera_attr_is_enabled_video_stabilization =
      _camera_attr_is_enabled_video_stabilizationPtr
          .asFunction<int Function(camera_h, ffi.Pointer<ffi.Bool>)>();

  /// @ingroup CAPI_MEDIA_CAMERA_CAPABILITY_MODULE
  /// @brief Gets the support state of the video stabilization feature.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] camera The handle to the camera
  /// @return @c true if supported, otherwise @c false
  /// @exception #CAMERA_ERROR_NONE Successful
  /// @exception #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @exception #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @see camera_attr_enable_video_stabilization()
  /// @see camera_attr_is_enabled_video_stabilization()
  bool camera_attr_is_supported_video_stabilization(
    camera_h camera,
  ) {
    return _camera_attr_is_supported_video_stabilization(
      camera,
    );
  }

  late final _camera_attr_is_supported_video_stabilizationPtr =
      _lookup<ffi.NativeFunction<ffi.Bool Function(camera_h)>>(
          'camera_attr_is_supported_video_stabilization');
  late final _camera_attr_is_supported_video_stabilization =
      _camera_attr_is_supported_video_stabilizationPtr
          .asFunction<bool Function(camera_h)>();

  /// @brief Enables/Disables auto contrast.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[in] enable If @c true auto contrast is enabled, otherwise @c false
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_CREATED or #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_is_enabled_auto_contrast()
  int camera_attr_enable_auto_contrast(
    camera_h camera,
    bool enable,
  ) {
    return _camera_attr_enable_auto_contrast(
      camera,
      enable,
    );
  }

  late final _camera_attr_enable_auto_contrastPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Bool)>>(
          'camera_attr_enable_auto_contrast');
  late final _camera_attr_enable_auto_contrast =
      _camera_attr_enable_auto_contrastPtr
          .asFunction<int Function(camera_h, bool)>();

  /// @brief Gets the state of auto contrast.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] camera The handle to the camera
  /// @param[out] enabled The state of auto contrast
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_enable_auto_contrast()
  int camera_attr_is_enabled_auto_contrast(
    camera_h camera,
    ffi.Pointer<ffi.Bool> enabled,
  ) {
    return _camera_attr_is_enabled_auto_contrast(
      camera,
      enabled,
    );
  }

  late final _camera_attr_is_enabled_auto_contrastPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<ffi.Bool>)>>('camera_attr_is_enabled_auto_contrast');
  late final _camera_attr_is_enabled_auto_contrast =
      _camera_attr_is_enabled_auto_contrastPtr
          .asFunction<int Function(camera_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets state of support of auto contrast feature.
  /// @ingroup CAPI_MEDIA_CAMERA_CAPABILITY_MODULE
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] camera The handle to the camera
  /// @return true on supported, otherwise false
  /// @exception #CAMERA_ERROR_NONE Successful
  /// @exception #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @exception #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @see camera_attr_enable_auto_contrast()
  /// @see camera_attr_is_enabled_auto_contrast()
  bool camera_attr_is_supported_auto_contrast(
    camera_h camera,
  ) {
    return _camera_attr_is_supported_auto_contrast(
      camera,
    );
  }

  late final _camera_attr_is_supported_auto_contrastPtr =
      _lookup<ffi.NativeFunction<ffi.Bool Function(camera_h)>>(
          'camera_attr_is_supported_auto_contrast');
  late final _camera_attr_is_supported_auto_contrast =
      _camera_attr_is_supported_auto_contrastPtr
          .asFunction<bool Function(camera_h)>();

  /// @brief Disables shutter sound.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks In some countries, this operation is not permitted.
  /// @param[in] camera The handle to the camera
  /// @param[in] disable If @c true shutter sound is disabled, otherwise @c false
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Disabling shutter sound is not permitted
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  int camera_attr_disable_shutter_sound(
    camera_h camera,
    bool disable,
  ) {
    return _camera_attr_disable_shutter_sound(
      camera,
      disable,
    );
  }

  late final _camera_attr_disable_shutter_soundPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Bool)>>(
          'camera_attr_disable_shutter_sound');
  late final _camera_attr_disable_shutter_sound =
      _camera_attr_disable_shutter_soundPtr
          .asFunction<int Function(camera_h, bool)>();

  /// @brief Sets the position to move horizontally.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[in] move_type The PTZ(Pan Tilt Zoom) move type
  /// @param[in] pan_step The step to move the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_get_pan()
  /// @see camera_attr_get_pan_range()
  int camera_attr_set_pan(
    camera_h camera,
    int move_type,
    int pan_step,
  ) {
    return _camera_attr_set_pan(
      camera,
      move_type,
      pan_step,
    );
  }

  late final _camera_attr_set_panPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32, ffi.Int)>>(
      'camera_attr_set_pan');
  late final _camera_attr_set_pan =
      _camera_attr_set_panPtr.asFunction<int Function(camera_h, int, int)>();

  /// @brief Gets the current position of the camera.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[out] pan_step The current horizontal distance from the starting point.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_pan()
  /// @see camera_attr_get_pan_range()
  int camera_attr_get_pan(
    camera_h camera,
    ffi.Pointer<ffi.Int> pan_step,
  ) {
    return _camera_attr_get_pan(
      camera,
      pan_step,
    );
  }

  late final _camera_attr_get_panPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_attr_get_pan');
  late final _camera_attr_get_pan = _camera_attr_get_panPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets lower limit and upper limit for pan position.
  /// @since_tizen 3.0
  /// @remarks If the min value is greater than the max value, it means that this feature is not supported.
  /// @param[in] camera The handle to the camera
  /// @param[out] min The lower limit for pan
  /// @param[out] max The upper limit for pan
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_pan()
  /// @see camera_attr_get_pan()
  int camera_attr_get_pan_range(
    camera_h camera,
    ffi.Pointer<ffi.Int> min,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _camera_attr_get_pan_range(
      camera,
      min,
      max,
    );
  }

  late final _camera_attr_get_pan_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('camera_attr_get_pan_range');
  late final _camera_attr_get_pan_range =
      _camera_attr_get_pan_rangePtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the position to move vertically.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[in] move_type The PTZ(Pan Tilt Zoom) move type
  /// @param[in] tilt_step The step to move the camera
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_get_tilt()
  /// @see camera_attr_get_tilt_range()
  int camera_attr_set_tilt(
    camera_h camera,
    int move_type,
    int tilt_step,
  ) {
    return _camera_attr_set_tilt(
      camera,
      move_type,
      tilt_step,
    );
  }

  late final _camera_attr_set_tiltPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32, ffi.Int)>>(
      'camera_attr_set_tilt');
  late final _camera_attr_set_tilt =
      _camera_attr_set_tiltPtr.asFunction<int Function(camera_h, int, int)>();

  /// @brief Gets the current position of the camera.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[out] tilt_step The current vertical distance from the starting point.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_tilt()
  /// @see camera_attr_get_tilt_range()
  int camera_attr_get_tilt(
    camera_h camera,
    ffi.Pointer<ffi.Int> tilt_step,
  ) {
    return _camera_attr_get_tilt(
      camera,
      tilt_step,
    );
  }

  late final _camera_attr_get_tiltPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>)>>(
      'camera_attr_get_tilt');
  late final _camera_attr_get_tilt = _camera_attr_get_tiltPtr
      .asFunction<int Function(camera_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets lower limit and upper limit for tilt position.
  /// @since_tizen 3.0
  /// @remarks If the min value is greater than the max value, it means that this feature is not supported.
  /// @param[in] camera The handle to the camera
  /// @param[out] min The lower limit for tilt
  /// @param[out] max The upper limit for tilt
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_tilt()
  /// @see camera_attr_get_tilt()
  int camera_attr_get_tilt_range(
    camera_h camera,
    ffi.Pointer<ffi.Int> min,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _camera_attr_get_tilt_range(
      camera,
      min,
      max,
    );
  }

  late final _camera_attr_get_tilt_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('camera_attr_get_tilt_range');
  late final _camera_attr_get_tilt_range =
      _camera_attr_get_tilt_rangePtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the type of PTZ(Pan Tilt Zoom).
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[in] ptz_type PTZ type
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_INVALID_STATE Invalid state
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The camera state must be set to #CAMERA_STATE_PREVIEW.
  /// @see camera_attr_get_pan()
  /// @see camera_attr_set_pan()
  /// @see camera_attr_get_pan_range()
  /// @see camera_attr_get_tilt()
  /// @see camera_attr_set_tilt()
  /// @see camera_attr_get_tilt_range()
  /// @see camera_attr_foreach_supported_ptz_type()
  int camera_attr_set_ptz_type(
    camera_h camera,
    int ptz_type,
  ) {
    return _camera_attr_set_ptz_type(
      camera,
      ptz_type,
    );
  }

  late final _camera_attr_set_ptz_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(camera_h, ffi.Int32)>>(
          'camera_attr_set_ptz_type');
  late final _camera_attr_set_ptz_type =
      _camera_attr_set_ptz_typePtr.asFunction<int Function(camera_h, int)>();

  /// @brief Retrieves all supported PTZ(Pan Tilt Zoom) types by invoking callback function once for each supported ptz type.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post This function invokes camera_attr_supported_ptz_type_cb() to get all supported ptz type.
  /// @see camera_attr_set_ptz_type()
  int camera_attr_foreach_supported_ptz_type(
    camera_h camera,
    camera_attr_supported_ptz_type_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _camera_attr_foreach_supported_ptz_type(
      camera,
      callback,
      user_data,
    );
  }

  late final _camera_attr_foreach_supported_ptz_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(camera_h, camera_attr_supported_ptz_type_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'camera_attr_foreach_supported_ptz_type');
  late final _camera_attr_foreach_supported_ptz_type =
      _camera_attr_foreach_supported_ptz_typePtr.asFunction<
          int Function(camera_h, camera_attr_supported_ptz_type_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the ROI(Region Of Interest) area of display.
  /// @since_tizen 3.0
  /// @remarks Before set display ROI area, #CAMERA_DISPLAY_MODE_CUSTOM_ROI should be set with camera_set_display_mode().
  /// The minimum value of width and height are 1.
  /// @param[in] camera The handle to the camera
  /// @param[in] x X coordinate of area
  /// @param[in] y Y coordinate of area
  /// @param[in] width Width of area
  /// @param[in] height Height of area
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_get_display_roi_area()
  int camera_attr_set_display_roi_area(
    camera_h camera,
    int x,
    int y,
    int width,
    int height,
  ) {
    return _camera_attr_set_display_roi_area(
      camera,
      x,
      y,
      width,
      height,
    );
  }

  late final _camera_attr_set_display_roi_areaPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h, ffi.Int, ffi.Int, ffi.Int,
              ffi.Int)>>('camera_attr_set_display_roi_area');
  late final _camera_attr_set_display_roi_area =
      _camera_attr_set_display_roi_areaPtr
          .asFunction<int Function(camera_h, int, int, int, int)>();

  /// @brief Gets the ROI(Region Of Interest) area of display.
  /// @since_tizen 3.0
  /// @param[in] camera The handle to the camera
  /// @param[out] x X coordinate of area
  /// @param[out] y Y coordinate of area
  /// @param[out] width Width of area
  /// @param[out] height Height of area
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CAMERA_ERROR_NONE Successful
  /// @retval #CAMERA_ERROR_INVALID_OPERATION Internal error
  /// @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CAMERA_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #CAMERA_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see camera_attr_set_display_roi_area()
  int camera_attr_get_display_roi_area(
    camera_h camera,
    ffi.Pointer<ffi.Int> x,
    ffi.Pointer<ffi.Int> y,
    ffi.Pointer<ffi.Int> width,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _camera_attr_get_display_roi_area(
      camera,
      x,
      y,
      width,
      height,
    );
  }

  late final _camera_attr_get_display_roi_areaPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              camera_h,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('camera_attr_get_display_roi_area');
  late final _camera_attr_get_display_roi_area =
      _camera_attr_get_display_roi_areaPtr.asFunction<
          int Function(camera_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief	Creates a media packet pool to handle the media packets.
  /// @details	It creates a media packet pool instance
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks	The @a pool must be released by using packet_pool_destroy().
  /// @param[out] pool The media packet pool handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_OUT_OF_MEMORY Out of memory
  int media_packet_pool_create(
    ffi.Pointer<media_packet_pool_h> pool,
  ) {
    return _media_packet_pool_create(
      pool,
    );
  }

  late final _media_packet_pool_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<media_packet_pool_h>)>>('media_packet_pool_create');
  late final _media_packet_pool_create = _media_packet_pool_createPtr
      .asFunction<int Function(ffi.Pointer<media_packet_pool_h>)>();

  /// @brief	Sets the media format for the media packet pool.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in]	pool	The media packet pool handle
  /// @param[in]	fmt	The #media_format_h allocated by the caller
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @pre Must have media_format_h instance by media_format_create().
  /// @post Must do media_format_unref().
  int media_packet_pool_set_media_format(
    media_packet_pool_h pool,
    media_format_h fmt,
  ) {
    return _media_packet_pool_set_media_format(
      pool,
      fmt,
    );
  }

  late final _media_packet_pool_set_media_formatPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_pool_h,
              media_format_h)>>('media_packet_pool_set_media_format');
  late final _media_packet_pool_set_media_format =
      _media_packet_pool_set_media_formatPtr
          .asFunction<int Function(media_packet_pool_h, media_format_h)>();

  /// @brief	Sets the media packet pool size.
  /// @details	Sets the number of packets to allocate with given parameters.
  /// The media packet pool will be allocated with @a min_buffers when media_pacet_pool_allocate() is called.
  /// When there are no media packets available, it will be increased to @a max_buffers of given parameter.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in]  pool The allocated pool handle
  /// @param[in]  min_buffers   The minimum number of buffers to allocate
  /// @param[in]  max_buffers   The maximum number of buffers to allocate
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_OUT_OF_MEMORY Out of memory
  /// @post After the pool has been configured, it can be allocated with media_packet_pool_allocate().
  /// @see media_packet_pool_get_size()
  int media_packet_pool_set_size(
    media_packet_pool_h pool,
    int min_buffers,
    int max_buffers,
  ) {
    return _media_packet_pool_set_size(
      pool,
      min_buffers,
      max_buffers,
    );
  }

  late final _media_packet_pool_set_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_pool_h, ffi.Int,
              ffi.Int)>>('media_packet_pool_set_size');
  late final _media_packet_pool_set_size = _media_packet_pool_set_sizePtr
      .asFunction<int Function(media_packet_pool_h, int, int)>();

  /// @brief	Gets the media packet pool size.
  /// @details	Gets the configuration values from the pool.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in]	pool	The allocated pool handle
  /// @param[out]	min_buffers		The minimum number of buffers to allocate
  /// @param[out]	max_buffers		The maximum number of buffers to allocate
  /// @param[out]	curr_buffers	The current number of allocated buffers
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post After the pool has been configured, it can be allocated with media_packet_pool_allocate().
  /// @see media_packet_pool_set_size()
  int media_packet_pool_get_size(
    media_packet_pool_h pool,
    ffi.Pointer<ffi.Int> min_buffers,
    ffi.Pointer<ffi.Int> max_buffers,
    ffi.Pointer<ffi.Int> curr_buffers,
  ) {
    return _media_packet_pool_get_size(
      pool,
      min_buffers,
      max_buffers,
      curr_buffers,
    );
  }

  late final _media_packet_pool_get_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_packet_pool_h,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('media_packet_pool_get_size');
  late final _media_packet_pool_get_size =
      _media_packet_pool_get_sizePtr.asFunction<
          int Function(media_packet_pool_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief	Allocates the media packet pool.
  /// @details It will allocate media packets with @a min_buffers which given to media_packet_pool_set_size().
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in]	pool	The allocated pool handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION The user set the invalid format with media_packet_pool_set_format() or set the invalid size with media_packet_pool_set_size().\n
  /// The user already allocate the pool.
  /// @pre media_packet_pool_set_media_format() and media_pool_set_size() should be called before calling media_packet_pool_allocate()
  /// @post The pool will be allocated. When the pool is allocated, media_packet_pool_acquire_packet() can be used to retrieve a packet from the pool.
  /// @see media_packet_pool_set_media_format()
  /// @see media_packet_pool_set_size()
  int media_packet_pool_allocate(
    media_packet_pool_h pool,
  ) {
    return _media_packet_pool_allocate(
      pool,
    );
  }

  late final _media_packet_pool_allocatePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_pool_h)>>(
          'media_packet_pool_allocate');
  late final _media_packet_pool_allocate = _media_packet_pool_allocatePtr
      .asFunction<int Function(media_packet_pool_h)>();

  /// @brief	Acquires a media packet from the media packet pool.
  /// @details	It will take a media packet from the queue and block until media packet is released into the pool agaian.
  /// When there are no media packets available, it will be increased to @a max_buffers of given parameter.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in]	pool	The media packet pool handle
  /// @param[out]	pkt		The media packet handle
  /// @param[in]   timeout It indicates the millisecond-timeouts to block
  /// while waiting for one of acquired packet to be released.
  /// If the value of timeout is -1, the pool blocks indefinitely until media packet into the pool.
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION The user does not allocate the pool.\n
  /// The pool should be allocated with media_packet_pool_allocate() before acquiring media packet from the pool.
  /// @retval #MEDIA_PACKET_ERROR_NO_AVAILABLE_PACKET No available packet
  /// @see media_pakcet_pool_set_size()
  /// @see media_packet_pool_release_packet()
  int media_packet_pool_acquire_packet(
    media_packet_pool_h pool,
    ffi.Pointer<media_packet_h> pkt,
    int timeout,
  ) {
    return _media_packet_pool_acquire_packet(
      pool,
      pkt,
      timeout,
    );
  }

  late final _media_packet_pool_acquire_packetPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_pool_h, ffi.Pointer<media_packet_h>,
              ffi.Long)>>('media_packet_pool_acquire_packet');
  late final _media_packet_pool_acquire_packet =
      _media_packet_pool_acquire_packetPtr.asFunction<
          int Function(
              media_packet_pool_h, ffi.Pointer<media_packet_h>, int)>();

  /// @brief	Releases the media packet to pool.
  /// @details	Rlease a packet back in the pool. It will put the packet back in the queue.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in]  pool The media packet pool handle
  /// @param[in]  pkt The packet to release, the pkt should have previously been acquired from the pool with media_packet_pool_acquire_packet()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION The user releases media packet which is not associated with a given pool.
  /// @see media_packet_pool_acquire_packet()
  int media_packet_pool_release_packet(
    media_packet_pool_h pool,
    media_packet_h pkt,
  ) {
    return _media_packet_pool_release_packet(
      pool,
      pkt,
    );
  }

  late final _media_packet_pool_release_packetPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_packet_pool_h,
              media_packet_h)>>('media_packet_pool_release_packet');
  late final _media_packet_pool_release_packet =
      _media_packet_pool_release_packetPtr
          .asFunction<int Function(media_packet_pool_h, media_packet_h)>();

  /// @brief	Deallocates all the media packets.
  /// @details	Deallocates the packets allocated with media_packet_pool_allocate().
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in]  pool The media packet pool handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION The user does not release all media packets to the pool.
  ///
  /// @pre media packet should be released before calling media_packet_pool_deallocate().
  /// @post The pool will be deallocated. media_packet_pool_acquire_packet() calls will return an error.
  /// @see media_packet_pool_allocate()
  int media_packet_pool_deallocate(
    media_packet_pool_h pool,
  ) {
    return _media_packet_pool_deallocate(
      pool,
    );
  }

  late final _media_packet_pool_deallocatePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_pool_h)>>(
          'media_packet_pool_deallocate');
  late final _media_packet_pool_deallocate = _media_packet_pool_deallocatePtr
      .asFunction<int Function(media_packet_pool_h)>();

  /// @brief	Destroys the media packet pool.
  /// @details	Destroys the media packet pool handle and releases all its resources.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in]	 pool	The handle to media packet pool to be destroyed
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_PACKET_ERROR_NONE Successful
  /// @retval #MEDIA_PACKET_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_PACKET_ERROR_INVALID_OPERATION The user does not create media packet pool instance, or not deallocate all media packets with media_packet_pool_deallocate().
  ///
  /// @see media_packet_pool_create()
  int media_packet_pool_destroy(
    media_packet_pool_h pool,
  ) {
    return _media_packet_pool_destroy(
      pool,
    );
  }

  late final _media_packet_pool_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_packet_pool_h)>>(
          'media_packet_pool_destroy');
  late final _media_packet_pool_destroy = _media_packet_pool_destroyPtr
      .asFunction<int Function(media_packet_pool_h)>();

  /// @brief Creates a mediacodec handle for decoding/encoding
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks you must release @a mediacodec using mediacodec_destroy().\n
  /// Although you can create multiple mediacodec handles at the same time,
  /// the mediacodec cannot guarantee proper operation because of limited resources, like
  /// audio or display device.
  ///
  /// @param[out] mediacodec  A new handle to mediacodec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_create(
    ffi.Pointer<mediacodec_h> mediacodec,
  ) {
    return _mediacodec_create(
      mediacodec,
    );
  }

  late final _mediacodec_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<mediacodec_h>)>>(
          'mediacodec_create');
  late final _mediacodec_create = _mediacodec_createPtr
      .asFunction<int Function(ffi.Pointer<mediacodec_h>)>();

  /// @brief Destroys the mediacodec handle and releases all its resources.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks To completely shutdown the mediacodec operation, call this function with a valid player handle from any
  /// mediacodec
  ///
  /// @param[in] mediacodec The handle to mediacodec to be destroyed.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_destroy(
    mediacodec_h mediacodec,
  ) {
    return _mediacodec_destroy(
      mediacodec,
    );
  }

  late final _mediacodec_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediacodec_h)>>(
          'mediacodec_destroy');
  late final _mediacodec_destroy =
      _mediacodec_destroyPtr.asFunction<int Function(mediacodec_h)>();

  /// @brief Sets the codec type and decoder/encoder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If this codec is to be used as a decoder, pass the #MEDIACODEC_DECODER flag.
  /// If this codec is to be used as an encoder, pass the #MEDIACODEC_ENCODER flag.\n
  /// The software codec is used as default setting(#MEDIACODEC_SUPPORT_TYPE_SW) if user doesn't set hardware flag.
  /// If user wants to use h/w decoder, user needs to pass the #MEDIACODEC_DECODER | #MEDIACODEC_SUPPORT_TYPE_HW.
  /// @param[in] mediacodec  The handle of mediacodec
  /// @param[in] codec_type  The identifier of the codec type of the decoder/encoder
  /// @param[in] flags  The encoding/decoding scheme, defined by #mediacodec_support_type_e
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_CODEC_NOT_FOUND Codec not found
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_set_codec(
    mediacodec_h mediacodec,
    int codec_type,
    int flags,
  ) {
    return _mediacodec_set_codec(
      mediacodec,
      codec_type,
      flags,
    );
  }

  late final _mediacodec_set_codecPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mediacodec_h, ffi.Int32, ffi.Int)>>('mediacodec_set_codec');
  late final _mediacodec_set_codec = _mediacodec_set_codecPtr
      .asFunction<int Function(mediacodec_h, int, int)>();

  /// @brief Sets the default info for the video decoder
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[in] width      The width for video decoding.
  /// @param[in] height     The height for video decoding.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_set_vdec_info(
    mediacodec_h mediacodec,
    int width,
    int height,
  ) {
    return _mediacodec_set_vdec_info(
      mediacodec,
      width,
      height,
    );
  }

  late final _mediacodec_set_vdec_infoPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(mediacodec_h, ffi.Int, ffi.Int)>>(
      'mediacodec_set_vdec_info');
  late final _mediacodec_set_vdec_info = _mediacodec_set_vdec_infoPtr
      .asFunction<int Function(mediacodec_h, int, int)>();

  /// @brief Sets the default info for the video encoder
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The frame rate is the speed of recording and the speed of playback.
  /// If user wants the default setting for ratecontrol, set @a target_bits to @c 0.
  /// @param[in] mediacodec  The handle to mediacodec
  /// @param[in] width  The width for video encoding.
  /// @param[in] height  The height for video encoding.
  /// @param[in] fps  The frame rate in frames per second.
  /// @param[in] target_bits The target bitrates in bits per second.(a unit of kbit)
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_set_venc_info(
    mediacodec_h mediacodec,
    int width,
    int height,
    int fps,
    int target_bits,
  ) {
    return _mediacodec_set_venc_info(
      mediacodec,
      width,
      height,
      fps,
      target_bits,
    );
  }

  late final _mediacodec_set_venc_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, ffi.Int, ffi.Int, ffi.Int,
              ffi.Int)>>('mediacodec_set_venc_info');
  late final _mediacodec_set_venc_info = _mediacodec_set_venc_infoPtr
      .asFunction<int Function(mediacodec_h, int, int, int, int)>();

  /// @brief Sets the default info for the audio decoder
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[in] samplerate The samplerate for audio decoding.
  /// @param[in] channel    The channels for audio decoding.
  /// @param[in] bit        The bits resolution for audio decoding.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_set_adec_info(
    mediacodec_h mediacodec,
    int samplerate,
    int channel,
    int bit,
  ) {
    return _mediacodec_set_adec_info(
      mediacodec,
      samplerate,
      channel,
      bit,
    );
  }

  late final _mediacodec_set_adec_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, ffi.Int, ffi.Int,
              ffi.Int)>>('mediacodec_set_adec_info');
  late final _mediacodec_set_adec_info = _mediacodec_set_adec_infoPtr
      .asFunction<int Function(mediacodec_h, int, int, int)>();

  /// @brief Sets the default info for the audio encoder
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[in] samplerate The samplerate for audio encoding.
  /// @param[in] channel    The channels for audio encoding.
  /// @param[in] bit        The bits resolution for audio encoding.
  /// @param[in] bitrate  The bitrate for audio encoding.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_set_aenc_info(
    mediacodec_h mediacodec,
    int samplerate,
    int channel,
    int bit,
    int bitrate,
  ) {
    return _mediacodec_set_aenc_info(
      mediacodec,
      samplerate,
      channel,
      bit,
      bitrate,
    );
  }

  late final _mediacodec_set_aenc_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, ffi.Int, ffi.Int, ffi.Int,
              ffi.Int)>>('mediacodec_set_aenc_info');
  late final _mediacodec_set_aenc_info = _mediacodec_set_aenc_infoPtr
      .asFunction<int Function(mediacodec_h, int, int, int, int)>();

  /// @brief Sets the codec type and codec default info via media format.
  /// @details Sets the value via media format instead of mediacodec_set_codec(), mediacodec_set_venc_info(),
  /// mediacodec_set_vdec_info(), mediacodec_set_aenc_info(), and mediacodec_set_adec_info().
  /// @since_tizen 4.0
  /// @remarks When using the @a format parameter from the output of the media demuxer, you can use media format via media_packet_get_format().
  /// Otherwise, you must set the following values after creating media format.
  /// Set the audio or video codec type via media_format_set_video_mime() or media_format_set_audio_mime().
  /// For video decoding, width, height must be set via media_format_set_video_width() and media_format_set_video_height().
  /// For video encoding, width, height, target bitrate, and frame rate must be set via media_format_set_video_avg_bps() and media_format_set_video_frame_rate().
  /// For audio decoding, samplerate, channel, and bit must be set via media_format_set_audio_samplerate(), media_format_set_audio_channel() and media_format_set_audio_bit().
  /// For audio encoding, samplerate, channel, bit, and bitrate must be set via media_format_set_audio_avg_bps().\n
  /// If this codec is to be used as a decoder, pass the #MEDIACODEC_DECODER flag.
  /// If this codec is to be used as an encoder, pass the #MEDIACODEC_ENCODER flag.\n
  /// The software codec is used as default setting (#MEDIACODEC_SUPPORT_TYPE_SW) if user doesn't set hardware flag.
  /// If you wants to use h/w decoder, you needs to pass the #MEDIACODEC_DECODER | #MEDIACODEC_SUPPORT_TYPE_HW.
  /// @param[in] mediacodec The mediacodec handle
  /// @param[in] format     The #media_format_h of input data
  /// @param[in] flags      The encoding/decoding scheme,
  /// values of #mediacodec_support_type_e combined with bitwise 'or'
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_CODEC_NOT_FOUND Unsupported codec
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @pre The media format has been created and the required values for configuration have been set.
  /// @see media_format_set_video_mime()
  /// @see media_format_set_audio_mime()
  /// @see media_format_set_video_width()
  /// @see media_format_set_video_height()
  /// @see media_format_set_video_avg_bps()
  /// @see media_format_set_video_frame_rate()
  /// @see media_format_set_audio_channel()
  /// @see media_format_set_audio_samplerate()
  /// @see media_format_set_audio_bit()
  /// @see media_format_set_audio_avg_bps()
  int mediacodec_configure_from_media_format(
    mediacodec_h mediacodec,
    media_format_h format,
    int flags,
  ) {
    return _mediacodec_configure_from_media_format(
      mediacodec,
      format,
      flags,
    );
  }

  late final _mediacodec_configure_from_media_formatPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, media_format_h,
              ffi.Int)>>('mediacodec_configure_from_media_format');
  late final _mediacodec_configure_from_media_format =
      _mediacodec_configure_from_media_formatPtr
          .asFunction<int Function(mediacodec_h, media_format_h, int)>();

  /// @brief Prepares @a mediacodec for encoding/decoding.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @pre The mediacodec should call mediacodec_set_codec()and mediacodec_set_vdec_info()/mediacodec_set_venc_info() before calling mediacodec_prepare()
  /// If the decoder is set by mediacodec_set_codec(), mediacodec_set_vdec_info() should be called. If the encoder is set by
  /// mediacodec_set_codec(), mediacodec_set_venc_info() should be called.
  int mediacodec_prepare(
    mediacodec_h mediacodec,
  ) {
    return _mediacodec_prepare(
      mediacodec,
    );
  }

  late final _mediacodec_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediacodec_h)>>(
          'mediacodec_prepare');
  late final _mediacodec_prepare =
      _mediacodec_preparePtr.asFunction<int Function(mediacodec_h)>();

  /// @brief Unprepares @a mediacodec for encoding/decoding.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_unprepare(
    mediacodec_h mediacodec,
  ) {
    return _mediacodec_unprepare(
      mediacodec,
    );
  }

  late final _mediacodec_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediacodec_h)>>(
          'mediacodec_unprepare');
  late final _mediacodec_unprepare =
      _mediacodec_unpreparePtr.asFunction<int Function(mediacodec_h)>();

  /// @brief Decodes/Encodes a packet. The function passed undecoded/unencoded packet to the input queue and decode/encode a
  /// frame sequentially.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[in] inbuf      The current input format for the decoder/encoder
  /// @param[in] timeOutUs  The timeout in microseconds. \n
  /// The input buffer wait up to "timeOutUs" microseconds.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_OVERFLOW_INBUFFER Overflow inputbuffer
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_process_input(
    mediacodec_h mediacodec,
    media_packet_h inbuf,
    int timeOutUs,
  ) {
    return _mediacodec_process_input(
      mediacodec,
      inbuf,
      timeOutUs,
    );
  }

  late final _mediacodec_process_inputPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, media_packet_h,
              ffi.Uint64)>>('mediacodec_process_input');
  late final _mediacodec_process_input = _mediacodec_process_inputPtr
      .asFunction<int Function(mediacodec_h, media_packet_h, int)>();

  /// @brief Gets the decoded or encoded packet from the output queue.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[out] outbuf    The current output of the decoder/encoder.
  /// this function passed decoded/encoded frame to output queue.
  /// @param[in] timeOutUs  The timeout in microseconds. \n
  /// The input buffer wait up to "timeOutUs" microseconds.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_get_output(
    mediacodec_h mediacodec,
    ffi.Pointer<media_packet_h> outbuf,
    int timeOutUs,
  ) {
    return _mediacodec_get_output(
      mediacodec,
      outbuf,
      timeOutUs,
    );
  }

  late final _mediacodec_get_outputPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, ffi.Pointer<media_packet_h>,
              ffi.Uint64)>>('mediacodec_get_output');
  late final _mediacodec_get_output = _mediacodec_get_outputPtr.asFunction<
      int Function(mediacodec_h, ffi.Pointer<media_packet_h>, int)>();

  /// @brief Flushes both input and output buffers.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_flush_buffers(
    mediacodec_h mediacodec,
  ) {
    return _mediacodec_flush_buffers(
      mediacodec,
    );
  }

  late final _mediacodec_flush_buffersPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediacodec_h)>>(
          'mediacodec_flush_buffers');
  late final _mediacodec_flush_buffers =
      _mediacodec_flush_buffersPtr.asFunction<int Function(mediacodec_h)>();

  /// @brief set empty buffer callback the media codec for process, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[in] callback   The callback function to register
  /// @param[in] user_data  The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @pre	mediacodec_set_input_buffer_used_cb should be called before mediacodec_preare().
  /// @post mediacodec_input_buffer_used_cb will be invoked.
  /// @see mediacodec_set_input_buffer_used_cb()
  /// @see mediacodec_unset_input_buffer_used_cb()
  int mediacodec_set_input_buffer_used_cb(
    mediacodec_h mediacodec,
    mediacodec_input_buffer_used_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mediacodec_set_input_buffer_used_cb(
      mediacodec,
      callback,
      user_data,
    );
  }

  late final _mediacodec_set_input_buffer_used_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, mediacodec_input_buffer_used_cb,
              ffi.Pointer<ffi.Void>)>>('mediacodec_set_input_buffer_used_cb');
  late final _mediacodec_set_input_buffer_used_cb =
      _mediacodec_set_input_buffer_used_cbPtr.asFunction<
          int Function(mediacodec_h, mediacodec_input_buffer_used_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief unset input buffer used callback the media codec for process, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @see mediacodec_set_input_buffer_used_cb()
  int mediacodec_unset_input_buffer_used_cb(
    mediacodec_h mediacodec,
  ) {
    return _mediacodec_unset_input_buffer_used_cb(
      mediacodec,
    );
  }

  late final _mediacodec_unset_input_buffer_used_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediacodec_h)>>(
          'mediacodec_unset_input_buffer_used_cb');
  late final _mediacodec_unset_input_buffer_used_cb =
      _mediacodec_unset_input_buffer_used_cbPtr
          .asFunction<int Function(mediacodec_h)>();

  /// @brief set output buffer available callback the media codec for process, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[in] callback   The callback function to register
  /// @param[in] user_data  The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @pre	mediacodec_set_output_buffer_available_cb should be called before mediacodec_preare().
  /// @post mediacodec_output_buffer_available_cb will be invoked.
  /// @see mediacodec_set_output_buffer_available_cb()
  /// @see mediacodec_unset_output_buffer_available_cb()
  int mediacodec_set_output_buffer_available_cb(
    mediacodec_h mediacodec,
    mediacodec_output_buffer_available_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mediacodec_set_output_buffer_available_cb(
      mediacodec,
      callback,
      user_data,
    );
  }

  late final _mediacodec_set_output_buffer_available_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mediacodec_h,
                  mediacodec_output_buffer_available_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'mediacodec_set_output_buffer_available_cb');
  late final _mediacodec_set_output_buffer_available_cb =
      _mediacodec_set_output_buffer_available_cbPtr.asFunction<
          int Function(mediacodec_h, mediacodec_output_buffer_available_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief unset output buffer available callback the media codec for process, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @see mediacodec_set_output_buffer_available_cb()
  int mediacodec_unset_output_buffer_available_cb(
    mediacodec_h mediacodec,
  ) {
    return _mediacodec_unset_output_buffer_available_cb(
      mediacodec,
    );
  }

  late final _mediacodec_unset_output_buffer_available_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediacodec_h)>>(
          'mediacodec_unset_output_buffer_available_cb');
  late final _mediacodec_unset_output_buffer_available_cb =
      _mediacodec_unset_output_buffer_available_cbPtr
          .asFunction<int Function(mediacodec_h)>();

  /// @brief set error callback the media codec for process, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[in] callback   The callback function to register
  /// @param[in] user_data  The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @pre	mediacodec_set_error_cb should be called before mediacodec_preare().
  /// @post mediacodec_error_cb will be invoked.
  /// @see mediacodec_set_error_cb()
  /// @see mediacodec_unset_error_cb()
  int mediacodec_set_error_cb(
    mediacodec_h mediacodec,
    mediacodec_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mediacodec_set_error_cb(
      mediacodec,
      callback,
      user_data,
    );
  }

  late final _mediacodec_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, mediacodec_error_cb,
              ffi.Pointer<ffi.Void>)>>('mediacodec_set_error_cb');
  late final _mediacodec_set_error_cb = _mediacodec_set_error_cbPtr.asFunction<
      int Function(mediacodec_h, mediacodec_error_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief unset error callback the media codec for process, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @see mediacodec_set_error_cb()
  int mediacodec_unset_error_cb(
    mediacodec_h mediacodec,
  ) {
    return _mediacodec_unset_error_cb(
      mediacodec,
    );
  }

  late final _mediacodec_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediacodec_h)>>(
          'mediacodec_unset_error_cb');
  late final _mediacodec_unset_error_cb =
      _mediacodec_unset_error_cbPtr.asFunction<int Function(mediacodec_h)>();

  /// @brief set eos callback the media codec for process, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[in] callback   The callback function to register
  /// @param[in] user_data  The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @pre	mediacodec_set_eos_cb should be called before mediacodec_preare().
  /// @post mediacodec_eos_cb will be invoked.
  /// @see mediacodec_set_eos_cb()
  /// @see mediacodec_unset_eos_cb()
  int mediacodec_set_eos_cb(
    mediacodec_h mediacodec,
    mediacodec_eos_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mediacodec_set_eos_cb(
      mediacodec,
      callback,
      user_data,
    );
  }

  late final _mediacodec_set_eos_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, mediacodec_eos_cb,
              ffi.Pointer<ffi.Void>)>>('mediacodec_set_eos_cb');
  late final _mediacodec_set_eos_cb = _mediacodec_set_eos_cbPtr.asFunction<
      int Function(mediacodec_h, mediacodec_eos_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief unset eos callback the media codec for process, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @see mediacodec_set_event_handler_cb()
  int mediacodec_unset_eos_cb(
    mediacodec_h mediacodec,
  ) {
    return _mediacodec_unset_eos_cb(
      mediacodec,
    );
  }

  late final _mediacodec_unset_eos_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediacodec_h)>>(
          'mediacodec_unset_eos_cb');
  late final _mediacodec_unset_eos_cb =
      _mediacodec_unset_eos_cbPtr.asFunction<int Function(mediacodec_h)>();

  /// @brief Registers a callback function to be invoked when the mediacodec needs more data or has enough data.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[in] callback   The callback function to register
  /// @param[in] user_data  The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @pre	mediacodec_set_buffer_status_cb should be called before mediacodec_preare().
  /// @post mediacodec_buffer_status_cb will be invoked.
  /// @see mediacodec_set_buffer_status_cb()
  /// @see mediacodec_unset_buffer_status_cb()
  int mediacodec_set_buffer_status_cb(
    mediacodec_h mediacodec,
    mediacodec_buffer_status_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mediacodec_set_buffer_status_cb(
      mediacodec,
      callback,
      user_data,
    );
  }

  late final _mediacodec_set_buffer_status_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, mediacodec_buffer_status_cb,
              ffi.Pointer<ffi.Void>)>>('mediacodec_set_buffer_status_cb');
  late final _mediacodec_set_buffer_status_cb =
      _mediacodec_set_buffer_status_cbPtr.asFunction<
          int Function(mediacodec_h, mediacodec_buffer_status_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  int mediacodec_unset_buffer_status_cb(
    mediacodec_h mediacodec,
  ) {
    return _mediacodec_unset_buffer_status_cb(
      mediacodec,
    );
  }

  late final _mediacodec_unset_buffer_status_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediacodec_h)>>(
          'mediacodec_unset_buffer_status_cb');
  late final _mediacodec_unset_buffer_status_cb =
      _mediacodec_unset_buffer_status_cbPtr
          .asFunction<int Function(mediacodec_h)>();

  /// @brief Retrieves all supported codecs by invoking callback function once for each supported codecs.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] mediacodec The handle to mediacodec
  /// @param[in] callback   The callback function to invoke
  /// @param[in] user_data  The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @see mediacodec_foreach_supported_codec()
  int mediacodec_foreach_supported_codec(
    mediacodec_h mediacodec,
    mediacodec_supported_codec_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mediacodec_foreach_supported_codec(
      mediacodec,
      callback,
      user_data,
    );
  }

  late final _mediacodec_foreach_supported_codecPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, mediacodec_supported_codec_cb,
              ffi.Pointer<ffi.Void>)>>('mediacodec_foreach_supported_codec');
  late final _mediacodec_foreach_supported_codec =
      _mediacodec_foreach_supported_codecPtr.asFunction<
          int Function(mediacodec_h, mediacodec_supported_codec_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Verifies whether encoding can be performed with codec_type or not.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in]  mediacodec   The handle to mediacodec
  /// @param[in]  codec_type   The identifier of the codec type of the encoder.
  /// @param[in]  encoder      Whether the encoder or decoder : (@c true = encoder, @c false = decoder).
  /// @param[out] support_type (@c MEDIACODEC_SUPPORT_TYPE_HW = mediacodec can be performed with hardware codec, @c MEDIACODEC_SUPPORT_TYPE_SW = mediacodec can be performed with software codec)
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @code
  /// #include <media_codec.h>
  /// mediacodec_h mediacodec;
  /// mediacodec_support_type_e type;
  /// mediacodec_codec_type_e codec_type = MEDIACODEC_H264;
  ///
  /// mediacodec_create(&mediacodec);
  /// mediacodec_get_supported_type(mediacodec, codec_type, 1, &type);
  ///
  /// if(type == MEDIACODEC_SUPPORT_TYPE_HW)
  /// // only h/w supported
  /// else if (type == MEDIACODEC_SUPPORT_TYPE_SW)
  /// // only s/w supported
  /// else if (type == (MEDIACODEC_SUPPORT_TYPE_HW|MEDIACODEC_SUPPORT_TYPE_SW)
  /// // both supported
  ///
  /// mediacodec_set_codec(mediacodec, codec_type, MEDIACODEC_ENCODER | MEDIACODEC_SUPPORT_TYPE_HW);
  /// @endcode
  int mediacodec_get_supported_type(
    mediacodec_h mediacodec,
    int codec_type,
    bool encoder,
    ffi.Pointer<ffi.Int> support_type,
  ) {
    return _mediacodec_get_supported_type(
      mediacodec,
      codec_type,
      encoder,
      support_type,
    );
  }

  late final _mediacodec_get_supported_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h, ffi.Int32, ffi.Bool,
              ffi.Pointer<ffi.Int>)>>('mediacodec_get_supported_type');
  late final _mediacodec_get_supported_type =
      _mediacodec_get_supported_typePtr.asFunction<
          int Function(mediacodec_h, int, bool, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the media packet pool allocated for recycling media packets.
  /// @details The user can get the pool allocated with the number of packets are required to be used in codecs.\n
  /// It is recomended to use media packet pool for better stability and performance.
  /// @since_tizen 3.0
  /// @remarks The @a pool should be released using media_packet_pool_deallocate() and destroyed using media_packet_pool_destroy().
  /// @param[in]  mediacodec The mediacodec handle
  /// @param[out] pool       The allocated pool handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIACODEC_ERROR_NONE Successful
  /// @retval #MEDIACODEC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIACODEC_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #MEDIACODEC_ERROR_INVALID_OPERATION The user calls mediacodec_get_packet_pool() before calling mediacodec_prepare().
  /// @retval #MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE Not supported on device (Since 4.0)
  /// @pre mediacodec_get_packet_pool() should be called after calling mediacodec_prepare().
  /// @post If the pool is used, media_packet_pool_deallocate() and media_packet_pool_destroy() should be called.
  /// @see media_packet_pool_acquire_packet()
  /// @see media_packet_pool_release_packet()
  /// @see media_packet_pool_deallocate()
  /// @see media_packet_pool_destroy()
  int mediacodec_get_packet_pool(
    mediacodec_h mediacodec,
    ffi.Pointer<media_packet_pool_h> pool,
  ) {
    return _mediacodec_get_packet_pool(
      mediacodec,
      pool,
    );
  }

  late final _mediacodec_get_packet_poolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediacodec_h,
              ffi.Pointer<media_packet_pool_h>)>>('mediacodec_get_packet_pool');
  late final _mediacodec_get_packet_pool =
      _mediacodec_get_packet_poolPtr.asFunction<
          int Function(mediacodec_h, ffi.Pointer<media_packet_pool_h>)>();

  /// @brief Creates a media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a server using mc_server_destroy().
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param[out] server The handle to media controller server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @see mc_server_destroy()
  int mc_server_create(
    ffi.Pointer<mc_server_h> server,
  ) {
    return _mc_server_create(
      server,
    );
  }

  late final _mc_server_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<mc_server_h>)>>(
          'mc_server_create');
  late final _mc_server_create =
      _mc_server_createPtr.asFunction<int Function(ffi.Pointer<mc_server_h>)>();

  /// @brief Sets the playback state to update the latest state info
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param [in] server The handle to media controller server
  /// @param [in] state The state to set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_OUT_OF_MEMORY File does not exist
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @post Apply the updated playback information by calling mc_server_update_playback_info().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  /// @see mc_server_update_playback_info()
  int mc_server_set_playback_state(
    mc_server_h server,
    int state,
  ) {
    return _mc_server_set_playback_state(
      server,
      state,
    );
  }

  late final _mc_server_set_playback_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_server_h, ffi.Int32)>>(
          'mc_server_set_playback_state');
  late final _mc_server_set_playback_state = _mc_server_set_playback_statePtr
      .asFunction<int Function(mc_server_h, int)>();

  /// @brief Sets the playback position to update the latest playback info
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param [in] server The handle to media controller server
  /// @param [in] position The position to set in milliseconds
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_OUT_OF_MEMORY File does not exist
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @post Apply the updated playback information by calling mc_server_update_playback_info().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  /// @see mc_server_update_playback_info()
  int mc_server_set_playback_position(
    mc_server_h server,
    int position,
  ) {
    return _mc_server_set_playback_position(
      server,
      position,
    );
  }

  late final _mc_server_set_playback_positionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_server_h,
              ffi.UnsignedLongLong)>>('mc_server_set_playback_position');
  late final _mc_server_set_playback_position =
      _mc_server_set_playback_positionPtr
          .asFunction<int Function(mc_server_h, int)>();

  /// @brief Update the modified playback info
  /// @details If this API is called, the updated playback information will be sent to the controller.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param [in] server The handle to media controller server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_OUT_OF_MEMORY File does not exist
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  int mc_server_update_playback_info(
    mc_server_h server,
  ) {
    return _mc_server_update_playback_info(
      server,
    );
  }

  late final _mc_server_update_playback_infoPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_server_h)>>(
          'mc_server_update_playback_info');
  late final _mc_server_update_playback_info =
      _mc_server_update_playback_infoPtr
          .asFunction<int Function(mc_server_h)>();

  /// @brief Sets the metadata to update the latest metadata info
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param [in] server The handle to media controller server
  /// @param [in] attribute    The key attribute name to set
  /// @param [in] value      The value of the attribute
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_OUT_OF_MEMORY File does not exist
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @post Apply the updated metadata information by calling mc_server_update_metadata().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  /// @see mc_server_update_metadata()
  int mc_server_set_metadata(
    mc_server_h server,
    int attribute,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _mc_server_set_metadata(
      server,
      attribute,
      value,
    );
  }

  late final _mc_server_set_metadataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_server_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('mc_server_set_metadata');
  late final _mc_server_set_metadata = _mc_server_set_metadataPtr
      .asFunction<int Function(mc_server_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Update the modified metadata info.
  /// @details If this API is called, the updated metadata will be sent to all controllers.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param [in] server The handle to media controller server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_OUT_OF_MEMORY File does not exist
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  int mc_server_update_metadata(
    mc_server_h server,
  ) {
    return _mc_server_update_metadata(
      server,
    );
  }

  late final _mc_server_update_metadataPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_server_h)>>(
          'mc_server_update_metadata');
  late final _mc_server_update_metadata =
      _mc_server_update_metadataPtr.asFunction<int Function(mc_server_h)>();

  /// @brief Update the modified shuffle mode
  /// @details If this API is called, the updated mode information will be sent to all controllers.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param [in] server The handle to media controller server
  /// @param [in] mode The shuffle mode to update the latest status
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_OUT_OF_MEMORY File does not exist
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  int mc_server_update_shuffle_mode(
    mc_server_h server,
    int mode,
  ) {
    return _mc_server_update_shuffle_mode(
      server,
      mode,
    );
  }

  late final _mc_server_update_shuffle_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_server_h, ffi.Int32)>>(
          'mc_server_update_shuffle_mode');
  late final _mc_server_update_shuffle_mode = _mc_server_update_shuffle_modePtr
      .asFunction<int Function(mc_server_h, int)>();

  /// @brief Updates the modified repeat mode
  /// @details If this API is called, the updated mode information will be sent to all controllers.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param [in] server The handle to media controller server
  /// @param [in] mode The repeat mode to update the latest status
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_OUT_OF_MEMORY File does not exist
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  int mc_server_update_repeat_mode(
    mc_server_h server,
    int mode,
  ) {
    return _mc_server_update_repeat_mode(
      server,
      mode,
    );
  }

  late final _mc_server_update_repeat_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_server_h, ffi.Int32)>>(
          'mc_server_update_repeat_mode');
  late final _mc_server_update_repeat_mode = _mc_server_update_repeat_modePtr
      .asFunction<int Function(mc_server_h, int)>();

  /// @brief Sets the callback for receiving playback state command from client.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param [in] server    The handle to media controller server
  /// @param [in] callback      The callback to be invoked when media controller server receives playback command from client.
  /// @param [in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  int mc_server_set_playback_state_command_received_cb(
    mc_server_h server,
    mc_server_playback_state_command_received_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mc_server_set_playback_state_command_received_cb(
      server,
      callback,
      user_data,
    );
  }

  late final _mc_server_set_playback_state_command_received_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mc_server_h,
                  mc_server_playback_state_command_received_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'mc_server_set_playback_state_command_received_cb');
  late final _mc_server_set_playback_state_command_received_cb =
      _mc_server_set_playback_state_command_received_cbPtr.asFunction<
          int Function(
              mc_server_h,
              mc_server_playback_state_command_received_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets the callback for receiving playback state command from client.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param [in] server    The handle to media controller server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  int mc_server_unset_playback_state_command_received_cb(
    mc_server_h server,
  ) {
    return _mc_server_unset_playback_state_command_received_cb(
      server,
    );
  }

  late final _mc_server_unset_playback_state_command_received_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_server_h)>>(
          'mc_server_unset_playback_state_command_received_cb');
  late final _mc_server_unset_playback_state_command_received_cb =
      _mc_server_unset_playback_state_command_received_cbPtr
          .asFunction<int Function(mc_server_h)>();

  /// @brief Sets the callback for receiving custom command from client.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param [in] server    The handle to media controller server
  /// @param [in] callback      The callback to be invoked when media controller server receives custom command from client.
  /// @param [in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  int mc_server_set_custom_command_received_cb(
    mc_server_h server,
    mc_server_custom_command_received_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mc_server_set_custom_command_received_cb(
      server,
      callback,
      user_data,
    );
  }

  late final _mc_server_set_custom_command_received_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mc_server_h,
                  mc_server_custom_command_received_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'mc_server_set_custom_command_received_cb');
  late final _mc_server_set_custom_command_received_cb =
      _mc_server_set_custom_command_received_cbPtr.asFunction<
          int Function(mc_server_h, mc_server_custom_command_received_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets the callback for receiving custom command from client.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param [in] server    The handle to media controller server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  int mc_server_unset_custom_command_received_cb(
    mc_server_h server,
  ) {
    return _mc_server_unset_custom_command_received_cb(
      server,
    );
  }

  late final _mc_server_unset_custom_command_received_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_server_h)>>(
          'mc_server_unset_custom_command_received_cb');
  late final _mc_server_unset_custom_command_received_cb =
      _mc_server_unset_custom_command_received_cbPtr
          .asFunction<int Function(mc_server_h)>();

  /// @brief Sends a reply for the requested command to the client.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks When server recieve command, this API can be called by mc_server_custom_command_received_cb().
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.server
  ///
  /// @param [in] server    The handle to media controller server
  /// @param [in] client_name    The app_id of the media controller client
  /// @param [in] result_code    The result code of custom command
  /// @param [in] data                The extra data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @pre mc_server_command_received_cb()
  /// @see mc_server_create()
  /// @see mc_server_destroy()
  int mc_server_send_command_reply(
    mc_server_h server,
    ffi.Pointer<ffi.Char> client_name,
    int result_code,
    ffi.Pointer<bundle> data,
  ) {
    return _mc_server_send_command_reply(
      server,
      client_name,
      result_code,
      data,
    );
  }

  late final _mc_server_send_command_replyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_server_h, ffi.Pointer<ffi.Char>, ffi.Int,
              ffi.Pointer<bundle>)>>('mc_server_send_command_reply');
  late final _mc_server_send_command_reply =
      _mc_server_send_command_replyPtr.asFunction<
          int Function(
              mc_server_h, ffi.Pointer<ffi.Char>, int, ffi.Pointer<bundle>)>();

  /// @brief Destroys media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param [in] server The handle to media controller server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Create a media controller server handle by calling mc_server_create().
  /// @see mc_server_create()
  int mc_server_destroy(
    mc_server_h server,
  ) {
    return _mc_server_destroy(
      server,
    );
  }

  late final _mc_server_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_server_h)>>(
          'mc_server_destroy');
  late final _mc_server_destroy =
      _mc_server_destroyPtr.asFunction<int Function(mc_server_h)>();

  /// @brief Creates a media controller client.
  /// @details The media controller client binds the latest media controller server when handlers are created.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @remarks You must release @a client using mc_client_destroy().
  ///
  /// @param[out] client The handle to the media controller client
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @see mc_client_destroy()
  int mc_client_create(
    ffi.Pointer<mc_client_h> client,
  ) {
    return _mc_client_create(
      client,
    );
  }

  late final _mc_client_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<mc_client_h>)>>(
          'mc_client_create');
  late final _mc_client_create =
      _mc_client_createPtr.asFunction<int Function(ffi.Pointer<mc_client_h>)>();

  /// @brief Sets the callback for monitoring status of the media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details If media controller client call this function, basically the media controller client recieve the callback from all media controller servers.
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client         The handle to the media controller client
  /// @param [in] callback      The callback to be invoked when the media controller server status is changed
  /// @param [in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_destroy()
  int mc_client_set_server_update_cb(
    mc_client_h client,
    mc_server_state_updated_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mc_client_set_server_update_cb(
      client,
      callback,
      user_data,
    );
  }

  late final _mc_client_set_server_update_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, mc_server_state_updated_cb,
              ffi.Pointer<ffi.Void>)>>('mc_client_set_server_update_cb');
  late final _mc_client_set_server_update_cb =
      _mc_client_set_server_update_cbPtr.asFunction<
          int Function(mc_client_h, mc_server_state_updated_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets the callback for monitoring status of the media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client         The handle to the media controller client
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_destroy()
  int mc_client_unset_server_update_cb(
    mc_client_h client,
  ) {
    return _mc_client_unset_server_update_cb(
      client,
    );
  }

  late final _mc_client_unset_server_update_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_client_h)>>(
          'mc_client_unset_server_update_cb');
  late final _mc_client_unset_server_update_cb =
      _mc_client_unset_server_update_cbPtr
          .asFunction<int Function(mc_client_h)>();

  /// @brief Sets the callback for monitoring playback status of the media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details If media controller client call this function, basically the media controller client recieve the callback from all media controller servers. \n
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client         The handle to the media controller client
  /// @param [in] callback      The callback to be invoked when the playback status is changed
  /// @param [in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_destroy()
  int mc_client_set_playback_update_cb(
    mc_client_h client,
    mc_playback_updated_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mc_client_set_playback_update_cb(
      client,
      callback,
      user_data,
    );
  }

  late final _mc_client_set_playback_update_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, mc_playback_updated_cb,
              ffi.Pointer<ffi.Void>)>>('mc_client_set_playback_update_cb');
  late final _mc_client_set_playback_update_cb =
      _mc_client_set_playback_update_cbPtr.asFunction<
          int Function(
              mc_client_h, mc_playback_updated_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets the callback for monitoring playback status of the media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client         The handle to the media controller client
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_destroy()
  int mc_client_unset_playback_update_cb(
    mc_client_h client,
  ) {
    return _mc_client_unset_playback_update_cb(
      client,
    );
  }

  late final _mc_client_unset_playback_update_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_client_h)>>(
          'mc_client_unset_playback_update_cb');
  late final _mc_client_unset_playback_update_cb =
      _mc_client_unset_playback_update_cbPtr
          .asFunction<int Function(mc_client_h)>();

  /// @brief Sets the callback for monitoring metadata status of the media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details If media controller client call this function, basically the media controller client recieve the callback from all media controller servers.
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client         The handle to the media controller client
  /// @param [in] callback      The callback to be invoked when the metadata status is changed
  /// @param [in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_destroy()
  int mc_client_set_metadata_update_cb(
    mc_client_h client,
    mc_metadata_updated_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mc_client_set_metadata_update_cb(
      client,
      callback,
      user_data,
    );
  }

  late final _mc_client_set_metadata_update_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, mc_metadata_updated_cb,
              ffi.Pointer<ffi.Void>)>>('mc_client_set_metadata_update_cb');
  late final _mc_client_set_metadata_update_cb =
      _mc_client_set_metadata_update_cbPtr.asFunction<
          int Function(
              mc_client_h, mc_metadata_updated_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets the callback for monitoring metadata status of the media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client         The handle to the media controller client
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_destroy()
  int mc_client_unset_metadata_update_cb(
    mc_client_h client,
  ) {
    return _mc_client_unset_metadata_update_cb(
      client,
    );
  }

  late final _mc_client_unset_metadata_update_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_client_h)>>(
          'mc_client_unset_metadata_update_cb');
  late final _mc_client_unset_metadata_update_cb =
      _mc_client_unset_metadata_update_cbPtr
          .asFunction<int Function(mc_client_h)>();

  /// @brief Sets the callback for monitoring shuffle mode of the media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details If media controller client call this function, basically the media controller client recieve the callback from all media controller servers.
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] callback      The callback to be invoked when the shuffle mode is changed
  /// @param [in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_destroy()
  int mc_client_set_shuffle_mode_update_cb(
    mc_client_h client,
    mc_shuffle_mode_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mc_client_set_shuffle_mode_update_cb(
      client,
      callback,
      user_data,
    );
  }

  late final _mc_client_set_shuffle_mode_update_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, mc_shuffle_mode_changed_cb,
              ffi.Pointer<ffi.Void>)>>('mc_client_set_shuffle_mode_update_cb');
  late final _mc_client_set_shuffle_mode_update_cb =
      _mc_client_set_shuffle_mode_update_cbPtr.asFunction<
          int Function(mc_client_h, mc_shuffle_mode_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets the callback for monitoring shuffle mode of the media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client    The handle to the media controller client
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_destroy()
  int mc_client_unset_shuffle_mode_update_cb(
    mc_client_h client,
  ) {
    return _mc_client_unset_shuffle_mode_update_cb(
      client,
    );
  }

  late final _mc_client_unset_shuffle_mode_update_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_client_h)>>(
          'mc_client_unset_shuffle_mode_update_cb');
  late final _mc_client_unset_shuffle_mode_update_cb =
      _mc_client_unset_shuffle_mode_update_cbPtr
          .asFunction<int Function(mc_client_h)>();

  /// @brief Sets the callback for monitoring repeat mode of the media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details If media controller client call this function, basically the media controller client recieve the callback from all media controller servers.
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] callback      The callback to be invoked when the repeat mode is changed
  /// @param [in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_destroy()
  int mc_client_set_repeat_mode_update_cb(
    mc_client_h client,
    mc_repeat_mode_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mc_client_set_repeat_mode_update_cb(
      client,
      callback,
      user_data,
    );
  }

  late final _mc_client_set_repeat_mode_update_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, mc_repeat_mode_changed_cb,
              ffi.Pointer<ffi.Void>)>>('mc_client_set_repeat_mode_update_cb');
  late final _mc_client_set_repeat_mode_update_cb =
      _mc_client_set_repeat_mode_update_cbPtr.asFunction<
          int Function(
              mc_client_h, mc_repeat_mode_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets the callback for monitoring repeat mode of the media controller server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client    The handle to the media controller client
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_destroy()
  int mc_client_unset_repeat_mode_update_cb(
    mc_client_h client,
  ) {
    return _mc_client_unset_repeat_mode_update_cb(
      client,
    );
  }

  late final _mc_client_unset_repeat_mode_update_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_client_h)>>(
          'mc_client_unset_repeat_mode_update_cb');
  late final _mc_client_unset_repeat_mode_update_cb =
      _mc_client_unset_repeat_mode_update_cbPtr
          .asFunction<int Function(mc_client_h)>();

  /// @brief Subscribes media controller server for monitoring status.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details If media controller client subscribe media controller server, \n
  /// the media controller client recieve callback from subscribed media controller server. \n
  /// If media controller client subscribe media controller server one or more, \n
  /// the media controller client can recieve callback from only subscribed media controller server. \n
  /// If you want to subscribe for the all media controller server again, \n
  /// unset mode update callback and set the callback for the monitoring status again. \n
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] subscription_type    The subscription type
  /// @param [in] server_name    The app_id of the media controller server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Create a media controller client handle by calling mc_client_create()
  /// @pre Set the callback for monitoring status of the media controller server
  /// @post Unsubscribe the media controller server for monitoring status by calling mc_client_unsubscribe()
  /// @see mc_client_create()
  /// @see mc_client_unsubscribe()
  int mc_client_subscribe(
    mc_client_h client,
    int subscription_type,
    ffi.Pointer<ffi.Char> server_name,
  ) {
    return _mc_client_subscribe(
      client,
      subscription_type,
      server_name,
    );
  }

  late final _mc_client_subscribePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('mc_client_subscribe');
  late final _mc_client_subscribe = _mc_client_subscribePtr
      .asFunction<int Function(mc_client_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Unsubscribes media controller server for monitoring status.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details If media controller client unsubscribe media controller server, \n
  /// the media controller client don't recieve callback from unsubscribed media controller server. \n
  /// If media controller client unsubscribe all subscibed media controller server, \n
  /// the media controller client don't recieve callback from all media controller server. \n
  /// After unset and set update callback function is called again, the media controller client can recieve callback from all media controller servers. \n
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] subscription_type    The subscription type
  /// @param [in] server_name    The app_id of the media controller server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Create a media controller client handle by calling mc_client_create()
  /// @pre Subscribe the media controller server for monitoring status by calling mc_client_subscribe()
  /// @see mc_client_create()
  /// @see mc_client_subscribe()
  int mc_client_unsubscribe(
    mc_client_h client,
    int subscription_type,
    ffi.Pointer<ffi.Char> server_name,
  ) {
    return _mc_client_unsubscribe(
      client,
      subscription_type,
      server_name,
    );
  }

  late final _mc_client_unsubscribePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('mc_client_unsubscribe');
  late final _mc_client_unsubscribe = _mc_client_unsubscribePtr
      .asFunction<int Function(mc_client_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Retrieves all subscribed Server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] subscription_type    The subscription type
  /// @param [in] callback      The callback to be invoked when the list of the subscribed media controller server.
  /// @param [in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Create a media controller client handle by calling mc_client_create()
  /// @pre Subscribe the media controller server for monitoring status by calling mc_client_subscribe()
  /// @see mc_client_create()
  /// @see mc_client_subscribe()
  int mc_client_foreach_server_subscribed(
    mc_client_h client,
    int subscription_type,
    mc_subscribed_server_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mc_client_foreach_server_subscribed(
      client,
      subscription_type,
      callback,
      user_data,
    );
  }

  late final _mc_client_foreach_server_subscribedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, ffi.Int32, mc_subscribed_server_cb,
              ffi.Pointer<ffi.Void>)>>('mc_client_foreach_server_subscribed');
  late final _mc_client_foreach_server_subscribed =
      _mc_client_foreach_server_subscribedPtr.asFunction<
          int Function(mc_client_h, int, mc_subscribed_server_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the playback state.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a playback using @c mc_client_destroy_playback().
  ///
  /// @param [in] playback    The handle to playback
  /// @param [out] state      The state of the playback
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Sets mc_client_set_playback_update_cb() function to get the state
  /// @see mc_client_set_playback_update_cb()
  int mc_client_get_playback_state(
    mc_playback_h playback,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _mc_client_get_playback_state(
      playback,
      state,
    );
  }

  late final _mc_client_get_playback_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_playback_h,
              ffi.Pointer<ffi.Int32>)>>('mc_client_get_playback_state');
  late final _mc_client_get_playback_state = _mc_client_get_playback_statePtr
      .asFunction<int Function(mc_playback_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the playback position.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a playback using @c mc_client_destroy_playback().
  ///
  /// @param [in] playback    The handle to playback
  /// @param [out] position      The position of the playback in milliseconds
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Sets mc_client_set_playback_update_cb() function to get the position
  /// @see mc_client_set_playback_update_cb()
  int mc_client_get_playback_position(
    mc_playback_h playback,
    ffi.Pointer<ffi.UnsignedLongLong> position,
  ) {
    return _mc_client_get_playback_position(
      playback,
      position,
    );
  }

  late final _mc_client_get_playback_positionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mc_playback_h, ffi.Pointer<ffi.UnsignedLongLong>)>>(
      'mc_client_get_playback_position');
  late final _mc_client_get_playback_position =
      _mc_client_get_playback_positionPtr.asFunction<
          int Function(mc_playback_h, ffi.Pointer<ffi.UnsignedLongLong>)>();

  /// @brief Destroys playback
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param [in] playback    The handle to playback
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Sets mc_client_set_playback_update_cb() function to create playback
  /// @see mc_client_set_playback_update_cb()
  int mc_client_destroy_playback(
    mc_playback_h playback,
  ) {
    return _mc_client_destroy_playback(
      playback,
    );
  }

  late final _mc_client_destroy_playbackPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_playback_h)>>(
          'mc_client_destroy_playback');
  late final _mc_client_destroy_playback =
      _mc_client_destroy_playbackPtr.asFunction<int Function(mc_playback_h)>();

  /// @brief Gets the metadata.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a metadata using @c mc_client_destroy_metadata(). \n
  /// And also You must release @a value using free().
  /// If the attribute value of the metadata is empty, return value is NULL.
  ///
  /// @param [in] metadata    The handle to metadata
  /// @param [in] attribute    The key attribute name to get
  /// @param [out] value      The value of the attribute
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Sets mc_client_set_metadata_update_cb() function to get the metadata
  /// @see mc_client_set_metadata_update_cb()
  int mc_client_get_metadata(
    mc_metadata_h metadata,
    int attribute,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _mc_client_get_metadata(
      metadata,
      attribute,
      value,
    );
  }

  late final _mc_client_get_metadataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_metadata_h, ffi.Int32,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('mc_client_get_metadata');
  late final _mc_client_get_metadata = _mc_client_get_metadataPtr.asFunction<
      int Function(mc_metadata_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Destroys metadata
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param [in] metadata    The handle to metadata
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Sets mc_client_set_metadata_update_cb() function to create metadata
  /// @see mc_client_set_metadata_update_cb()
  int mc_client_destroy_metadata(
    mc_metadata_h metadata,
  ) {
    return _mc_client_destroy_metadata(
      metadata,
    );
  }

  late final _mc_client_destroy_metadataPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_metadata_h)>>(
          'mc_client_destroy_metadata');
  late final _mc_client_destroy_metadata =
      _mc_client_destroy_metadataPtr.asFunction<int Function(mc_metadata_h)>();

  /// @brief Gets the latest media controller server info.
  /// @details The media controller client will get the most recently updated information by the server.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @remarks If there is no activated media controller server, return value of the server name is NULL.
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [out] server_name    The app_id of the latest media controller server
  /// @param [out] server_state      The state of the latest media controller server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  int mc_client_get_latest_server_info(
    mc_client_h client,
    ffi.Pointer<ffi.Pointer<ffi.Char>> server_name,
    ffi.Pointer<ffi.Int32> server_state,
  ) {
    return _mc_client_get_latest_server_info(
      client,
      server_name,
      server_state,
    );
  }

  late final _mc_client_get_latest_server_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int32>)>>('mc_client_get_latest_server_info');
  late final _mc_client_get_latest_server_info =
      _mc_client_get_latest_server_infoPtr.asFunction<
          int Function(mc_client_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the latest playback info.
  /// @details The media controller client will get the most recently updated information from @a server_name.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @remarks You must release @a playback using @c mc_client_destroy_playback(). \n
  /// If there is no playback info, return value of the playback is NULL.
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] server_name    The app_id of the server to requesting
  /// @param [out] playback    The handle to playback
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  int mc_client_get_server_playback_info(
    mc_client_h client,
    ffi.Pointer<ffi.Char> server_name,
    ffi.Pointer<mc_playback_h> playback,
  ) {
    return _mc_client_get_server_playback_info(
      client,
      server_name,
      playback,
    );
  }

  late final _mc_client_get_server_playback_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mc_client_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<mc_playback_h>)>>(
      'mc_client_get_server_playback_info');
  late final _mc_client_get_server_playback_info =
      _mc_client_get_server_playback_infoPtr.asFunction<
          int Function(mc_client_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<mc_playback_h>)>();

  /// @brief Gets the latest metadata.
  /// @details The media controller client will get the most recently updated information from @a server_name.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @remarks You must release @a metadata using @c mc_client_destroy_metadata(). \n
  /// If there is no metadata, return value of the metadata is NULL.
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] server_name    The app_id of the server to requesting
  /// @param [out] metadata    The handle to metadata
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  int mc_client_get_server_metadata(
    mc_client_h client,
    ffi.Pointer<ffi.Char> server_name,
    ffi.Pointer<mc_metadata_h> metadata,
  ) {
    return _mc_client_get_server_metadata(
      client,
      server_name,
      metadata,
    );
  }

  late final _mc_client_get_server_metadataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<mc_metadata_h>)>>('mc_client_get_server_metadata');
  late final _mc_client_get_server_metadata =
      _mc_client_get_server_metadataPtr.asFunction<
          int Function(mc_client_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<mc_metadata_h>)>();

  /// @brief Gets the latest shuffle mode.
  /// @details The media controller client will get the most recently updated information from @a server_name.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @remarks If there is no shuffle mode info, return value is #MC_SHUFFLE_MODE_OFF.
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] server_name    The app_id of the server to requesting
  /// @param [out] mode    The info of the latest shuffle mode
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  int mc_client_get_server_shuffle_mode(
    mc_client_h client,
    ffi.Pointer<ffi.Char> server_name,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _mc_client_get_server_shuffle_mode(
      client,
      server_name,
      mode,
    );
  }

  late final _mc_client_get_server_shuffle_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>>('mc_client_get_server_shuffle_mode');
  late final _mc_client_get_server_shuffle_mode =
      _mc_client_get_server_shuffle_modePtr.asFunction<
          int Function(
              mc_client_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the latest repeat mode.
  /// @details The media controller client will get the most recently updated information from @a server_name.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @remarks If there is no repeat mode info, return value is #MC_REPEAT_MODE_OFF.
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] server_name    The app_id of the server to requesting
  /// @param [out] mode    The info of the latest shuffle mode
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  int mc_client_get_server_repeat_mode(
    mc_client_h client,
    ffi.Pointer<ffi.Char> server_name,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _mc_client_get_server_repeat_mode(
      client,
      server_name,
      mode,
    );
  }

  late final _mc_client_get_server_repeat_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>>('mc_client_get_server_repeat_mode');
  late final _mc_client_get_server_repeat_mode =
      _mc_client_get_server_repeat_modePtr.asFunction<
          int Function(
              mc_client_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all activated Server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] callback      The callback to be invoked when the list of the registered media controller server created completely.
  /// @param [in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  int mc_client_foreach_server(
    mc_client_h client,
    mc_activated_server_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mc_client_foreach_server(
      client,
      callback,
      user_data,
    );
  }

  late final _mc_client_foreach_serverPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, mc_activated_server_cb,
              ffi.Pointer<ffi.Void>)>>('mc_client_foreach_server');
  late final _mc_client_foreach_server =
      _mc_client_foreach_serverPtr.asFunction<
          int Function(
              mc_client_h, mc_activated_server_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sends the playback state command to server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] server_name    The app_id of the media controller server
  /// @param [in] state   The playback state command to send media controller server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  /// @see mc_client_get_server_playback_info()
  int mc_client_send_playback_state_command(
    mc_client_h client,
    ffi.Pointer<ffi.Char> server_name,
    int state,
  ) {
    return _mc_client_send_playback_state_command(
      client,
      server_name,
      state,
    );
  }

  late final _mc_client_send_playback_state_commandPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mc_client_h, ffi.Pointer<ffi.Char>,
              ffi.Int32)>>('mc_client_send_playback_state_command');
  late final _mc_client_send_playback_state_command =
      _mc_client_send_playback_state_commandPtr
          .asFunction<int Function(mc_client_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Sends the custom command to server.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details If there is the result for comand from server, the media controller client will get the result of the custom command by mc_command_reply_received_cb() callback.
  ///
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/mediacontroller.client
  ///
  /// @param [in] client    The handle to the media controller client
  /// @param [in] server_name    The app_id of the media controller server
  /// @param [in] command      The command to be sent
  /// @param [in] data      The extra data
  /// @param [in] callback      The callback to be invoked when the custom command execute completely.
  /// @param [in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_CONTROLLER_ERROR_NONE Successful
  /// @retval #MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  int mc_client_send_custom_command(
    mc_client_h client,
    ffi.Pointer<ffi.Char> server_name,
    ffi.Pointer<ffi.Char> command,
    ffi.Pointer<bundle> data,
    mc_command_reply_received_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mc_client_send_custom_command(
      client,
      server_name,
      command,
      data,
      callback,
      user_data,
    );
  }

  late final _mc_client_send_custom_commandPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mc_client_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>,
              mc_command_reply_received_cb,
              ffi.Pointer<ffi.Void>)>>('mc_client_send_custom_command');
  late final _mc_client_send_custom_command =
      _mc_client_send_custom_commandPtr.asFunction<
          int Function(
              mc_client_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<bundle>,
              mc_command_reply_received_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Destroys client.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param [in] client The handle to the media controller client
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Create a media controller client handle by calling mc_client_create().
  /// @see mc_client_create()
  int mc_client_destroy(
    mc_client_h client,
  ) {
    return _mc_client_destroy(
      client,
    );
  }

  late final _mc_client_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mc_client_h)>>(
          'mc_client_destroy');
  late final _mc_client_destroy =
      _mc_client_destroyPtr.asFunction<int Function(mc_client_h)>();

  /// @brief Creates a media demuxer handle for demuxing.
  /// @since_tizen 3.0
  /// @remarks You must release @a demuxer using mediademuxer_destroy() function.
  /// @param[out] demuxer    A new handle to media demuxer
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @retval #MEDIADEMUXER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post The media demuxer state will be #MEDIADEMUXER_STATE_IDLE.
  /// @see mediademuxer_destroy()
  int mediademuxer_create(
    ffi.Pointer<mediademuxer_h> demuxer,
  ) {
    return _mediademuxer_create(
      demuxer,
    );
  }

  late final _mediademuxer_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<mediademuxer_h>)>>(
      'mediademuxer_create');
  late final _mediademuxer_create = _mediademuxer_createPtr
      .asFunction<int Function(ffi.Pointer<mediademuxer_h>)>();

  /// @brief Sets the source path of input stream.
  /// @since_tizen 3.0
  /// @remarks The mediastorage privilege(http://tizen.org/privilege/mediastorage) should be added if any video/audio files are used to play located in the internal storage.
  /// @remarks The externalstorage privilege(http://tizen.org/privilege/externalstorage) should be added if any video/audio files are used to play located in the external storage.
  /// @remarks You must release @a demuxer using mediademuxer_destroy() function.
  /// @param[in] demuxer    The media demuxer handle
  /// @param[in] path    The content location, such as the file path
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PATH Invalid path
  /// @pre The media muxer state will be #MEDIADEMUXER_STATE_IDLE by calling mediademuxer_create() function.
  int mediademuxer_set_data_source(
    mediademuxer_h demuxer,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _mediademuxer_set_data_source(
      demuxer,
      path,
    );
  }

  late final _mediademuxer_set_data_sourcePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediademuxer_h,
              ffi.Pointer<ffi.Char>)>>('mediademuxer_set_data_source');
  late final _mediademuxer_set_data_source = _mediademuxer_set_data_sourcePtr
      .asFunction<int Function(mediademuxer_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Prepares the media demuxer for demuxing.
  /// @since_tizen 3.0
  /// @remark User should call this before mediademuxer_start() function.
  /// @param[in] demuxer    The media demuxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre The media demuxer state should be #MEDIADEMUXER_STATE_IDLE.
  /// @pre mediademuxer_set_error_cb should be called before mediademuxer_prepare().
  /// @post The media demuxer state will be #MEDIADEMUXER_STATE_READY.
  /// @see mediademuxer_set_data_source()
  /// @see mediademuxer_unprepare()
  int mediademuxer_prepare(
    mediademuxer_h demuxer,
  ) {
    return _mediademuxer_prepare(
      demuxer,
    );
  }

  late final _mediademuxer_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediademuxer_h)>>(
          'mediademuxer_prepare');
  late final _mediademuxer_prepare =
      _mediademuxer_preparePtr.asFunction<int Function(mediademuxer_h)>();

  /// @brief Gets the total track count present in the container stream.
  /// @since_tizen 3.0
  /// @param[in] demuxer    The media demuxer handle
  /// @param[out] count     The number of tracks present
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre The media demuxer state should be #MEDIADEMUXER_STATE_READY.
  /// @see mediademuxer_prepare()
  /// @see mediademuxer_select_track()
  int mediademuxer_get_track_count(
    mediademuxer_h demuxer,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _mediademuxer_get_track_count(
      demuxer,
      count,
    );
  }

  late final _mediademuxer_get_track_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediademuxer_h,
              ffi.Pointer<ffi.Int>)>>('mediademuxer_get_track_count');
  late final _mediademuxer_get_track_count = _mediademuxer_get_track_countPtr
      .asFunction<int Function(mediademuxer_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Selects the track to be performed.
  /// @since_tizen 3.0
  /// @param[in] demuxer    The media demuxer handle
  /// @param[in] track_index      The track index on which is selected for read
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre The media demuxer state should be #MEDIADEMUXER_STATE_READY.
  /// @see mediademuxer_get_track_count()
  /// @see mediademuxer_start()
  int mediademuxer_select_track(
    mediademuxer_h demuxer,
    int track_index,
  ) {
    return _mediademuxer_select_track(
      demuxer,
      track_index,
    );
  }

  late final _mediademuxer_select_trackPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediademuxer_h, ffi.Int)>>(
          'mediademuxer_select_track');
  late final _mediademuxer_select_track = _mediademuxer_select_trackPtr
      .asFunction<int Function(mediademuxer_h, int)>();

  /// @brief Starts the media demuxer.
  /// @since_tizen 3.0
  /// @remark User should call this before mediademuxer_read_sample() function.
  /// @param[in] demuxer    The media demuxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre The media demuxer state should be #MEDIADEMUXER_STATE_READY.
  /// @post The media demuxer state will be #MEDIADEMUXER_STATE_DEMUXING.
  /// @see mediademuxer_prepare()
  /// @see mediademuxer_get_track_count()
  /// @see mediademuxer_select_track()
  /// @see mediademuxer_get_track_info()
  int mediademuxer_start(
    mediademuxer_h demuxer,
  ) {
    return _mediademuxer_start(
      demuxer,
    );
  }

  late final _mediademuxer_startPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediademuxer_h)>>(
          'mediademuxer_start');
  late final _mediademuxer_start =
      _mediademuxer_startPtr.asFunction<int Function(mediademuxer_h)>();

  /// @brief Retrieves the track format of the read sample.
  /// @since_tizen 3.0
  /// @remarks The @a format should be released using media_format_unref() function.
  /// @param[in] demuxer    The media demuxer handle
  /// @param[in] track_index     The index of the track
  /// @param[out] format    The media format handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre The media demuxer state must be set to #MEDIADEMUXER_STATE_DEMUXING by calling
  /// mediademuxer_start() or set to #MEDIADEMUXER_STATE_READY by calling mediademuxer_prepare().
  /// @see mediademuxer_get_track_count()
  /// @see mediademuxer_select_track()
  /// @see media_format_unref()
  /// @see #media_format_h
  int mediademuxer_get_track_info(
    mediademuxer_h demuxer,
    int track_index,
    ffi.Pointer<media_format_h> format,
  ) {
    return _mediademuxer_get_track_info(
      demuxer,
      track_index,
      format,
    );
  }

  late final _mediademuxer_get_track_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediademuxer_h, ffi.Int,
              ffi.Pointer<media_format_h>)>>('mediademuxer_get_track_info');
  late final _mediademuxer_get_track_info =
      _mediademuxer_get_track_infoPtr.asFunction<
          int Function(mediademuxer_h, int, ffi.Pointer<media_format_h>)>();

  /// @brief Reads a frame(sample) of one single track.
  /// @since_tizen 3.0
  /// @remark The @a outbuf should be released using media_packet_destroy() function.
  /// @remark Once this API is called, user app can call the mediatool APIs to extract
  /// side information such as pts, size, duration, flags etc.
  /// @param[in] demuxer    The media demuxer handle
  /// @param[in] track_index      The index of track of which data is needed
  /// @param[out] outbuf      The media packet handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre The media demuxer state should be #MEDIADEMUXER_STATE_DEMUXING.
  /// @see mediademuxer_start()
  /// @see mediademuxer_get_track_info()
  /// @see mediademuxer_seek() if need to seek to a particular location
  /// @see mediademuxer_unselect_track()
  /// @see mediademuxer_stop()
  /// @see media_packet_destroy()
  /// @see #media_packet_h
  int mediademuxer_read_sample(
    mediademuxer_h demuxer,
    int track_index,
    ffi.Pointer<media_packet_h> outbuf,
  ) {
    return _mediademuxer_read_sample(
      demuxer,
      track_index,
      outbuf,
    );
  }

  late final _mediademuxer_read_samplePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediademuxer_h, ffi.Int,
              ffi.Pointer<media_packet_h>)>>('mediademuxer_read_sample');
  late final _mediademuxer_read_sample =
      _mediademuxer_read_samplePtr.asFunction<
          int Function(mediademuxer_h, int, ffi.Pointer<media_packet_h>)>();

  /// @brief Seeks to a particular instance of time (in milli seconds).
  /// @since_tizen 3.0
  /// @remark If mediademuxer_seek() is followed by mediademuxer_read_sample(), outbuf will be the key frame right before the seek position.
  /// @param[in] demuxer    The media demuxer handle
  /// @param[in] pos       The value of the new start position
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre The media demuxer state should be #MEDIADEMUXER_STATE_DEMUXING.
  /// @see mediademuxer_read_sample()
  /// @see mediademuxer_stop()
  int mediademuxer_seek(
    mediademuxer_h demuxer,
    int pos,
  ) {
    return _mediademuxer_seek(
      demuxer,
      pos,
    );
  }

  late final _mediademuxer_seekPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediademuxer_h, ffi.Int64)>>(
          'mediademuxer_seek');
  late final _mediademuxer_seek =
      _mediademuxer_seekPtr.asFunction<int Function(mediademuxer_h, int)>();

  /// @brief Unselects the selected track.
  /// @since_tizen 3.0
  /// @param[in] demuxer    The media demuxer handle
  /// @param[in] track_index      The track index to be unselected
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre The media demuxer state must be set to #MEDIADEMUXER_STATE_DEMUXING by calling
  /// mediademuxer_read_sample() or set to #MEDIADEMUXER_STATE_READY by calling mediademuxer_select_track().
  /// @see mediademuxer_select_track()
  /// @see mediademuxer_read_sample()
  int mediademuxer_unselect_track(
    mediademuxer_h demuxer,
    int track_index,
  ) {
    return _mediademuxer_unselect_track(
      demuxer,
      track_index,
    );
  }

  late final _mediademuxer_unselect_trackPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediademuxer_h, ffi.Int)>>(
          'mediademuxer_unselect_track');
  late final _mediademuxer_unselect_track = _mediademuxer_unselect_trackPtr
      .asFunction<int Function(mediademuxer_h, int)>();

  /// @brief Stops the media demuxer.
  /// @since_tizen 3.0
  /// @remark User can call this if need to stop demuxing if needed.
  /// @param[in] demuxer    The media demuxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre The media demuxer state must be set to #MEDIADEMUXER_STATE_DEMUXING.
  /// @post The media demuxer state will be in  #MEDIADEMUXER_STATE_READY.
  /// @see mediademuxer_start()
  /// @see mediademuxer_unprepare()
  int mediademuxer_stop(
    mediademuxer_h demuxer,
  ) {
    return _mediademuxer_stop(
      demuxer,
    );
  }

  late final _mediademuxer_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediademuxer_h)>>(
          'mediademuxer_stop');
  late final _mediademuxer_stop =
      _mediademuxer_stopPtr.asFunction<int Function(mediademuxer_h)>();

  /// @brief Resets the media demuxer.
  /// @since_tizen 3.0
  /// @remarks User should call this before mediademuxer_destroy() function.
  /// @param[in] demuxer    The media demuxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre The media demuxer state should be #MEDIADEMUXER_STATE_READY.
  /// @post The media demuxer state will be #MEDIADEMUXER_STATE_IDLE.
  /// @see mediademuxer_prepare()
  int mediademuxer_unprepare(
    mediademuxer_h demuxer,
  ) {
    return _mediademuxer_unprepare(
      demuxer,
    );
  }

  late final _mediademuxer_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediademuxer_h)>>(
          'mediademuxer_unprepare');
  late final _mediademuxer_unprepare =
      _mediademuxer_unpreparePtr.asFunction<int Function(mediademuxer_h)>();

  /// @brief Removes the instance of media demuxer and clear all its context memory.
  /// @since_tizen 3.0
  /// @param[in] demuxer    The media demuxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre Create a media demuxer handle by calling mediademuxer_create() function.
  /// @post The media demuxer state will be #MEDIADEMUXER_STATE_NONE.
  /// @see mediademuxer_create()
  int mediademuxer_destroy(
    mediademuxer_h demuxer,
  ) {
    return _mediademuxer_destroy(
      demuxer,
    );
  }

  late final _mediademuxer_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediademuxer_h)>>(
          'mediademuxer_destroy');
  late final _mediademuxer_destroy =
      _mediademuxer_destroyPtr.asFunction<int Function(mediademuxer_h)>();

  /// @brief Gets media demuxer state.
  /// @since_tizen 3.0
  /// @param[in] demuxer   The media demuxer handle
  /// @param[out] state   The media demuxer sate
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a media demuxer handle by calling mediademuxer_create() function.
  /// @see #mediademuxer_state
  int mediademuxer_get_state(
    mediademuxer_h demuxer,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _mediademuxer_get_state(
      demuxer,
      state,
    );
  }

  late final _mediademuxer_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediademuxer_h,
              ffi.Pointer<ffi.Int32>)>>('mediademuxer_get_state');
  late final _mediademuxer_get_state = _mediademuxer_get_statePtr
      .asFunction<int Function(mediademuxer_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Registers an error callback function to be invoked when an error occurs.
  /// @since_tizen 3.0
  /// @param[in] demuxer   The media demuxer handle
  /// @param[in] callback  Callback function pointer
  /// @param[in] user_data   The user data passed from the code where
  /// mediademuxer_set_error_cb() was invoked
  /// This data will be accessible from mediademuxer_error_cb()
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre Create a media demuxer handle by calling mediademuxer_create() function.
  /// @post mediademuxer_error_cb() will be invoked.
  /// @see mediademuxer_unset_error_cb()
  /// @see mediademuxer_error_cb()
  int mediademuxer_set_error_cb(
    mediademuxer_h demuxer,
    mediademuxer_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mediademuxer_set_error_cb(
      demuxer,
      callback,
      user_data,
    );
  }

  late final _mediademuxer_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediademuxer_h, mediademuxer_error_cb,
              ffi.Pointer<ffi.Void>)>>('mediademuxer_set_error_cb');
  late final _mediademuxer_set_error_cb =
      _mediademuxer_set_error_cbPtr.asFunction<
          int Function(
              mediademuxer_h, mediademuxer_error_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the error callback function.
  /// @since_tizen 3.0
  /// @param[in] demuxer   The media demuxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @see mediademuxer_error_cb()
  int mediademuxer_unset_error_cb(
    mediademuxer_h demuxer,
  ) {
    return _mediademuxer_unset_error_cb(
      demuxer,
    );
  }

  late final _mediademuxer_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediademuxer_h)>>(
          'mediademuxer_unset_error_cb');
  late final _mediademuxer_unset_error_cb = _mediademuxer_unset_error_cbPtr
      .asFunction<int Function(mediademuxer_h)>();

  /// @brief Registers an eos callback function to be invoked when an eos occurs.
  /// @since_tizen 3.0
  /// @param[in] demuxer   The media demuxer handle
  /// @param[in] callback  Callback function pointer
  /// @param[in] user_data   The user data passed from the code where
  /// mediademuxer_set_eos_cb() was invoked
  /// This data will be accessible from mediademuxer_eos_cb()
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre Create a media demuxer handle by calling mediademuxer_create() function.
  /// @post mediademuxer_eos_cb() will be invoked.
  /// @see mediademuxer_unset_eos_cb()
  /// @see mediademuxer_eos_cb()
  int mediademuxer_set_eos_cb(
    mediademuxer_h demuxer,
    mediademuxer_eos_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mediademuxer_set_eos_cb(
      demuxer,
      callback,
      user_data,
    );
  }

  late final _mediademuxer_set_eos_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediademuxer_h, mediademuxer_eos_cb,
              ffi.Pointer<ffi.Void>)>>('mediademuxer_set_eos_cb');
  late final _mediademuxer_set_eos_cb = _mediademuxer_set_eos_cbPtr.asFunction<
      int Function(
          mediademuxer_h, mediademuxer_eos_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the eos callback function.
  /// @since_tizen 3.0
  /// @param[in] demuxer   The media demuxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIADEMUXER_ERROR_NONE Successful
  /// @retval #MEDIADEMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIADEMUXER_ERROR_INVALID_STATE Invalid state
  /// @see mediademuxer_eos_cb()
  int mediademuxer_unset_eos_cb(
    mediademuxer_h demuxer,
  ) {
    return _mediademuxer_unset_eos_cb(
      demuxer,
    );
  }

  late final _mediademuxer_unset_eos_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediademuxer_h)>>(
          'mediademuxer_unset_eos_cb');
  late final _mediademuxer_unset_eos_cb =
      _mediademuxer_unset_eos_cbPtr.asFunction<int Function(mediademuxer_h)>();

  /// @brief Creates a media muxer handle for muxing.
  /// @since_tizen 3.0
  /// @param[out] muxer  A new handle to media muxer
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid Operation
  /// @retval #MEDIAMUXER_ERROR_OUT_OF_MEMORY Allocation Failed, Out of Memory.
  /// @post The media muxer state will be #MEDIAMUXER_STATE_IDLE.
  /// @see mediamuxer_destroy()
  int mediamuxer_create(
    ffi.Pointer<mediamuxer_h> muxer,
  ) {
    return _mediamuxer_create(
      muxer,
    );
  }

  late final _mediamuxer_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<mediamuxer_h>)>>(
          'mediamuxer_create');
  late final _mediamuxer_create = _mediamuxer_createPtr
      .asFunction<int Function(ffi.Pointer<mediamuxer_h>)>();

  /// @brief Sets the sink path of output stream.
  /// @since_tizen 3.0
  /// @remarks The mediastorage privilege(http://tizen.org/privilege/mediastorage) should be added if any video/audio files are to be saved in the internal storage.
  /// @remarks The externalstorage privilege(http://tizen.org/privilege/externalstorage) should be added if any video/audio files are to be saved in the external storage.
  /// @param[in] muxer  A new handle to media muxer
  /// @param[in] path  The location of the output media file, such as the file path
  /// This is the path at which the muxed file should be saved.
  /// @param[in] format  The format of the output media file
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIAMUXER_ERROR_INVALID_PATH Invalid path
  /// @pre The media muxer state will be #MEDIAMUXER_STATE_IDLE by calling mediamuxer_create
  /// @see #mediamuxer_output_format_e
  int mediamuxer_set_data_sink(
    mediamuxer_h muxer,
    ffi.Pointer<ffi.Char> path,
    int format,
  ) {
    return _mediamuxer_set_data_sink(
      muxer,
      path,
      format,
    );
  }

  late final _mediamuxer_set_data_sinkPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediamuxer_h, ffi.Pointer<ffi.Char>,
              ffi.Int32)>>('mediamuxer_set_data_sink');
  late final _mediamuxer_set_data_sink = _mediamuxer_set_data_sinkPtr
      .asFunction<int Function(mediamuxer_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Adds the media track of interest to the muxer handle.
  /// @since_tizen 3.0
  /// @param[in] muxer     The media muxer handle
  /// @param[in] media_format  The format of media muxer
  /// @param[out] track_index  The index of the media track
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre The media muxer state must be set to #MEDIAMUXER_STATE_IDLE.
  /// @see #media_format_h
  /// @see mediamuxer_create()
  /// @see mediamuxer_prepare()
  int mediamuxer_add_track(
    mediamuxer_h muxer,
    media_format_h media_format,
    ffi.Pointer<ffi.Int> track_index,
  ) {
    return _mediamuxer_add_track(
      muxer,
      media_format,
      track_index,
    );
  }

  late final _mediamuxer_add_trackPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediamuxer_h, media_format_h,
              ffi.Pointer<ffi.Int>)>>('mediamuxer_add_track');
  late final _mediamuxer_add_track = _mediamuxer_add_trackPtr.asFunction<
      int Function(mediamuxer_h, media_format_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Prepares the media muxer.
  /// @remarks Initiates the necessary parameters.
  /// @since_tizen 3.0
  /// @param[in] muxer     The media muxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre The media muxer state must be set to #MEDIAMUXER_STATE_IDLE.
  /// @post The media muxer state will be #MEDIAMUXER_STATE_READY.
  /// @see mediamuxer_create()
  /// @see mediamuxer_unprepare()
  int mediamuxer_prepare(
    mediamuxer_h muxer,
  ) {
    return _mediamuxer_prepare(
      muxer,
    );
  }

  late final _mediamuxer_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediamuxer_h)>>(
          'mediamuxer_prepare');
  late final _mediamuxer_prepare =
      _mediamuxer_preparePtr.asFunction<int Function(mediamuxer_h)>();

  /// @brief Starts the media muxer.
  /// @remarks Keeps the muxer ready for writing data.
  /// @since_tizen 3.0
  /// @param[in] muxer     The media muxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre The media muxer state must be set to #MEDIAMUXER_STATE_READY.
  /// @post The media muxer state will be #MEDIAMUXER_STATE_MUXING.
  /// @see mediamuxer_prepare()
  /// @see mediamuxer_stop()
  int mediamuxer_start(
    mediamuxer_h muxer,
  ) {
    return _mediamuxer_start(
      muxer,
    );
  }

  late final _mediamuxer_startPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediamuxer_h)>>(
          'mediamuxer_start');
  late final _mediamuxer_start =
      _mediamuxer_startPtr.asFunction<int Function(mediamuxer_h)>();

  /// @brief Writes the media packet of interest to the muxer handle.
  /// @since_tizen 3.0
  /// @param[in] muxer     The media muxer handle
  /// @param[in] track_index  The index of the media track
  /// @param[in] inbuf  The packet of media muxer
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre The media muxer state must be set to #MEDIAMUXER_STATE_READY by calling mediamuxer_prepare() or
  /// set to #MEDIAMUXER_STATE_PAUSED by calling mediamuxer_pause().
  /// @post The media muxer state will be #MEDIAMUXER_STATE_MUXING.
  /// @see mediamuxer_prepare()
  /// @see mediamuxer_close_track()
  /// @see mediamuxer_pause()
  /// @see #media_packet_h
  int mediamuxer_write_sample(
    mediamuxer_h muxer,
    int track_index,
    media_packet_h inbuf,
  ) {
    return _mediamuxer_write_sample(
      muxer,
      track_index,
      inbuf,
    );
  }

  late final _mediamuxer_write_samplePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediamuxer_h, ffi.Int,
              media_packet_h)>>('mediamuxer_write_sample');
  late final _mediamuxer_write_sample = _mediamuxer_write_samplePtr
      .asFunction<int Function(mediamuxer_h, int, media_packet_h)>();

  /// @brief Closes the track from further writing of data.
  /// @remarks For each added track, user needs to call this API to indicate the end of stream.
  /// @since_tizen 3.0
  /// @param[in] muxer     The media muxer handle
  /// @param[in] track_index the selected track index
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The media muxer state must be set to #MEDIAMUXER_STATE_MUXING.
  /// @see mediamuxer_write_sample()
  /// @see mediamuxer_pause()
  /// @see mediamuxer_unprepare()
  /// @see #mediamuxer_error_e
  int mediamuxer_close_track(
    mediamuxer_h muxer,
    int track_index,
  ) {
    return _mediamuxer_close_track(
      muxer,
      track_index,
    );
  }

  late final _mediamuxer_close_trackPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediamuxer_h, ffi.Int)>>(
          'mediamuxer_close_track');
  late final _mediamuxer_close_track =
      _mediamuxer_close_trackPtr.asFunction<int Function(mediamuxer_h, int)>();

  /// @brief Pauses the media muxer.
  /// @remarks To temporarily disable writing data for muxing. This API pauses a playing muxer
  /// If the prior state of the muxer is not in PLAYING, no action will be taken.
  /// @since_tizen 3.0
  /// @param[in] muxer     The media muxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre The media muxer state must be set to #MEDIAMUXER_STATE_MUXING.
  /// @post The media muxer state will be #MEDIAMUXER_STATE_PAUSED.
  /// @see mediamuxer_write_sample()
  /// @see mediamuxer_resume()
  int mediamuxer_pause(
    mediamuxer_h muxer,
  ) {
    return _mediamuxer_pause(
      muxer,
    );
  }

  late final _mediamuxer_pausePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediamuxer_h)>>(
          'mediamuxer_pause');
  late final _mediamuxer_pause =
      _mediamuxer_pausePtr.asFunction<int Function(mediamuxer_h)>();

  /// @brief Resumes the media muxer.
  /// @remarks Make it ready for any further writing. This API will resume a paused muxer.
  /// If the prior state of the muxer is not playing, no action will be taken.
  /// @since_tizen 3.0
  /// @param[in] muxer     The media muxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre The media muxer state must be set to #MEDIAMUXER_STATE_PAUSED.
  /// @post The media muxer state will be #MEDIAMUXER_STATE_MUXING.
  /// @see mediamuxer_pause()
  int mediamuxer_resume(
    mediamuxer_h muxer,
  ) {
    return _mediamuxer_resume(
      muxer,
    );
  }

  late final _mediamuxer_resumePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediamuxer_h)>>(
          'mediamuxer_resume');
  late final _mediamuxer_resume =
      _mediamuxer_resumePtr.asFunction<int Function(mediamuxer_h)>();

  /// @brief Stops the media muxer.
  /// @remarks Keeps the muxer ready for writing data.
  /// @since_tizen 3.0
  /// @param[in] muxer     The media muxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre The media muxer state must be set to #MEDIAMUXER_STATE_MUXING
  /// or #MEDIAMUXER_STATE_PAUSED.
  /// @post The media muxer state will be #MEDIAMUXER_STATE_READY.
  /// @see mediamuxer_start()
  /// @see mediamuxer_unprepare()
  int mediamuxer_stop(
    mediamuxer_h muxer,
  ) {
    return _mediamuxer_stop(
      muxer,
    );
  }

  late final _mediamuxer_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediamuxer_h)>>(
          'mediamuxer_stop');
  late final _mediamuxer_stop =
      _mediamuxer_stopPtr.asFunction<int Function(mediamuxer_h)>();

  /// @brief Unprepares the media muxer.
  /// @remarks Unrefs the variables created after calling mediamuxer_prepare().
  /// @since_tizen 3.0
  /// @param[in] muxer     The media muxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre The media muxer state must be set to #MEDIAMUXER_STATE_READY or
  /// set to #MEDIAMUXER_STATE_PAUSED by calling mediamuxer_pause().
  /// @post The media muxer state will be #MEDIAMUXER_STATE_IDLE.
  /// @see mediamuxer_write_sample()
  /// @see mediamuxer_pause()
  /// @see mediamuxer_destroy()
  int mediamuxer_unprepare(
    mediamuxer_h muxer,
  ) {
    return _mediamuxer_unprepare(
      muxer,
    );
  }

  late final _mediamuxer_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediamuxer_h)>>(
          'mediamuxer_unprepare');
  late final _mediamuxer_unprepare =
      _mediamuxer_unpreparePtr.asFunction<int Function(mediamuxer_h)>();

  /// @brief Removes the instance of media muxer and clear all its context memory.
  /// @since_tizen 3.0
  /// @param[in] muxer     The media muxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre Create a media muxer handle by calling mediamuxer_create() function.
  /// @post The media muxer state will be #MEDIAMUXER_STATE_NONE.
  /// @see mediamuxer_create()
  int mediamuxer_destroy(
    mediamuxer_h muxer,
  ) {
    return _mediamuxer_destroy(
      muxer,
    );
  }

  late final _mediamuxer_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediamuxer_h)>>(
          'mediamuxer_destroy');
  late final _mediamuxer_destroy =
      _mediamuxer_destroyPtr.asFunction<int Function(mediamuxer_h)>();

  /// @brief Gets media muxer state.
  /// @since_tizen 3.0
  /// @param[in] muxer   The media muxer handle
  /// @param[out] state   The media muxer sate
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a media muxer handle by calling mediamuxer_create() function.
  /// @see #mediamuxer_state_e
  int mediamuxer_get_state(
    mediamuxer_h muxer,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _mediamuxer_get_state(
      muxer,
      state,
    );
  }

  late final _mediamuxer_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mediamuxer_h, ffi.Pointer<ffi.Int32>)>>('mediamuxer_get_state');
  late final _mediamuxer_get_state = _mediamuxer_get_statePtr
      .asFunction<int Function(mediamuxer_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Registers a error callback function to be invoked when an error occurs.
  /// @since_tizen 3.0
  /// @param[in] muxer   The media muxer handle
  /// @param[in] callback  Callback function pointer
  /// @param[in] user_data   The user data passed from the code where
  /// mediamuxer_set_error_cb() was invoked
  /// This data will be accessible from @a mediamuxer_error_cb
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre Create a media muxer handle by calling mediamuxer_create() function.
  /// @post mediamuxer_error_cb() will be invoked.
  /// @see mediamuxer_unset_error_cb()
  /// @see mediamuxer_error_cb()
  int mediamuxer_set_error_cb(
    mediamuxer_h muxer,
    mediamuxer_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mediamuxer_set_error_cb(
      muxer,
      callback,
      user_data,
    );
  }

  late final _mediamuxer_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediamuxer_h, mediamuxer_error_cb,
              ffi.Pointer<ffi.Void>)>>('mediamuxer_set_error_cb');
  late final _mediamuxer_set_error_cb = _mediamuxer_set_error_cbPtr.asFunction<
      int Function(mediamuxer_h, mediamuxer_error_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the error callback function.
  /// @since_tizen 3.0
  /// @param[in] muxer   The media muxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see mediamuxer_error_cb()
  int mediamuxer_unset_error_cb(
    mediamuxer_h muxer,
  ) {
    return _mediamuxer_unset_error_cb(
      muxer,
    );
  }

  late final _mediamuxer_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediamuxer_h)>>(
          'mediamuxer_unset_error_cb');
  late final _mediamuxer_unset_error_cb =
      _mediamuxer_unset_error_cbPtr.asFunction<int Function(mediamuxer_h)>();

  /// @brief Registers an EOS (end of stream) callback function to be invoked when an EOS occurs.
  /// @since_tizen 4.0
  /// @param[in] muxer       The media muxer handle
  /// @param[in] callback    Callback function pointer
  /// @param[in] user_data   The user data passed from the code where
  /// mediamuxer_set_eos_cb() was invoked;\n
  /// this data will be accessible from mediamuxer_eos_cb()
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @pre Create a media muxer handle by calling mediamuxer_create() function.
  /// @post mediamuxer_eos_cb() will be invoked.
  /// @see mediamuxer_unset_eos_cb()
  /// @see mediamuxer_eos_cb()
  int mediamuxer_set_eos_cb(
    mediamuxer_h muxer,
    mediamuxer_eos_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mediamuxer_set_eos_cb(
      muxer,
      callback,
      user_data,
    );
  }

  late final _mediamuxer_set_eos_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mediamuxer_h, mediamuxer_eos_cb,
              ffi.Pointer<ffi.Void>)>>('mediamuxer_set_eos_cb');
  late final _mediamuxer_set_eos_cb = _mediamuxer_set_eos_cbPtr.asFunction<
      int Function(mediamuxer_h, mediamuxer_eos_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the EOS (end of stream) callback function.
  /// @since_tizen 4.0
  /// @param[in] muxer   The media muxer handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIAMUXER_ERROR_NONE Successful
  /// @retval #MEDIAMUXER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIAMUXER_ERROR_INVALID_STATE Invalid state
  /// @see mediamuxer_eos_cb()
  int mediamuxer_unset_eos_cb(
    mediamuxer_h muxer,
  ) {
    return _mediamuxer_unset_eos_cb(
      muxer,
    );
  }

  late final _mediamuxer_unset_eos_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mediamuxer_h)>>(
          'mediamuxer_unset_eos_cb');
  late final _mediamuxer_unset_eos_cb =
      _mediamuxer_unset_eos_cbPtr.asFunction<int Function(mediamuxer_h)>();

  /// @brief Registers a error callback function to be invoked when an error occurs.
  /// @details Following error codes can be delivered by error callback.
  /// #MEDIA_STREAMER_ERROR_INVALID_OPERATION,
  /// #MEDIA_STREAMER_ERROR_FILE_NO_SPACE_ON_DEVICE,
  /// #MEDIA_STREAMER_ERROR_NOT_SUPPORTED,
  /// #MEDIA_STREAMER_ERROR_CONNECTION_FAILED,
  /// #MEDIA_STREAMER_ERROR_RESOURCE_CONFLICT
  /// @since_tizen 3.0
  /// @param [in] streamer  Media streamer handle
  /// @param [in] callback  Callback function pointer
  /// @param [in] user_data The user data passed from the code where
  /// media_streamer_set_error_cb() was invoked
  /// This data will be accessible from @a media_streamer_error_cb
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a media streamer handle by calling media_streamer_create() function
  /// @post media_streamer_error_cb() will be invoked.
  /// @see media_streamer_unset_error_cb()
  /// @see media_streamer_error_cb()
  int media_streamer_set_error_cb(
    media_streamer_h streamer,
    media_streamer_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_streamer_set_error_cb(
      streamer,
      callback,
      user_data,
    );
  }

  late final _media_streamer_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_h, media_streamer_error_cb,
              ffi.Pointer<ffi.Void>)>>('media_streamer_set_error_cb');
  late final _media_streamer_set_error_cb =
      _media_streamer_set_error_cbPtr.asFunction<
          int Function(media_streamer_h, media_streamer_error_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the error callback function.
  /// @since_tizen 3.0
  /// @param [in] streamer  Media streamer handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_streamer_error_cb()
  int media_streamer_unset_error_cb(
    media_streamer_h streamer,
  ) {
    return _media_streamer_unset_error_cb(
      streamer,
    );
  }

  late final _media_streamer_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_h)>>(
          'media_streamer_unset_error_cb');
  late final _media_streamer_unset_error_cb = _media_streamer_unset_error_cbPtr
      .asFunction<int Function(media_streamer_h)>();

  /// @brief Registers a callback that will be triggered after media streamer state is changed.
  /// @since_tizen 3.0
  /// @param [in] streamer  Media streamer handle
  /// @param [in] callback  Callback function pointer
  /// @param [in] user_data The user data passed from the code
  /// where media_streamer_set_state_change_cb() was invoked
  /// This data will be accessible from @a media_streamer_state_changed_cb
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a media streamer handle by calling media_streamer_create() function
  /// @post media_streamer_state_changed_cb() will be invoked.
  /// @see media_streamer_unset_state_change_cb()
  /// @see media_streamer_state_change_cb()
  int media_streamer_set_state_change_cb(
    media_streamer_h streamer,
    media_streamer_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_streamer_set_state_change_cb(
      streamer,
      callback,
      user_data,
    );
  }

  late final _media_streamer_set_state_change_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_h, media_streamer_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('media_streamer_set_state_change_cb');
  late final _media_streamer_set_state_change_cb =
      _media_streamer_set_state_change_cbPtr.asFunction<
          int Function(media_streamer_h, media_streamer_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the state changed callback function.
  /// @since_tizen 3.0
  /// @param [in] streamer  Media streamer handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_streamer_set_state_change_cb()
  int media_streamer_unset_state_change_cb(
    media_streamer_h streamer,
  ) {
    return _media_streamer_unset_state_change_cb(
      streamer,
    );
  }

  late final _media_streamer_unset_state_change_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_h)>>(
          'media_streamer_unset_state_change_cb');
  late final _media_streamer_unset_state_change_cb =
      _media_streamer_unset_state_change_cbPtr
          .asFunction<int Function(media_streamer_h)>();

  /// @brief Registers a callback function to be invoked when the media streamer is interrupted.
  /// @since_tizen 3.0
  /// @param[in] streamer	Media streamer handle
  /// @param[in] callback	The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @post media_streamer_interrupted_cb() will be invoked.
  /// @see media_streamer_unset_interrupted_cb()
  /// @see #media_streamer_interrupted_code_e
  int media_streamer_set_interrupted_cb(
    media_streamer_h streamer,
    media_streamer_interrupted_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_streamer_set_interrupted_cb(
      streamer,
      callback,
      user_data,
    );
  }

  late final _media_streamer_set_interrupted_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_h, media_streamer_interrupted_cb,
              ffi.Pointer<ffi.Void>)>>('media_streamer_set_interrupted_cb');
  late final _media_streamer_set_interrupted_cb =
      _media_streamer_set_interrupted_cbPtr.asFunction<
          int Function(media_streamer_h, media_streamer_interrupted_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 3.0
  /// @param[in] streamer Media streamer handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_streamer_set_interrupted_cb()
  int media_streamer_unset_interrupted_cb(
    media_streamer_h streamer,
  ) {
    return _media_streamer_unset_interrupted_cb(
      streamer,
    );
  }

  late final _media_streamer_unset_interrupted_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_h)>>(
          'media_streamer_unset_interrupted_cb');
  late final _media_streamer_unset_interrupted_cb =
      _media_streamer_unset_interrupted_cbPtr
          .asFunction<int Function(media_streamer_h)>();

  /// @brief Registers a callback function to be invoked when buffer underrun or overflow is occurred.
  /// @details This function can be called only for MEDIA_STREAMER_NODE_SRC_TYPE_CUSTOM source type
  /// @since_tizen 3.0
  /// @remarks This API is used for media stream playback only.
  /// @param [in] source    Media streamer source node handle
  /// @param [in] callback  The buffer status callback function to register
  /// @param [in] user_data The user data passed from the code where
  /// media_streamer_src_set_buffer_status_cb() was invoked
  /// This data will be accessible from @a media_streamer_custom_buffer_status_cb()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a media streamer source node handle by calling media_streamer_node_create_src() function
  /// @pre Add created media streamer source node to media streamer by calling media_streamer_node_add() function
  /// @post media_streamer_custom_buffer_status_cb() will be invoked.
  /// @see media_streamer_src_unset_buffer_status_cb()
  /// @see media_streamer_custom_buffer_status_cb()
  int media_streamer_src_set_buffer_status_cb(
    media_streamer_node_h source,
    media_streamer_custom_buffer_status_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_streamer_src_set_buffer_status_cb(
      source,
      callback,
      user_data,
    );
  }

  late final _media_streamer_src_set_buffer_status_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_streamer_node_h,
                  media_streamer_custom_buffer_status_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'media_streamer_src_set_buffer_status_cb');
  late final _media_streamer_src_set_buffer_status_cb =
      _media_streamer_src_set_buffer_status_cbPtr.asFunction<
          int Function(media_streamer_node_h,
              media_streamer_custom_buffer_status_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the src buffer status callback function.
  /// @since_tizen 3.0
  /// @param [in] source    Media streamer source node handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_streamer_src_set_buffer_status_cb()
  int media_streamer_src_unset_buffer_status_cb(
    media_streamer_node_h source,
  ) {
    return _media_streamer_src_unset_buffer_status_cb(
      source,
    );
  }

  late final _media_streamer_src_unset_buffer_status_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_node_h)>>(
          'media_streamer_src_unset_buffer_status_cb');
  late final _media_streamer_src_unset_buffer_status_cb =
      _media_streamer_src_unset_buffer_status_cbPtr
          .asFunction<int Function(media_streamer_node_h)>();

  /// @brief Registers a callback function to be called when the custom sink is ready for data processing.
  /// @details This function can be called only for MEDIA_STREAMER_NODE_SINK_TYPE_CUSTOM sink type
  /// @since_tizen 3.0
  /// @param [in] sink      Media streamer sink node handle
  /// @param [in] callback  Callback function pointer
  /// @param [in] user_data The user data passed from the code where
  /// media_streamer_sink_set_data_ready_cb() was invoked
  /// This data will be accessible from @a media_streamer_sink_data_ready_cb
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a media streamer sink handle by calling media_streamer_node_create_sink() function
  /// @pre Add created media streamer sink node to media streamer by calling media_streamer_node_add() function
  /// @post media_streamer_sink_data_ready_cb() will be invoked.
  /// @see media_streamer_sink_unset_data_ready_cb()
  /// @see media_streamer_sink_data_ready_cb()
  int media_streamer_sink_set_data_ready_cb(
    media_streamer_node_h sink,
    media_streamer_sink_data_ready_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_streamer_sink_set_data_ready_cb(
      sink,
      callback,
      user_data,
    );
  }

  late final _media_streamer_sink_set_data_ready_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_streamer_node_h,
              media_streamer_sink_data_ready_cb,
              ffi.Pointer<ffi.Void>)>>('media_streamer_sink_set_data_ready_cb');
  late final _media_streamer_sink_set_data_ready_cb =
      _media_streamer_sink_set_data_ready_cbPtr.asFunction<
          int Function(media_streamer_node_h, media_streamer_sink_data_ready_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the sink data ready callback function.
  /// @since_tizen 3.0
  /// @param [in] sink    Media streamer sink node handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_streamer_sink_set_data_ready_cb()
  int media_streamer_sink_unset_data_ready_cb(
    media_streamer_node_h sink,
  ) {
    return _media_streamer_sink_unset_data_ready_cb(
      sink,
    );
  }

  late final _media_streamer_sink_unset_data_ready_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_node_h)>>(
          'media_streamer_sink_unset_data_ready_cb');
  late final _media_streamer_sink_unset_data_ready_cb =
      _media_streamer_sink_unset_data_ready_cbPtr
          .asFunction<int Function(media_streamer_node_h)>();

  /// @brief Registers a callback function to be called when custom sink detect the end-of-stream.
  /// @since_tizen 3.0
  /// @param [in] sink      Media streamer sink node handle
  /// @param [in] callback  Callback function pointer
  /// @param [in] user_data The user data passed from the code where
  /// media_streamer_sink_set_eos_cb() was invoked.
  /// This data will be accessible from @a media_streamer_sink_eos_cb
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a media streamer sink handle by calling media_streamer_node_create_sink() function
  /// @pre Add created media streamer sink node to media streamer by calling media_streamer_node_add() function
  /// @post media_streamer_sink_eos_cb() will be invoked.
  /// @see media_streamer_sink_unset_eos_cb()
  /// @see media_streamer_sink_eos_cb()
  int media_streamer_sink_set_eos_cb(
    media_streamer_node_h sink,
    media_streamer_sink_eos_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_streamer_sink_set_eos_cb(
      sink,
      callback,
      user_data,
    );
  }

  late final _media_streamer_sink_set_eos_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_node_h, media_streamer_sink_eos_cb,
              ffi.Pointer<ffi.Void>)>>('media_streamer_sink_set_eos_cb');
  late final _media_streamer_sink_set_eos_cb =
      _media_streamer_sink_set_eos_cbPtr.asFunction<
          int Function(media_streamer_node_h, media_streamer_sink_eos_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the sink end-of-stream callback function.
  /// @since_tizen 3.0
  /// @param [in] sink    Media streamer sink node handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @see media_streamer_sink_set_eos_cb()
  int media_streamer_sink_unset_eos_cb(
    media_streamer_node_h sink,
  ) {
    return _media_streamer_sink_unset_eos_cb(
      sink,
    );
  }

  late final _media_streamer_sink_unset_eos_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_node_h)>>(
          'media_streamer_sink_unset_eos_cb');
  late final _media_streamer_sink_unset_eos_cb =
      _media_streamer_sink_unset_eos_cbPtr
          .asFunction<int Function(media_streamer_node_h)>();

  /// @brief Creates an instance of media streamer and
  /// passes the handle to the caller.
  /// @since_tizen 3.0
  /// @remarks You must release @a streamer using media_streamer_destroy()
  /// @param [out] streamer    Media streamer handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @post The media streamer state will be #MEDIA_STREAMER_STATE_IDLE.
  /// @see media_streamer_destroy()
  int media_streamer_create(
    ffi.Pointer<media_streamer_h> streamer,
  ) {
    return _media_streamer_create(
      streamer,
    );
  }

  late final _media_streamer_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<media_streamer_h>)>>(
      'media_streamer_create');
  late final _media_streamer_create = _media_streamer_createPtr
      .asFunction<int Function(ffi.Pointer<media_streamer_h>)>();

  /// @brief Sets media streamer state to MEDIA_STREAMER_STATE_READY.
  /// @since_tizen 3.0
  /// @param [in] streamer     Media streamer handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre	The media streamer state must be set to #MEDIA_STREAMER_STATE_IDLE
  /// by calling media_streamer_create() or media_streamer_unprepare().
  /// @pre At least one src and one sink should be added and linked in the streamer
  /// by calling media_streamer_node_create_src(), media_streamer_node_create_sink() and media_streamer_node_link().
  /// @post The media streamer state will be #MEDIA_STREAMER_STATE_READY.
  /// @see media_streamer_unprepare()
  /// @see media_streamer_create()
  int media_streamer_prepare(
    media_streamer_h streamer,
  ) {
    return _media_streamer_prepare(
      streamer,
    );
  }

  late final _media_streamer_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_h)>>(
          'media_streamer_prepare');
  late final _media_streamer_prepare =
      _media_streamer_preparePtr.asFunction<int Function(media_streamer_h)>();

  /// @brief Sets media streamer state to MEDIA_STREAMER_STATE_IDLE.
  /// @details The most recently used media is reset and no longer associated with the media streamer.
  /// @since_tizen 3.0
  /// @param [in] streamer     Media streamer handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The media streamer state should be higher than #MEDIA_STREAMER_STATE_IDLE.
  /// @post The media streamer state will be #MEDIA_STREAMER_STATE_IDLE.
  /// @see media_streamer_prepare()
  int media_streamer_unprepare(
    media_streamer_h streamer,
  ) {
    return _media_streamer_unprepare(
      streamer,
    );
  }

  late final _media_streamer_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_h)>>(
          'media_streamer_unprepare');
  late final _media_streamer_unprepare =
      _media_streamer_unpreparePtr.asFunction<int Function(media_streamer_h)>();

  /// @brief Sets media streamer state to MEDIA_STREAMER_STATE_PLAYING.
  /// @details Start running the current streamer, or resumes it if paused.
  /// @since_tizen 3.0
  /// @param [in] streamer     Media streamer handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The media streamer state must be set to #MEDIA_STREAMER_STATE_READY by calling media_streamer_prepare() or
  /// set to #MEDIA_STREAMER_STATE_PAUSED by calling media_streamer_pause().
  /// @post The media streamer state will be #MEDIA_STREAMER_STATE_PLAYING.
  /// @see media_streamer_create()
  /// @see media_streamer_pause()
  /// @see media_streamer_stop()
  int media_streamer_play(
    media_streamer_h streamer,
  ) {
    return _media_streamer_play(
      streamer,
    );
  }

  late final _media_streamer_playPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_h)>>(
          'media_streamer_play');
  late final _media_streamer_play =
      _media_streamer_playPtr.asFunction<int Function(media_streamer_h)>();

  /// @brief Pauses the media streamer.
  /// @since_tizen 3.0
  /// @param [in] streamer     Media streamer handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The media streamer state must be set to #MEDIA_STREAMER_STATE_PLAYING.
  /// @post The media streamer state will be #MEDIA_STREAMER_STATE_READY.
  /// @see media_streamer_create()
  /// @see media_streamer_play()
  int media_streamer_pause(
    media_streamer_h streamer,
  ) {
    return _media_streamer_pause(
      streamer,
    );
  }

  late final _media_streamer_pausePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_h)>>(
          'media_streamer_pause');
  late final _media_streamer_pause =
      _media_streamer_pausePtr.asFunction<int Function(media_streamer_h)>();

  /// @brief Stops the media streamer.
  /// @since_tizen 3.0
  /// @param [in] streamer     Media streamer handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The media streamer state must be set to #MEDIA_STREAMER_STATE_PLAYING by calling media_streamer_play() or
  /// set to #MEDIA_STREAMER_STATE_PAUSED by calling media_streamer_pause().
  /// @post The media streamer state will be #MEDIA_STREAMER_STATE_READY.
  /// @see media_streamer_create()
  /// @see media_streamer_play()
  /// @see media_streamer_pause()
  int media_streamer_stop(
    media_streamer_h streamer,
  ) {
    return _media_streamer_stop(
      streamer,
    );
  }

  late final _media_streamer_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_h)>>(
          'media_streamer_stop');
  late final _media_streamer_stop =
      _media_streamer_stopPtr.asFunction<int Function(media_streamer_h)>();

  /// @brief Destroys media streamer.
  /// @since_tizen 3.0
  /// @remark Nodes in streamer will be removed automatically.
  /// Don't need to remove nodes by calling media_streamer_node_remove().
  /// If you want to change the node without destroying streamer handle,
  /// you can call the media_streamer_node_remove() function
  /// after setting the streamer state to MEDIA_STREAMER_STATE_IDLE state.
  /// @param [in] streamer     Media streamer handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a media streamer handle by calling media_streamer_create() function
  /// @post The media streamer state will be #MEDIA_STREAMER_STATE_NONE.
  /// @see media_streamer_create()
  int media_streamer_destroy(
    media_streamer_h streamer,
  ) {
    return _media_streamer_destroy(
      streamer,
    );
  }

  late final _media_streamer_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_h)>>(
          'media_streamer_destroy');
  late final _media_streamer_destroy =
      _media_streamer_destroyPtr.asFunction<int Function(media_streamer_h)>();

  /// @brief Changes playback position to the defined time value, asynchronously.
  /// @since_tizen 3.0
  /// @param [in] streamer     Media streamer handle
  /// @param [in] time         Time in millisecond
  /// @param [in] accurate     If @c true, it will seek to the accurate position, but this might be considerably slower for some formats,
  /// otherwise @c false, it will seek to the nearest keyframe.
  /// @param [in] callback	    The callback function to register
  /// @param [in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE    Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_STREAMER_ERROR_SEEK_FAILED Seek operation failure
  /// @pre The media streamer state must be one of these: #MEDIA_STREAMER_STATE_PAUSED, or #MEDIA_STREAMER_STATE_PLAYING.
  /// @post It invokes media_streamer_set_play_position() when seek operation completes, if you set a callback.
  /// @see media_streamer_get_play_position()
  int media_streamer_set_play_position(
    media_streamer_h streamer,
    int time,
    bool accurate,
    media_streamer_position_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_streamer_set_play_position(
      streamer,
      time,
      accurate,
      callback,
      user_data,
    );
  }

  late final _media_streamer_set_play_positionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_streamer_h,
              ffi.Int,
              ffi.Bool,
              media_streamer_position_changed_cb,
              ffi.Pointer<ffi.Void>)>>('media_streamer_set_play_position');
  late final _media_streamer_set_play_position =
      _media_streamer_set_play_positionPtr.asFunction<
          int Function(media_streamer_h, int, bool,
              media_streamer_position_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the current position in milliseconds.
  /// @since_tizen 3.0
  /// @param [in]  streamer     Media streamer handle
  /// @param [out] time         The current position in milliseconds
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The media streamer state must be one of these: #MEDIA_STREAMER_STATE_PAUSED, or #MEDIA_STREAMER_STATE_PLAYING.
  /// @see media_streamer_set_play_position()
  int media_streamer_get_play_position(
    media_streamer_h streamer,
    ffi.Pointer<ffi.Int> time,
  ) {
    return _media_streamer_get_play_position(
      streamer,
      time,
    );
  }

  late final _media_streamer_get_play_positionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_h,
              ffi.Pointer<ffi.Int>)>>('media_streamer_get_play_position');
  late final _media_streamer_get_play_position =
      _media_streamer_get_play_positionPtr
          .asFunction<int Function(media_streamer_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the total running time of the associated media.
  /// @since_tizen 3.0
  /// @remarks The streamer's src node type should be MEDIA_STREAMER_NODE_SRC_TYPE_FILE or MEDIA_STREAMER_NODE_SRC_TYPE_HTTP.
  /// If not, return value will be MEDIA_STREAMER_ERROR_NONE and duration will be -1.
  /// @param [in]  streamer     Media streamer handle
  /// @param [out] duration     The duration in milliseconds
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The media streamer state must be one of these: #MEDIA_STREAMER_STATE_PAUSED, or #MEDIA_STREAMER_STATE_PLAYING.
  int media_streamer_get_duration(
    media_streamer_h streamer,
    ffi.Pointer<ffi.Int> duration,
  ) {
    return _media_streamer_get_duration(
      streamer,
      duration,
    );
  }

  late final _media_streamer_get_durationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_h,
              ffi.Pointer<ffi.Int>)>>('media_streamer_get_duration');
  late final _media_streamer_get_duration = _media_streamer_get_durationPtr
      .asFunction<int Function(media_streamer_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets media streamer state.
  /// @since_tizen 3.0
  /// @param [in]  streamer     Media streamer handle
  /// @param [out] state        Media streamer state
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE    Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a media streamer handle by calling media_streamer_create() function
  /// @see #media_streamer_state_e
  int media_streamer_get_state(
    media_streamer_h streamer,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _media_streamer_get_state(
      streamer,
      state,
    );
  }

  late final _media_streamer_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_h,
              ffi.Pointer<ffi.Int32>)>>('media_streamer_get_state');
  late final _media_streamer_get_state = _media_streamer_get_statePtr
      .asFunction<int Function(media_streamer_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Creates media streamer source node.
  /// @since_tizen 3.0
  /// @remarks The internet privilege(http://tizen.org/privilege/internet) should be added if any URIs are used to play from network.
  /// The camera privilege(http://tizen.org/privilege/camera) should be added if the src node handle the camera device.
  /// The recorder privilege(http://tizen.org/privilege/recorder) should be added if the src node handle the recorder device.
  /// You can release @a source node using media_streamer_node_destroy() function.
  /// @param [in]  type     Media streamer source node type
  /// @param [out] src      Media streamer source node handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_STREAMER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_STREAMER_ERROR_NOT_SUPPORTED Not supported
  /// @see #media_streamer_node_src_type_e
  /// @see media_streamer_node_destroy()
  int media_streamer_node_create_src(
    int type,
    ffi.Pointer<media_streamer_node_h> src,
  ) {
    return _media_streamer_node_create_src(
      type,
      src,
    );
  }

  late final _media_streamer_node_create_srcPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int32, ffi.Pointer<media_streamer_node_h>)>>(
      'media_streamer_node_create_src');
  late final _media_streamer_node_create_src =
      _media_streamer_node_create_srcPtr
          .asFunction<int Function(int, ffi.Pointer<media_streamer_node_h>)>();

  /// @brief Pushes packet into custom source node.
  /// @details This function can be called only for MEDIA_STREAMER_NODE_SRC_TYPE_CUSTOM.
  /// @since_tizen 3.0
  /// @param [in] src       Media streamer source node handle
  /// @param [in] packet    Media packet handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_STREAMER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a source node handle by calling media_streamer_node_create_src() function
  /// @pre	The media streamer state must be set to #MEDIA_STREAMER_STATE_IDLE at least.
  /// @see #media_packet_h
  int media_streamer_node_push_packet(
    media_streamer_node_h src,
    media_packet_h packet,
  ) {
    return _media_streamer_node_push_packet(
      src,
      packet,
    );
  }

  late final _media_streamer_node_push_packetPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_node_h,
              media_packet_h)>>('media_streamer_node_push_packet');
  late final _media_streamer_node_push_packet =
      _media_streamer_node_push_packetPtr
          .asFunction<int Function(media_streamer_node_h, media_packet_h)>();

  /// @brief Creates media streamer sink node.
  /// @since_tizen 3.0
  /// @remarks The internet privilege(http://tizen.org/privilege/internet) should be added if any URIs are used to transmit the output data.
  /// You can release @a sink node using media_streamer_node_destroy()
  /// @remarks If @a type is #MEDIA_STREAMER_NODE_SINK_TYPE_ADAPTIVE, the HTTP server will be started and the server will be able to transmit the output data to the other device.
  /// The application must have an authentication responsibility between a server and client because the data transmission is not secure.
  /// @param [in]  type     Type of sink node to be created
  /// @param [out] sink     Media streamer sink node handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_STREAMER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_STREAMER_ERROR_NOT_SUPPORTED Not supported
  /// @see #media_streamer_node_sink_type_e
  /// @see media_streamer_node_destroy()
  int media_streamer_node_create_sink(
    int type,
    ffi.Pointer<media_streamer_node_h> sink,
  ) {
    return _media_streamer_node_create_sink(
      type,
      sink,
    );
  }

  late final _media_streamer_node_create_sinkPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int32, ffi.Pointer<media_streamer_node_h>)>>(
      'media_streamer_node_create_sink');
  late final _media_streamer_node_create_sink =
      _media_streamer_node_create_sinkPtr
          .asFunction<int Function(int, ffi.Pointer<media_streamer_node_h>)>();

  /// @brief Pulls packet from custom sink node.
  /// @details This function can be called only for MEDIA_STREAMER_NODE_SINK_TYPE_CUSTOM
  /// @since_tizen 3.0
  /// @param [in] sink      Media streamer sink node handle
  /// @param [out] packet   Media packet handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a sink node handle by calling media_streamer_node_create_sink() function
  /// @pre Set media_streamer_data_ready_cb by calling media_streamer_set_data_ready_cb() function.
  /// @see #media_packet_h
  /// @see media_streamer_node_create_sink()
  int media_streamer_node_pull_packet(
    media_streamer_node_h sink,
    ffi.Pointer<media_packet_h> packet,
  ) {
    return _media_streamer_node_pull_packet(
      sink,
      packet,
    );
  }

  late final _media_streamer_node_pull_packetPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_node_h,
              ffi.Pointer<media_packet_h>)>>('media_streamer_node_pull_packet');
  late final _media_streamer_node_pull_packet =
      _media_streamer_node_pull_packetPtr.asFunction<
          int Function(media_streamer_node_h, ffi.Pointer<media_packet_h>)>();

  /// @brief Creates media streamer node except MEDIA_STREAMER_NODE_TYPE_SRC and MEDIA_STREAMER_NODE_TYPE_SINK.
  /// @details Creates node specific @a type with specific format of input
  /// and output data.
  /// @since_tizen 3.0
  /// @remarks The node type should not be MEDIA_STREAMER_NODE_TYPE_SRC and MEDIA_STREAMER_NODE_TYPE_SINK.
  /// To create src/sink type node, media_streamer_node_create_src()/media_streamer_node_create_sink() should be called.
  /// You can release @a node using media_streamer_node_destroy() function
  /// @param [in]  type      Created node type
  /// @param [in]  in_fmt    Media format handle for input data
  /// @param [in]  out_fmt   Media format handle for output data
  /// @param [out] node      Media streamer node handle to be created
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @see #media_streamer_node_type_e
  /// @see #media_format_h
  /// @see media_streamer_node_destroy()
  int media_streamer_node_create(
    int type,
    media_format_h in_fmt,
    media_format_h out_fmt,
    ffi.Pointer<media_streamer_node_h> node,
  ) {
    return _media_streamer_node_create(
      type,
      in_fmt,
      out_fmt,
      node,
    );
  }

  late final _media_streamer_node_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int32, media_format_h, media_format_h,
                  ffi.Pointer<media_streamer_node_h>)>>(
      'media_streamer_node_create');
  late final _media_streamer_node_create =
      _media_streamer_node_createPtr.asFunction<
          int Function(int, media_format_h, media_format_h,
              ffi.Pointer<media_streamer_node_h>)>();

  /// @brief Adds node to media streamer.
  /// @since_tizen 3.0
  /// @param [in] streamer    Media streamer handle
  /// @param [in] node        Media streamer node handle to be added
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create media streamer handle by calling media_streamer_create() function
  /// @pre Create node handle by calling media_streamer_node_create() function
  /// @see media_streamer_create()
  /// @see media_streamer_node_create()
  /// @see media_streamer_node_create_src()
  /// @see media_streamer_node_create_sink()
  int media_streamer_node_add(
    media_streamer_h streamer,
    media_streamer_node_h node,
  ) {
    return _media_streamer_node_add(
      streamer,
      node,
    );
  }

  late final _media_streamer_node_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_h,
              media_streamer_node_h)>>('media_streamer_node_add');
  late final _media_streamer_node_add = _media_streamer_node_addPtr
      .asFunction<int Function(media_streamer_h, media_streamer_node_h)>();

  /// @brief Destroys media streamer node.
  /// @since_tizen 3.0
  /// @param [in] node        Media streamer node handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create node handle by calling media_streamer_node_create() function
  /// @pre If the node was added to media streamer, it have to be removed by calling media_streamer_node_remove() function
  /// @see media_streamer_node_create()
  /// @see media_streamer_node_create_src()
  /// @see media_streamer_node_create_sink()
  /// @see media_streamer_node_remove()
  int media_streamer_node_destroy(
    media_streamer_node_h node,
  ) {
    return _media_streamer_node_destroy(
      node,
    );
  }

  late final _media_streamer_node_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(media_streamer_node_h)>>(
          'media_streamer_node_destroy');
  late final _media_streamer_node_destroy = _media_streamer_node_destroyPtr
      .asFunction<int Function(media_streamer_node_h)>();

  /// @brief Removes media streamer node from streamer.
  /// @since_tizen 3.0
  /// @remarks To remove node without error posting, the state of streamer should be MEDIA_STREAMER_STATE_IDLE.
  /// If the node is linked, it will be unlinked before removing.
  /// @param [in] streamer    Media streamer handle
  /// @param [in] node        Media streamer node handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Add node to streamer by calling media_streamer_node_add() function
  /// @see media_streamer_node_add()
  int media_streamer_node_remove(
    media_streamer_h streamer,
    media_streamer_node_h node,
  ) {
    return _media_streamer_node_remove(
      streamer,
      node,
    );
  }

  late final _media_streamer_node_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_h,
              media_streamer_node_h)>>('media_streamer_node_remove');
  late final _media_streamer_node_remove = _media_streamer_node_removePtr
      .asFunction<int Function(media_streamer_h, media_streamer_node_h)>();

  /// @brief Links two media streamer nodes.
  /// @since_tizen 3.0
  /// @remark Pads are node's input and output, where you can connect other nodes.
  /// (src_node) - (sink_node)
  /// src_node and sink_node is determined relatively.
  /// In case of (A)-(B)-(C),
  /// (B) can be sink_node with (A) or (B) can be src_node with (C).
  /// However, src type node is always src node and sink type node is always sink node.
  /// (A) is src node and can not be sink node at all.
  /// (C) is sink node and can not be src node at all.
  /// @param [in] src_node      Media streamer node handle
  /// @param [in] src_pad_name  The name of the source pad of the source node
  /// @param [in] dest_node     The destination media streamer node handle
  /// @param [in] sink_pad_name The name of the sink pad of the destination node
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a source node and a destination node handles
  /// by calling media_streamer_node_create() function
  /// and add the nodes into streamer by calling media_streamer_node_add() function.
  /// @see media_streamer_node_create()
  /// @see media_streamer_node_add()
  int media_streamer_node_link(
    media_streamer_node_h src_node,
    ffi.Pointer<ffi.Char> src_pad_name,
    media_streamer_node_h dest_node,
    ffi.Pointer<ffi.Char> sink_pad_name,
  ) {
    return _media_streamer_node_link(
      src_node,
      src_pad_name,
      dest_node,
      sink_pad_name,
    );
  }

  late final _media_streamer_node_linkPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_streamer_node_h,
              ffi.Pointer<ffi.Char>,
              media_streamer_node_h,
              ffi.Pointer<ffi.Char>)>>('media_streamer_node_link');
  late final _media_streamer_node_link =
      _media_streamer_node_linkPtr.asFunction<
          int Function(media_streamer_node_h, ffi.Pointer<ffi.Char>,
              media_streamer_node_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets media format for pad of media streamer node.
  /// @since_tizen 3.0
  /// @param [in] node        Media streamer node handle
  /// @param [in] pad_name    Pad name
  /// @param [in] fmt         Media format handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a node handle by calling media_streamer_node_createxxx() function
  /// @pre Get pad name by calling media_streamer_node_get_pad_name() function
  /// @see #media_format_h
  int media_streamer_node_set_pad_format(
    media_streamer_node_h node,
    ffi.Pointer<ffi.Char> pad_name,
    media_format_h fmt,
  ) {
    return _media_streamer_node_set_pad_format(
      node,
      pad_name,
      fmt,
    );
  }

  late final _media_streamer_node_set_pad_formatPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_node_h, ffi.Pointer<ffi.Char>,
              media_format_h)>>('media_streamer_node_set_pad_format');
  late final _media_streamer_node_set_pad_format =
      _media_streamer_node_set_pad_formatPtr.asFunction<
          int Function(
              media_streamer_node_h, ffi.Pointer<ffi.Char>, media_format_h)>();

  /// @brief Gets media format for pad of media streamer node.
  /// @since_tizen 3.0
  /// @param [in] node        Media streamer node handle
  /// @param [in] pad_name    Pad name
  /// @param [out] fmt        Media format handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a node handle by calling media_streamer_node_createxxx() function
  /// @pre Get pad name by calling media_streamer_node_get_pad_name() function
  /// @see #media_format_h
  int media_streamer_node_get_pad_format(
    media_streamer_node_h node,
    ffi.Pointer<ffi.Char> pad_name,
    ffi.Pointer<media_format_h> fmt,
  ) {
    return _media_streamer_node_get_pad_format(
      node,
      pad_name,
      fmt,
    );
  }

  late final _media_streamer_node_get_pad_formatPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(media_streamer_node_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<media_format_h>)>>(
      'media_streamer_node_get_pad_format');
  late final _media_streamer_node_get_pad_format =
      _media_streamer_node_get_pad_formatPtr.asFunction<
          int Function(media_streamer_node_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<media_format_h>)>();

  /// @brief Gets name of node pads.
  /// @since_tizen 3.0
  /// @remark After using the src_pad_name and sink_pad_name, it have to be free.
  /// src_pad_name or sink_pad_name can be null according to the node type.
  /// In case of src type node, sink_pad_name will be null.
  /// In case of sink type node, src_pad_name will be null.
  /// @param [in]  node            Media streamer node handle
  /// @param [out] src_pad_name    Array of source pad name
  /// @param [out] src_pad_num     The number of source pads
  /// @param [out] sink_pad_name   Array of sink pad name
  /// @param [out] sink_pad_num    The number of sink pads
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a node handle by calling media_streamer_node_createxxx() function
  /// @see media_streamer_node_create()
  /// @see media_streamer_node_create_src()
  /// @see media_streamer_node_create_sink()
  int media_streamer_node_get_pad_name(
    media_streamer_node_h node,
    ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>> src_pad_name,
    ffi.Pointer<ffi.Int> src_pad_num,
    ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>> sink_pad_name,
    ffi.Pointer<ffi.Int> sink_pad_num,
  ) {
    return _media_streamer_node_get_pad_name(
      node,
      src_pad_name,
      src_pad_num,
      sink_pad_name,
      sink_pad_num,
    );
  }

  late final _media_streamer_node_get_pad_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_streamer_node_h,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>)>>('media_streamer_node_get_pad_name');
  late final _media_streamer_node_get_pad_name =
      _media_streamer_node_get_pad_namePtr.asFunction<
          int Function(
              media_streamer_node_h,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Sets parameters of node.
  /// @details Many parameters can be set at one time all together by using bundle.
  /// @since_tizen 3.0
  /// @remarks The mediastorage privilege(http://tizen.org/privilege/mediastorage) should be added if any video/audio files are written in the internal storage devices.
  /// The externalstorage privilege(http://tizen.org/privilege/externalstorage) should be added if any video/audio files are written in the external storage devices.
  /// @param [in] node        Media streamer node handle
  /// @param [in] param_list  Key value array of media streamer node parameters
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_STREAMER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a node handle by calling media_streamer_node_createXXX() function.
  /// @pre Get param list to set by calling media_streamer_node_get_params() function.
  /// @see media_streamer_node_create()
  /// @see media_streamer_node_create_src()
  /// @see media_streamer_node_create_sink()
  /// @see media_streamer_node_get_params()
  int media_streamer_node_set_params(
    media_streamer_node_h node,
    ffi.Pointer<bundle> param_list,
  ) {
    return _media_streamer_node_set_params(
      node,
      param_list,
    );
  }

  late final _media_streamer_node_set_paramsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_node_h,
              ffi.Pointer<bundle>)>>('media_streamer_node_set_params');
  late final _media_streamer_node_set_params =
      _media_streamer_node_set_paramsPtr.asFunction<
          int Function(media_streamer_node_h, ffi.Pointer<bundle>)>();

  /// @brief Gets node parameter list.
  /// @since_tizen 3.0
  /// @remark After using param_list, it have to be free by calling bundle_free() in bundle.h
  /// Refer to the "Parameter information of node" in this file to get info.
  /// @param [in]  node         Media streamer node handle
  /// @param [out] param_list   Key value array of media streamer node parameters
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a node handle by calling media_streamer_node_createXXX() function
  /// @post Set params which are needed to set by calling media_streamer_node_set_params() or media_streamer_node_set_param() function.
  /// @see media_streamer_node_create()
  /// @see media_streamer_src_create()
  /// @see media_streamer_sink_create()
  /// @see media_streamer_node_set_params()
  /// @see media_streamer_node_set_param()
  int media_streamer_node_get_params(
    media_streamer_node_h node,
    ffi.Pointer<ffi.Pointer<bundle>> param_list,
  ) {
    return _media_streamer_node_get_params(
      node,
      param_list,
    );
  }

  late final _media_streamer_node_get_paramsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  media_streamer_node_h, ffi.Pointer<ffi.Pointer<bundle>>)>>(
      'media_streamer_node_get_params');
  late final _media_streamer_node_get_params =
      _media_streamer_node_get_paramsPtr.asFunction<
          int Function(
              media_streamer_node_h, ffi.Pointer<ffi.Pointer<bundle>>)>();

  /// @brief Sets single parameter of node.
  /// @details Sets parameter one by one without creating param bundle.
  /// @since_tizen 3.0
  /// @remarks The mediastorage privilege(http://tizen.org/privilege/mediastorage) should be added if any video/audio files are written in the internal storage devices.
  /// The externalstorage privilege(http://tizen.org/privilege/externalstorage) should be added if any video/audio files are written in the external storage devices.
  /// @param [in] node        Media streamer node handle
  /// @param [in] param_name  Param name of node
  /// @param [in] param_value Param value of node
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_STREAMER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Create a node handle by calling media_streamer_node_createXXX() function.
  /// @pre Get param list to set by calling media_streamer_node_get_params() function.
  /// @see media_streamer_node_create()
  /// @see media_streamer_src_create()
  /// @see media_streamer_sink_create()
  /// @see media_streamer_node_get_params()
  /// @see media_streamer_node_get_param()
  int media_streamer_node_set_param(
    media_streamer_node_h node,
    ffi.Pointer<ffi.Char> param_name,
    ffi.Pointer<ffi.Char> param_value,
  ) {
    return _media_streamer_node_set_param(
      node,
      param_name,
      param_value,
    );
  }

  late final _media_streamer_node_set_paramPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(media_streamer_node_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('media_streamer_node_set_param');
  late final _media_streamer_node_set_param =
      _media_streamer_node_set_paramPtr.asFunction<
          int Function(media_streamer_node_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief Gets value of parameter.
  /// @details Gets parameter one by one without creating param bundle.
  /// @since_tizen 3.0
  /// @param [in] node         Media streamer node handle
  /// @param [in] param_name   Param name of node
  /// @param [out] param_value Param value of node
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #MEDIA_STREAMER_ERROR_NONE Successful
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_STATE Invalid state
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_STREAMER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre Create a node handle by calling media_streamer_node_createXXX() function.
  /// @pre Get param list to know the param name by calling media_streamer_node_get_params() function.
  /// @see media_streamer_node_create()
  /// @see media_streamer_src_create()
  /// @see media_streamer_sink_create()
  /// @see media_streamer_node_get_params()
  /// @see media_streamer_node_set_param()
  int media_streamer_node_get_param(
    media_streamer_node_h node,
    ffi.Pointer<ffi.Char> param_name,
    ffi.Pointer<ffi.Pointer<ffi.Char>> param_value,
  ) {
    return _media_streamer_node_get_param(
      node,
      param_name,
      param_value,
    );
  }

  late final _media_streamer_node_get_paramPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(media_streamer_node_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'media_streamer_node_get_param');
  late final _media_streamer_node_get_param =
      _media_streamer_node_get_paramPtr.asFunction<
          int Function(media_streamer_node_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Creates a source handle.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @remarks You must release @a source by using @ref mv_destroy_source().
  /// @param [out] source    A new handle to the source
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_destroy_source()
  int mv_create_source(
    ffi.Pointer<mv_source_h> source,
  ) {
    return _mv_create_source(
      source,
    );
  }

  late final _mv_create_sourcePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<mv_source_h>)>>(
          'mv_create_source');
  late final _mv_create_source =
      _mv_create_sourcePtr.asFunction<int Function(ffi.Pointer<mv_source_h>)>();

  /// @brief Destroys the source handle and releases all its resources.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in] source    The handle to the source to be destroyed
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_create_source()
  int mv_destroy_source(
    mv_source_h source,
  ) {
    return _mv_destroy_source(
      source,
    );
  }

  late final _mv_destroy_sourcePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mv_source_h)>>(
          'mv_destroy_source');
  late final _mv_destroy_source =
      _mv_destroy_sourcePtr.asFunction<int Function(mv_source_h)>();

  /// @brief Fills the media source based on the media packet.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in,out] source          The handle to the source
  /// @param [in]     media_packet    The handle to the media packet from which
  /// will be filled the source
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Not supported format
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a source handle by calling @ref mv_create_source()
  ///
  /// @see mv_create_source()
  /// @see mv_destroy_source()
  int mv_source_fill_by_media_packet(
    mv_source_h source,
    media_packet_h media_packet,
  ) {
    return _mv_source_fill_by_media_packet(
      source,
      media_packet,
    );
  }

  late final _mv_source_fill_by_media_packetPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(mv_source_h, media_packet_h)>>(
      'mv_source_fill_by_media_packet');
  late final _mv_source_fill_by_media_packet =
      _mv_source_fill_by_media_packetPtr
          .asFunction<int Function(mv_source_h, media_packet_h)>();

  /// @brief Fills the media source based on the buffer and metadata.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in,out] source             The handle to the source
  /// @param [in]     data_buffer        The buffer of image data
  /// @param [in]     buffer_size        The buffer size
  /// @param [in]     image_width        The width of image data
  /// @param [in]     image_height       The height of image data
  /// @param [in]     image_colorspace   The image colorspace
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a source handle by calling @ref mv_create_source()
  ///
  /// @see mv_source_clear()
  int mv_source_fill_by_buffer(
    mv_source_h source,
    ffi.Pointer<ffi.UnsignedChar> data_buffer,
    int buffer_size,
    int image_width,
    int image_height,
    int image_colorspace,
  ) {
    return _mv_source_fill_by_buffer(
      source,
      data_buffer,
      buffer_size,
      image_width,
      image_height,
      image_colorspace,
    );
  }

  late final _mv_source_fill_by_bufferPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_source_h,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.UnsignedInt,
              ffi.UnsignedInt,
              ffi.UnsignedInt,
              ffi.Int32)>>('mv_source_fill_by_buffer');
  late final _mv_source_fill_by_buffer =
      _mv_source_fill_by_bufferPtr.asFunction<
          int Function(mv_source_h, ffi.Pointer<ffi.UnsignedChar>, int, int,
              int, int)>();

  /// @brief Clears the buffer of the media source.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in,out] source    The handle to the source
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_source_fill_by_buffer()
  int mv_source_clear(
    mv_source_h source,
  ) {
    return _mv_source_clear(
      source,
    );
  }

  late final _mv_source_clearPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mv_source_h)>>(
          'mv_source_clear');
  late final _mv_source_clear =
      _mv_source_clearPtr.asFunction<int Function(mv_source_h)>();

  /// @brief Gets buffer of the media source.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @remarks Note that the retrieved buffer will be destroyed when
  /// @ref mv_destroy_source() or @ref mv_source_clear() function
  /// is called for the @a source.
  ///
  /// @param [in]    source        The handle to the source
  /// @param [out]   data_buffer   The buffer of the source
  /// @param [out]   buffer_size   The size of buffer
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_source_get_width()
  /// @see mv_source_get_height()
  /// @see mv_source_get_colorspace()
  int mv_source_get_buffer(
    mv_source_h source,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> data_buffer,
    ffi.Pointer<ffi.UnsignedInt> buffer_size,
  ) {
    return _mv_source_get_buffer(
      source,
      data_buffer,
      buffer_size,
    );
  }

  late final _mv_source_get_bufferPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_source_h,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.UnsignedInt>)>>('mv_source_get_buffer');
  late final _mv_source_get_buffer = _mv_source_get_bufferPtr.asFunction<
      int Function(mv_source_h, ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
          ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets height of the media source.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in]    source         The handle to the source
  /// @param [out]   image_height   The height of an image in the source
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_source_get_width()
  /// @see mv_source_get_colorspace()
  /// @see mv_source_get_buffer()
  int mv_source_get_height(
    mv_source_h source,
    ffi.Pointer<ffi.UnsignedInt> image_height,
  ) {
    return _mv_source_get_height(
      source,
      image_height,
    );
  }

  late final _mv_source_get_heightPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_source_h,
              ffi.Pointer<ffi.UnsignedInt>)>>('mv_source_get_height');
  late final _mv_source_get_height = _mv_source_get_heightPtr
      .asFunction<int Function(mv_source_h, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets width of the media source.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in]    source        The handle to the source
  /// @param [out]   image_width   The width of an image in the source
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_source_get_height()
  /// @see mv_source_get_colorspace()
  /// @see mv_source_get_buffer()
  int mv_source_get_width(
    mv_source_h source,
    ffi.Pointer<ffi.UnsignedInt> image_width,
  ) {
    return _mv_source_get_width(
      source,
      image_width,
    );
  }

  late final _mv_source_get_widthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_source_h,
              ffi.Pointer<ffi.UnsignedInt>)>>('mv_source_get_width');
  late final _mv_source_get_width = _mv_source_get_widthPtr
      .asFunction<int Function(mv_source_h, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets colorspace of the media source.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in]    source             The handle to the source
  /// @param [out]   image_colorspace   The colorspace of an image in the source
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_source_get_width()
  /// @see mv_source_get_height()
  /// @see mv_source_get_buffer()
  int mv_source_get_colorspace(
    mv_source_h source,
    ffi.Pointer<ffi.Int32> image_colorspace,
  ) {
    return _mv_source_get_colorspace(
      source,
      image_colorspace,
    );
  }

  late final _mv_source_get_colorspacePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_source_h,
              ffi.Pointer<ffi.Int32>)>>('mv_source_get_colorspace');
  late final _mv_source_get_colorspace = _mv_source_get_colorspacePtr
      .asFunction<int Function(mv_source_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Creates the handle to the configuration of engine.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @remarks Available engine configuration attributes can be get by using
  /// @ref mv_engine_config_foreach_supported_attribute().
  /// The attributes can be changed by @ref mv_engine_config_h
  /// related setters. Default values are used if the attributes
  /// are not changed.
  /// @param [out] engine_cfg    The handle to the engine to be created
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_h
  /// @see mv_destroy_engine_config()
  /// @see mv_engine_config_set_double_attribute()
  /// @see mv_engine_config_set_int_attribute()
  /// @see mv_engine_config_set_bool_attribute()
  /// @see mv_engine_config_set_string_attribute()
  /// @see mv_engine_config_get_double_attribute()
  /// @see mv_engine_config_get_int_attribute()
  /// @see mv_engine_config_get_bool_attribute()
  /// @see mv_engine_config_get_string_attribute()
  int mv_create_engine_config(
    ffi.Pointer<mv_engine_config_h> engine_cfg,
  ) {
    return _mv_create_engine_config(
      engine_cfg,
    );
  }

  late final _mv_create_engine_configPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<mv_engine_config_h>)>>('mv_create_engine_config');
  late final _mv_create_engine_config = _mv_create_engine_configPtr
      .asFunction<int Function(ffi.Pointer<mv_engine_config_h>)>();

  /// @brief Destroys the engine configuration handle and releases all its
  /// resources.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in] engine_cfg    The handle to the engine configuration
  /// to be destroyed
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_h
  /// @see mv_create_engine_config()
  int mv_destroy_engine_config(
    mv_engine_config_h engine_cfg,
  ) {
    return _mv_destroy_engine_config(
      engine_cfg,
    );
  }

  late final _mv_destroy_engine_configPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mv_engine_config_h)>>(
          'mv_destroy_engine_config');
  late final _mv_destroy_engine_config = _mv_destroy_engine_configPtr
      .asFunction<int Function(mv_engine_config_h)>();

  /// @brief Sets the double attribute to the configuration.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in] engine_cfg        Engine configuration for which @a value has
  /// to be set
  /// @param [in] name              String key of the attribute will be used for
  /// storing the @a value into configuration
  /// dictionary
  /// @param [in] value             The double value of the attribute
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_KEY_NOT_AVAILABLE Attribute key isn't available
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_get_double_attribute()
  /// @see mv_engine_config_set_int_attribute()
  /// @see mv_engine_config_set_bool_attribute()
  /// @see mv_engine_config_set_string_attribute()
  int mv_engine_config_set_double_attribute(
    mv_engine_config_h engine_cfg,
    ffi.Pointer<ffi.Char> name,
    double value,
  ) {
    return _mv_engine_config_set_double_attribute(
      engine_cfg,
      name,
      value,
    );
  }

  late final _mv_engine_config_set_double_attributePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Double)>>('mv_engine_config_set_double_attribute');
  late final _mv_engine_config_set_double_attribute =
      _mv_engine_config_set_double_attributePtr.asFunction<
          int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>, double)>();

  /// @brief Sets the integer attribute to the configuration.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in] engine_cfg        Engine configuration for which @a value has
  /// to be set
  /// @param [in] name              String key of the attribute will be used for
  /// storing the @a value into configuration
  /// dictionary
  /// @param [in] value             The integer value of the attribute
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_KEY_NOT_AVAILABLE Attribute key isn't available
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_get_int_attribute()
  /// @see mv_engine_config_set_double_attribute()
  /// @see mv_engine_config_set_bool_attribute()
  /// @see mv_engine_config_set_string_attribute()
  /// @see mv_barcode_detect_attr_target_e
  /// @see mv_barcode_generate_attr_text_e
  int mv_engine_config_set_int_attribute(
    mv_engine_config_h engine_cfg,
    ffi.Pointer<ffi.Char> name,
    int value,
  ) {
    return _mv_engine_config_set_int_attribute(
      engine_cfg,
      name,
      value,
    );
  }

  late final _mv_engine_config_set_int_attributePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Int)>>('mv_engine_config_set_int_attribute');
  late final _mv_engine_config_set_int_attribute =
      _mv_engine_config_set_int_attributePtr.asFunction<
          int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Sets the boolean attribute to the configuration.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in] engine_cfg        Engine configuration for which @a value has
  /// to be set
  /// @param [in] name              String key of the attribute will be used for
  /// storing the @a value into configuration
  /// dictionary
  /// @param [in] value             The boolean value of the attribute
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_KEY_NOT_AVAILABLE Attribute key isn't available
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_get_bool_attribute()
  /// @see mv_engine_config_set_double_attribute()
  /// @see mv_engine_config_set_int_attribute()
  /// @see mv_engine_config_set_string_attribute()
  int mv_engine_config_set_bool_attribute(
    mv_engine_config_h engine_cfg,
    ffi.Pointer<ffi.Char> name,
    bool value,
  ) {
    return _mv_engine_config_set_bool_attribute(
      engine_cfg,
      name,
      value,
    );
  }

  late final _mv_engine_config_set_bool_attributePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Bool)>>('mv_engine_config_set_bool_attribute');
  late final _mv_engine_config_set_bool_attribute =
      _mv_engine_config_set_bool_attributePtr.asFunction<
          int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>, bool)>();

  /// @brief Sets the string attribute to the configuration.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in] engine_cfg        Engine configuration for which @a value has
  /// to be set
  /// @param [in] name              String key of the attribute will be used for
  /// storing the @a value into configuration
  /// dictionary
  /// @param [in] value             The string value of the attribute
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_KEY_NOT_AVAILABLE Attribute key isn't available
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_get_string_attribute()
  /// @see mv_engine_config_set_double_attribute()
  /// @see mv_engine_config_set_int_attribute()
  /// @see mv_engine_config_set_bool_attribute()
  int mv_engine_config_set_string_attribute(
    mv_engine_config_h engine_cfg,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _mv_engine_config_set_string_attribute(
      engine_cfg,
      name,
      value,
    );
  }

  late final _mv_engine_config_set_string_attributePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('mv_engine_config_set_string_attribute');
  late final _mv_engine_config_set_string_attribute =
      _mv_engine_config_set_string_attributePtr.asFunction<
          int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the double attribute from the configuration dictionary.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in] engine_cfg        Engine configuration from which @a value
  /// has to be gotten
  /// @param [in] name              String key of the attribute will be used for
  /// getting the @a value from the
  /// configuration dictionary
  /// @param [out] value            The attribute to be filled with double value
  /// from dictionary
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_KEY_NOT_AVAILABLE Attribute key isn't available
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_set_double_attribute()
  /// @see mv_engine_config_get_int_attribute()
  /// @see mv_engine_config_get_bool_attribute()
  /// @see mv_engine_config_get_string_attribute()
  int mv_engine_config_get_double_attribute(
    mv_engine_config_h engine_cfg,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Double> value,
  ) {
    return _mv_engine_config_get_double_attribute(
      engine_cfg,
      name,
      value,
    );
  }

  late final _mv_engine_config_get_double_attributePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Double>)>>(
      'mv_engine_config_get_double_attribute');
  late final _mv_engine_config_get_double_attribute =
      _mv_engine_config_get_double_attributePtr.asFunction<
          int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Double>)>();

  /// @brief Gets the integer attribute from the configuration dictionary.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in] engine_cfg        Engine configuration from which @a value
  /// has to be gotten
  /// @param [in] name              String key of the attribute will be used for
  /// getting the @a value from the
  /// configuration dictionary
  /// @param [out] value            The attribute to be filled with integer value
  /// from dictionary
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_KEY_NOT_AVAILABLE Attribute key isn't available
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_set_int_attribute()
  /// @see mv_engine_config_get_double_attribute()
  /// @see mv_engine_config_get_bool_attribute()
  /// @see mv_engine_config_get_string_attribute()
  /// @see mv_barcode_detect_attr_target_e
  /// @see mv_barcode_generate_attr_text_e
  int mv_engine_config_get_int_attribute(
    mv_engine_config_h engine_cfg,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _mv_engine_config_get_int_attribute(
      engine_cfg,
      name,
      value,
    );
  }

  late final _mv_engine_config_get_int_attributePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('mv_engine_config_get_int_attribute');
  late final _mv_engine_config_get_int_attribute =
      _mv_engine_config_get_int_attributePtr.asFunction<
          int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the boolean attribute from the configuration dictionary.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in] engine_cfg        Engine configuration from which @a value
  /// has to be gotten
  /// @param [in] name              String key of the attribute will be used for
  /// getting the @a value from the
  /// configuration dictionary
  /// @param [out] value            The attribute to be filled with boolean value
  /// from dictionary
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_KEY_NOT_AVAILABLE Attribute key isn't available
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_set_bool_attribute()
  /// @see mv_engine_config_get_double_attribute()
  /// @see mv_engine_config_get_int_attribute()
  /// @see mv_engine_config_get_string_attribute()
  int mv_engine_config_get_bool_attribute(
    mv_engine_config_h engine_cfg,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Bool> value,
  ) {
    return _mv_engine_config_get_bool_attribute(
      engine_cfg,
      name,
      value,
    );
  }

  late final _mv_engine_config_get_bool_attributePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('mv_engine_config_get_bool_attribute');
  late final _mv_engine_config_get_bool_attribute =
      _mv_engine_config_get_bool_attributePtr.asFunction<
          int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the string attribute from the configuration dictionary.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @remarks Function allocates memory required for output @a value, so
  /// it has to be removed by the user himself.
  /// @param [in] engine_cfg        Engine configuration from which @a value
  /// has to be gotten
  /// @param [in] name              String key of the attribute will be used for
  /// getting the @a value from the
  /// configuration dictionary
  /// @param [out] value            The attribute to be filled with string value
  /// from dictionary
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_KEY_NOT_AVAILABLE Attribute key isn't available
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_set_string_attribute()
  /// @see mv_engine_config_get_double_attribute()
  /// @see mv_engine_config_get_int_attribute()
  /// @see mv_engine_config_get_bool_attribute()
  int mv_engine_config_get_string_attribute(
    mv_engine_config_h engine_cfg,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _mv_engine_config_get_string_attribute(
      engine_cfg,
      name,
      value,
    );
  }

  late final _mv_engine_config_get_string_attributePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mv_engine_config_get_string_attribute');
  late final _mv_engine_config_get_string_attribute =
      _mv_engine_config_get_string_attributePtr.asFunction<
          int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Traverses the list of supported attribute names and types.
  /// @details Using this function names of supported attributes can be obtained.
  /// Names of the attributes can be used with @ref mv_engine_config_h
  /// related getters and setters to get/set appropriate attribute values.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @remarks If @a callback is called zero times after
  /// @ref mv_engine_config_foreach_supported_attribute() call, then
  /// engine configuration is not supported and setting of attributes will
  /// cause no effect. In this case for all Media Vision functions which
  /// require @ref mv_engine_config_h handle as in parameter this
  /// parameter can be set NULL.
  /// @remarks If @a callback is called at least once, then attribute names and
  /// types obtained in the @ref mv_supported_attribute_cb callback can be
  /// changed after mv_engine_config_h handle creation (with
  /// @ref mv_create_engine_config() function) by corresponding setters.
  /// Although, if attributes aren't changed by setters, then default
  /// values will be used.\n
  /// Changing of attribute values will affect internal functionality
  /// provided by concrete library underlying Media Vision API.
  /// @param [in] callback     The iteration callback function
  /// @param [in] user_data    The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_NO_DATA Can't determine list of supported attributes
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_engine_config_set_double_attribute()
  /// @see mv_engine_config_set_int_attribute()
  /// @see mv_engine_config_set_bool_attribute()
  /// @see mv_engine_config_set_string_attribute()
  /// @see mv_engine_config_get_double_attribute()
  /// @see mv_engine_config_get_int_attribute()
  /// @see mv_engine_config_get_bool_attribute()
  /// @see mv_engine_config_get_string_attribute()
  int mv_engine_config_foreach_supported_attribute(
    mv_supported_attribute_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_engine_config_foreach_supported_attribute(
      callback,
      user_data,
    );
  }

  late final _mv_engine_config_foreach_supported_attributePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mv_supported_attribute_cb, ffi.Pointer<ffi.Void>)>>(
      'mv_engine_config_foreach_supported_attribute');
  late final _mv_engine_config_foreach_supported_attribute =
      _mv_engine_config_foreach_supported_attributePtr.asFunction<
          int Function(mv_supported_attribute_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Detects barcode(s) on source and reads message from it.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @param [in] source            The media source handle
  /// @param [in] engine_cfg        The handle to the configuration of the engine
  /// @param [in] roi               Region of interest - rectangular area on the
  /// @a source which will be used for barcode detection
  /// Note that @a roi should be inside area on the
  /// @a source.
  /// @param [in] detect_cb         The callback for result handling
  /// @param [in] user_data    The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Not supported format
  /// @retval #MEDIA_VISION_ERROR_INTERNAL Internal error
  ///
  /// @pre Create a source handle by calling @ref mv_create_source()
  /// @pre Create an engine configuration handle by calling
  /// @ref mv_create_engine_config(), otherwise use NULL
  ///
  /// @see mv_barcode_detected_cb()
  int mv_barcode_detect(
    mv_source_h source,
    mv_engine_config_h engine_cfg,
    mv_rectangle_s roi,
    mv_barcode_detected_cb detect_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_barcode_detect(
      source,
      engine_cfg,
      roi,
      detect_cb,
      user_data,
    );
  }

  late final _mv_barcode_detectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_source_h,
              mv_engine_config_h,
              mv_rectangle_s,
              mv_barcode_detected_cb,
              ffi.Pointer<ffi.Void>)>>('mv_barcode_detect');
  late final _mv_barcode_detect = _mv_barcode_detectPtr.asFunction<
      int Function(mv_source_h, mv_engine_config_h, mv_rectangle_s,
          mv_barcode_detected_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Generates @ref mv_source_h with barcode image.
  /// @details Pay attention that for EAN-8 and EAN-13 barcode types the barcode
  /// type may be selected automatically and this selection depends on the input
  /// message length. Also for QR codes the version may be selected as minimum
  /// required to generate QR code with the input message length.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @remarks If the text attribute of engine configuration is set to
  /// MV_BARCODE_GENERATE_ATTR_TEXT_VISIBLE,
  /// MEDIA_VISION_ERROR_INVALID_OPERATION will be return
  /// when @a type is MV_BARCODE_QR
  ///
  /// @param [in]  engine_cfg      The handle to the configuration of the engine
  /// @param [in]  message         The message to be encoded in the barcode
  /// @param [in]  type            Type of the barcode to be generated
  /// @param [in]  qr_enc_mode     Encoding mode for the message (only for QR codes;
  /// for 1D barcodes set this parameter to
  /// @a MV_BARCODE_QR_MODE_UNAVAILABLE)
  /// @param [in]  qr_ecc          Error correction level (only for QR codes; for
  /// 1D barcodes set this parameter to
  /// @a MV_BARCODE_QR_ECC_UNAVAILABLE)
  /// @param [in]  qr_version      QR code version (for 1D barcodes set this
  /// parameter to 0)
  /// @param [in, out] image       The media source handle which will be used to
  /// fill by the buffer with generated image
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_MSG_TOO_LONG Too long or short message
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  /// @retval #MEDIA_VISION_ERROR_INVALID_DATA Invalid data
  /// @retval #MEDIA_VISION_ERROR_INTERNAL Internal error
  /// @retval #MEDIA_VISION_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Create an engine configuration handle by calling
  /// @ref mv_create_engine_config(), otherwise use NULL
  ///
  /// @see mv_barcode_generate_image()
  int mv_barcode_generate_source(
    mv_engine_config_h engine_cfg,
    ffi.Pointer<ffi.Char> message,
    int type,
    int qr_enc_mode,
    int qr_ecc,
    int qr_version,
    mv_source_h image,
  ) {
    return _mv_barcode_generate_source(
      engine_cfg,
      message,
      type,
      qr_enc_mode,
      qr_ecc,
      qr_version,
      image,
    );
  }

  late final _mv_barcode_generate_sourcePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_engine_config_h,
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Int32,
              ffi.Int32,
              ffi.Int,
              mv_source_h)>>('mv_barcode_generate_source');
  late final _mv_barcode_generate_source =
      _mv_barcode_generate_sourcePtr.asFunction<
          int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>, int, int, int,
              int, mv_source_h)>();

  /// @brief Generates image file with barcode.
  /// @details Pay attention that for EAN-8 and EAN-13 barcode types the barcode
  /// type may be selected automatically and this selection depends on the input
  /// message length. Also for QR codes the version may be selected as minimum
  /// required to generate QR code with the input message length.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @remarks If the text attribute of engine configuration is set to
  /// MV_BARCODE_GENERATE_ATTR_TEXT_VISIBLE,
  /// MEDIA_VISION_ERROR_INVALID_OPERATION will be return
  /// when @a type is MV_BARCODE_QR
  ///
  /// @remarks The mediastorage privilege http://tizen.org/privilege/mediastorage is needed \n
  /// if @a image_path is relevant to media storage.\n
  /// The externalstorage privilege http://tizen.org/privilege/externalstorage is needed \n
  /// if @a image_path is relevant to external storage.
  /// @param [in] engine_cfg      The handle to the configuration of the engine
  /// @param [in] message         The message to be encoded in the barcode
  /// @param [in] image_width     The width of the generated image
  /// @param [in] image_height    The height of the generated image
  /// @param [in] type            Type of the barcode to be generated
  /// @param [in] qr_enc_mode     Encoding mode for the message (only for QR codes;
  /// for 1D barcodes set this parameter to
  /// @a MV_BARCODE_QR_MODE_UNAVAILABLE)
  /// @param [in] qr_ecc          Error correction level (only for QR codes; for
  /// 1D barcodes set this parameter to
  /// @a MV_BARCODE_QR_ECC_UNAVAILABLE)
  /// @param [in] qr_version      QR code version (for 1D barcodes set this
  /// parameter to 0)
  /// @param [in] image_path      The path to the file that has to be generated
  /// @param [in] image_format    The format of the output image
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_MSG_TOO_LONG Too long or short message
  /// @retval #MEDIA_VISION_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  /// @retval #MEDIA_VISION_ERROR_INVALID_DATA Invalid data
  /// @retval #MEDIA_VISION_ERROR_INVALID_PATH Invalid path
  /// @retval #MEDIA_VISION_ERROR_INTERNAL Internal error
  /// @retval #MEDIA_VISION_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Create an engine configuration handle by calling
  /// @ref mv_create_engine_config(), otherwise use NULL
  ///
  /// @see mv_barcode_generate_source()
  int mv_barcode_generate_image(
    mv_engine_config_h engine_cfg,
    ffi.Pointer<ffi.Char> message,
    int image_width,
    int image_height,
    int type,
    int qr_enc_mode,
    int qr_ecc,
    int qr_version,
    ffi.Pointer<ffi.Char> image_path,
    int image_format,
  ) {
    return _mv_barcode_generate_image(
      engine_cfg,
      message,
      image_width,
      image_height,
      type,
      qr_enc_mode,
      qr_ecc,
      qr_version,
      image_path,
      image_format,
    );
  }

  late final _mv_barcode_generate_imagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_engine_config_h,
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Int,
              ffi.Int32,
              ffi.Int32,
              ffi.Int32,
              ffi.Int,
              ffi.Pointer<ffi.Char>,
              ffi.Int32)>>('mv_barcode_generate_image');
  late final _mv_barcode_generate_image =
      _mv_barcode_generate_imagePtr.asFunction<
          int Function(mv_engine_config_h, ffi.Pointer<ffi.Char>, int, int, int,
              int, int, int, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Performs face detection on the @a source for the @a engine_conf.
  /// @details Use this function to launch face detection algorithm configured by
  /// @a engine_conf configuration. Each time when mv_face_detect is
  /// called, @a detected_cb will receive a set of the detected
  /// faces at the media source.
  ///
  /// @since_tizen 3.0
  /// @param [in] source         The handle to the source of the media where faces
  /// will be detected
  /// @param [in] engine_cfg     The handle to the configuration of engine will be
  /// used for detecting. If NULL, then default settings
  /// will be used.
  /// @param [in] detected_cb    The callback which will be called for all face
  /// locations detected on media source. This callback
  /// will receive detecting results
  /// @param [in] user_data      The user data passed from the code where
  /// @ref mv_face_detect() is invoked. This data will
  /// be accessible from @a detected_cb callback.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Source colorspace
  /// isn't supported
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a source handle by calling @ref mv_create_source()
  /// @post @a detected_cb will be called to process detection results
  ///
  /// @see mv_face_detected_cb
  int mv_face_detect(
    mv_source_h source,
    mv_engine_config_h engine_cfg,
    mv_face_detected_cb detected_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_face_detect(
      source,
      engine_cfg,
      detected_cb,
      user_data,
    );
  }

  late final _mv_face_detectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_source_h, mv_engine_config_h, mv_face_detected_cb,
              ffi.Pointer<ffi.Void>)>>('mv_face_detect');
  late final _mv_face_detect = _mv_face_detectPtr.asFunction<
      int Function(mv_source_h, mv_engine_config_h, mv_face_detected_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Performs face recognition on the @a source image.
  /// @details Use this function to launch face recognition algorithm configured by
  /// @a engine_conf configuration using @a recognition_model recognition
  /// model. Each time when @ref mv_face_recognize() is called,
  /// @a recognized_cb will receive recognition results:\n
  /// - Location in the @a source of the face has been recognized;
  /// - Label of the face has been recognized;
  /// - Confidence of the @a recognition_model that face has been
  /// recognized correctly (value from 0.0 to 1.0).
  ///
  /// @since_tizen 3.0
  /// @remarks Using of untrained or weakly trained recognition models will cause
  /// not accurate results even if resulting confidence will be high.
  /// Use @ref mv_face_recognition_model_learn() function before
  /// @ref mv_face_recognize() call. Best results can be achieved when big
  /// set of face image examples were added by
  /// @ref mv_face_recognition_model_add() before
  /// @ref mv_face_recognition_model_learn() call.
  /// @param [in] source              The handle to the source of the media to
  /// recognize face(s) for
  /// @param [in] recognition_model   The handle to the model will be used for
  /// recognition
  /// @param [in] engine_cfg          The handle to the configuration of engine
  /// will be used for recognition. If NULL, then
  /// default settings will be used
  /// @param [in] face_location       Rectangular box bounding face image on the
  /// @a source. If NULL, then full source will be
  /// analyzed
  /// @param [in] recognized_cb       The callback which will be called for the
  /// face recognition results on the @a source.
  /// @param [in] user_data           The user data passed from the code where
  /// @ref mv_face_recognize() is invoked. This
  /// data will be accessible from @a recognized_cb
  /// callback
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Source colorspace
  /// isn't supported
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a source handle by calling @ref mv_create_source()
  /// @pre Create a face recognition model handle by calling
  /// @ref mv_face_recognition_model_create()
  /// @post @a recognized_cb will be called to process recognition results
  ///
  /// @see mv_face_recognized_cb
  int mv_face_recognize(
    mv_source_h source,
    mv_face_recognition_model_h recognition_model,
    mv_engine_config_h engine_cfg,
    ffi.Pointer<mv_rectangle_s> face_location,
    mv_face_recognized_cb recognized_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_face_recognize(
      source,
      recognition_model,
      engine_cfg,
      face_location,
      recognized_cb,
      user_data,
    );
  }

  late final _mv_face_recognizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_source_h,
              mv_face_recognition_model_h,
              mv_engine_config_h,
              ffi.Pointer<mv_rectangle_s>,
              mv_face_recognized_cb,
              ffi.Pointer<ffi.Void>)>>('mv_face_recognize');
  late final _mv_face_recognize = _mv_face_recognizePtr.asFunction<
      int Function(
          mv_source_h,
          mv_face_recognition_model_h,
          mv_engine_config_h,
          ffi.Pointer<mv_rectangle_s>,
          mv_face_recognized_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Performs face tracking on the @a source for the @a tracking_model.
  /// @details Use this function to launch face tracking algorithm configured by
  /// @a engine_conf configuration using @a tracking_model tracking
  /// model. Each time when this function is called, @a tracked_cb
  /// will receive updated @a tracking_model, new location determined for
  /// the tracked face and model confidence that location is determined
  /// correctly.
  ///
  /// @since_tizen 3.0
  /// @remarks To allow correct tracking @a tracking_model has to be already used
  /// in previous tracking process(es) or prepared with
  /// @ref mv_face_tracking_model_prepare(). Preparation requires
  /// specifying the face location for the @a source on which tracking was
  /// started. I.e. @ref mv_face_tracking_model_prepare() function has to
  /// be called at least once before this method call.
  /// @param [in] source           The handle to the source of the media to
  /// recognize face for
  /// @param [in] tracking_model   The handle to the model will be used for
  /// tracking
  /// @param [in] engine_cfg       The handle to the configuration of engine will
  /// be used for tracking. If NULL, the default
  /// configuration will be used.
  /// @param [in] tracked_cb       The callback which will be called for tracking
  /// event on the @a source where face would be
  /// tracked. This callback will receive tracking
  /// results
  /// @param [in] do_learn         The model learning flag. If it is set @c true
  /// then model will try to learn (if it supports
  /// learning feature), otherwise model will be not
  /// learned during the invoking tracking iteration.
  /// Learning process improves tracking correctness,
  /// but can decrease tracking performance
  /// @param [in] user_data        The user data passed from the code where
  /// @ref mv_face_track() is invoked. This data will
  /// be accessible from @a tracked_cb callback
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Source colorspace
  /// isn't supported
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a source handle by calling @ref mv_create_source()
  /// @pre Create a face tracking model handle by calling
  /// @ref mv_face_tracking_model_create()
  /// @post @a tracked_cb will be called to process tracking results
  ///
  /// @see mv_face_tracked_cb
  int mv_face_track(
    mv_source_h source,
    mv_face_tracking_model_h tracking_model,
    mv_engine_config_h engine_cfg,
    mv_face_tracked_cb tracked_cb,
    bool do_learn,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_face_track(
      source,
      tracking_model,
      engine_cfg,
      tracked_cb,
      do_learn,
      user_data,
    );
  }

  late final _mv_face_trackPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_source_h,
              mv_face_tracking_model_h,
              mv_engine_config_h,
              mv_face_tracked_cb,
              ffi.Bool,
              ffi.Pointer<ffi.Void>)>>('mv_face_track');
  late final _mv_face_track = _mv_face_trackPtr.asFunction<
      int Function(mv_source_h, mv_face_tracking_model_h, mv_engine_config_h,
          mv_face_tracked_cb, bool, ffi.Pointer<ffi.Void>)>();

  /// @brief Determines eye-blink condition for @a face_location on media @a source.
  /// @details Use this function to recognize eye-blink condition for the face
  /// bounded by @a face_location at @a source.
  ///
  /// @since_tizen 3.0
  /// @param [in] source           The handle to the source of the media to
  /// recognize eye-blink condition for
  /// @param [in] engine_cfg       The handle to the configuration of engine
  /// will be used for eye-blink condition
  /// recognition. If NULL, the default configuration
  /// will be used.
  /// @param [in] face_location    The location bounding the face at the @a source
  /// @param [in] eye_condition_recognized_cb    The callback for processing result
  /// of eye-blink condition recognition
  /// @param [in] user_data        The user data passed from the code where
  /// mv_face_eye_condition_recognize() is invoked.
  /// This data will be accessible from
  /// @a eye_condition_recognized_cb callback.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Source colorspace
  /// isn't supported
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a source handle by calling mv_create_source()
  ///
  /// @see mv_face_eye_condition_recognized_cb
  int mv_face_eye_condition_recognize(
    mv_source_h source,
    mv_engine_config_h engine_cfg,
    mv_rectangle_s face_location,
    mv_face_eye_condition_recognized_cb eye_condition_recognized_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_face_eye_condition_recognize(
      source,
      engine_cfg,
      face_location,
      eye_condition_recognized_cb,
      user_data,
    );
  }

  late final _mv_face_eye_condition_recognizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_source_h,
              mv_engine_config_h,
              mv_rectangle_s,
              mv_face_eye_condition_recognized_cb,
              ffi.Pointer<ffi.Void>)>>('mv_face_eye_condition_recognize');
  late final _mv_face_eye_condition_recognize =
      _mv_face_eye_condition_recognizePtr.asFunction<
          int Function(mv_source_h, mv_engine_config_h, mv_rectangle_s,
              mv_face_eye_condition_recognized_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Determines facial expression for @a face_location on media @a source.
  /// @details Use this function to determine facial expression for the face
  /// bounded by @a face_location at @a source.
  ///
  /// @since_tizen 3.0
  /// @param [in] source           The handle to the source of the media
  /// to recognize facial expression for
  /// @param [in] engine_cfg       The handle to the configuration of
  /// engine will be used for expression recognition
  /// @param [in] face_location    The location bounding the face at the @a source
  /// @param [in] expression_recognized_cb   The callback for processing result
  /// of facial expression determining
  /// @param [in] user_data        The user data passed from the code where
  /// mv_face_facial_expression_recognize() is invoked.
  /// This data will be accessible from
  /// @a expression_recognized_cb callback.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Source colorspace
  /// isn't supported
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a source handle by calling mv_create_source()
  /// @pre Create a face engine configuration handle by calling @ref mv_create_engine_config()
  ///
  /// @see mv_face_facial_expression_recognized_cb
  int mv_face_facial_expression_recognize(
    mv_source_h source,
    mv_engine_config_h engine_cfg,
    mv_rectangle_s face_location,
    mv_face_facial_expression_recognized_cb expression_recognized_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_face_facial_expression_recognize(
      source,
      engine_cfg,
      face_location,
      expression_recognized_cb,
      user_data,
    );
  }

  late final _mv_face_facial_expression_recognizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_source_h,
              mv_engine_config_h,
              mv_rectangle_s,
              mv_face_facial_expression_recognized_cb,
              ffi.Pointer<ffi.Void>)>>('mv_face_facial_expression_recognize');
  late final _mv_face_facial_expression_recognize =
      _mv_face_facial_expression_recognizePtr.asFunction<
          int Function(
              mv_source_h,
              mv_engine_config_h,
              mv_rectangle_s,
              mv_face_facial_expression_recognized_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Creates a face recognition model handle.
  /// @details Use this function to create default face recognition model. Creating
  /// process is defined by concrete face engine library. After creation
  /// recognition model has to be learned with
  /// @ref mv_face_recognition_model_learn() function to provide
  /// appropriate results of face recognition functionality. Or learned
  /// earlier model can be loaded by @ref mv_face_recognition_model_load()
  /// function.
  ///
  /// @since_tizen 3.0
  /// @remarks It can cause incompatibility issues when saved models (see
  /// @ref mv_face_recognition_model_save(),
  /// @ref mv_face_recognition_model_load()
  /// functions documentation) are used in applications for different
  /// platforms which use different computer vision libraries underlying
  /// this API.
  /// @remarks You must release @a recognition_model by using
  /// @ref mv_face_recognition_model_destroy() function.
  /// @param [out] recognition_model    The handle to the recognition model to be
  /// created
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @post Model can be loaded from the file after creation. Use
  /// @ref mv_face_recognition_model_load() function to load it from file
  /// @post Release @a recognition_model by using
  /// @ref mv_face_recognition_model_destroy() function when it is not needed
  /// anymore
  ///
  /// @see mv_face_recognition_model_destroy()
  int mv_face_recognition_model_create(
    ffi.Pointer<mv_face_recognition_model_h> recognition_model,
  ) {
    return _mv_face_recognition_model_create(
      recognition_model,
    );
  }

  late final _mv_face_recognition_model_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<mv_face_recognition_model_h>)>>(
      'mv_face_recognition_model_create');
  late final _mv_face_recognition_model_create =
      _mv_face_recognition_model_createPtr
          .asFunction<int Function(ffi.Pointer<mv_face_recognition_model_h>)>();

  /// @brief Destroys the face recognition model handle and releases all its
  /// resources.
  ///
  /// @since_tizen 3.0
  /// @param [in] recognition_model    The handle to the face recognition model to
  /// be destroyed
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create recognition model by using @ref mv_face_recognition_model_create()
  ///
  /// @see mv_face_recognition_model_create()
  int mv_face_recognition_model_destroy(
    mv_face_recognition_model_h recognition_model,
  ) {
    return _mv_face_recognition_model_destroy(
      recognition_model,
    );
  }

  late final _mv_face_recognition_model_destroyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(mv_face_recognition_model_h)>>(
      'mv_face_recognition_model_destroy');
  late final _mv_face_recognition_model_destroy =
      _mv_face_recognition_model_destroyPtr
          .asFunction<int Function(mv_face_recognition_model_h)>();

  /// @brief Creates a copy of existed recognition model handle and clones all its
  /// resources.
  ///
  /// @since_tizen 3.0
  /// @remarks Cloning perform not only handle copy, but also copies all internal
  /// resources of the model. @a dst must be released using
  /// @ref mv_face_recognition_model_destroy().
  /// @param [in]     src    The handle to the recognition model to be copied
  /// @param [out]    dst    The handle to the copy of existed recognition model
  /// specified as @a src
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create face recognition handles by calling
  /// @ref mv_face_recognition_model_create()
  ///
  /// @see mv_face_recognition_model_create()
  int mv_face_recognition_model_clone(
    mv_face_recognition_model_h src,
    ffi.Pointer<mv_face_recognition_model_h> dst,
  ) {
    return _mv_face_recognition_model_clone(
      src,
      dst,
    );
  }

  late final _mv_face_recognition_model_clonePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_face_recognition_model_h,
                  ffi.Pointer<mv_face_recognition_model_h>)>>(
      'mv_face_recognition_model_clone');
  late final _mv_face_recognition_model_clone =
      _mv_face_recognition_model_clonePtr.asFunction<
          int Function(mv_face_recognition_model_h,
              ffi.Pointer<mv_face_recognition_model_h>)>();

  /// @brief Saves recognition model to the file.
  ///
  /// @since_tizen 3.0
  /// @remarks This function doesn't save face image examples (image itself) added by
  /// @ref mv_face_recognition_model_add() function.
  /// This examples can be removed by
  /// @ref mv_face_recognition_model_reset() function if
  /// it is needed to clear the memory.
  /// @remarks @a recognition_model is saved to the absolute path directory.
  /// Use @ref app_get_data_path for the private app storage path.
  /// After model is saved to the file, it can be loaded from this file
  /// by @ref mv_face_recognition_model_load() function.
  /// @param [in] file_name            Name of the path/file to save the model
  /// @param [in] recognition_model    The handle to the recognition model to be
  /// saved to the file
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_VISION_ERROR_INVALID_PATH Invalid path
  /// @retval #MEDIA_VISION_ERROR_PERMISSION_DENIED Not permitted
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Not supported model format
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a face recognition handle by calling
  /// @ref mv_face_recognition_model_create() function
  /// @post Saved model can be loaded later by calling
  /// @ref mv_face_recognition_model_load() function
  ///
  /// @see mv_face_recognition_model_load()
  /// @see mv_face_recognition_model_create()
  /// @see app_get_data_path()
  int mv_face_recognition_model_save(
    ffi.Pointer<ffi.Char> file_name,
    mv_face_recognition_model_h recognition_model,
  ) {
    return _mv_face_recognition_model_save(
      file_name,
      recognition_model,
    );
  }

  late final _mv_face_recognition_model_savePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              mv_face_recognition_model_h)>>('mv_face_recognition_model_save');
  late final _mv_face_recognition_model_save =
      _mv_face_recognition_model_savePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, mv_face_recognition_model_h)>();

  /// @brief Loads recognition model from file.
  ///
  /// @since_tizen 3.0
  /// @remarks This function doesn't modify the set of face image examples added
  /// with @ref mv_face_recognition_model_add() function.
  /// Model will be loaded from file without loss of collected examples.
  /// If you want to free memory from examples, use
  /// @ref mv_face_recognition_model_reset() function. It
  /// is recommended to clear the memory if learning algorithm doesn't
  /// support reinforcement learning.
  /// @remarks @a recognition_model is loaded from the absolute path directory.
  /// Use @ref app_get_data_path for the private app storage path.
  /// @a recognition_model must be destroyed using
  /// @ref mv_face_recognition_model_destroy().
  /// @param [in]  file_name            Name of path/file to load the model
  /// @param [out] recognition_model    The handle to the recognition model
  /// to be loaded from the file
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_PATH Invalid path
  /// @retval #MEDIA_VISION_ERROR_PERMISSION_DENIED Not permitted
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Not supported model format
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Recognition model can be preliminary saved with
  /// @ref mv_face_recognition_model_save() function
  ///
  /// @see mv_face_recognition_model_save()
  /// @see mv_face_recognition_model_destroy()
  /// @see app_get_data_path()
  int mv_face_recognition_model_load(
    ffi.Pointer<ffi.Char> file_name,
    ffi.Pointer<mv_face_recognition_model_h> recognition_model,
  ) {
    return _mv_face_recognition_model_load(
      file_name,
      recognition_model,
    );
  }

  late final _mv_face_recognition_model_loadPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>,
                  ffi.Pointer<mv_face_recognition_model_h>)>>(
      'mv_face_recognition_model_load');
  late final _mv_face_recognition_model_load =
      _mv_face_recognition_model_loadPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<mv_face_recognition_model_h>)>();

  /// @brief Adds face image example to be used for face recognition model learning
  /// with @ref mv_face_recognition_model_learn().
  ///
  /// @since_tizen 3.0
  /// @remarks It is possible to destroy @a source after calling this method.
  /// Source isn't used for learning directly.
  /// @remarks Face image @a example_location location can be determined using
  /// @ref mv_face_detect function.
  /// @param [in] source               The handle to @a source that contains face
  /// image
  /// @param [in] recognition_model    The handle to the recognition model which
  /// could be learned based on example
  /// @param [in] example_location     The pointer to the rectangular location of
  /// the face image at the source image. If NULL,
  /// then full image will be analyzed as the face
  /// image
  /// @param [in] face_label           The label that identifies face for which
  /// example is adding. Specify the same labels
  /// for the face images of a single person when
  /// calling this method. Has to be unique for
  /// each face
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Source colorspace
  /// isn't supported
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a face recognition handle by calling
  /// @ref mv_face_recognition_model_create() function
  /// @post When appropriate amount of face image examples is added to the
  /// @a recognition_model, this model has to be learned by
  /// @ref mv_face_recognition_model_learn() function call. Only after
  /// learning of the model it can be used for face recognition with
  /// @ref mv_face_recognize() function
  ///
  /// @see mv_face_recognition_model_reset()
  /// @see mv_face_recognition_model_learn()
  int mv_face_recognition_model_add(
    mv_source_h source,
    mv_face_recognition_model_h recognition_model,
    ffi.Pointer<mv_rectangle_s> example_location,
    int face_label,
  ) {
    return _mv_face_recognition_model_add(
      source,
      recognition_model,
      example_location,
      face_label,
    );
  }

  late final _mv_face_recognition_model_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_source_h,
              mv_face_recognition_model_h,
              ffi.Pointer<mv_rectangle_s>,
              ffi.Int)>>('mv_face_recognition_model_add');
  late final _mv_face_recognition_model_add =
      _mv_face_recognition_model_addPtr.asFunction<
          int Function(mv_source_h, mv_face_recognition_model_h,
              ffi.Pointer<mv_rectangle_s>, int)>();

  /// @brief Removes from @a recognition_model all collected with
  /// @ref mv_face_recognition_model_add() function
  /// face examples labeled with @a face_label.
  ///
  /// @since_tizen 3.0
  /// @remarks Be aware that if this function is called before
  /// @ref mv_face_recognition_model_learn() function call, all or part of
  /// the required for learning data will be lost. It means that face
  /// image examples determined by the @a face_label label will be removed
  /// from the model and not taken into account when
  /// @ref mv_face_recognition_model_learn() will be called next time.
  /// @remarks Call of this function will free all the memory has been allocated
  /// during previous @ref mv_face_recognition_model_add()
  /// calls for the corresponding @a face_label label.
  /// @param [in] recognition_model    The handle to the recognition model for
  /// which face image examples will be reset.
  /// @param [in] face_label           The label that identifies face for which
  /// examples will be removed from the
  /// @a recognition_model. If NULL, then all
  /// known by @a recognition_model face image
  /// examples will be removed
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_KEY_NOT_AVAILABLE Key not available
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_face_recognition_model_add()
  /// @see mv_face_recognition_model_learn()
  int mv_face_recognition_model_reset(
    mv_face_recognition_model_h recognition_model,
    ffi.Pointer<ffi.Int> face_label,
  ) {
    return _mv_face_recognition_model_reset(
      recognition_model,
      face_label,
    );
  }

  late final _mv_face_recognition_model_resetPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_face_recognition_model_h,
              ffi.Pointer<ffi.Int>)>>('mv_face_recognition_model_reset');
  late final _mv_face_recognition_model_reset =
      _mv_face_recognition_model_resetPtr.asFunction<
          int Function(mv_face_recognition_model_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Learns face recognition model.
  /// @details Before you start learning process, face recognition models has to be
  /// filled with training data - face image examples. These examples has
  /// to be provided by
  /// @ref mv_face_recognition_model_add() function.
  /// Usually, recognition accuracy is increased when number of not
  /// identical examples is large. But it depends on the used learning
  /// algorithm.
  ///
  /// @since_tizen 3.0
  /// @remarks Common flow is to collect face examples as much as possible, add
  /// them to the recognition model with
  /// @ref mv_face_recognition_model_add(), then call
  /// @ref mv_face_recognition_model_learn() for this recognition model to
  /// learn it (or update the model if updating is supported by the used
  /// algorithm).
  /// @remarks Selection of the learning algorithm can be performed by setting
  /// corresponding attributes for the @a engine_cfg. You can check
  /// supported by @a engine_cfg attributes using
  /// @ref mv_engine_config_foreach_supported_attribute() function call.
  /// By default, Local Binary Patterns Histograms (LBPH) based
  /// recognition algorithm will be used.
  /// @param [in]     engine_cfg           The handle to the configuration of
  /// engine will be used for learning of the
  /// recognition models. If NULL, then
  /// default settings will be used
  /// @param [in,out] recognition_model    The model which will be learned. After
  /// learning process these model may be
  /// changed, so @ref mv_face_recognize()
  /// results may differ before and after
  /// method call respectively to the face
  /// examples collected for the
  /// @a recognition_model
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NO_DATA No data
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a face engine configuration handle by calling
  /// @ref mv_create_engine_config() and set supported parameters if
  /// needed. Or just set @a engine_cfg as NULL to learn with default settings
  /// @pre Create a face recognition model handles by calling
  /// @ref mv_face_recognition_model_create() function
  /// @pre Add face image examples to the @a recognition_model by calling
  /// @ref mv_face_recognition_model_add() function
  /// @post If it is not planned to learn the model again, clear memory by
  /// @ref mv_face_recognition_model_reset() function
  /// @post When model has been learned, it can be used for face recognition with
  /// @ref mv_face_recognize() function
  ///
  /// @see mv_face_recognition_model_add()
  /// @see mv_face_recognition_model_reset()
  /// @see mv_face_recognize()
  int mv_face_recognition_model_learn(
    mv_engine_config_h engine_cfg,
    mv_face_recognition_model_h recognition_model,
  ) {
    return _mv_face_recognition_model_learn(
      engine_cfg,
      recognition_model,
    );
  }

  late final _mv_face_recognition_model_learnPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_engine_config_h,
              mv_face_recognition_model_h)>>('mv_face_recognition_model_learn');
  late final _mv_face_recognition_model_learn =
      _mv_face_recognition_model_learnPtr.asFunction<
          int Function(mv_engine_config_h, mv_face_recognition_model_h)>();

  /// @brief Queries labels list and number of labels had been learned by the model.
  ///
  /// @since_tizen 3.0
  /// @remarks @a labels array has to be released using free().
  /// @param [in]  recognition_model    The handle to the recognition model for
  /// which set of the learned labels will be
  /// queried
  /// @param [out] labels               The array which will be filled with labels
  /// had been learned by the model
  /// @param [out] number_of_labels     The number of labels in @a labels array
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Add face image examples with labels to the @a recognition_model by
  /// calling the @ref mv_face_recognition_model_add() function
  /// @pre Learn the @a recognition_model by labeled examples using
  /// @ref mv_face_recognition_model_learn() function
  /// @post @a labels array has to be freed in the function invoking code
  ///
  /// @see mv_face_recognition_model_add()
  /// @see mv_face_recognition_model_reset()
  /// @see mv_face_recognition_model_learn()
  int mv_face_recognition_model_query_labels(
    mv_face_recognition_model_h recognition_model,
    ffi.Pointer<ffi.Pointer<ffi.Int>> labels,
    ffi.Pointer<ffi.UnsignedInt> number_of_labels,
  ) {
    return _mv_face_recognition_model_query_labels(
      recognition_model,
      labels,
      number_of_labels,
    );
  }

  late final _mv_face_recognition_model_query_labelsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mv_face_recognition_model_h,
                  ffi.Pointer<ffi.Pointer<ffi.Int>>,
                  ffi.Pointer<ffi.UnsignedInt>)>>(
      'mv_face_recognition_model_query_labels');
  late final _mv_face_recognition_model_query_labels =
      _mv_face_recognition_model_query_labelsPtr.asFunction<
          int Function(
              mv_face_recognition_model_h,
              ffi.Pointer<ffi.Pointer<ffi.Int>>,
              ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Calls this function to create a face tracking model handle.
  /// @details Use this function to create default face tracking model handle.
  /// After creation this handle has to be initialized with
  /// @ref mv_face_tracking_model_prepare() function to provide
  /// appropriate results of face tracking functionality. When handle is
  /// prepared, it is possible to use it for tracking on continuous
  /// sequence of the sources. Call @ref mv_face_tracking_model_prepare()
  /// function each time before starting tracking on the new sequence.
  /// The exception is situation when the new sequence is continuation
  /// of the previous sequence for which model has been tracked.
  ///
  /// @since_tizen 3.0
  /// @param [out] tracking_model    The pointer to the handle to the tracking
  /// model that will be created
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @post Model can be loaded from the file after creation. Use
  /// @ref mv_face_tracking_model_load() function to load it from file
  /// @post Use @ref mv_face_tracking_model_prepare() function before tracking on
  /// the new video or continuous images sequence
  /// @post Release @a tracking_model by using
  /// @ref mv_face_tracking_model_destroy() function when it is not needed
  /// anymore
  ///
  /// @see mv_face_tracking_model_destroy()
  /// @see mv_face_tracking_model_prepare()
  /// @see mv_face_tracking_model_load()
  int mv_face_tracking_model_create(
    ffi.Pointer<mv_face_tracking_model_h> tracking_model,
  ) {
    return _mv_face_tracking_model_create(
      tracking_model,
    );
  }

  late final _mv_face_tracking_model_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<mv_face_tracking_model_h>)>>(
      'mv_face_tracking_model_create');
  late final _mv_face_tracking_model_create = _mv_face_tracking_model_createPtr
      .asFunction<int Function(ffi.Pointer<mv_face_tracking_model_h>)>();

  /// @brief Calls this function to destroy the face tracking model handle and
  /// release all its resources.
  ///
  /// @since_tizen 3.0
  /// @param [in] tracking_model    The handle to the face tracking model that
  /// will be destroyed
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create tracking model by using @ref mv_face_tracking_model_create()
  ///
  /// @see mv_face_tracking_model_create()
  int mv_face_tracking_model_destroy(
    mv_face_tracking_model_h tracking_model,
  ) {
    return _mv_face_tracking_model_destroy(
      tracking_model,
    );
  }

  late final _mv_face_tracking_model_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mv_face_tracking_model_h)>>(
          'mv_face_tracking_model_destroy');
  late final _mv_face_tracking_model_destroy =
      _mv_face_tracking_model_destroyPtr
          .asFunction<int Function(mv_face_tracking_model_h)>();

  /// @brief Calls this function to initialize tracking model by the location of the
  /// face to be tracked.
  /// @details This function is usually called once after tracking model is created
  /// and each time before tracking is started for the new sequence of
  /// sources which is not the direct continuation of the sequence for
  /// which tracking has been performed before. But it is allowed to call
  /// it between tracking sessions to allow Media Vision start to track
  /// more accurately.
  ///
  /// @since_tizen 3.0
  /// @param [in] tracking_model    The handle to the tracking model that will be
  /// prepared for tracking on new video or image
  /// sequence
  /// @param [in] engine_cfg        The handle to the configuration of engine
  /// will be used for model preparing. If NULL, then
  /// default settings will be used.
  /// @param [in] source            The handle to the source where face @a location
  /// is specified. Usually it is the first frame of
  /// the video or the first image in the continuous
  /// image sequence planned to be used for tracking
  /// @param [in] location          The quadrangle-shaped location (actually,
  /// rectangle can be used) determining position
  /// of the face to be tracked on the @a source. If
  /// @c NULL, then tracking model will try to find
  /// previously tracked face by itself. Don't set
  /// NULL when called first time for the tracking
  /// model.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a face tracking model handle by calling
  /// @ref mv_face_tracking_model_create() function
  /// @pre Create a source handle by calling @ref mv_create_source() function
  /// @post When model is prepared, @ref mv_face_track() function can be used to
  /// track on the video or continuous image sequence
  ///
  /// @see mv_face_tracking_model_create()
  /// @see mv_face_track()
  int mv_face_tracking_model_prepare(
    mv_face_tracking_model_h tracking_model,
    mv_engine_config_h engine_cfg,
    mv_source_h source,
    ffi.Pointer<mv_quadrangle_s> location,
  ) {
    return _mv_face_tracking_model_prepare(
      tracking_model,
      engine_cfg,
      source,
      location,
    );
  }

  late final _mv_face_tracking_model_preparePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_face_tracking_model_h,
              mv_engine_config_h,
              mv_source_h,
              ffi.Pointer<mv_quadrangle_s>)>>('mv_face_tracking_model_prepare');
  late final _mv_face_tracking_model_prepare =
      _mv_face_tracking_model_preparePtr.asFunction<
          int Function(mv_face_tracking_model_h, mv_engine_config_h,
              mv_source_h, ffi.Pointer<mv_quadrangle_s>)>();

  /// @brief Calls this function to make a copy of existed tracking model handle and
  /// clone all its resources to the copy.
  ///
  /// @since_tizen 3.0
  /// @remarks Cloning performs not only handle copy, but also copies all internal
  /// resources of the model. @a dst must be released using
  /// mv_face_tracking_model_destroy().
  /// @param [in]     src    The handle to the tracking model to be copied
  /// @param [out]    dst    The handle to the copy of existed tracking model
  /// specified as @a src
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create face tracking @a src handle by calling
  /// @ref mv_face_tracking_model_create()
  ///
  /// @see mv_face_tracking_model_create()
  int mv_face_tracking_model_clone(
    mv_face_tracking_model_h src,
    ffi.Pointer<mv_face_tracking_model_h> dst,
  ) {
    return _mv_face_tracking_model_clone(
      src,
      dst,
    );
  }

  late final _mv_face_tracking_model_clonePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_face_tracking_model_h,
                  ffi.Pointer<mv_face_tracking_model_h>)>>(
      'mv_face_tracking_model_clone');
  late final _mv_face_tracking_model_clone =
      _mv_face_tracking_model_clonePtr.asFunction<
          int Function(mv_face_tracking_model_h,
              ffi.Pointer<mv_face_tracking_model_h>)>();

  /// @brief Calls this method to save tracking model to the file.
  ///
  /// @since_tizen 3.0
  /// @remarks @a tracking_model is saved to the absolute path directory.
  /// Use @ref app_get_data_path for the private app storage path.
  /// After model is saved to the file, it can be loaded from this file
  /// with @ref mv_face_tracking_model_load() function.
  /// @param [in] file_name         Name of the path/file to save the model
  /// @param [in] tracking_model    The handle to the tracking model to be
  /// saved to the file
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_VISION_ERROR_INVALID_PATH Invalid path
  /// @retval #MEDIA_VISION_ERROR_PERMISSION_DENIED Not permitted
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Not supported model format
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a face tracking handle by calling
  /// @ref mv_face_tracking_model_create()
  /// @post Saved model can be loaded from file using
  /// @ref mv_face_tracking_model_load() function
  ///
  /// @see mv_face_tracking_model_load()
  /// @see mv_face_tracking_model_create()
  /// @see app_get_data_path()
  int mv_face_tracking_model_save(
    ffi.Pointer<ffi.Char> file_name,
    mv_face_tracking_model_h tracking_model,
  ) {
    return _mv_face_tracking_model_save(
      file_name,
      tracking_model,
    );
  }

  late final _mv_face_tracking_model_savePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              mv_face_tracking_model_h)>>('mv_face_tracking_model_save');
  late final _mv_face_tracking_model_save =
      _mv_face_tracking_model_savePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, mv_face_tracking_model_h)>();

  /// @brief Calls this method to load a tracking model from file.
  ///
  /// @since_tizen 3.0
  /// @remarks @a tracking_model is loaded from the absolute path directory.
  /// Use @ref app_get_data_path for the private app storage path.
  /// @a tracking_model must be destroyed using
  /// @ref mv_face_tracking_model_destroy.
  /// @param [in] file_name         Name of path/file to load the model
  /// @param [out] tracking_model   The handle to the tracking model to be
  /// loaded from file
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #MEDIA_VISION_ERROR_INVALID_PATH Invalid path
  /// @retval #MEDIA_VISION_ERROR_PERMISSION_DENIED Not permitted
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Not supported model format
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Models has been saved by @ref mv_face_tracking_model_save() function
  /// can be loaded with this function
  /// @post After model has been loaded and if further tracking will be performed
  /// on the video which is not continuation of the last tracking performed
  /// for the model, it is recommended to call
  /// @ref mv_face_tracking_model_prepare() function
  ///
  /// @see mv_face_tracking_model_save()
  /// @see mv_face_tracking_model_destroy()
  /// @see app_get_data_path()
  int mv_face_tracking_model_load(
    ffi.Pointer<ffi.Char> file_name,
    ffi.Pointer<mv_face_tracking_model_h> tracking_model,
  ) {
    return _mv_face_tracking_model_load(
      file_name,
      tracking_model,
    );
  }

  late final _mv_face_tracking_model_loadPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>,
                  ffi.Pointer<mv_face_tracking_model_h>)>>(
      'mv_face_tracking_model_load');
  late final _mv_face_tracking_model_load =
      _mv_face_tracking_model_loadPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<mv_face_tracking_model_h>)>();

  /// @brief Recognizes the given image objects on the source image.
  /// @details Use this function to launch image recognition algorithm configured
  /// by @a engine_conf configuration.
  ///
  /// @since_tizen 3.0
  /// @param [in] source              The handle to the source image on which image
  /// objects will be recognized
  /// @param [in] image_objects       The set of handles to the image objects which
  /// will be processed as targets of recognition
  /// @param [in] number_of_objects   The number of image objects
  /// @param [in] engine_cfg          The handle to the configuration of engine
  /// which will be used for recognition. If NULL,
  /// then default settings will be used.
  /// @param [in] recognized_cb       The callback which will be called in order to
  /// process recognition result
  /// @param [in] user_data           The user data to be passed to the
  /// @a recognized_cb
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Source colorspace
  /// isn't supported
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create a set of image objects using @ref mv_image_object_create() for
  /// each of them and construct (fill / load / clone) them on images that
  /// will be recognized
  /// @pre Create a source handle by calling @ref mv_create_source() and fill
  /// by the image for which recognition will be performed
  /// @post @a mv_image_recognized_cb will be called to process recognition result
  /// @post Release source image by using @ref mv_destroy_source()
  /// @post Release image objects by using @ref mv_image_object_destroy() for each
  /// handle from @a image_objects set
  ///
  /// @see mv_image_recognized_cb
  /// @see mv_source_h
  /// @see mv_create_source()
  /// @see mv_destroy_source()
  /// @see mv_image_object_h
  /// @see mv_image_object_create()
  /// @see mv_image_object_destroy()
  /// @see mv_engine_config_h
  int mv_image_recognize(
    mv_source_h source,
    ffi.Pointer<mv_image_object_h> image_objects,
    int number_of_objects,
    mv_engine_config_h engine_cfg,
    mv_image_recognized_cb recognized_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_image_recognize(
      source,
      image_objects,
      number_of_objects,
      engine_cfg,
      recognized_cb,
      user_data,
    );
  }

  late final _mv_image_recognizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_source_h,
              ffi.Pointer<mv_image_object_h>,
              ffi.Int,
              mv_engine_config_h,
              mv_image_recognized_cb,
              ffi.Pointer<ffi.Void>)>>('mv_image_recognize');
  late final _mv_image_recognize = _mv_image_recognizePtr.asFunction<
      int Function(mv_source_h, ffi.Pointer<mv_image_object_h>, int,
          mv_engine_config_h, mv_image_recognized_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Tracks the given image tracking model on the current frame
  /// @details Image tracking on a sequence of frames assumes calling this
  /// function for each frame in the correct order.
  /// @a tracked_cb will be called  for result processing.
  ///
  /// @since_tizen 3.0
  /// @remarks Tracking algorithm is usually using for recognition of image object
  /// on the sequence of images that are organized by time. For example,
  /// it may be the sequence of frames from a video stream.
  /// @remarks If object is lost during the tracking, system tries to find it
  /// further for the following frames. Therefore, tracking will be
  /// recovered when object appears again.
  /// @remarks Previous calls of @ref mv_image_track() for this
  /// @a image_tracking_model will affect on current call
  /// @param [in]     source                 The handle to the current image of
  /// sequence where image tracking model
  /// will be tracked
  /// @param [in,out] image_tracking_model   The handle to the image tracking model
  /// which processed as target of tracking
  /// @param [in]     engine_cfg             The handle to the configuration of
  /// engine which will be used for tracking.
  /// If NULL, then default settings will be
  /// used.
  /// @param [in]     tracked_cb             The callback which will receive
  /// tracking results
  /// @param [in]     user_data              The user data to be passed to the
  /// @a tracked_cb
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Source colorspace
  /// isn't supported
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image tracking model by calling
  /// @ref mv_image_tracking_model_create() and set target by calling
  /// @ref mv_image_tracking_model_set_target()
  /// @pre Create a source images by calling @ref mv_create_source() for each of
  /// them and construct them based on sequence of images for which will be
  /// held image tracking
  /// @post @a tracked_cb will be called to process tracking result
  /// @post Release image tracking model by using
  /// @ref mv_image_tracking_model_destroy()
  ///
  /// @see mv_image_tracked_cb
  /// @see mv_source_h
  /// @see image_tracking_model_h
  /// @see mv_image_tracking_model_create()
  /// @see mv_image_tracking_model_set_target()
  /// @see mv_image_tracking_model_destroy()
  int mv_image_track(
    mv_source_h source,
    mv_image_tracking_model_h image_tracking_model,
    mv_engine_config_h engine_cfg,
    mv_image_tracked_cb tracked_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_image_track(
      source,
      image_tracking_model,
      engine_cfg,
      tracked_cb,
      user_data,
    );
  }

  late final _mv_image_trackPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mv_source_h,
              mv_image_tracking_model_h,
              mv_engine_config_h,
              mv_image_tracked_cb,
              ffi.Pointer<ffi.Void>)>>('mv_image_track');
  late final _mv_image_track = _mv_image_trackPtr.asFunction<
      int Function(mv_source_h, mv_image_tracking_model_h, mv_engine_config_h,
          mv_image_tracked_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Creates an image object.
  ///
  /// @since_tizen 3.0
  /// @param [out] image_object    A new handle to the image object
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @post Release image object by using @ref mv_image_object_destroy()
  ///
  /// @see mv_image_object_destroy()
  /// @see mv_image_object_h
  int mv_image_object_create(
    ffi.Pointer<mv_image_object_h> image_object,
  ) {
    return _mv_image_object_create(
      image_object,
    );
  }

  late final _mv_image_object_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<mv_image_object_h>)>>(
      'mv_image_object_create');
  late final _mv_image_object_create = _mv_image_object_createPtr
      .asFunction<int Function(ffi.Pointer<mv_image_object_h>)>();

  /// @brief Destroys the image object.
  ///
  /// @since_tizen 3.0
  /// @param [in] image_object    The handle to the image object to be destroyed
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image object by using @ref mv_image_object_create()
  ///
  /// @see mv_image_object_create()
  /// @see mv_image_object_h
  int mv_image_object_destroy(
    mv_image_object_h image_object,
  ) {
    return _mv_image_object_destroy(
      image_object,
    );
  }

  late final _mv_image_object_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mv_image_object_h)>>(
          'mv_image_object_destroy');
  late final _mv_image_object_destroy =
      _mv_image_object_destroyPtr.asFunction<int Function(mv_image_object_h)>();

  /// @brief Fills the image object.
  /// @details Extracts data from @a source image which will be needed for
  /// recognition of depicted object in @a location.
  ///
  /// @since_tizen 3.0
  /// @remarks After filling the image object it can be evaluated by
  /// @ref mv_image_object_get_recognition_rate(). If recognition rate
  /// is too low, try to use another image of object or change
  /// configuration parameters (see @ref mv_engine_config_h) and construct
  /// the image object again.
  /// @param [in,out] image_object    The handle to the image object which will be
  /// filled and can be recognized in future
  /// @param [in]     engine_cfg      The handle to the configuration of engine
  /// which will be used for extract recognition
  /// data from @a source. If NULL, then default
  /// settings will be used.
  /// @param [in]     source          The source image where image object is depicted
  /// @param [in]     location        The pointer to location of the image object
  /// on the source image, or NULL if the object is
  /// shown in full
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT Source colorspace
  /// isn't supported
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image object by using @ref mv_image_object_create()
  /// @post Release image object by using @ref mv_image_object_destroy()
  ///
  /// @see mv_image_object_h
  /// @see mv_image_object_create()
  /// @see mv_image_object_get_recognition_rate()
  /// @see mv_image_recognize()
  /// @see mv_image_object_destroy()
  /// @see mv_engine_config_h
  int mv_image_object_fill(
    mv_image_object_h image_object,
    mv_engine_config_h engine_cfg,
    mv_source_h source,
    ffi.Pointer<mv_rectangle_s> location,
  ) {
    return _mv_image_object_fill(
      image_object,
      engine_cfg,
      source,
      location,
    );
  }

  late final _mv_image_object_fillPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_image_object_h, mv_engine_config_h, mv_source_h,
              ffi.Pointer<mv_rectangle_s>)>>('mv_image_object_fill');
  late final _mv_image_object_fill = _mv_image_object_fillPtr.asFunction<
      int Function(mv_image_object_h, mv_engine_config_h, mv_source_h,
          ffi.Pointer<mv_rectangle_s>)>();

  /// @brief Gets a value that determines how well an image object can be recognized.
  /// @details Recognition rate determines how well an image object can be
  /// recognized. This value can be from 0 to 1. If the recognition rate
  /// is 0 object can not be recognized and the bigger it is the more
  /// likely to recognize the object.
  ///
  /// @since_tizen 3.0
  /// @remarks If recognition rate is too low, try to use another image of object
  /// or change some configuration parameters (see @ref mv_engine_config_h)
  /// and fill the image object again (see @ref mv_image_object_fill()).
  /// @param [in]  image_object        The handle to the image object which will be
  /// evaluated by this function
  /// @param [out] recognition_rate    A value that determines how well an image
  /// object can be recognized, if 0 then object
  /// can not be recognized
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image object by using @ref mv_image_object_create()
  /// @post Release image object by using @ref mv_image_object_destroy()
  ///
  /// @see mv_image_object_h
  /// @see mv_image_object_create()
  /// @see mv_image_object_fill()
  /// @see mv_image_object_destroy()
  /// @see mv_engine_config_h
  int mv_image_object_get_recognition_rate(
    mv_image_object_h image_object,
    ffi.Pointer<ffi.Double> recognition_rate,
  ) {
    return _mv_image_object_get_recognition_rate(
      image_object,
      recognition_rate,
    );
  }

  late final _mv_image_object_get_recognition_ratePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_image_object_h, ffi.Pointer<ffi.Double>)>>(
      'mv_image_object_get_recognition_rate');
  late final _mv_image_object_get_recognition_rate =
      _mv_image_object_get_recognition_ratePtr.asFunction<
          int Function(mv_image_object_h, ffi.Pointer<ffi.Double>)>();

  /// @brief Sets a label for the image object.
  ///
  /// @since_tizen 3.0
  /// @param [in] image_object   The handle to the image object for which the label
  /// will be assigned
  /// @param [in] label          The label which will be assigned to the image
  /// object
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image object by using @ref mv_image_object_create()
  /// @post Label could be received by using @ref mv_image_object_get_label()
  /// @post Release image object by using @ref mv_image_object_destroy()
  ///
  /// @see mv_image_object_get_label()
  /// @see mv_image_object_h
  /// @see mv_image_object_create()
  /// @see mv_image_object_destroy()
  int mv_image_object_set_label(
    mv_image_object_h image_object,
    int label,
  ) {
    return _mv_image_object_set_label(
      image_object,
      label,
    );
  }

  late final _mv_image_object_set_labelPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mv_image_object_h, ffi.Int)>>(
          'mv_image_object_set_label');
  late final _mv_image_object_set_label = _mv_image_object_set_labelPtr
      .asFunction<int Function(mv_image_object_h, int)>();

  /// @brief Gets a label of image object.
  ///
  /// @since_tizen 3.0
  /// @remarks If @a image_object have not a label, this function return
  /// MEDIA_VISION_ERROR_NO_DATA value.
  /// @param [in]  image_object   The handle to the image object from which a
  /// label will be received
  /// @param [out] label          The label of image object
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NO_DATA Image object hasn't label
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image object by using @ref mv_image_object_create()
  /// @pre Set label for the image object by using @ref mv_image_object_set_label()
  /// @post Release image object by using @ref mv_image_object_destroy()
  ///
  /// @see mv_image_object_set_label()
  /// @see mv_image_object_h
  /// @see mv_image_object_create()
  /// @see mv_image_object_destroy()
  int mv_image_object_get_label(
    mv_image_object_h image_object,
    ffi.Pointer<ffi.Int> label,
  ) {
    return _mv_image_object_get_label(
      image_object,
      label,
    );
  }

  late final _mv_image_object_get_labelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_image_object_h,
              ffi.Pointer<ffi.Int>)>>('mv_image_object_get_label');
  late final _mv_image_object_get_label = _mv_image_object_get_labelPtr
      .asFunction<int Function(mv_image_object_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Clones the image object.
  ///
  /// @since_tizen 3.0
  /// @remarks @a dst must be released using mv_image_object_destroy().
  /// @param [in]  src    The handle to the source image object
  /// @param [out] dst    The handle to the destination image object
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @pre Create image object handles by calling mv_image_object_create()
  ///
  /// @see mv_image_object_create()
  /// @see mv_image_object_destroy()
  int mv_image_object_clone(
    mv_image_object_h src,
    ffi.Pointer<mv_image_object_h> dst,
  ) {
    return _mv_image_object_clone(
      src,
      dst,
    );
  }

  late final _mv_image_object_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_image_object_h,
              ffi.Pointer<mv_image_object_h>)>>('mv_image_object_clone');
  late final _mv_image_object_clone = _mv_image_object_clonePtr.asFunction<
      int Function(mv_image_object_h, ffi.Pointer<mv_image_object_h>)>();

  /// @brief Saves the image object.
  ///
  /// @since_tizen 3.0
  /// @remarks @a image_object is saved to the absolute path directory.
  /// Use @ref app_get_data_path for the private app storage path.
  /// @param [in] file_name       Name of the file to path/save the image object
  /// @param [in] image_object    The handle to the image object which will be saved
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_PATH Invalid path
  /// @retval #MEDIA_VISION_ERROR_PERMISSION_DENIED Not permitted
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image object handle by calling mv_image_object_create()
  /// @post Saved model can be loaded later by calling
  /// mv_image_object_load() function
  ///
  /// @see mv_image_object_create()
  /// @see mv_image_object_load()
  /// @see mv_image_object_destroy()
  int mv_image_object_save(
    ffi.Pointer<ffi.Char> file_name,
    mv_image_object_h image_object,
  ) {
    return _mv_image_object_save(
      file_name,
      image_object,
    );
  }

  late final _mv_image_object_savePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              mv_image_object_h)>>('mv_image_object_save');
  late final _mv_image_object_save = _mv_image_object_savePtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, mv_image_object_h)>();

  /// @brief Loads an image object from the file.
  ///
  /// @since_tizen 3.0
  /// @remarks @a image_object is loaded from the absolute path directory.
  /// Use @ref app_get_data_path for the private app storage path.
  /// @a image_object must be destroyed using
  /// @ref mv_image_object_destroy().
  /// @param [in]  file_name       Name of path/file to load the image object
  /// @param [out] image_object    The handle to the image object which will be
  /// filled
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_PATH Invalid path
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_PERMISSION_DENIED Not permitted
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Image object can be preliminary saved with mv_image_object_save()
  /// function
  ///
  /// @see mv_image_object_save()
  /// @see mv_image_object_destroy()
  int mv_image_object_load(
    ffi.Pointer<ffi.Char> file_name,
    ffi.Pointer<mv_image_object_h> image_object,
  ) {
    return _mv_image_object_load(
      file_name,
      image_object,
    );
  }

  late final _mv_image_object_loadPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<mv_image_object_h>)>>('mv_image_object_load');
  late final _mv_image_object_load = _mv_image_object_loadPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<mv_image_object_h>)>();

  /// @brief Creates an image tracking model.
  ///
  /// @since_tizen 3.0
  /// @param [out] image_tracking_model    A new handle to the image tracking model
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @post Release image tracking model by using mv_image_tracking_model_destroy()
  ///
  /// @see mv_image_tracking_model_destroy()
  int mv_image_tracking_model_create(
    ffi.Pointer<mv_image_tracking_model_h> image_tracking_model,
  ) {
    return _mv_image_tracking_model_create(
      image_tracking_model,
    );
  }

  late final _mv_image_tracking_model_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<mv_image_tracking_model_h>)>>(
      'mv_image_tracking_model_create');
  late final _mv_image_tracking_model_create =
      _mv_image_tracking_model_createPtr
          .asFunction<int Function(ffi.Pointer<mv_image_tracking_model_h>)>();

  /// @brief Sets target of image tracking model.
  /// @details Sets image object which will be tracked by using tracking
  /// functionality with @a image_tracking_model.
  ///
  /// @since_tizen 3.0
  /// @param [in] image_object            Image object which will be set
  /// as target for tracking
  /// @param [in] image_tracking_model    Handle to the image tracking model
  /// for which will be set a new target
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image tracking model by calling
  /// @ref mv_image_tracking_model_create()
  /// @pre Create an image object using @ref mv_image_object_create() and construct
  /// (fill / load / clone) it on image that will be tracking
  /// @post Release image object by using @ref mv_image_object_destroy()
  /// @post Release image tracking model by using
  /// @ref mv_image_tracking_model_destroy()
  ///
  /// @see mv_image_object_h
  /// @see mv_image_tracking_model_h
  /// @see mv_image_object_create()
  /// @see mv_image_object_destroy()
  /// @see mv_image_tracking_model_create()
  /// @see mv_image_track()
  /// @see mv_image_tracking_model_destroy()
  int mv_image_tracking_model_set_target(
    mv_image_object_h image_object,
    mv_image_tracking_model_h image_tracking_model,
  ) {
    return _mv_image_tracking_model_set_target(
      image_object,
      image_tracking_model,
    );
  }

  late final _mv_image_tracking_model_set_targetPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_image_object_h, mv_image_tracking_model_h)>>(
      'mv_image_tracking_model_set_target');
  late final _mv_image_tracking_model_set_target =
      _mv_image_tracking_model_set_targetPtr.asFunction<
          int Function(mv_image_object_h, mv_image_tracking_model_h)>();

  /// @brief Destroys the image tracking model.
  ///
  /// @since_tizen 3.0
  /// @param [in] image_tracking_model    The handle to the image tracking model
  /// to be destroyed
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image tracking model by using mv_image_tracking_model_create()
  ///
  /// @see mv_image_tracking_model_create()
  int mv_image_tracking_model_destroy(
    mv_image_tracking_model_h image_tracking_model,
  ) {
    return _mv_image_tracking_model_destroy(
      image_tracking_model,
    );
  }

  late final _mv_image_tracking_model_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mv_image_tracking_model_h)>>(
          'mv_image_tracking_model_destroy');
  late final _mv_image_tracking_model_destroy =
      _mv_image_tracking_model_destroyPtr
          .asFunction<int Function(mv_image_tracking_model_h)>();

  /// @brief Refreshes the state of image tracking model.
  /// @details Clears moving history and change state to undetected. This function
  /// is usually called each time before tracking is started for the new
  /// sequence of sources which is not the direct continuation of the
  /// sequence for which tracking has been performed before. Tracking
  /// algorithm will try to find image by itself.
  ///
  /// @since_tizen 3.0
  /// @param [in] image_tracking_model   The handle to the image tracking model
  /// which will be refreshed
  /// @param [in] engine_cfg             The handle to the configuration of
  /// engine which will be used. If NULL,
  /// then default settings will be used.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image tracking model by calling
  /// @ref mv_image_tracking_model_create()
  /// @post Release image tracking model by using
  /// @ref mv_image_tracking_model_destroy()
  ///
  /// @see mv_image_tracking_model_h
  /// @see mv_image_tracking_model_create()
  /// @see mv_image_track()
  /// @see mv_image_tracking_model_destroy()
  int mv_image_tracking_model_refresh(
    mv_image_tracking_model_h image_tracking_model,
    mv_engine_config_h engine_cfg,
  ) {
    return _mv_image_tracking_model_refresh(
      image_tracking_model,
      engine_cfg,
    );
  }

  late final _mv_image_tracking_model_refreshPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_image_tracking_model_h,
              mv_engine_config_h)>>('mv_image_tracking_model_refresh');
  late final _mv_image_tracking_model_refresh =
      _mv_image_tracking_model_refreshPtr.asFunction<
          int Function(mv_image_tracking_model_h, mv_engine_config_h)>();

  /// @brief Clones the image tracking model.
  ///
  /// @since_tizen 3.0
  /// @remarks @a dst must be released using mv_image_tracking_model_destroy().
  /// @param [in]  src    The handle to the source image tracking model
  /// @param [out] dst    The handle to the destination image tracking model
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  ///
  /// @pre Create image tracking model handles by calling
  /// mv_image_tracking_model_create()
  ///
  /// @see mv_image_tracking_model_create()
  /// @see mv_image_tracking_model_destroy()
  int mv_image_tracking_model_clone(
    mv_image_tracking_model_h src,
    ffi.Pointer<mv_image_tracking_model_h> dst,
  ) {
    return _mv_image_tracking_model_clone(
      src,
      dst,
    );
  }

  late final _mv_image_tracking_model_clonePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_image_tracking_model_h,
                  ffi.Pointer<mv_image_tracking_model_h>)>>(
      'mv_image_tracking_model_clone');
  late final _mv_image_tracking_model_clone =
      _mv_image_tracking_model_clonePtr.asFunction<
          int Function(mv_image_tracking_model_h,
              ffi.Pointer<mv_image_tracking_model_h>)>();

  /// @brief Saves the image tracking model.
  ///
  /// @since_tizen 3.0
  /// @remarks @a image_tracking_model is saved to the absolute path directory.
  /// Use @ref app_get_data_path for the private app storage path.
  /// @param [in] file_name               Name of path/file to save the model
  /// @param [in] image_tracking_model    The handle to the image tracking model
  /// to be saved
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_PATH Invalid path
  /// @retval #MEDIA_VISION_ERROR_PERMISSION_DENIED Not permitted
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Create image tracking model handle by calling
  /// mv_image_tracking_model_create()
  /// @post Saved model can be loaded later by calling
  /// mv_image_tracking_model_load() function
  ///
  /// @see mv_image_tracking_model_create()
  /// @see mv_image_tracking_model_load()
  /// @see mv_image_tracking_model_destroy()
  int mv_image_tracking_model_save(
    ffi.Pointer<ffi.Char> file_name,
    mv_image_tracking_model_h image_tracking_model,
  ) {
    return _mv_image_tracking_model_save(
      file_name,
      image_tracking_model,
    );
  }

  late final _mv_image_tracking_model_savePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              mv_image_tracking_model_h)>>('mv_image_tracking_model_save');
  late final _mv_image_tracking_model_save =
      _mv_image_tracking_model_savePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, mv_image_tracking_model_h)>();

  /// @brief Loads an image tracking model from the file.
  ///
  /// @since_tizen 3.0
  /// @remarks @a image_tracking_model is loaded from the absolute path directory.
  /// Use @ref app_get_data_path for the private app storage path.
  /// @a image_tracking_model must be destroyed using
  /// @ref mv_image_tracking_model_destroy.
  /// @param [in]  file_name               Name of path/file to load model
  /// @param [out] image_tracking_model    The handle to the image tracking
  /// model to be filled
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_INVALID_PATH Invalid path
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_PERMISSION_DENIED Not permitted
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Image tracking model handle can be preliminary saved with
  /// mv_image_tracking_model_save() function
  ///
  /// @see mv_image_tracking_model_save()
  /// @see mv_image_tracking_model_destroy()
  int mv_image_tracking_model_load(
    ffi.Pointer<ffi.Char> file_name,
    ffi.Pointer<mv_image_tracking_model_h> image_tracking_model,
  ) {
    return _mv_image_tracking_model_load(
      file_name,
      image_tracking_model,
    );
  }

  late final _mv_image_tracking_model_loadPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>,
                  ffi.Pointer<mv_image_tracking_model_h>)>>(
      'mv_image_tracking_model_load');
  late final _mv_image_tracking_model_load =
      _mv_image_tracking_model_loadPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<mv_image_tracking_model_h>)>();

  /// @brief Creates surveillance event trigger handle.
  ///
  /// @since_tizen 3.0
  /// @remarks List of supported event types can be obtained by
  /// @ref mv_surveillance_foreach_supported_event_type function
  /// @remarks You must release @a trigger by using
  /// @ref mv_surveillance_event_trigger_destroy()
  /// @param [in]  event_type    Name of the event type to be supported by the
  /// @a trigger
  /// @param [out] trigger       A new handle to the event trigger
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_surveillance_event_trigger_destroy()
  /// @see mv_surveillance_foreach_supported_event_type()
  int mv_surveillance_event_trigger_create(
    ffi.Pointer<ffi.Char> event_type,
    ffi.Pointer<mv_surveillance_event_trigger_h> trigger,
  ) {
    return _mv_surveillance_event_trigger_create(
      event_type,
      trigger,
    );
  }

  late final _mv_surveillance_event_trigger_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>,
                  ffi.Pointer<mv_surveillance_event_trigger_h>)>>(
      'mv_surveillance_event_trigger_create');
  late final _mv_surveillance_event_trigger_create =
      _mv_surveillance_event_trigger_createPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<mv_surveillance_event_trigger_h>)>();

  /// @brief Destroys the surveillance event trigger handle and releases all its
  /// resources.
  ///
  /// @since_tizen 3.0
  /// @param [in] trigger    The handle to the event trigger to be destroyed
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_surveillance_event_trigger_create
  int mv_surveillance_event_trigger_destroy(
    mv_surveillance_event_trigger_h trigger,
  ) {
    return _mv_surveillance_event_trigger_destroy(
      trigger,
    );
  }

  late final _mv_surveillance_event_trigger_destroyPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_surveillance_event_trigger_h)>>(
      'mv_surveillance_event_trigger_destroy');
  late final _mv_surveillance_event_trigger_destroy =
      _mv_surveillance_event_trigger_destroyPtr
          .asFunction<int Function(mv_surveillance_event_trigger_h)>();

  /// @brief Gets the surveillance event trigger type as character string.
  ///
  /// @since_tizen 3.0
  /// @remarks The @a event_type should be freed using free()
  /// @param [in]  trigger       The handle to the event trigger
  /// @param [out] event_type    The pointer to the character string which will be
  /// filled by textual name of the event type
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Event trigger has to be created by
  /// @ref mv_surveillance_event_trigger_create() function
  int mv_surveillance_get_event_trigger_type(
    mv_surveillance_event_trigger_h trigger,
    ffi.Pointer<ffi.Pointer<ffi.Char>> event_type,
  ) {
    return _mv_surveillance_get_event_trigger_type(
      trigger,
      event_type,
    );
  }

  late final _mv_surveillance_get_event_trigger_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_surveillance_event_trigger_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mv_surveillance_get_event_trigger_type');
  late final _mv_surveillance_get_event_trigger_type =
      _mv_surveillance_get_event_trigger_typePtr.asFunction<
          int Function(mv_surveillance_event_trigger_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets ROI (Region Of Interest) to the event trigger.
  /// @details When ROI is set for the event trigger, then event check for this
  /// @a triger will be performed only inside the polygonal region
  /// determined by @a roi parameter.
  /// If this method has been never called for the @a trigger, then event
  /// will be checked for the whole input frame (event check is performed
  /// for each @ref mv_surveillance_push_source() function call).
  /// It is possible to change the ROI between
  /// @ref mv_surveillance_push_source() calls.
  ///
  /// @since_tizen 3.0
  /// @param [in] trigger             The handle to the event trigger
  /// @param [in] number_of_points    The number of ROI points
  /// @param [in] roi                 The input array with ROI points
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Event trigger has to be created by
  /// @ref mv_surveillance_event_trigger_create() function
  ///
  /// @see mv_surveillance_event_trigger_h
  /// @see mv_surveillance_get_event_trigger_roi()
  int mv_surveillance_set_event_trigger_roi(
    mv_surveillance_event_trigger_h trigger,
    int number_of_points,
    ffi.Pointer<mv_point_s> roi,
  ) {
    return _mv_surveillance_set_event_trigger_roi(
      trigger,
      number_of_points,
      roi,
    );
  }

  late final _mv_surveillance_set_event_trigger_roiPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_surveillance_event_trigger_h, ffi.Int,
                  ffi.Pointer<mv_point_s>)>>(
      'mv_surveillance_set_event_trigger_roi');
  late final _mv_surveillance_set_event_trigger_roi =
      _mv_surveillance_set_event_trigger_roiPtr.asFunction<
          int Function(
              mv_surveillance_event_trigger_h, int, ffi.Pointer<mv_point_s>)>();

  /// @brief Gets ROI (Region Of Interest) from the event trigger.
  ///
  /// @since_tizen 3.0
  /// @remark If @ref mv_surveillance_set_event_trigger_roi() has been never
  /// called for @a trigger, then @a number_of_points output value will be
  /// zero and @a roi pointer will be not changed.
  /// @param [in]  trigger             The handle to the event trigger
  /// @param [out] number_of_points    The number of ROI points
  /// @param [out] roi                 The output array with ROI points
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Event trigger has to be created by
  /// @ref mv_surveillance_event_trigger_create() function
  ///
  /// @post Memory for @a roi array must be released
  ///
  /// @see mv_surveillance_event_trigger_h
  /// @see mv_surveillance_set_event_trigger_roi()
  int mv_surveillance_get_event_trigger_roi(
    mv_surveillance_event_trigger_h trigger,
    ffi.Pointer<ffi.Int> number_of_points,
    ffi.Pointer<ffi.Pointer<mv_point_s>> roi,
  ) {
    return _mv_surveillance_get_event_trigger_roi(
      trigger,
      number_of_points,
      roi,
    );
  }

  late final _mv_surveillance_get_event_trigger_roiPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mv_surveillance_event_trigger_h,
                  ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Pointer<mv_point_s>>)>>(
      'mv_surveillance_get_event_trigger_roi');
  late final _mv_surveillance_get_event_trigger_roi =
      _mv_surveillance_get_event_trigger_roiPtr.asFunction<
          int Function(mv_surveillance_event_trigger_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Pointer<mv_point_s>>)>();

  /// @brief Subscribes @a trigger to process sources pushed from video identified
  /// by @a video_stream_id.
  /// @details When @a trigger is subscribed, then each time when function
  /// @ref mv_surveillance_push_source() is called for @a video_stream_id,
  /// event occurrence is checked. If this check is successful,
  /// @a callback is invoked. Details on occurred event can be obtained
  /// using @ref mv_surveillance_result_h handle from @a callback.
  ///
  /// @since_tizen 3.0
  /// @remarks Use @ref mv_surveillance_unsubscribe_event_trigger() function for
  /// the same @a trigger and @a video_stream_id parameters to stop
  /// subscription.
  /// @param [in] trigger            The handle to the event trigger activating
  /// calls of the @a callback function
  /// @param [in] video_stream_id    The identifier of the video stream for which
  /// event trigger activation will be checked
  /// @param [in] engine_cfg         The engine configuration of the event
  /// @param [in] callback           Callback to be called each time when event
  /// occurrence is detected
  /// @param [in] user_data          The user data to be passed to the @a callback
  /// function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @post @ref mv_surveillance_event_occurred_cb will be called each time
  /// @a trigger is activated after @ref mv_surveillance_push_source() call
  ///
  /// @see mv_surveillance_event_trigger_h
  /// @see mv_surveillance_unsubscribe_event_trigger()
  /// @see mv_surveillance_push_source()
  int mv_surveillance_subscribe_event_trigger(
    mv_surveillance_event_trigger_h trigger,
    int video_stream_id,
    mv_engine_config_h engine_cfg,
    mv_surveillance_event_occurred_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_surveillance_subscribe_event_trigger(
      trigger,
      video_stream_id,
      engine_cfg,
      callback,
      user_data,
    );
  }

  late final _mv_surveillance_subscribe_event_triggerPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mv_surveillance_event_trigger_h,
                  ffi.Int,
                  mv_engine_config_h,
                  mv_surveillance_event_occurred_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'mv_surveillance_subscribe_event_trigger');
  late final _mv_surveillance_subscribe_event_trigger =
      _mv_surveillance_subscribe_event_triggerPtr.asFunction<
          int Function(mv_surveillance_event_trigger_h, int, mv_engine_config_h,
              mv_surveillance_event_occurred_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unsubscribes @a trigger from the event and stop calling @a callback.
  ///
  /// @since_tizen 3.0
  /// @remarks To start handling trigger activation use
  /// @ref mv_surveillance_subscribe_event_trigger().
  /// @param [in] trigger            The handle to the event trigger for which
  /// subscription will be stopped
  /// @param [in] video_stream_id    The identifier of the video source for which
  /// subscription will be stopped
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre To stop subscription it has to be created earlier with
  /// @ref mv_surveillance_subscribe_event_trigger() function
  ///
  /// @see mv_surveillance_event_trigger_h
  /// @see mv_surveillance_subscribe_event_trigger()
  int mv_surveillance_unsubscribe_event_trigger(
    mv_surveillance_event_trigger_h trigger,
    int video_stream_id,
  ) {
    return _mv_surveillance_unsubscribe_event_trigger(
      trigger,
      video_stream_id,
    );
  }

  late final _mv_surveillance_unsubscribe_event_triggerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_surveillance_event_trigger_h,
              ffi.Int)>>('mv_surveillance_unsubscribe_event_trigger');
  late final _mv_surveillance_unsubscribe_event_trigger =
      _mv_surveillance_unsubscribe_event_triggerPtr
          .asFunction<int Function(mv_surveillance_event_trigger_h, int)>();

  /// @brief Pushes source to the surveillance system to detect events.
  /// @details mv_surveillance_event_occurred_cb() will be called when any
  /// subscribing event detected.
  ///
  /// @since_tizen 3.0
  /// @remarks @ref mv_surveillance_set_event_trigger_roi() function can be used
  /// to specify the polygon region where event can be detected only
  /// @param [in] source             The handle to the media source
  /// @param [in] video_stream_id    The identifier of video stream from which
  /// @a source is coming
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre To receive surveillance results, some event triggers has to be
  /// subscribed by @ref mv_surveillance_subscribe_event_trigger() function
  /// before @ref mv_surveillance_push_source() calls
  /// @pre Before calling of this method @a source has to be correctly filled.
  /// @ref mv_source_fill_by_media_packet(), @ref mv_source_fill_by_buffer()
  /// functions can be used to fill @a source
  ///
  /// @see mv_surveillance_event_trigger_h
  /// @see mv_surveillance_event_occurred_cb
  /// @see mv_surveillance_subscribe_event_trigger()
  /// @see mv_surveillance_unsubscribe_event_trigger()
  int mv_surveillance_push_source(
    mv_source_h source,
    int video_stream_id,
  ) {
    return _mv_surveillance_push_source(
      source,
      video_stream_id,
    );
  }

  late final _mv_surveillance_push_sourcePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mv_source_h, ffi.Int)>>(
          'mv_surveillance_push_source');
  late final _mv_surveillance_push_source = _mv_surveillance_push_sourcePtr
      .asFunction<int Function(mv_source_h, int)>();

  /// @brief Starts traversing through list of supported event types.
  ///
  /// @since_tizen 3.0
  /// @remarks Supported event types and their descriptions can be found in
  /// @ref CAPI_MEDIA_VISION_SURVEILLANCE_EVENT_TYPES documentation
  /// section
  /// @param [in] callback     The callback function to be called for each
  /// supported event type
  /// @param [in] user_data    The user data to be passed to the @a callback
  /// function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_surveillance_event_type_cb
  /// @see mv_surveillance_foreach_event_result_name()
  int mv_surveillance_foreach_supported_event_type(
    mv_surveillance_event_type_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_surveillance_foreach_supported_event_type(
      callback,
      user_data,
    );
  }

  late final _mv_surveillance_foreach_supported_event_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mv_surveillance_event_type_cb, ffi.Pointer<ffi.Void>)>>(
      'mv_surveillance_foreach_supported_event_type');
  late final _mv_surveillance_foreach_supported_event_type =
      _mv_surveillance_foreach_supported_event_typePtr.asFunction<
          int Function(mv_surveillance_event_type_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Starts traversing through list of supported event result value names.
  ///
  /// @since_tizen 3.0
  /// @remarks Supported event types, event result value names and their
  /// descriptions can be found in
  /// @ref CAPI_MEDIA_VISION_SURVEILLANCE_EVENT_TYPES documentation
  /// section
  /// @param [in] event_type    The name of the event type for which result value
  /// names will be passed to the @a callback. Can be
  /// set @c NULL. If set @c NULL then all supported
  /// event result value names will be traversed
  /// @param [in] callback      The callback function to be called for each
  /// supported event result value name
  /// @param [in] user_data     The user data to be passed to the @a callback
  /// function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see mv_surveillance_event_result_name_cb
  /// @see mv_surveillance_foreach_supported_event_type()
  /// @see mv_surveillance_get_result_value()
  int mv_surveillance_foreach_event_result_name(
    ffi.Pointer<ffi.Char> event_type,
    mv_surveillance_event_result_name_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mv_surveillance_foreach_event_result_name(
      event_type,
      callback,
      user_data,
    );
  }

  late final _mv_surveillance_foreach_event_result_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>,
                  mv_surveillance_event_result_name_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'mv_surveillance_foreach_event_result_name');
  late final _mv_surveillance_foreach_event_result_name =
      _mv_surveillance_foreach_event_result_namePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>,
              mv_surveillance_event_result_name_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets result value.
  /// @details See the output values names in the event types descriptions located
  /// in @ref CAPI_MEDIA_VISION_SURVEILLANCE_EVENT_TYPES documentation
  /// section.
  ///
  /// @since_tizen 3.0
  /// @remarks The name can be obtained by
  /// @ref mv_surveillance_foreach_event_result_name function
  /// @param [in] result        The handle to the event result
  /// @param [in] name          The name of the value to be gotten
  /// @param [in, out] value    The pointer to variable which will be filled
  /// by result value. To find the type of @a value
  /// please refer to the
  /// @ref CAPI_MEDIA_VISION_SURVEILLANCE_EVENT_TYPES
  /// documentation section
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #MEDIA_VISION_ERROR_NONE Successful
  /// @retval #MEDIA_VISION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MEDIA_VISION_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre Memory for value has to be allocated
  ///
  /// @see mv_surveillance_event_trigger_h
  /// @see mv_surveillance_event_occurred_cb
  /// @see mv_surveillance_subscribe_event_trigger()
  /// @see mv_surveillance_unsubscribe_event_trigger()
  /// @see mv_surveillance_foreach_supported_event_type()
  /// @see mv_surveillance_foreach_event_result_name()
  int mv_surveillance_get_result_value(
    mv_surveillance_result_h result,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Void> value,
  ) {
    return _mv_surveillance_get_result_value(
      result,
      name,
      value,
    );
  }

  late final _mv_surveillance_get_result_valuePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mv_surveillance_result_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Void>)>>('mv_surveillance_get_result_value');
  late final _mv_surveillance_get_result_value =
      _mv_surveillance_get_result_valuePtr.asFunction<
          int Function(mv_surveillance_result_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Create metadata
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a metadata using metadata_editor_destroy().
  ///
  /// @param [in] metadata The handle to metadata
  /// @return 0 on success, otherwise a negative error value
  /// @retval #METADATA_EDITOR_ERROR_NONE Successful
  /// @retval #METADATA_EDITOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EDITOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @see metadata_editor_destroy()
  int metadata_editor_create(
    ffi.Pointer<metadata_editor_h> metadata,
  ) {
    return _metadata_editor_create(
      metadata,
    );
  }

  late final _metadata_editor_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<metadata_editor_h>)>>(
      'metadata_editor_create');
  late final _metadata_editor_create = _metadata_editor_createPtr
      .asFunction<int Function(ffi.Pointer<metadata_editor_h>)>();

  /// @brief Set file path to read or write metadata
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks In case of accessing specific path in internal storage or external storage, you may add the privilege for accessing the path. \n
  /// For example, if you get the specific path by using storage_get_directory(). you should add previlege http://tizen.org/privilege/mediastorage or http://tizen.org/privilege/externalstorage.
  ///
  /// @param [in] metadata The handle to metadata
  /// @param [in] path path to read or write metadata
  /// @return 0 on success, otherwise a negative error value
  /// @retval #METADATA_EDITOR_ERROR_NONE Successful
  /// @retval #METADATA_EDITOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EDITOR_ERROR_FILE_EXISTS File not exist
  /// @retval #METADATA_EDITOR_ERROR_NOT_SUPPORTED unsupported file type
  /// @retval #METADATA_EDITOR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #METADATA_EDITOR_ERROR_OPERATION_FAILED Internal Operation Fail
  /// @pre Create metadata handle by calling metadata_editor_create()
  /// @see metadata_editor_create(), metadata_editor_destroy()
  int metadata_editor_set_path(
    metadata_editor_h metadata,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _metadata_editor_set_path(
      metadata,
      path,
    );
  }

  late final _metadata_editor_set_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(metadata_editor_h,
              ffi.Pointer<ffi.Char>)>>('metadata_editor_set_path');
  late final _metadata_editor_set_path = _metadata_editor_set_pathPtr
      .asFunction<int Function(metadata_editor_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Get the metadata corresponding to the attribute.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a value using @c free(). \n
  /// If the attribute value of the metadata is empty, return value is NULL. \n
  /// In case of accessing specific path in internal storage or external storage, you may add the privilege for accessing the path. \n
  /// For example, if you get the specific path by using storage_get_directory(). you should add previlege http://tizen.org/privilege/mediastorage or http://tizen.org/privilege/externalstorage.
  ///
  /// @param [in] metadata The handle to metadata
  /// @param [in] attribute key attribute name to get
  /// @param [out] value The value of the attribute
  /// @return 0 on success, otherwise a negative error value
  /// @retval #METADATA_EDITOR_ERROR_NONE Successful
  /// @retval #METADATA_EDITOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EDITOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EDITOR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #METADATA_EDITOR_ERROR_OPERATION_FAILED Internal Operation Fail
  /// @pre Set path to read or write metadata by calling metadata_editor_set_path()
  /// @see metadata_editor_create(), metadata_editor_destroy()
  int metadata_editor_get_metadata(
    metadata_editor_h metadata,
    int attribute,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _metadata_editor_get_metadata(
      metadata,
      attribute,
      value,
    );
  }

  late final _metadata_editor_get_metadataPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(metadata_editor_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'metadata_editor_get_metadata');
  late final _metadata_editor_get_metadata =
      _metadata_editor_get_metadataPtr.asFunction<
          int Function(
              metadata_editor_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Set the attribute of the metadata.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details This function set the attribute of the metadata for updating the metadata. \n
  ///
  /// @remarks You must release @a value using @c free(). \n
  /// You must call metadata_editor_update_metadata() for applying to the metadata of the media file. if not, you will see the existing metadata when you call metadata_editor_get_metadata().
  ///
  /// @param [in] metadata The handle to metadata
  /// @param [in] attribute key attribute name to get
  /// @param [in] value The value of the attribute
  /// @return 0 on success, otherwise a negative error value
  /// @retval #METADATA_EDITOR_ERROR_NONE Successful
  /// @retval #METADATA_EDITOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EDITOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EDITOR_ERROR_OPERATION_FAILED Internal Operation Fail
  /// @pre Set path to read or write metadata by calling metadata_editor_set_path()
  /// @see metadata_editor_create(), metadata_editor_update_metadata(), metadata_editor_destroy()
  int metadata_editor_set_metadata(
    metadata_editor_h metadata,
    int attribute,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _metadata_editor_set_metadata(
      metadata,
      attribute,
      value,
    );
  }

  late final _metadata_editor_set_metadataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(metadata_editor_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('metadata_editor_set_metadata');
  late final _metadata_editor_set_metadata =
      _metadata_editor_set_metadataPtr.asFunction<
          int Function(metadata_editor_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Update the modified metadata
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @details This function update the metadata in the media file that is modified by metadata_editor_set_metadata().
  ///
  /// @remarks In case of accessing specific path in internal storage or external storage, you may add the privilege for accessing the path. \n
  /// For example, if you get the specific path by using storage_get_directory(). you should add previlege http://tizen.org/privilege/mediastorage or http://tizen.org/privilege/externalstorage.
  ///
  /// @param [in] metadata The handle to metadata
  /// @return 0 on success, otherwise a negative error value
  /// @retval #METADATA_EDITOR_ERROR_NONE Successful
  /// @retval #METADATA_EDITOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EDITOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EDITOR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #METADATA_EDITOR_ERROR_OPERATION_FAILED Internal Operation Fail
  /// @pre Set path to read or write metadata by calling metadata_editor_set_path()
  /// @see metadata_editor_create(), metadata_editor_destroy()
  int metadata_editor_update_metadata(
    metadata_editor_h metadata,
  ) {
    return _metadata_editor_update_metadata(
      metadata,
    );
  }

  late final _metadata_editor_update_metadataPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(metadata_editor_h)>>(
          'metadata_editor_update_metadata');
  late final _metadata_editor_update_metadata =
      _metadata_editor_update_metadataPtr
          .asFunction<int Function(metadata_editor_h)>();

  /// @brief Get the picture in the media file
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a picture using @c free(). \n
  /// In case of accessing specific path in internal storage or external storage, you may add the privilege for accessing the path. \n
  /// For example, if you get the specific path by using storage_get_directory(). you should add previlege http://tizen.org/privilege/mediastorage or http://tizen.org/privilege/externalstorage.
  ///
  /// @param [in] metadata The handle to metadata
  /// @param [in] index picture order
  /// @param [out] picture encoded picture
  /// @param [out] size encoded picture size
  /// @param [out] mime_type the mime type of picture
  /// @return 0 on success, otherwise a negative error value
  /// @retval #METADATA_EDITOR_ERROR_NONE Successful
  /// @retval #METADATA_EDITOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EDITOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EDITOR_ERROR_OPERATION_FAILED Internal Operation Fail
  /// @retval #METADATA_EDITOR_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Set path to read or write metadata by calling metadata_editor_set_path()
  /// @see metadata_editor_create(), metadata_editor_destroy()
  int metadata_editor_get_picture(
    metadata_editor_h metadata,
    int index,
    ffi.Pointer<ffi.Pointer<ffi.Void>> picture,
    ffi.Pointer<ffi.Int> size,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mime_type,
  ) {
    return _metadata_editor_get_picture(
      metadata,
      index,
      picture,
      size,
      mime_type,
    );
  }

  late final _metadata_editor_get_picturePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  metadata_editor_h,
                  ffi.Int,
                  ffi.Pointer<ffi.Pointer<ffi.Void>>,
                  ffi.Pointer<ffi.Int>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'metadata_editor_get_picture');
  late final _metadata_editor_get_picture =
      _metadata_editor_get_picturePtr.asFunction<
          int Function(
              metadata_editor_h,
              int,
              ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Append the picture to the media file
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must call metadata_editor_update_metadata() for applying to the metadata of the media file. if not, you will see the existing metadata when you call metadata_editor_get_metadata(). \n
  /// Image type of the metadata supports jpeg and png. \n
  /// In case of accessing specific path in internal storage or external storage, you may add the privilege for accessing the path. \n
  /// For example, if you get the specific path by using storage_get_directory(). you should add previlege http://tizen.org/privilege/mediastorage or http://tizen.org/privilege/externalstorage.
  ///
  /// @param [in] metadata The handle to metadata
  /// @param [in] picture_path The path of picture for adding to the metadata
  /// @return 0 on success, otherwise a negative error value
  /// @retval #METADATA_EDITOR_ERROR_NONE Successful
  /// @retval #METADATA_EDITOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EDITOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EDITOR_ERROR_NOT_SUPPORTED unsupported file type
  /// @retval #METADATA_EDITOR_ERROR_OPERATION_FAILED Internal Operation Fail
  /// @retval #METADATA_EDITOR_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Set path to read or write metadata by calling metadata_editor_set_path()
  /// @see metadata_editor_create(), metadata_editor_destroy()
  int metadata_editor_append_picture(
    metadata_editor_h metadata,
    ffi.Pointer<ffi.Char> picture_path,
  ) {
    return _metadata_editor_append_picture(
      metadata,
      picture_path,
    );
  }

  late final _metadata_editor_append_picturePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(metadata_editor_h,
              ffi.Pointer<ffi.Char>)>>('metadata_editor_append_picture');
  late final _metadata_editor_append_picture =
      _metadata_editor_append_picturePtr
          .asFunction<int Function(metadata_editor_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Remove artwork image from media file
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must call metadata_editor_update_metadata() for applying to the metadata of the media file. if not, you will see the existing metadata when you call metadata_editor_get_metadata(). \n
  ///
  /// @param [in] metadata The handle to metadata
  /// @param [in] index artwork image order
  /// @return 0 on success, otherwise a negative error value
  /// @retval #METADATA_EDITOR_ERROR_NONE Successful
  /// @retval #METADATA_EDITOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EDITOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EDITOR_ERROR_OPERATION_FAILED Internal Operation Fail
  /// @retval #METADATA_EDITOR_ERROR_PERMISSION_DENIED Permission denied
  /// @pre Set path to read or write metadata by calling metadata_editor_set_path()
  /// @see metadata_editor_create(), metadata_editor_destroy()
  int metadata_editor_remove_picture(
    metadata_editor_h metadata,
    int index,
  ) {
    return _metadata_editor_remove_picture(
      metadata,
      index,
    );
  }

  late final _metadata_editor_remove_picturePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(metadata_editor_h, ffi.Int)>>(
          'metadata_editor_remove_picture');
  late final _metadata_editor_remove_picture =
      _metadata_editor_remove_picturePtr
          .asFunction<int Function(metadata_editor_h, int)>();

  /// @brief Destroy metadata
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param [in] metadata The handle to metadata
  /// @return 0 on success, otherwise a negative error value
  /// @retval #METADATA_EDITOR_ERROR_NONE Successful
  /// @retval #METADATA_EDITOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EDITOR_ERROR_OPERATION_FAILED Internal Operation Fail
  /// @pre Create metadata handle by calling metadata_editor_create()
  /// @see metadata_editor_create()
  int metadata_editor_destroy(
    metadata_editor_h metadata,
  ) {
    return _metadata_editor_destroy(
      metadata,
    );
  }

  late final _metadata_editor_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(metadata_editor_h)>>(
          'metadata_editor_destroy');
  late final _metadata_editor_destroy =
      _metadata_editor_destroyPtr.asFunction<int Function(metadata_editor_h)>();

  /// @brief Creates metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a metadata using metadata_extractor_destroy().
  ///
  /// @param[in] metadata The handle to metadata
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EXTRACTOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EXTRACTOR_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see metadata_extractor_destroy()
  int metadata_extractor_create(
    ffi.Pointer<metadata_extractor_h> metadata,
  ) {
    return _metadata_extractor_create(
      metadata,
    );
  }

  late final _metadata_extractor_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<metadata_extractor_h>)>>('metadata_extractor_create');
  late final _metadata_extractor_create = _metadata_extractor_createPtr
      .asFunction<int Function(ffi.Pointer<metadata_extractor_h>)>();

  /// @brief Sets the file path to extract.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param [in] metadata The handle to metadata
  /// @param [in] path The path to extract metadata
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EXTRACTOR_ERROR_FILE_EXISTS File does not exist
  /// @retval #METADATA_EXTRACTOR_ERROR_OPERATION_FAILED Internal operation failed
  /// @retval #METADATA_EXTRACTOR_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Create a metadata handle by calling metadata_extractor_create().
  /// @see metadata_extractor_create()
  /// @see metadata_extractor_destroy()
  int metadata_extractor_set_path(
    metadata_extractor_h metadata,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _metadata_extractor_set_path(
      metadata,
      path,
    );
  }

  late final _metadata_extractor_set_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(metadata_extractor_h,
              ffi.Pointer<ffi.Char>)>>('metadata_extractor_set_path');
  late final _metadata_extractor_set_path = _metadata_extractor_set_pathPtr
      .asFunction<int Function(metadata_extractor_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the buffer to extract.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param [in] metadata The handle to metadata
  /// @param [in] buffer The buffer to extract metadata
  /// @param [in] size The buffer size
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EXTRACTOR_ERROR_OPERATION_FAILED Internal operation failed
  /// @retval #METADATA_EXTRACTOR_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Create a metadata handle by calling metadata_extractor_create().
  /// @see metadata_extractor_create()
  /// @see metadata_extractor_destroy()
  int metadata_extractor_set_buffer(
    metadata_extractor_h metadata,
    ffi.Pointer<ffi.Void> buffer,
    int size,
  ) {
    return _metadata_extractor_set_buffer(
      metadata,
      buffer,
      size,
    );
  }

  late final _metadata_extractor_set_bufferPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(metadata_extractor_h, ffi.Pointer<ffi.Void>,
              ffi.Int)>>('metadata_extractor_set_buffer');
  late final _metadata_extractor_set_buffer =
      _metadata_extractor_set_bufferPtr.asFunction<
          int Function(metadata_extractor_h, ffi.Pointer<ffi.Void>, int)>();

  /// @brief Destroys metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param [in] metadata The handle to metadata
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EXTRACTOR_ERROR_OPERATION_FAILED Internal operation failed
  /// @retval #METADATA_EXTRACTOR_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Create a metadata handle by calling metadata_extractor_create().
  /// @see metadata_extractor_create()
  int metadata_extractor_destroy(
    metadata_extractor_h metadata,
  ) {
    return _metadata_extractor_destroy(
      metadata,
    );
  }

  late final _metadata_extractor_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(metadata_extractor_h)>>(
          'metadata_extractor_destroy');
  late final _metadata_extractor_destroy = _metadata_extractor_destroyPtr
      .asFunction<int Function(metadata_extractor_h)>();

  /// @brief Gets metadata.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a value using @c free(). \n
  /// In case of accessing specific path in internal storage or external storage, you may add the privilege for accessing the path. \n
  /// For example, if you get the specific path by using storage_get_directory(). you should add previlege http://tizen.org/privilege/mediastorage or http://tizen.org/privilege/externalstorage.
  ///
  /// @param[in] metadata The handle to metadata
  /// @param[in] attribute The key attribute name to get
  /// @param[out] value The value of the attribute
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EXTRACTOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EXTRACTOR_ERROR_OPERATION_FAILED Internal operation failed
  /// @retval #METADATA_EXTRACTOR_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Set the path to extract by calling metadata_extractor_set_path().
  /// @see metadata_extractor_create()
  /// @see metadata_extractor_destroy()
  int metadata_extractor_get_metadata(
    metadata_extractor_h metadata,
    int attribute,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _metadata_extractor_get_metadata(
      metadata,
      attribute,
      value,
    );
  }

  late final _metadata_extractor_get_metadataPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(metadata_extractor_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'metadata_extractor_get_metadata');
  late final _metadata_extractor_get_metadata =
      _metadata_extractor_get_metadataPtr.asFunction<
          int Function(
              metadata_extractor_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the artwork image in a media file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a artwork and @a artwork_mime using @c free(). \n
  /// In case of accessing specific path in internal storage or external storage, you may add the privilege for accessing the path. \n
  /// For example, if you get the specific path by using storage_get_directory(). you should add previlege http://tizen.org/privilege/mediastorage or http://tizen.org/privilege/externalstorage.
  ///
  /// @param[in] metadata The handle to metadata
  /// @param[out] artwork The encoded artwork image
  /// @param[out] size The encoded artwork size
  /// @param[out] mime_type The mime type of artwork
  /// @return @c 0 on success, otherwise a negative error value
  ///
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EXTRACTOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EXTRACTOR_ERROR_OPERATION_FAILED Internal operation failed
  /// @retval #METADATA_EXTRACTOR_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Set the path to extract by calling metadata_extractor_set_path().
  /// @see metadata_extractor_create()
  /// @see metadata_extractor_destroy()
  int metadata_extractor_get_artwork(
    metadata_extractor_h metadata,
    ffi.Pointer<ffi.Pointer<ffi.Void>> artwork,
    ffi.Pointer<ffi.Int> size,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mime_type,
  ) {
    return _metadata_extractor_get_artwork(
      metadata,
      artwork,
      size,
      mime_type,
    );
  }

  late final _metadata_extractor_get_artworkPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  metadata_extractor_h,
                  ffi.Pointer<ffi.Pointer<ffi.Void>>,
                  ffi.Pointer<ffi.Int>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'metadata_extractor_get_artwork');
  late final _metadata_extractor_get_artwork =
      _metadata_extractor_get_artworkPtr.asFunction<
          int Function(metadata_extractor_h, ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the frame of a video media file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a frame using @c free().
  /// In case of accessing specific path in internal storage or external storage, you may add the privilege for accessing the path. \n
  /// For example, if you get the specific path by using storage_get_directory(). you should add previlege http://tizen.org/privilege/mediastorage or http://tizen.org/privilege/externalstorage.
  ///
  /// @param[in] metadata The handle to metadata
  /// @param[out] frame The raw frame data in RGB888
  /// @param[out] size The frame data size
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EXTRACTOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EXTRACTOR_ERROR_OPERATION_FAILED Internal operation failed
  /// @retval #METADATA_EXTRACTOR_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Set the path to extract by calling metadata_extractor_set_path().
  /// @see metadata_extractor_create()
  /// @see metadata_extractor_destroy()
  int metadata_extractor_get_frame(
    metadata_extractor_h metadata,
    ffi.Pointer<ffi.Pointer<ffi.Void>> frame,
    ffi.Pointer<ffi.Int> size,
  ) {
    return _metadata_extractor_get_frame(
      metadata,
      frame,
      size,
    );
  }

  late final _metadata_extractor_get_framePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              metadata_extractor_h,
              ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.Int>)>>('metadata_extractor_get_frame');
  late final _metadata_extractor_get_frame =
      _metadata_extractor_get_framePtr.asFunction<
          int Function(metadata_extractor_h, ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the synclyrics of a media file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a lyrics using @c free().
  /// In case of accessing specific path in internal storage or external storage, you may add the privilege for accessing the path. \n
  /// For example, if you get the specific path by using storage_get_directory(). you should add previlege http://tizen.org/privilege/mediastorage or http://tizen.org/privilege/externalstorage.
  ///
  /// @param[in] metadata The handle to metadata
  /// @param[in] index The index of time/lyrics to set
  /// @param[out] time_stamp The time information of the index
  /// @param[out] lyrics The lyrics of the index
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EXTRACTOR_ERROR_OPERATION_FAILED Internal operation failed
  /// @retval #METADATA_EXTRACTOR_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Set the path to extract by calling metadata_extractor_set_path().
  /// @pre Get the time/lyrics set number by calling metadata_extractor_get_metadata(METADATA_SYNCLYRICS_NUM).
  /// @see metadata_extractor_create()
  /// @see metadata_extractor_destroy()
  int metadata_extractor_get_synclyrics(
    metadata_extractor_h metadata,
    int index,
    ffi.Pointer<ffi.UnsignedLong> time_stamp,
    ffi.Pointer<ffi.Pointer<ffi.Char>> lyrics,
  ) {
    return _metadata_extractor_get_synclyrics(
      metadata,
      index,
      time_stamp,
      lyrics,
    );
  }

  late final _metadata_extractor_get_synclyricsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  metadata_extractor_h,
                  ffi.Int,
                  ffi.Pointer<ffi.UnsignedLong>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'metadata_extractor_get_synclyrics');
  late final _metadata_extractor_get_synclyrics =
      _metadata_extractor_get_synclyricsPtr.asFunction<
          int Function(metadata_extractor_h, int, ffi.Pointer<ffi.UnsignedLong>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the frame of a video media.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You must release @a frame using @c free().
  /// In case of accessing specific path in internal storage or external storage, you may add the privilege for accessing the path. \n
  /// For example, if you get the specific path by using storage_get_directory(). you should add previlege http://tizen.org/privilege/mediastorage or http://tizen.org/privilege/externalstorage.
  ///
  /// @param[in] metadata The handle to metadata
  /// @param[in] timestamp The timestamp in milliseconds
  /// @param[in] is_accurate If @c true the user can get an accurate frame for the given timestamp,\n
  /// otherwise @c false if the user can only get the nearest i-frame of the video rapidly
  /// @param[out] frame The raw frame data in RGB888
  /// @param[out] size The frame data size
  ///
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #METADATA_EXTRACTOR_ERROR_NONE Successful
  /// @retval #METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #METADATA_EXTRACTOR_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #METADATA_EXTRACTOR_ERROR_OPERATION_FAILED Internal operation failed
  /// @retval #METADATA_EXTRACTOR_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Set the path to extract by calling metadata_extractor_set_path().
  /// @see metadata_extractor_create()
  /// @see metadata_extractor_destroy()
  int metadata_extractor_get_frame_at_time(
    metadata_extractor_h metadata,
    int timestamp,
    bool is_accurate,
    ffi.Pointer<ffi.Pointer<ffi.Void>> frame,
    ffi.Pointer<ffi.Int> size,
  ) {
    return _metadata_extractor_get_frame_at_time(
      metadata,
      timestamp,
      is_accurate,
      frame,
      size,
    );
  }

  late final _metadata_extractor_get_frame_at_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              metadata_extractor_h,
              ffi.UnsignedLong,
              ffi.Bool,
              ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.Int>)>>('metadata_extractor_get_frame_at_time');
  late final _metadata_extractor_get_frame_at_time =
      _metadata_extractor_get_frame_at_timePtr.asFunction<
          int Function(metadata_extractor_h, int, bool,
              ffi.Pointer<ffi.Pointer<ffi.Void>>, ffi.Pointer<ffi.Int>)>();

  /// @brief Creates a player handle for playing multimedia content.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks You must release @a player by using player_destroy().\n
  /// Although you can create multiple player handles at the same time,
  /// the player cannot guarantee proper operation because of limited resources, such as
  /// audio or display device.
  ///
  /// @param[out]  player  A new handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_RESOURCE_LIMIT Cannot create more instance due to resource(socket, thread, etc) limitation on system.
  /// @post The player state will be #PLAYER_STATE_IDLE.
  /// @see player_destroy()
  int player_create(
    ffi.Pointer<player_h> player,
  ) {
    return _player_create(
      player,
    );
  }

  late final _player_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<player_h>)>>(
          'player_create');
  late final _player_create =
      _player_createPtr.asFunction<int Function(ffi.Pointer<player_h>)>();

  /// @brief Destroys the media player handle and releases all its resources.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks To completely shutdown player operation, call this function with a valid player handle from any player state.
  /// @param[in] player The handle to the media player to be destroyed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @post The player state will be #PLAYER_STATE_NONE.
  /// @see player_create()
  int player_destroy(
    player_h player,
  ) {
    return _player_destroy(
      player,
    );
  }

  late final _player_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>('player_destroy');
  late final _player_destroy =
      _player_destroyPtr.asFunction<int Function(player_h)>();

  /// @brief Prepares the media player for playback.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The mediastorage privilege(http://tizen.org/privilege/mediastorage) must be added if any video/audio files are used to play located in the internal storage.
  /// @remarks The externalstorage privilege(http://tizen.org/privilege/externalstorage) must be added if any video/audio files are used to play located in the external storage.
  /// @remarks The internet privilege(http://tizen.org/privilege/internet) must be added if any URLs are used to play from network.
  /// @param[in]	player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_URI Invalid URI
  /// @retval #PLAYER_ERROR_NO_SUCH_FILE File not found
  /// @retval #PLAYER_ERROR_NOT_SUPPORTED_FILE File not supported
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PLAYER_ERROR_NOT_SUPPORTED_AUDIO_CODEC Not support audio codec format (Since 4.0)
  /// @retval #PLAYER_ERROR_NOT_SUPPORTED_VIDEO_CODEC Not support video codec format (Since 4.0)
  /// @pre	The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare(). After that, call player_set_uri() to load the media content you want to play.
  /// @post The player state will be #PLAYER_STATE_READY.
  /// @see player_prepare_async()
  /// @see player_unprepare()
  /// @see player_set_uri()
  int player_prepare(
    player_h player,
  ) {
    return _player_prepare(
      player,
    );
  }

  late final _player_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>('player_prepare');
  late final _player_prepare =
      _player_preparePtr.asFunction<int Function(player_h)>();

  /// @brief Prepares the media player for playback, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The mediastorage privilege(http://tizen.org/privilege/mediastorage) must be added if any video/audio files are used to play located in the internal storage.
  /// @remarks The externalstorage privilege(http://tizen.org/privilege/externalstorage) must be added if any video/audio files are used to play located in the external storage.
  /// @remarks The internet privilege(http://tizen.org/privilege/internet) must be added if any URLs are used to play from network.
  /// @param[in] player The handle to the media player
  /// @param[in] callback	The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_URI Invalid URI
  /// @retval #PLAYER_ERROR_NO_SUCH_FILE File not found
  /// @retval #PLAYER_ERROR_NOT_SUPPORTED_FILE File not supported
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre	The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare(). After that, call player_set_uri() to load the media content you want to play.
  /// @post It invokes player_prepared_cb() when playback is prepared.
  /// @see player_prepare()
  /// @see player_prepared_cb()
  /// @see player_unprepare()
  /// @see player_set_uri()
  int player_prepare_async(
    player_h player,
    player_prepared_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_prepare_async(
      player,
      callback,
      user_data,
    );
  }

  late final _player_prepare_asyncPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, player_prepared_cb,
              ffi.Pointer<ffi.Void>)>>('player_prepare_async');
  late final _player_prepare_async = _player_prepare_asyncPtr.asFunction<
      int Function(player_h, player_prepared_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Resets the media player.
  /// @details The most recently used media is reset and no longer associated with the player.
  /// Playback is no longer possible. If you want to use the player again, you must set the data URI and call
  /// player_prepare() again.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre	The player state must be higher than #PLAYER_STATE_IDLE.
  /// @post The player state will be #PLAYER_STATE_IDLE.
  /// @see player_prepare()
  int player_unprepare(
    player_h player,
  ) {
    return _player_unprepare(
      player,
    );
  }

  late final _player_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>(
          'player_unprepare');
  late final _player_unprepare =
      _player_unpreparePtr.asFunction<int Function(player_h)>();

  /// @brief Sets the data source (file-path, HTTP or RTSP URI) to use.
  ///
  /// @details Associates media contents, referred to by the URI, with the player.
  /// If the function call is successful, subsequent calls to player_prepare() and player_start() will start playing the media.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks If you use HTTP or RTSP, URI must start with "http://" or "rtsp://". The default protocol is "file://".
  /// If you provide an invalid URI, you won't receive an error message until you call player_start().
  /// @remarks This API must be called before calling the player_prepare() or player_prepare_async() to build the player based on the uri information.
  /// @remarks The mediastorage privilege(http://tizen.org/privilege/mediastorage) must be added if any video/audio files are used to play located in the internal storage.
  /// @remarks The externalstorage privilege(http://tizen.org/privilege/externalstorage) must be added if any video/audio files are used to play located in the external storage.
  /// @remarks The internet privilege(http://tizen.org/privilege/internet) must be added if any URLs are used to play from network.
  ///
  /// @param[in]   player The handle to the media player
  /// @param[in]   uri The content location, such as the file path, the URI of the HTTP or RTSP stream you want to play
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_PERMISSION_DENIED Permission denied
  /// @if WEARABLE @retval #PLAYER_ERROR_FEATURE_NOT_SUPPORTED_ON_DEVICE Unsupported feature @endif
  /// @pre The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare().
  /// @see player_set_memory_buffer()
  int player_set_uri(
    player_h player,
    ffi.Pointer<ffi.Char> uri,
  ) {
    return _player_set_uri(
      player,
      uri,
    );
  }

  late final _player_set_uriPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Char>)>>('player_set_uri');
  late final _player_set_uri = _player_set_uriPtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets memory as the data source.
  ///
  /// @details Associates media content, cached in memory, with the player. Unlike the case of player_set_uri(), the media resides in memory.
  /// If the function call is successful, subsequent calls to player_prepare() and player_start() will start playing the media.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks If you provide an invalid data, you won't receive an error message until you call player_start().
  /// @remarks This API must be called before calling the player_prepare() or player_prepare_async()
  /// to build the player based on the data.
  ///
  /// @param[in]   player The handle to the media player
  /// @param[in]   data The memory pointer of media data
  /// @param[in]   size The size of media data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre	The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare().
  /// @see player_set_uri()
  int player_set_memory_buffer(
    player_h player,
    ffi.Pointer<ffi.Void> data,
    int size,
  ) {
    return _player_set_memory_buffer(
      player,
      data,
      size,
    );
  }

  late final _player_set_memory_bufferPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Void>,
              ffi.Int)>>('player_set_memory_buffer');
  late final _player_set_memory_buffer = _player_set_memory_bufferPtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Void>, int)>();

  /// @brief Gets the player's current state.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in]   player	The handle to the media player
  /// @param[out]  state	The current state of the player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see #player_state_e
  int player_get_state(
    player_h player,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _player_get_state(
      player,
      state,
    );
  }

  late final _player_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              player_h, ffi.Pointer<ffi.Int32>)>>('player_get_state');
  late final _player_get_state = _player_get_statePtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the player's volume.
  /// @details  Setting this volume adjusts the player's instance volume, not the system volume.
  /// The valid range is from 0 to 1.0, inclusive (1.0 = 100%). Default value is 1.0.
  /// To change system volume, use the @ref CAPI_MEDIA_SOUND_MANAGER_MODULE API.
  /// Finally, it does not support to set other value into each channel currently.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in]   player The handle to the media player
  /// @param[in]   left The left volume scalar
  /// @param[in]   right The right volume scalar
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @see player_get_volume()
  int player_set_volume(
    player_h player,
    double left,
    double right,
  ) {
    return _player_set_volume(
      player,
      left,
      right,
    );
  }

  late final _player_set_volumePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(player_h, ffi.Float, ffi.Float)>>(
      'player_set_volume');
  late final _player_set_volume = _player_set_volumePtr
      .asFunction<int Function(player_h, double, double)>();

  /// @brief Gets the player's current volume factor.
  /// @details The range of @a left and @a right is from @c 0 to @c 1.0, inclusive (1.0 = 100%).
  /// This function gets the player volume, not the system volume.
  /// To get the system volume, use the @ref CAPI_MEDIA_SOUND_MANAGER_MODULE API.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in]   player The handle to the media player
  /// @param[out]  left The current left volume scalar
  /// @param[out]  right The current right volume scalar
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @see player_set_volume()
  int player_get_volume(
    player_h player,
    ffi.Pointer<ffi.Float> left,
    ffi.Pointer<ffi.Float> right,
  ) {
    return _player_get_volume(
      player,
      left,
      right,
    );
  }

  late final _player_get_volumePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Float>,
              ffi.Pointer<ffi.Float>)>>('player_get_volume');
  late final _player_get_volume = _player_get_volumePtr.asFunction<
      int Function(player_h, ffi.Pointer<ffi.Float>, ffi.Pointer<ffi.Float>)>();

  /// @deprecated Deprecated since 3.0. Use player_set_sound_stream_info() instead.
  /// @brief Sets the player's volume type.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The default sound type of the player is #SOUND_TYPE_MEDIA.
  /// To get the current sound type, use sound_manager_get_current_sound_type().
  /// @remarks If stream_info already exists by calling sound_manager_create_stream_info(),
  /// It will return error since 3.0.
  ///
  /// @param[in]   player The handle to the media player
  /// @param[in]   type The sound type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_SOUND_POLICY Sound policy error
  /// @pre The player state must be set to #PLAYER_STATE_IDLE by calling player_create().
  /// @see sound_manager_get_current_sound_type()
  int player_set_sound_type(
    player_h player,
    int type,
  ) {
    return _player_set_sound_type(
      player,
      type,
    );
  }

  late final _player_set_sound_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Int32)>>(
          'player_set_sound_type');
  late final _player_set_sound_type =
      _player_set_sound_typePtr.asFunction<int Function(player_h, int)>();

  /// @brief Sets the player's sound manager stream information.
  /// @since_tizen 3.0
  /// @remarks You can set sound stream information including audio routing and volume type.
  /// For more details, please refer to sound_manager.h
  /// @remarks This API must be called before calling the player_prepare() or player_prepare_async()
  /// to reflect the sound stream information when the player is building.
  /// @remarks This function is related to the following feature:\n
  /// %http://tizen.org/feature/multimedia.player.stream_info\n
  /// If this feature is not supported, the stream_type of the player is fixed to the #SOUND_STREAM_TYPE_MEDIA.
  /// @param[in] player The handle to the media player
  /// @param[in] stream_info The sound manager info type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_FEATURE_NOT_SUPPORTED_ON_DEVICE Unsupported feature
  /// @pre The player state must be set to #PLAYER_STATE_IDLE by calling player_create().
  /// @see #sound_stream_info_h
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  /// @par Example
  /// @code
  /// #include <player.h>
  /// #include <sound_manager.h>
  /// ...
  /// player_h player = NULL;
  /// sound_stream_info_h stream_info = NULL;
  /// sound_stream_type_e stream_type = SOUND_STREAM_TYPE_MEDIA;
  /// ...
  /// sound_manager_create_stream_information (stream_type, _focus_callback, use_data, &stream_info);
  /// player_create (&player);
  /// player_set_sound_stream_info (player, stream_info);
  /// ...
  /// player_prepare_async (player, _prepared_cb, udata);
  /// ...
  /// @endcode
  int player_set_sound_stream_info(
    player_h player,
    sound_stream_info_h stream_info,
  ) {
    return _player_set_sound_stream_info(
      player,
      stream_info,
    );
  }

  late final _player_set_sound_stream_infoPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(player_h, sound_stream_info_h)>>(
      'player_set_sound_stream_info');
  late final _player_set_sound_stream_info = _player_set_sound_stream_infoPtr
      .asFunction<int Function(player_h, sound_stream_info_h)>();

  /// @brief Sets the audio latency mode.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The default audio latency mode of the player is #AUDIO_LATENCY_MODE_MID.
  /// To get the current audio latency mode, use player_get_audio_latency_mode().
  /// If it's high mode, audio output interval can be increased so, it can keep more audio data to play.
  /// But, state transition like pause or resume can be more slower than default(mid) mode.
  ///
  /// @param[in] player The handle to the media player
  /// @param[in] latency_mode The latency mode to be applied to the audio
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @see #audio_latency_mode_e
  /// @see player_get_audio_latency_mode()
  int player_set_audio_latency_mode(
    player_h player,
    int latency_mode,
  ) {
    return _player_set_audio_latency_mode(
      player,
      latency_mode,
    );
  }

  late final _player_set_audio_latency_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Int32)>>(
          'player_set_audio_latency_mode');
  late final _player_set_audio_latency_mode = _player_set_audio_latency_modePtr
      .asFunction<int Function(player_h, int)>();

  /// @brief Gets the current audio latency mode.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[out] latency_mode The latency mode to get from the audio
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @see #audio_latency_mode_e
  /// @see player_set_audio_latency_mode()
  int player_get_audio_latency_mode(
    player_h player,
    ffi.Pointer<ffi.Int32> latency_mode,
  ) {
    return _player_get_audio_latency_mode(
      player,
      latency_mode,
    );
  }

  late final _player_get_audio_latency_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h,
              ffi.Pointer<ffi.Int32>)>>('player_get_audio_latency_mode');
  late final _player_get_audio_latency_mode = _player_get_audio_latency_modePtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Starts or resumes playback.
  /// @details Plays current media content, or resumes play if paused.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks Sound can be mixed with other sounds if you don't control the stream focus in sound-manager module since 3.0.\n
  /// You can refer to @ref CAPI_MEDIA_SOUND_MANAGER_MODULE.
  /// @remarks Even if you don't set visible to true by calling player_set_display_visible, the video will be shown on #PLAYER_STATE_PLAYING state.
  ///
  /// @param[in]   player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_CONNECTION_FAILED Network connection failed
  /// @retval #PLAYER_ERROR_SOUND_POLICY Sound policy error
  /// @pre player_prepare() must be called before calling this function.
  /// @pre The player state must be set to #PLAYER_STATE_READY by calling player_prepare() or set to #PLAYER_STATE_PAUSED by calling player_pause().
  /// @post The player state will be #PLAYER_STATE_PLAYING.
  /// @post It invokes player_completed_cb() when playback completes, if you set a callback with player_set_completed_cb().
  /// @post It invokes player_pd_message_cb() when progressive download starts or completes, if you set a download path with player_set_progressive_download_path() and a callback with player_set_progressive_download_message_cb().
  /// @see player_prepare()
  /// @see player_prepare_async()
  /// @see player_stop()
  /// @see player_pause()
  /// @see player_set_completed_cb()
  /// @see player_completed_cb()
  /// @see player_set_progressive_download_path()
  /// @see player_set_progressive_download_message_cb()
  /// @see player_pd_message_cb()
  /// @see player_set_display_visible()
  int player_start(
    player_h player,
  ) {
    return _player_start(
      player,
    );
  }

  late final _player_startPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>('player_start');
  late final _player_start =
      _player_startPtr.asFunction<int Function(player_h)>();

  /// @brief Stops playing media content.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in]   player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid state
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_SOUND_POLICY Sound policy error
  /// @pre The player state must be set to #PLAYER_STATE_PLAYING by calling player_start() or set to #PLAYER_STATE_PAUSED by calling player_pause().
  /// @post The player state will be #PLAYER_STATE_READY.
  /// @post The downloading will be aborted if you use progressive download.
  /// @see player_start()
  /// @see player_pause()
  int player_stop(
    player_h player,
  ) {
    return _player_stop(
      player,
    );
  }

  late final _player_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>('player_stop');
  late final _player_stop =
      _player_stopPtr.asFunction<int Function(player_h)>();

  /// @brief Pauses the player.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks	You can resume playback using player_start().
  ///
  /// @param[in]   player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid state
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_SOUND_POLICY Sound policy error
  /// @pre The player state must be set to #PLAYER_STATE_PLAYING.
  /// @post The player state will be #PLAYER_STATE_READY.
  /// @see player_start()
  int player_pause(
    player_h player,
  ) {
    return _player_pause(
      player,
    );
  }

  late final _player_pausePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>('player_pause');
  late final _player_pause =
      _player_pausePtr.asFunction<int Function(player_h)>();

  /// @brief Sets the seek position for playback, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks This api will trigger the seeking operation on player instance.
  /// Normally application need to wait for player_seek_completed_cb() before calling it again.
  /// Otherwise it will return PLAYER_ERROR_SEEK_FAILED.
  /// Please note that if application is playing external media data via player_set_media_stream_info(),
  /// then consecutive calling of this api will always success and no need to wait for player_seek_completed_cb()
  /// before next calling of this api.(since_tizen 3.0)
  /// @remarks Even if you don't set visible to true by calling player_set_display_visible,
  /// the video will be shown when the _seek_completed cb is invoked.
  /// @remarks In case of non-seekable content, it will return PLAYER_ERROR_INVALID_OPERATION.
  /// If application ignore this error, player will keep playing without changing play position.
  /// @param[in] player The handle to the media player
  /// @param[in] millisecond The position in milliseconds from the start to the seek point
  /// @param[in] accurate If @c true the selected position is returned, but this might be considerably slow,
  /// if @c false the nearest key frame position is returned, but this might be faster but less accurate.
  /// @param[in] callback	The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_SEEK_FAILED Seek operation failure
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @post It invokes player_seek_completed_cb() when seek operation completes, if you set a callback.
  /// @see player_get_play_position()
  int player_set_play_position(
    player_h player,
    int millisecond,
    bool accurate,
    player_seek_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_play_position(
      player,
      millisecond,
      accurate,
      callback,
      user_data,
    );
  }

  late final _player_set_play_positionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              player_h,
              ffi.Int,
              ffi.Bool,
              player_seek_completed_cb,
              ffi.Pointer<ffi.Void>)>>('player_set_play_position');
  late final _player_set_play_position =
      _player_set_play_positionPtr.asFunction<
          int Function(player_h, int, bool, player_seek_completed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the current position in milliseconds.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in]   player The handle to the media player
  /// @param[out]  millisecond The current position in milliseconds
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_SEEK_FAILED Seek operation failure
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_set_play_position()
  int player_get_play_position(
    player_h player,
    ffi.Pointer<ffi.Int> millisecond,
  ) {
    return _player_get_play_position(
      player,
      millisecond,
    );
  }

  late final _player_get_play_positionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(player_h, ffi.Pointer<ffi.Int>)>>(
      'player_get_play_position');
  late final _player_get_play_position = _player_get_play_positionPtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the player's mute status.
  /// @details If the mute status is @c true, no sounds are played.
  /// If it is @c false, sounds are played at the previously set volume level.
  /// Until this function is called, by default the player is not muted.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in]   player The handle to the media player
  /// @param[in]   muted The new mute status: (@c true = mute, @c false = not muted)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_is_muted()
  int player_set_mute(
    player_h player,
    bool muted,
  ) {
    return _player_set_mute(
      player,
      muted,
    );
  }

  late final _player_set_mutePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Bool)>>(
          'player_set_mute');
  late final _player_set_mute =
      _player_set_mutePtr.asFunction<int Function(player_h, bool)>();

  /// @brief Gets the player's mute status.
  /// @details If the mute status is @c true, no sounds are played.
  /// If it is @c false, sounds are played at the previously set volume level.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in]   player The handle to the media player
  /// @param[out]  muted  The current mute status: (@c true = mute, @c false = not muted)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_set_mute()
  int player_is_muted(
    player_h player,
    ffi.Pointer<ffi.Bool> muted,
  ) {
    return _player_is_muted(
      player,
      muted,
    );
  }

  late final _player_is_mutedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              player_h, ffi.Pointer<ffi.Bool>)>>('player_is_muted');
  late final _player_is_muted = _player_is_mutedPtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the player's looping status.
  /// @details If the looping status is @c true, playback automatically restarts upon finishing.
  /// If it is @c false, it won't. The default value is @c false.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in]   player The handle to the media player
  /// @param[in]   looping The new looping status: (@c true = looping, @c false = non-looping )
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_is_looping()
  int player_set_looping(
    player_h player,
    bool looping,
  ) {
    return _player_set_looping(
      player,
      looping,
    );
  }

  late final _player_set_loopingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Bool)>>(
          'player_set_looping');
  late final _player_set_looping =
      _player_set_loopingPtr.asFunction<int Function(player_h, bool)>();

  /// @brief Gets the player's looping status.
  /// @details If the looping status is @c true, playback automatically restarts upon finishing.
  /// If it is @c false, it won't.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in]   player The handle to the media player
  /// @param[out]  looping The looping status: (@c true = looping, @c false = non-looping )
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_set_looping()
  int player_is_looping(
    player_h player,
    ffi.Pointer<ffi.Bool> looping,
  ) {
    return _player_is_looping(
      player,
      looping,
    );
  }

  late final _player_is_loopingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              player_h, ffi.Pointer<ffi.Bool>)>>('player_is_looping');
  late final _player_is_looping = _player_is_loopingPtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the video display.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks To get @a display to set, use #GET_DISPLAY().
  /// @remarks We are not supporting changing display.
  /// @remarks This API have be called before calling the player_prepare() or player_prepare_async() \n
  /// to reflect the display type.
  /// @param[in]   player The handle to the media player
  /// @param[in]   type The display type
  /// @param[in]   display The handle to display
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre	The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare().
  /// @see #player_display_type_e
  /// @see player_set_display_mode
  /// @see player_set_display_roi_area
  /// @see player_set_display_visible
  /// @see player_set_display_rotation
  int player_set_display(
    player_h player,
    int type,
    player_display_h display,
  ) {
    return _player_set_display(
      player,
      type,
      display,
    );
  }

  late final _player_set_displayPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              player_h, ffi.Int32, player_display_h)>>('player_set_display');
  late final _player_set_display = _player_set_displayPtr
      .asFunction<int Function(player_h, int, player_display_h)>();

  /// @brief Registers a media packet video callback function to be called once per frame.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks This function must be called before calling player_prepare() or player_prepare_async().\n
  /// A registered callback is called in a separate thread (not in the main loop).\n
  /// A video frame can be retrieved using a registered callback as a media packet.\n
  /// The callback function holds the same buffer that will be drawn on the display device.\n
  /// So if you change the media packet in a registered callback, it will be displayed on the device\n
  /// and the media packet is available until it's destroyed by media_packet_destroy().\n
  /// The packet have to be destroyed as quickly as possible after rendering the packet\n
  /// and all the packets have to be destroyed before player_unprepare() is called.\n
  /// @param[in] player The handle to the media player
  /// @param[in] callback The callback function to be registered
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid state
  /// @pre	The player's state must be #PLAYER_STATE_IDLE. And, #PLAYER_DISPLAY_TYPE_NONE must be set by calling player_set_display().
  /// @see player_unset_media_packet_video_frame_decoded_cb
  int player_set_media_packet_video_frame_decoded_cb(
    player_h player,
    player_media_packet_video_decoded_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_media_packet_video_frame_decoded_cb(
      player,
      callback,
      user_data,
    );
  }

  late final _player_set_media_packet_video_frame_decoded_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(player_h, player_media_packet_video_decoded_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'player_set_media_packet_video_frame_decoded_cb');
  late final _player_set_media_packet_video_frame_decoded_cb =
      _player_set_media_packet_video_frame_decoded_cbPtr.asFunction<
          int Function(player_h, player_media_packet_video_decoded_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre The player's state must be #PLAYER_STATE_READY or #PLAYER_STATE_IDLE
  /// @see player_set_media_packet_video_frame_decoded_cb()
  int player_unset_media_packet_video_frame_decoded_cb(
    player_h player,
  ) {
    return _player_unset_media_packet_video_frame_decoded_cb(
      player,
    );
  }

  late final _player_unset_media_packet_video_frame_decoded_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>(
          'player_unset_media_packet_video_frame_decoded_cb');
  late final _player_unset_media_packet_video_frame_decoded_cb =
      _player_unset_media_packet_video_frame_decoded_cbPtr
          .asFunction<int Function(player_h)>();

  /// @brief  Pushes elementary stream to decode audio or video
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks player_set_media_stream_info() must be called before using this API.
  /// @remarks The available buffer size can be set by calling player_set_media_stream_buffer_max_size() API.
  /// If there is no available buffer space, this api will return error since 3.0.
  /// @param[in]  player   The handle to media player
  /// @param[in]  packet   The media packet to decode
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid state
  /// @retval #PLAYER_ERROR_NOT_SUPPORTED_FILE File not supported
  /// @retval #PLAYER_ERROR_BUFFER_SPACE No buffer space available (since 3.0)
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation (since 3.0)
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING or #PLAYER_STATE_PAUSED.
  /// @see player_set_media_stream_info()
  /// @see player_set_media_stream_buffer_max_size()
  int player_push_media_stream(
    player_h player,
    media_packet_h packet,
  ) {
    return _player_push_media_stream(
      player,
      packet,
    );
  }

  late final _player_push_media_streamPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, media_packet_h)>>(
          'player_push_media_stream');
  late final _player_push_media_stream = _player_push_media_streamPtr
      .asFunction<int Function(player_h, media_packet_h)>();

  /// @brief  Sets contents information for media stream
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks AV format must be set before pushing elementary stream with player_push_media_stream().
  /// @remarks This API must be called before calling the player_prepare() or player_prepare_async()
  /// to reflect the media information.
  /// @remarks AAC can be supported.
  /// @remarks H.264 can be supported.
  /// @param[in] player The handle to media player
  /// @param[in] type   The type of target stream
  /// @param[in] format The media format to set audio information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid state
  /// @pre The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare().
  /// @see  player_push_media_stream()
  int player_set_media_stream_info(
    player_h player,
    int type,
    media_format_h format,
  ) {
    return _player_set_media_stream_info(
      player,
      type,
      format,
    );
  }

  late final _player_set_media_stream_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Int32,
              media_format_h)>>('player_set_media_stream_info');
  late final _player_set_media_stream_info = _player_set_media_stream_infoPtr
      .asFunction<int Function(player_h, int, media_format_h)>();

  /// @brief Registers a callback function to be invoked when buffer underrun or overflow is occurred.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks This API is used for media stream playback only.
  /// @remarks The callback is called in a separate thread (not in the main loop).
  /// @param[in] player   The handle to the media player
  /// @param[in] type     The type of target stream
  /// @param[in] callback The buffer status callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare().
  /// @post player_media_stream_buffer_status_cb() will be invoked.
  /// @see player_unset_media_stream_buffer_status_cb()
  /// @see player_media_stream_buffer_status_cb()
  int player_set_media_stream_buffer_status_cb(
    player_h player,
    int type,
    player_media_stream_buffer_status_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_media_stream_buffer_status_cb(
      player,
      type,
      callback,
      user_data,
    );
  }

  late final _player_set_media_stream_buffer_status_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  player_h,
                  ffi.Int32,
                  player_media_stream_buffer_status_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'player_set_media_stream_buffer_status_cb');
  late final _player_set_media_stream_buffer_status_cb =
      _player_set_media_stream_buffer_status_cbPtr.asFunction<
          int Function(player_h, int, player_media_stream_buffer_status_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the buffer status callback function.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks This API is used for media stream playback only.
  /// @param[in] player The handle to the media player
  /// @param[in] type   The type of target stream
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see player_set_media_stream_buffer_status_cb()
  int player_unset_media_stream_buffer_status_cb(
    player_h player,
    int type,
  ) {
    return _player_unset_media_stream_buffer_status_cb(
      player,
      type,
    );
  }

  late final _player_unset_media_stream_buffer_status_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Int32)>>(
          'player_unset_media_stream_buffer_status_cb');
  late final _player_unset_media_stream_buffer_status_cb =
      _player_unset_media_stream_buffer_status_cbPtr
          .asFunction<int Function(player_h, int)>();

  /// @brief Registers a callback function to be invoked when seeking is occurred.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks This API is used for media stream playback only.
  /// @remarks The callback is called in a separate thread (not in the main loop).
  /// @param[in] player    The handle to the media player
  /// @param[in] type      The type of target stream
  /// @param[in] callback  The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare().
  /// @post player_media_stream_seek_cb() will be invoked.
  /// @see player_unset_media_stream_seek_cb()
  /// @see player_media_stream_seek_cb()
  int player_set_media_stream_seek_cb(
    player_h player,
    int type,
    player_media_stream_seek_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_media_stream_seek_cb(
      player,
      type,
      callback,
      user_data,
    );
  }

  late final _player_set_media_stream_seek_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Int32, player_media_stream_seek_cb,
              ffi.Pointer<ffi.Void>)>>('player_set_media_stream_seek_cb');
  late final _player_set_media_stream_seek_cb =
      _player_set_media_stream_seek_cbPtr.asFunction<
          int Function(player_h, int, player_media_stream_seek_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the seek callback function.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @param[in] player The handle to the media player
  /// @param[in] type   The type of target stream
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see player_set_media_stream_seek_cb()
  int player_unset_media_stream_seek_cb(
    player_h player,
    int type,
  ) {
    return _player_unset_media_stream_seek_cb(
      player,
      type,
    );
  }

  late final _player_unset_media_stream_seek_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Int32)>>(
          'player_unset_media_stream_seek_cb');
  late final _player_unset_media_stream_seek_cb =
      _player_unset_media_stream_seek_cbPtr
          .asFunction<int Function(player_h, int)>();

  /// @brief Sets the max size bytes of buffer.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks This API is used for media stream playback only.
  /// @remarks If the buffer level over the max size, player_media_stream_buffer_status_cb() will be invoked with overflow status.
  /// @param[in] player The handle to the media player
  /// @param[in] type   The type of target stream
  /// @param[in] max_size The max bytes of buffer, it has to be bigger than zero. (default: 200000)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED. (since 3.0)
  /// @see player_get_media_stream_buffer_max_size()
  /// @see player_media_stream_buffer_status_cb()
  int player_set_media_stream_buffer_max_size(
    player_h player,
    int type,
    int max_size,
  ) {
    return _player_set_media_stream_buffer_max_size(
      player,
      type,
      max_size,
    );
  }

  late final _player_set_media_stream_buffer_max_sizePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(player_h, ffi.Int32, ffi.UnsignedLongLong)>>(
      'player_set_media_stream_buffer_max_size');
  late final _player_set_media_stream_buffer_max_size =
      _player_set_media_stream_buffer_max_sizePtr
          .asFunction<int Function(player_h, int, int)>();

  /// @brief Gets the max size bytes of buffer.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks This API is used for media stream playback only.
  /// @remarks If the buffer level over the max size, player_media_stream_buffer_status_cb() will be invoked with overflow status.
  /// @param[in] player The handle to the media player
  /// @param[in] type   The type of target stream
  /// @param[out] max_size The max bytes of buffer
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_set_media_stream_buffer_max_size()
  /// @see player_media_stream_buffer_status_cb()
  int player_get_media_stream_buffer_max_size(
    player_h player,
    int type,
    ffi.Pointer<ffi.UnsignedLongLong> max_size,
  ) {
    return _player_get_media_stream_buffer_max_size(
      player,
      type,
      max_size,
    );
  }

  late final _player_get_media_stream_buffer_max_sizePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  player_h, ffi.Int32, ffi.Pointer<ffi.UnsignedLongLong>)>>(
      'player_get_media_stream_buffer_max_size');
  late final _player_get_media_stream_buffer_max_size =
      _player_get_media_stream_buffer_max_sizePtr.asFunction<
          int Function(player_h, int, ffi.Pointer<ffi.UnsignedLongLong>)>();

  /// @brief Sets the buffer threshold percent of buffer.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks This API is used for media stream playback only.
  /// @remarks If the buffer level drops below the percent value, player_media_stream_buffer_status_cb() will be invoked with underrun status.
  /// @param[in] player The handle to the media player
  /// @param[in] type   The type of target stream
  /// @param[in] percent The minimum threshold(0~100) of buffer (default: 0)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED. (since 3.0)
  /// @see player_get_media_stream_buffer_min_threshold()
  /// @see player_media_stream_buffer_status_cb()
  int player_set_media_stream_buffer_min_threshold(
    player_h player,
    int type,
    int percent,
  ) {
    return _player_set_media_stream_buffer_min_threshold(
      player,
      type,
      percent,
    );
  }

  late final _player_set_media_stream_buffer_min_thresholdPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(player_h, ffi.Int32, ffi.UnsignedInt)>>(
      'player_set_media_stream_buffer_min_threshold');
  late final _player_set_media_stream_buffer_min_threshold =
      _player_set_media_stream_buffer_min_thresholdPtr
          .asFunction<int Function(player_h, int, int)>();

  /// @brief Gets the buffer threshold percent of buffer.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks This API is used for media stream playback only.
  /// @remarks If the buffer level drops below the percent value, player_media_stream_buffer_status_cb() will be invoked with underrun status.
  /// @param[in] player The handle to the media player
  /// @param[in] type   The type of target stream
  /// @param[out] percent The minimum threshold(0~100) of buffer
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_set_media_stream_buffer_min_threshold()
  /// @see player_media_stream_buffer_status_cb()
  int player_get_media_stream_buffer_min_threshold(
    player_h player,
    int type,
    ffi.Pointer<ffi.UnsignedInt> percent,
  ) {
    return _player_get_media_stream_buffer_min_threshold(
      player,
      type,
      percent,
    );
  }

  late final _player_get_media_stream_buffer_min_thresholdPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  player_h, ffi.Int32, ffi.Pointer<ffi.UnsignedInt>)>>(
      'player_get_media_stream_buffer_min_threshold');
  late final _player_get_media_stream_buffer_min_threshold =
      _player_get_media_stream_buffer_min_thresholdPtr.asFunction<
          int Function(player_h, int, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Sets the video display mode.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks If no display is set, no operation is performed.
  /// @param[in] player   The handle to the media player
  /// @param[in] mode     The display mode
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see #player_display_mode_e
  /// @see player_set_display()
  /// @see	player_get_display_mode()
  int player_set_display_mode(
    player_h player,
    int mode,
  ) {
    return _player_set_display_mode(
      player,
      mode,
    );
  }

  late final _player_set_display_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Int32)>>(
          'player_set_display_mode');
  late final _player_set_display_mode =
      _player_set_display_modePtr.asFunction<int Function(player_h, int)>();

  /// @brief Gets the video display mode.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks If no display is set, no operation is performed.
  /// @param[in] player The handle to the media player
  /// @param[out] mode The current display mode
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #PLAYER_ERROR_NONE Successful
  /// @retval  #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval  #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see #player_display_mode_e
  /// @see player_set_display_mode()
  int player_get_display_mode(
    player_h player,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _player_get_display_mode(
      player,
      mode,
    );
  }

  late final _player_get_display_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              player_h, ffi.Pointer<ffi.Int32>)>>('player_get_display_mode');
  late final _player_get_display_mode = _player_get_display_modePtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the ROI(Region Of Interest) area of display.
  /// @since_tizen 3.0
  /// @remarks If no display is set, no operation is performed.
  /// @remarks Before set display ROI area, #PLAYER_DISPLAY_MODE_DST_ROI must be set with player_set_display_mode().
  /// The minimum value of width and height are 1.
  /// @param[in] player The handle to the media player
  /// @param[in] x X coordinate of area
  /// @param[in] y Y coordinate of area
  /// @param[in] width Width of area
  /// @param[in] height Height of area
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #PLAYER_ERROR_NONE Successful
  /// @retval  #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval  #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre display_mode must be set to #PLAYER_DISPLAY_MODE_DST_ROI.
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_set_display()
  /// @see player_set_display_mode()
  int player_set_display_roi_area(
    player_h player,
    int x,
    int y,
    int width,
    int height,
  ) {
    return _player_set_display_roi_area(
      player,
      x,
      y,
      width,
      height,
    );
  }

  late final _player_set_display_roi_areaPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Int, ffi.Int, ffi.Int,
              ffi.Int)>>('player_set_display_roi_area');
  late final _player_set_display_roi_area = _player_set_display_roi_areaPtr
      .asFunction<int Function(player_h, int, int, int, int)>();

  /// @brief Sets the visibility of the video display
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks If no display is set, no operation is performed.
  /// @remarks If you set visible before calling player_set_display, it will be applied on #PLAYER_STATE_READY state.
  /// @param[in] player   The handle to the media player
  /// @param[in] visible The visibility of the display (@c true = visible, @c false = non-visible )
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_set_display()
  /// @see	player_is_display_visible()
  int player_set_display_visible(
    player_h player,
    bool visible,
  ) {
    return _player_set_display_visible(
      player,
      visible,
    );
  }

  late final _player_set_display_visiblePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Bool)>>(
          'player_set_display_visible');
  late final _player_set_display_visible =
      _player_set_display_visiblePtr.asFunction<int Function(player_h, bool)>();

  /// @brief Gets the visibility of the video display.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[out] visible The current visibility of the display (@c true = visible, @c false = non-visible )
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #PLAYER_ERROR_NONE Successful
  /// @retval  #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval  #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see	player_set_display_visible()
  int player_is_display_visible(
    player_h player,
    ffi.Pointer<ffi.Bool> visible,
  ) {
    return _player_is_display_visible(
      player,
      visible,
    );
  }

  late final _player_is_display_visiblePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              player_h, ffi.Pointer<ffi.Bool>)>>('player_is_display_visible');
  late final _player_is_display_visible = _player_is_display_visiblePtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the rotation settings of the video surface display.
  /// @details Use this function to change the video orientation to portrait mode.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks If no display is set, no operation is performed.
  /// @param[in] player   The handle to the media player
  /// @param[in] rotation The rotation of the display
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see #player_display_rotation_e
  /// @see  player_set_display
  /// @see  player_get_display_rotation()
  int player_set_display_rotation(
    player_h player,
    int rotation,
  ) {
    return _player_set_display_rotation(
      player,
      rotation,
    );
  }

  late final _player_set_display_rotationPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Int32)>>(
          'player_set_display_rotation');
  late final _player_set_display_rotation =
      _player_set_display_rotationPtr.asFunction<int Function(player_h, int)>();

  /// @brief Gets the rotation of the video surface display.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[out] rotation The current rotation of the display
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #PLAYER_ERROR_NONE Successful
  /// @retval  #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval  #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see #player_display_rotation_e
  /// @see     player_set_display_rotation()
  int player_get_display_rotation(
    player_h player,
    ffi.Pointer<ffi.Int32> rotation,
  ) {
    return _player_get_display_rotation(
      player,
      rotation,
    );
  }

  late final _player_get_display_rotationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h,
              ffi.Pointer<ffi.Int32>)>>('player_get_display_rotation');
  late final _player_get_display_rotation = _player_get_display_rotationPtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the media content information.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks You must release @a value using @c free().
  /// @remarks The playback type should be local playback or HTTP streaming playback.
  /// @param[in]  player The handle to the media player
  /// @param[in] key The key attribute name to get
  /// @param[out] value The value of the key attribute \n
  /// It can be an empty string if there is no content information.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #PLAYER_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING or #PLAYER_STATE_PAUSED.
  int player_get_content_info(
    player_h player,
    int key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _player_get_content_info(
      player,
      key,
      value,
    );
  }

  late final _player_get_content_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Int32,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('player_get_content_info');
  late final _player_get_content_info = _player_get_content_infoPtr.asFunction<
      int Function(player_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the audio and video codec information.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks You must release @a audio_codec and @a video_codec using free().
  /// @remarks The playback type should be local playback or HTTP streaming playback.
  /// @param[in] player The handle to the media player
  /// @param[out] audio_codec The name of the audio codec \n
  /// It can be @c NULL if there is no audio codec.
  /// @param[out] video_codec The name of the video codec \n
  /// It can be @c NULL if there is no video codec.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING or #PLAYER_STATE_PAUSED.
  int player_get_codec_info(
    player_h player,
    ffi.Pointer<ffi.Pointer<ffi.Char>> audio_codec,
    ffi.Pointer<ffi.Pointer<ffi.Char>> video_codec,
  ) {
    return _player_get_codec_info(
      player,
      audio_codec,
      video_codec,
    );
  }

  late final _player_get_codec_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('player_get_codec_info');
  late final _player_get_codec_info = _player_get_codec_infoPtr.asFunction<
      int Function(player_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the audio stream information.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The playback type should be local playback or HTTP streaming playback.
  /// @param[in] player The handle to the media player
  /// @param[out]  sample_rate The audio sample rate [Hz] \n
  /// Value can be invalid if there is no audio stream information.
  /// @param[out]  channel The audio channel (1: mono, 2: stereo) \n
  /// Value can be invalid if there is no audio stream information.
  /// @param[out]  bit_rate The audio bit rate [Hz] \n
  /// Value can be invalid if there is no audio stream information.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING or #PLAYER_STATE_PAUSED.
  int player_get_audio_stream_info(
    player_h player,
    ffi.Pointer<ffi.Int> sample_rate,
    ffi.Pointer<ffi.Int> channel,
    ffi.Pointer<ffi.Int> bit_rate,
  ) {
    return _player_get_audio_stream_info(
      player,
      sample_rate,
      channel,
      bit_rate,
    );
  }

  late final _player_get_audio_stream_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('player_get_audio_stream_info');
  late final _player_get_audio_stream_info =
      _player_get_audio_stream_infoPtr.asFunction<
          int Function(player_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the video stream information.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The playback type should be local playback or HTTP streaming playback.
  /// @param[in] player The handle to the media player
  /// @param[out]  fps The frame per second of the video \n
  /// It can be @c 0 if there is no video stream information.
  /// @param[out]  bit_rate The video bit rate [Hz] \n
  /// It can be an invalid value if there is no video stream information.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING or #PLAYER_STATE_PAUSED.
  int player_get_video_stream_info(
    player_h player,
    ffi.Pointer<ffi.Int> fps,
    ffi.Pointer<ffi.Int> bit_rate,
  ) {
    return _player_get_video_stream_info(
      player,
      fps,
      bit_rate,
    );
  }

  late final _player_get_video_stream_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('player_get_video_stream_info');
  late final _player_get_video_stream_info =
      _player_get_video_stream_infoPtr.asFunction<
          int Function(player_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the video display's height and width.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The playback type should be local playback or HTTP streaming playback.
  /// @param[in] player The handle to the media player
  /// @param[out] width The width of the video \n
  /// Value can be invalid if there is no video or no display is set.
  /// @param[out] height The height of the video \n
  /// Value can be invalid value if there is no video or no display is set.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING or #PLAYER_STATE_PAUSED.
  int player_get_video_size(
    player_h player,
    ffi.Pointer<ffi.Int> width,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _player_get_video_size(
      player,
      width,
      height,
    );
  }

  late final _player_get_video_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('player_get_video_size');
  late final _player_get_video_size = _player_get_video_sizePtr.asFunction<
      int Function(player_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the album art in the media resource.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks You must not release @a album_art. It will be released by framework when the player is destroyed.
  /// @param[in] player The handle to the media player
  /// @param[out] album_art The encoded artwork image
  /// @param[out] size The encoded artwork size
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING or #PLAYER_STATE_PAUSED.
  int player_get_album_art(
    player_h player,
    ffi.Pointer<ffi.Pointer<ffi.Void>> album_art,
    ffi.Pointer<ffi.Int> size,
  ) {
    return _player_get_album_art(
      player,
      album_art,
      size,
    );
  }

  late final _player_get_album_artPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.Int>)>>('player_get_album_art');
  late final _player_get_album_art = _player_get_album_artPtr.asFunction<
      int Function(player_h, ffi.Pointer<ffi.Pointer<ffi.Void>>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the total running time of the associated media.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The media source is associated with the player, using either player_set_uri() or player_set_memory_buffer().
  /// @remarks The playback type should be local playback or HTTP streaming playback.
  /// @param[in]   player The handle to the media player
  /// @param[out]  duration The duration in milliseconds
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING or #PLAYER_STATE_PAUSED.
  /// @see player_set_uri()
  /// @see player_set_memory_buffer()
  int player_get_duration(
    player_h player,
    ffi.Pointer<ffi.Int> duration,
  ) {
    return _player_get_duration(
      player,
      duration,
    );
  }

  late final _player_get_durationPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(player_h, ffi.Pointer<ffi.Int>)>>(
      'player_get_duration');
  late final _player_get_duration = _player_get_durationPtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the number of equalizer bands.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[out] count The number of equalizer bands
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_audio_effect_equalizer_is_available()
  /// @see player_audio_effect_set_equalizer_band_level()
  /// @see player_audio_effect_set_equalizer_all_bands()
  int player_audio_effect_get_equalizer_bands_count(
    player_h player,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _player_audio_effect_get_equalizer_bands_count(
      player,
      count,
    );
  }

  late final _player_audio_effect_get_equalizer_bands_countPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(player_h, ffi.Pointer<ffi.Int>)>>(
      'player_audio_effect_get_equalizer_bands_count');
  late final _player_audio_effect_get_equalizer_bands_count =
      _player_audio_effect_get_equalizer_bands_countPtr
          .asFunction<int Function(player_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the gain set for the given equalizer band.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[in] index The index of the equalizer band to be set
  /// @param[in] level The new gain in decibel that is set to the given band [dB]
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_audio_effect_equalizer_is_available()
  /// @see player_audio_effect_get_equalizer_bands_count()
  /// @see player_audio_effect_get_equalizer_level_range()
  /// @see player_audio_effect_get_equalizer_band_level()
  /// @see player_audio_effect_set_equalizer_all_bands()
  int player_audio_effect_set_equalizer_band_level(
    player_h player,
    int index,
    int level,
  ) {
    return _player_audio_effect_set_equalizer_band_level(
      player,
      index,
      level,
    );
  }

  late final _player_audio_effect_set_equalizer_band_levelPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Int, ffi.Int)>>(
          'player_audio_effect_set_equalizer_band_level');
  late final _player_audio_effect_set_equalizer_band_level =
      _player_audio_effect_set_equalizer_band_levelPtr
          .asFunction<int Function(player_h, int, int)>();

  /// @brief Gets the gain set for the given equalizer band.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in]   player The handle to the media player
  /// @param[in]   index The index of the requested equalizer band
  /// @param[out]   level The gain in decibel of the given band [dB]
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_audio_effect_equalizer_is_available()
  /// @see player_audio_effect_set_equalizer_band_level()
  int player_audio_effect_get_equalizer_band_level(
    player_h player,
    int index,
    ffi.Pointer<ffi.Int> level,
  ) {
    return _player_audio_effect_get_equalizer_band_level(
      player,
      index,
      level,
    );
  }

  late final _player_audio_effect_get_equalizer_band_levelPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(player_h, ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'player_audio_effect_get_equalizer_band_level');
  late final _player_audio_effect_get_equalizer_band_level =
      _player_audio_effect_get_equalizer_band_levelPtr
          .asFunction<int Function(player_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets all bands of the equalizer.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[in] band_levels The list of band levels to be set
  /// @param[in] length The length of the band level
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_audio_effect_equalizer_is_available()
  /// @see player_audio_effect_get_equalizer_bands_count()
  /// @see player_audio_effect_get_equalizer_level_range()
  /// @see player_audio_effect_set_equalizer_band_level()
  int player_audio_effect_set_equalizer_all_bands(
    player_h player,
    ffi.Pointer<ffi.Int> band_levels,
    int length,
  ) {
    return _player_audio_effect_set_equalizer_all_bands(
      player,
      band_levels,
      length,
    );
  }

  late final _player_audio_effect_set_equalizer_all_bandsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Int>,
              ffi.Int)>>('player_audio_effect_set_equalizer_all_bands');
  late final _player_audio_effect_set_equalizer_all_bands =
      _player_audio_effect_set_equalizer_all_bandsPtr
          .asFunction<int Function(player_h, ffi.Pointer<ffi.Int>, int)>();

  /// @brief Gets the valid band level range of the equalizer.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[out] min The minimum value to be set [dB]
  /// @param[out] max The maximum value to be set [dB]
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_audio_effect_equalizer_is_available()
  /// @see player_audio_effect_set_equalizer_band_level()
  /// @see player_audio_effect_set_equalizer_all_bands()
  int player_audio_effect_get_equalizer_level_range(
    player_h player,
    ffi.Pointer<ffi.Int> min,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _player_audio_effect_get_equalizer_level_range(
      player,
      min,
      max,
    );
  }

  late final _player_audio_effect_get_equalizer_level_rangePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  player_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>>(
      'player_audio_effect_get_equalizer_level_range');
  late final _player_audio_effect_get_equalizer_level_range =
      _player_audio_effect_get_equalizer_level_rangePtr.asFunction<
          int Function(player_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the band frequency of the equalizer.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[in]  index The index of the requested equalizer band
  /// @param[out] frequency The frequency of the given band [dB]
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_audio_effect_equalizer_is_available()
  int player_audio_effect_get_equalizer_band_frequency(
    player_h player,
    int index,
    ffi.Pointer<ffi.Int> frequency,
  ) {
    return _player_audio_effect_get_equalizer_band_frequency(
      player,
      index,
      frequency,
    );
  }

  late final _player_audio_effect_get_equalizer_band_frequencyPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(player_h, ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'player_audio_effect_get_equalizer_band_frequency');
  late final _player_audio_effect_get_equalizer_band_frequency =
      _player_audio_effect_get_equalizer_band_frequencyPtr
          .asFunction<int Function(player_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the band frequency range of the equalizer.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[in]  index The index of the requested equalizer band
  /// @param[out] range The frequency range of the given band [dB]
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_audio_effect_equalizer_is_available()
  int player_audio_effect_get_equalizer_band_frequency_range(
    player_h player,
    int index,
    ffi.Pointer<ffi.Int> range,
  ) {
    return _player_audio_effect_get_equalizer_band_frequency_range(
      player,
      index,
      range,
    );
  }

  late final _player_audio_effect_get_equalizer_band_frequency_rangePtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(player_h, ffi.Int, ffi.Pointer<ffi.Int>)>>(
          'player_audio_effect_get_equalizer_band_frequency_range');
  late final _player_audio_effect_get_equalizer_band_frequency_range =
      _player_audio_effect_get_equalizer_band_frequency_rangePtr
          .asFunction<int Function(player_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Clears the equalizer effect.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_audio_effect_equalizer_is_available()
  /// @see player_audio_effect_set_equalizer_band_level()
  /// @see player_audio_effect_set_equalizer_all_bands()
  int player_audio_effect_equalizer_clear(
    player_h player,
  ) {
    return _player_audio_effect_equalizer_clear(
      player,
    );
  }

  late final _player_audio_effect_equalizer_clearPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>(
          'player_audio_effect_equalizer_clear');
  late final _player_audio_effect_equalizer_clear =
      _player_audio_effect_equalizer_clearPtr
          .asFunction<int Function(player_h)>();

  /// @brief Checks whether the custom equalizer effect is available.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[out] available If @c true the specified audio effect is available,
  /// otherwise @c false
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_audio_effect_set_equalizer_band_level()
  /// @see player_audio_effect_set_equalizer_all_bands()
  int player_audio_effect_equalizer_is_available(
    player_h player,
    ffi.Pointer<ffi.Bool> available,
  ) {
    return _player_audio_effect_equalizer_is_available(
      player,
      available,
    );
  }

  late final _player_audio_effect_equalizer_is_availablePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(player_h, ffi.Pointer<ffi.Bool>)>>(
      'player_audio_effect_equalizer_is_available');
  late final _player_audio_effect_equalizer_is_available =
      _player_audio_effect_equalizer_is_availablePtr
          .asFunction<int Function(player_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Captures the video frame, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[in] callback	The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be set to #PLAYER_STATE_PLAYING by calling player_start() or set to #PLAYER_STATE_PAUSED by calling player_pause().
  /// @pre Video display type should be set by calling player_set_display() otherwise, audio stream is only processed even though video file is set.
  /// @post It invokes player_video_captured_cb() when capture completes, if you set a callback.
  /// @see player_video_captured_cb()
  int player_capture_video(
    player_h player,
    player_video_captured_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_capture_video(
      player,
      callback,
      user_data,
    );
  }

  late final _player_capture_videoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, player_video_captured_cb,
              ffi.Pointer<ffi.Void>)>>('player_capture_video');
  late final _player_capture_video = _player_capture_videoPtr.asFunction<
      int Function(
          player_h, player_video_captured_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the cookie for streaming playback.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks This API must be called before calling the player_prepare() or player_prepare_async()
  /// to reflect the cookie information when the streaming connection is set up.
  /// @param[in] player The handle to the media player
  /// @param[in] cookie The cookie to set
  /// @param[in] size The size of the cookie
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare().
  /// @see player_set_uri()
  /// @see player_set_streaming_user_agent()
  int player_set_streaming_cookie(
    player_h player,
    ffi.Pointer<ffi.Char> cookie,
    int size,
  ) {
    return _player_set_streaming_cookie(
      player,
      cookie,
      size,
    );
  }

  late final _player_set_streaming_cookiePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Char>,
              ffi.Int)>>('player_set_streaming_cookie');
  late final _player_set_streaming_cookie = _player_set_streaming_cookiePtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Sets the streaming user agent for playback.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks This API must be called before calling the player_prepare() or player_prepare_async()
  /// to reflect the user agent information when the streaming connection is set up.
  /// @param[in] player The handle to the media player
  /// @param[in] user_agent The user agent to set
  /// @param[in] size The size of the user agent
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare().
  /// @see player_set_uri()
  /// @see player_set_streaming_cookie()
  int player_set_streaming_user_agent(
    player_h player,
    ffi.Pointer<ffi.Char> user_agent,
    int size,
  ) {
    return _player_set_streaming_user_agent(
      player,
      user_agent,
      size,
    );
  }

  late final _player_set_streaming_user_agentPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Char>,
              ffi.Int)>>('player_set_streaming_user_agent');
  late final _player_set_streaming_user_agent =
      _player_set_streaming_user_agentPtr
          .asFunction<int Function(player_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Gets the download progress for streaming playback.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[out] start The starting position in percentage [0, 100]
  /// @param[out] current The current position in percentage [0, 100]
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be set to #PLAYER_STATE_PLAYING by calling player_start() or set to #PLAYER_STATE_PAUSED by calling player_pause().
  int player_get_streaming_download_progress(
    player_h player,
    ffi.Pointer<ffi.Int> start,
    ffi.Pointer<ffi.Int> current,
  ) {
    return _player_get_streaming_download_progress(
      player,
      start,
      current,
    );
  }

  late final _player_get_streaming_download_progressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('player_get_streaming_download_progress');
  late final _player_get_streaming_download_progress =
      _player_get_streaming_download_progressPtr.asFunction<
          int Function(player_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Registers a callback function to be invoked when the playback is finished.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player	The handle to the media player
  /// @param[in] callback	The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @post  player_completed_cb() will be invoked.
  /// @see player_unset_completed_cb()
  /// @see player_completed_cb()
  /// @see player_start()
  int player_set_completed_cb(
    player_h player,
    player_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_completed_cb(
      player,
      callback,
      user_data,
    );
  }

  late final _player_set_completed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, player_completed_cb,
              ffi.Pointer<ffi.Void>)>>('player_set_completed_cb');
  late final _player_set_completed_cb = _player_set_completed_cbPtr.asFunction<
      int Function(player_h, player_completed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @see player_set_completed_cb()
  int player_unset_completed_cb(
    player_h player,
  ) {
    return _player_unset_completed_cb(
      player,
    );
  }

  late final _player_unset_completed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>(
          'player_unset_completed_cb');
  late final _player_unset_completed_cb =
      _player_unset_completed_cbPtr.asFunction<int Function(player_h)>();

  /// @brief Registers a callback function to be invoked when the playback is interrupted or the interrupt is completed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player	The handle to the media player
  /// @param[in] callback	The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @post  player_interrupted_cb() will be invoked.
  /// @see player_unset_interrupted_cb()
  /// @see #player_interrupted_code_e
  /// @see player_interrupted_cb()
  int player_set_interrupted_cb(
    player_h player,
    player_interrupted_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_interrupted_cb(
      player,
      callback,
      user_data,
    );
  }

  late final _player_set_interrupted_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, player_interrupted_cb,
              ffi.Pointer<ffi.Void>)>>('player_set_interrupted_cb');
  late final _player_set_interrupted_cb =
      _player_set_interrupted_cbPtr.asFunction<
          int Function(
              player_h, player_interrupted_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @see player_set_interrupted_cb()
  int player_unset_interrupted_cb(
    player_h player,
  ) {
    return _player_unset_interrupted_cb(
      player,
    );
  }

  late final _player_unset_interrupted_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>(
          'player_unset_interrupted_cb');
  late final _player_unset_interrupted_cb =
      _player_unset_interrupted_cbPtr.asFunction<int Function(player_h)>();

  /// @brief Registers a callback function to be invoked when an error occurs.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player	The handle to the media player
  /// @param[in] callback	The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @post  player_error_cb() will be invoked.
  /// @see player_unset_error_cb()
  /// @see player_error_cb()
  int player_set_error_cb(
    player_h player,
    player_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_error_cb(
      player,
      callback,
      user_data,
    );
  }

  late final _player_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, player_error_cb,
              ffi.Pointer<ffi.Void>)>>('player_set_error_cb');
  late final _player_set_error_cb = _player_set_error_cbPtr.asFunction<
      int Function(player_h, player_error_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @see player_set_error_cb()
  int player_unset_error_cb(
    player_h player,
  ) {
    return _player_unset_error_cb(
      player,
    );
  }

  late final _player_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>(
          'player_unset_error_cb');
  late final _player_unset_error_cb =
      _player_unset_error_cbPtr.asFunction<int Function(player_h)>();

  /// @brief Registers a callback function to be invoked when there is a change in the buffering status of a media stream.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The media resource should be streamed over the network.
  /// @param[in] player	The handle to the media player
  /// @param[in] callback	The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @if WEARABLE @retval #PLAYER_ERROR_FEATURE_NOT_SUPPORTED_ON_DEVICE Unsupported feature @endif
  /// @post  player_buffering_cb() will be invoked.
  /// @see player_unset_buffering_cb()
  /// @see player_set_uri()
  /// @see player_buffering_cb()
  int player_set_buffering_cb(
    player_h player,
    player_buffering_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_buffering_cb(
      player,
      callback,
      user_data,
    );
  }

  late final _player_set_buffering_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, player_buffering_cb,
              ffi.Pointer<ffi.Void>)>>('player_set_buffering_cb');
  late final _player_set_buffering_cb = _player_set_buffering_cbPtr.asFunction<
      int Function(player_h, player_buffering_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @see player_set_buffering_cb()
  int player_unset_buffering_cb(
    player_h player,
  ) {
    return _player_unset_buffering_cb(
      player,
    );
  }

  late final _player_unset_buffering_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>(
          'player_unset_buffering_cb');
  late final _player_unset_buffering_cb =
      _player_unset_buffering_cbPtr.asFunction<int Function(player_h)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Sets a path to download, progressively.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks Progressive download will be started when you invoke player_start().
  /// @remarks This API must be called before calling the player_prepare() or player_prepare_async() to reflect the download path when the player is building.
  /// @remarks The mediastorage privilege(http://tizen.org/privilege/mediastorage) must be added if any files are used to download and play located in the internal storage.
  /// @remarks The externalstorage privilege(http://tizen.org/privilege/externalstorage) must be added if any files are used to download and play located in the external storage.
  ///
  /// @param[in]   player The handle to the media player
  /// @param[in]   path The absolute path to download
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @if WEARABLE @retval #PLAYER_ERROR_FEATURE_NOT_SUPPORTED_ON_DEVICE Unsupported feature @endif
  /// @retval #PLAYER_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare().
  /// @see player_set_progressive_download_message_cb()
  /// @see player_unset_progressive_download_message_cb()
  int player_set_progressive_download_path(
    player_h player,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _player_set_progressive_download_path(
      player,
      path,
    );
  }

  late final _player_set_progressive_download_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h,
              ffi.Pointer<ffi.Char>)>>('player_set_progressive_download_path');
  late final _player_set_progressive_download_path =
      _player_set_progressive_download_pathPtr
          .asFunction<int Function(player_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Gets the status of progressive download.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @param[out] current The current download position (bytes)
  /// @param[out] total_size The total size of the file (bytes)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The progressive download path must be set by calling player_set_progressive_download_path().
  /// @pre The player state must be set to #PLAYER_STATE_PLAYING by calling player_start() or set to #PLAYER_STATE_PAUSED by calling player_pause().
  int player_get_progressive_download_status(
    player_h player,
    ffi.Pointer<ffi.UnsignedLong> current,
    ffi.Pointer<ffi.UnsignedLong> total_size,
  ) {
    return _player_get_progressive_download_status(
      player,
      current,
      total_size,
    );
  }

  late final _player_get_progressive_download_statusPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(player_h, ffi.Pointer<ffi.UnsignedLong>,
                  ffi.Pointer<ffi.UnsignedLong>)>>(
      'player_get_progressive_download_status');
  late final _player_get_progressive_download_status =
      _player_get_progressive_download_statusPtr.asFunction<
          int Function(player_h, ffi.Pointer<ffi.UnsignedLong>,
              ffi.Pointer<ffi.UnsignedLong>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Registers a callback function to be invoked when progressive download is started or completed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player	The handle to the media player
  /// @param[in] callback	The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @if WEARABLE @retval #PLAYER_ERROR_FEATURE_NOT_SUPPORTED_ON_DEVICE Unsupported feature @endif
  /// @pre The path to download must be set by calling player_set_progressive_download_path().
  /// @post  player_pd_message_cb() will be invoked.
  /// @see player_unset_progressive_download_message_cb()
  /// @see player_set_progressive_download_path()
  int player_set_progressive_download_message_cb(
    player_h player,
    player_pd_message_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_progressive_download_message_cb(
      player,
      callback,
      user_data,
    );
  }

  late final _player_set_progressive_download_message_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  player_h, player_pd_message_cb, ffi.Pointer<ffi.Void>)>>(
      'player_set_progressive_download_message_cb');
  late final _player_set_progressive_download_message_cb =
      _player_set_progressive_download_message_cbPtr.asFunction<
          int Function(
              player_h, player_pd_message_cb, ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 4.0.
  /// @brief Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @see player_set_progressive_download_message_cb()
  int player_unset_progressive_download_message_cb(
    player_h player,
  ) {
    return _player_unset_progressive_download_message_cb(
      player,
    );
  }

  late final _player_unset_progressive_download_message_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>(
          'player_unset_progressive_download_message_cb');
  late final _player_unset_progressive_download_message_cb =
      _player_unset_progressive_download_message_cbPtr
          .asFunction<int Function(player_h)>();

  /// @brief Sets the playback rate.
  /// @details The default value is @c 1.0.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks #PLAYER_ERROR_INVALID_OPERATION occurs when streaming playback.
  /// @remarks No operation is performed, if @a rate is @c 0.
  /// @remarks The sound is muted, when playback rate is under @c 0.0 and over @c 2.0.
  /// @param[in] player The handle to the media player
  /// @param[in] rate The playback rate (-5.0x ~ 5.0x)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  int player_set_playback_rate(
    player_h player,
    double rate,
  ) {
    return _player_set_playback_rate(
      player,
      rate,
    );
  }

  late final _player_set_playback_ratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Float)>>(
          'player_set_playback_rate');
  late final _player_set_playback_rate =
      _player_set_playback_ratePtr.asFunction<int Function(player_h, double)>();

  /// @brief Sets a subtitle path.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks Only MicroDVD/SubViewer(*.sub), SAMI(*.smi), and SubRip(*.srt) subtitle formats are supported.
  /// @remarks The mediastorage privilege(http://tizen.org/privilege/mediastorage) must be added if any files are used to play located in the internal storage.
  /// @remarks The externalstorage privilege(http://tizen.org/privilege/externalstorage) must be added if any files are used to play located in the external storage.
  /// @remarks The path value can be @c NULL for reset before calling player_prepare() or player_prepare_async().
  ///
  /// @param[in]   player The handle to the media player
  /// @param[in]   path The absolute path of the subtitle file, it can be @c NULL in the #PLAYER_STATE_IDLE state.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PLAYER_ERROR_NO_SUCH_FILE File not found (Since 4.0)
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  int player_set_subtitle_path(
    player_h player,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _player_set_subtitle_path(
      player,
      path,
    );
  }

  late final _player_set_subtitle_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              player_h, ffi.Pointer<ffi.Char>)>>('player_set_subtitle_path');
  late final _player_set_subtitle_path = _player_set_subtitle_pathPtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Registers a callback function to be invoked when a subtitle updates.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The callback is called in a separate thread (not in the main loop).
  /// @param[in] player	The handle to the media player
  /// @param[in] callback	The callback function to register
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The subtitle must be set by calling player_set_subtitle_path().
  /// @post  player_subtitle_updated_cb() will be invoked.
  /// @see player_unset_subtitle_updated_cb()
  /// @see player_subtitle_updated_cb()
  /// @see player_set_subtitle_path()
  int player_set_subtitle_updated_cb(
    player_h player,
    player_subtitle_updated_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_subtitle_updated_cb(
      player,
      callback,
      user_data,
    );
  }

  late final _player_set_subtitle_updated_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, player_subtitle_updated_cb,
              ffi.Pointer<ffi.Void>)>>('player_set_subtitle_updated_cb');
  late final _player_set_subtitle_updated_cb =
      _player_set_subtitle_updated_cbPtr.asFunction<
          int Function(
              player_h, player_subtitle_updated_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @see player_set_subtitle_updated_cb()
  int player_unset_subtitle_updated_cb(
    player_h player,
  ) {
    return _player_unset_subtitle_updated_cb(
      player,
    );
  }

  late final _player_unset_subtitle_updated_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>(
          'player_unset_subtitle_updated_cb');
  late final _player_unset_subtitle_updated_cb =
      _player_unset_subtitle_updated_cbPtr.asFunction<int Function(player_h)>();

  /// @brief Sets the seek position for the subtitle.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif.1
  /// @remarks Only MicroDVD/SubViewer(*.sub), SAMI(*.smi), and SubRip(*.srt) subtitle formats are supported.
  /// @param[in]  player The handle to the media player
  /// @param[in]  millisecond The position in milliseconds from the start to the seek point
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The subtitle must be set by calling player_set_subtitle_path().
  /// @pre The player state must be one of #PLAYER_STATE_PLAYING or #PLAYER_STATE_PAUSED.
  int player_set_subtitle_position_offset(
    player_h player,
    int millisecond,
  ) {
    return _player_set_subtitle_position_offset(
      player,
      millisecond,
    );
  }

  late final _player_set_subtitle_position_offsetPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Int)>>(
          'player_set_subtitle_position_offset');
  late final _player_set_subtitle_position_offset =
      _player_set_subtitle_position_offsetPtr
          .asFunction<int Function(player_h, int)>();

  /// @brief Registers a callback function to be invoked when video stream is changed.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks The stream changing is detected just before rendering operation.
  /// @remarks The callback is called in a separate thread (not in the main loop).
  /// @remarks This API must be called before calling the player_prepare() or player_prepare_async()
  /// to reflect the requirement when the player is building.
  /// @param[in] player   The handle to the media player
  /// @param[in] callback The stream changed callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre The player state must be set to #PLAYER_STATE_IDLE by calling player_create() or player_unprepare().
  /// @post player_video_stream_changed_cb() will be invoked.
  /// @see player_unset_video_stream_changed_cb()
  /// @see player_video_stream_changed_cb()
  int player_set_video_stream_changed_cb(
    player_h player,
    player_video_stream_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_set_video_stream_changed_cb(
      player,
      callback,
      user_data,
    );
  }

  late final _player_set_video_stream_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, player_video_stream_changed_cb,
              ffi.Pointer<ffi.Void>)>>('player_set_video_stream_changed_cb');
  late final _player_set_video_stream_changed_cb =
      _player_set_video_stream_changed_cbPtr.asFunction<
          int Function(player_h, player_video_stream_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the video stream changed callback function.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @param[in] player The handle to the media player
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see player_set_video_stream_changed_cb()
  int player_unset_video_stream_changed_cb(
    player_h player,
  ) {
    return _player_unset_video_stream_changed_cb(
      player,
    );
  }

  late final _player_unset_video_stream_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h)>>(
          'player_unset_video_stream_changed_cb');
  late final _player_unset_video_stream_changed_cb =
      _player_unset_video_stream_changed_cbPtr
          .asFunction<int Function(player_h)>();

  /// @brief Gets current track index.
  /// @details Index starts from 0.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @param[in] player The handle to the media player
  /// @param[in] type The type of target stream which is PLAYER_STREAM_TYPE_AUDIO or PLAYER_STREAM_TYPE_TEXT
  /// @param[out] index  The index of track
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED
  int player_get_current_track(
    player_h player,
    int type,
    ffi.Pointer<ffi.Int> index,
  ) {
    return _player_get_current_track(
      player,
      type,
      index,
    );
  }

  late final _player_get_current_trackPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Int32,
              ffi.Pointer<ffi.Int>)>>('player_get_current_track');
  late final _player_get_current_track = _player_get_current_trackPtr
      .asFunction<int Function(player_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets language code of a track.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks @a code must be released with @c free() by caller
  /// @param[in] player The handle to the media player
  /// @param[in] type The type of target stream which is PLAYER_STREAM_TYPE_AUDIO or PLAYER_STREAM_TYPE_TEXT
  /// @param[in] index  The index of track
  /// @param[out] code A language code in ISO 639-1. "und" will be returned if the language is undefined.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED
  int player_get_track_language_code(
    player_h player,
    int type,
    int index,
    ffi.Pointer<ffi.Pointer<ffi.Char>> code,
  ) {
    return _player_get_track_language_code(
      player,
      type,
      index,
      code,
    );
  }

  late final _player_get_track_language_codePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(player_h, ffi.Int32, ffi.Int,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'player_get_track_language_code');
  late final _player_get_track_language_code =
      _player_get_track_language_codePtr.asFunction<
          int Function(
              player_h, int, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the track count.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @param[in] player The handle to the media player
  /// @param[in] type The type of target stream which is PLAYER_STREAM_TYPE_AUDIO or PLAYER_STREAM_TYPE_TEXT
  /// @param[out] count The number of track
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED
  int player_get_track_count(
    player_h player,
    int type,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _player_get_track_count(
      player,
      type,
      count,
    );
  }

  late final _player_get_track_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Int32,
              ffi.Pointer<ffi.Int>)>>('player_get_track_count');
  late final _player_get_track_count = _player_get_track_countPtr
      .asFunction<int Function(player_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Selects a track to play.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @param[in] player The handle to the media player
  /// @param[in] type The type of target stream which is PLAYER_STREAM_TYPE_AUDIO or PLAYER_STREAM_TYPE_TEXT
  /// @param[in] index  The index of track
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED
  /// @see player_get_current_track()
  int player_select_track(
    player_h player,
    int type,
    int index,
  ) {
    return _player_select_track(
      player,
      type,
      index,
    );
  }

  late final _player_select_trackPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(player_h, ffi.Int32, ffi.Int)>>(
      'player_select_track');
  late final _player_select_track =
      _player_select_trackPtr.asFunction<int Function(player_h, int, int)>();

  /// @brief Retrieves all the streaming variant information.
  /// @since_tizen 4.0
  /// @remarks This API is used for adaptive streaming(hls/mpeg dash) only.
  /// @param[in] player The handle to the media player
  /// @param[in] callback The iteration callback function
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid player state
  /// @pre The player state must be one of #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED
  /// @see player_adaptive_variant_cb
  int player_foreach_adaptive_variant(
    player_h player,
    player_adaptive_variant_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _player_foreach_adaptive_variant(
      player,
      callback,
      user_data,
    );
  }

  late final _player_foreach_adaptive_variantPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, player_adaptive_variant_cb,
              ffi.Pointer<ffi.Void>)>>('player_foreach_adaptive_variant');
  late final _player_foreach_adaptive_variant =
      _player_foreach_adaptive_variantPtr.asFunction<
          int Function(
              player_h, player_adaptive_variant_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the maximum limit of the streaming variant.
  /// @since_tizen 4.0
  /// @remarks This API is used for adaptive streaming(hls/mpeg dash) only.
  /// @remarks The bandwidth setting can only be applied if there is no width, height information at streaming variant header.
  /// Application can get all the variant information by calling player_foreach_adaptive_variant() function.
  /// @remarks If there is no affordable stream for the condition, the minimum bandwidth stream will be selected.
  /// @param[in] player The handle to the media player
  /// @param[in] bandwidth The max bandwidth limit of the stream variant (default: -1)
  /// @param[in] width The max width limit of the stream variant (deafult: -1)
  /// @param[in] height The max height limit of the stream variant (deafult: -1)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_foreach_adaptive_variant()
  /// @see player_get_max_adaptive_variant_limit()
  int player_set_max_adaptive_variant_limit(
    player_h player,
    int bandwidth,
    int width,
    int height,
  ) {
    return _player_set_max_adaptive_variant_limit(
      player,
      bandwidth,
      width,
      height,
    );
  }

  late final _player_set_max_adaptive_variant_limitPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Int, ffi.Int,
              ffi.Int)>>('player_set_max_adaptive_variant_limit');
  late final _player_set_max_adaptive_variant_limit =
      _player_set_max_adaptive_variant_limitPtr
          .asFunction<int Function(player_h, int, int, int)>();

  /// @brief Gets the maximum limit of the streaming variant.
  /// @since_tizen 4.0
  /// @remarks This API is used for adaptive streaming(hls/mpeg dash) only.
  /// @param[in] player The handle to the media player
  /// @param[out] bandwidth The max bandwidth limit of the stream variant (default: -1)
  /// @param[out] width The max width limit of the stream variant (deafult: -1)
  /// @param[out] height The max height limit of the stream variant (deafult: -1)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_foreach_adaptive_variant()
  /// @see player_set_max_adaptive_variant_limit()
  int player_get_max_adaptive_variant_limit(
    player_h player,
    ffi.Pointer<ffi.Int> bandwidth,
    ffi.Pointer<ffi.Int> width,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _player_get_max_adaptive_variant_limit(
      player,
      bandwidth,
      width,
      height,
    );
  }

  late final _player_get_max_adaptive_variant_limitPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('player_get_max_adaptive_variant_limit');
  late final _player_get_max_adaptive_variant_limit =
      _player_get_max_adaptive_variant_limitPtr.asFunction<
          int Function(player_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the audio only mode.
  /// @details This function is used to disable or enable video rendering during playback.
  /// @since_tizen 4.0
  /// @param[in] player       The handle to the media player
  /// @param[in] audio_only   The new audio only status: (@c true = enable audio only, @c false = disable audio only)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE                Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION   Invalid operation
  /// @retval #PLAYER_ERROR_INVALID_STATE       Invalid player state
  /// @pre The player state must be one of: #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_is_audio_only()
  int player_set_audio_only(
    player_h player,
    bool audio_only,
  ) {
    return _player_set_audio_only(
      player,
      audio_only,
    );
  }

  late final _player_set_audio_onlyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Bool)>>(
          'player_set_audio_only');
  late final _player_set_audio_only =
      _player_set_audio_onlyPtr.asFunction<int Function(player_h, bool)>();

  /// @brief Gets the audio only mode status.
  /// @since_tizen 4.0
  /// @param[in]  player      The handle to the media player
  /// @param[out] audio_only  The current audio only status: (@c true = audio only enabled, @c false = audio only disabled)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE                Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_OPERATION   Invalid operation
  /// @pre The player state must be one of: #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_set_audio_only()
  int player_is_audio_only(
    player_h player,
    ffi.Pointer<ffi.Bool> audio_only,
  ) {
    return _player_is_audio_only(
      player,
      audio_only,
    );
  }

  late final _player_is_audio_onlyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              player_h, ffi.Pointer<ffi.Bool>)>>('player_is_audio_only');
  late final _player_is_audio_only = _player_is_audio_onlyPtr
      .asFunction<int Function(player_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the streaming buffering time.
  /// @since_tizen 4.0
  /// @param[in] player       The handle to the media player
  /// @param[in] prebuffer_ms The buffer time to start playback
  /// @param[in] rebuffer_ms  The buffer time during playback if player enter pause state for buffering.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid state
  /// @if WEARABLE @retval #PLAYER_ERROR_FEATURE_NOT_SUPPORTED_ON_DEVICE Unsupported feature @endif
  /// @pre The player state must be #PLAYER_STATE_IDLE.
  /// @see player_get_streaming_buffering_time()
  int player_set_streaming_buffering_time(
    player_h player,
    int prebuffer_ms,
    int rebuffer_ms,
  ) {
    return _player_set_streaming_buffering_time(
      player,
      prebuffer_ms,
      rebuffer_ms,
    );
  }

  late final _player_set_streaming_buffering_timePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(player_h, ffi.Int, ffi.Int)>>(
          'player_set_streaming_buffering_time');
  late final _player_set_streaming_buffering_time =
      _player_set_streaming_buffering_timePtr
          .asFunction<int Function(player_h, int, int)>();

  /// @brief Gets the streaming buffering time.
  /// @since_tizen 4.0
  /// @param[in] player       The handle to the media player
  /// @param[in] prebuffer_ms The buffer time to start playback
  /// @param[in] rebuffer_ms  The buffer time during playback if player enter pause state for buffering.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PLAYER_ERROR_NONE Successful
  /// @retval #PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PLAYER_ERROR_INVALID_STATE Invalid state
  /// @if WEARABLE @retval #PLAYER_ERROR_FEATURE_NOT_SUPPORTED_ON_DEVICE Unsupported feature @endif
  /// @pre The player state must be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, #PLAYER_STATE_PLAYING, or #PLAYER_STATE_PAUSED.
  /// @see player_get_streaming_buffering_time()
  int player_get_streaming_buffering_time(
    player_h player,
    ffi.Pointer<ffi.Int> prebuffer_ms,
    ffi.Pointer<ffi.Int> rebuffer_ms,
  ) {
    return _player_get_streaming_buffering_time(
      player,
      prebuffer_ms,
      rebuffer_ms,
    );
  }

  late final _player_get_streaming_buffering_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(player_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('player_get_streaming_buffering_time');
  late final _player_get_streaming_buffering_time =
      _player_get_streaming_buffering_timePtr.asFunction<
          int Function(player_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Creates a recorder handle to record a video.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a recorder using recorder_destroy(). \n
  /// The @a camera handle also could be used for capturing images. \n
  /// If the camera state was #CAMERA_STATE_CREATED, the preview format will be changed to the recommended preview format for recording.
  /// @remarks The created recorder state will be different according to camera state : \n
  /// #CAMERA_STATE_CREATED -> #RECORDER_STATE_CREATED\n
  /// #CAMERA_STATE_PREVIEW -> #RECORDER_STATE_READY\n
  /// #CAMERA_STATE_CAPTURED -> #RECORDER_STATE_READY
  /// @remarks The privilege %http://tizen.org/privilege/recorder is not required since 4.0,\n
  /// but it is required in all earlier versions.
  /// @remarks Since 4.0, It's related to the following feature: %http://tizen.org/feature/media.video_recording \n
  /// instead of using %http://tizen.org/feature/microphone
  /// @param[in]  camera       The handle to the camera
  /// @param[out] recorder     A handle to the recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #RECORDER_ERROR_SOUND_POLICY Sound policy error
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @see camera_create()
  /// @see camera_stop_preview()
  /// @see recorder_destroy()
  int recorder_create_videorecorder(
    camera_h camera,
    ffi.Pointer<recorder_h> recorder,
  ) {
    return _recorder_create_videorecorder(
      camera,
      recorder,
    );
  }

  late final _recorder_create_videorecorderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(camera_h,
              ffi.Pointer<recorder_h>)>>('recorder_create_videorecorder');
  late final _recorder_create_videorecorder = _recorder_create_videorecorderPtr
      .asFunction<int Function(camera_h, ffi.Pointer<recorder_h>)>();

  /// @brief Creates a recorder handle to record an audio.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a recorder using recorder_destroy().
  /// @remarks The privilege %http://tizen.org/privilege/recorder is not required since 4.0,\n
  /// but it is required in all earlier versions.
  /// @remarks Since 4.0, It's related to the following feature: %http://tizen.org/feature/media.audio_recording \n
  /// instead of using %http://tizen.org/feature/microphone
  /// @param[out]  recorder  A handle to the recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #RECORDER_ERROR_SOUND_POLICY Sound policy error
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @post The recorder state will be #RECORDER_STATE_CREATED.
  /// @see recorder_destroy()
  int recorder_create_audiorecorder(
    ffi.Pointer<recorder_h> recorder,
  ) {
    return _recorder_create_audiorecorder(
      recorder,
    );
  }

  late final _recorder_create_audiorecorderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<recorder_h>)>>(
          'recorder_create_audiorecorder');
  late final _recorder_create_audiorecorder = _recorder_create_audiorecorderPtr
      .asFunction<int Function(ffi.Pointer<recorder_h>)>();

  /// @brief Destroys the recorder handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The video recorder's camera handle is not released by this function.
  /// @param[in]	recorder    The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @pre  The recorder state should be #RECORDER_STATE_CREATED.
  /// @post The recorder state will be #RECORDER_STATE_NONE.
  /// @see	camera_destroy()
  /// @see	recorder_create_videorecorder()
  /// @see	recorder_create_audiorecorder()
  int recorder_destroy(
    recorder_h recorder,
  ) {
    return _recorder_destroy(
      recorder,
    );
  }

  late final _recorder_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_destroy');
  late final _recorder_destroy =
      _recorder_destroyPtr.asFunction<int Function(recorder_h)>();

  /// @brief Prepares the media recorder for recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Before calling the function, it is required to properly set audio encoder (recorder_set_audio_encoder()),
  /// video encoder(recorder_set_video_encoder()) and file format (recorder_set_file_format()).
  /// @param[in]	recorder  The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_SOUND_POLICY Sound policy error
  /// @retval #RECORDER_ERROR_RESOURCE_CONFLICT Resource conflict error
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre  The recorder state should be #RECORDER_STATE_CREATED by recorder_create_videorecorder(), recorder_create_audiorecorder() or recorder_unprepare().
  /// @post The recorder state will be #RECORDER_STATE_READY.
  /// @post If recorder handle is created by recorder_create_videorecorder(), the camera state will be changed to #CAMERA_STATE_PREVIEW.
  /// @see	recorder_create_videorecorder()
  /// @see	recorder_create_audiorecorder()
  /// @see	recorder_unprepare()
  /// @see	recorder_set_audio_encoder()
  /// @see	recorder_set_video_encoder()
  /// @see	recorder_set_file_format()
  int recorder_prepare(
    recorder_h recorder,
  ) {
    return _recorder_prepare(
      recorder,
    );
  }

  late final _recorder_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_prepare');
  late final _recorder_prepare =
      _recorder_preparePtr.asFunction<int Function(recorder_h)>();

  /// @brief Resets the media recorder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder  The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre  The recorder state should be #RECORDER_STATE_READY set by recorder_prepare(), recorder_cancel() or recorder_commit().
  /// @post The recorder state will be #RECORDER_STATE_CREATED.
  /// @post If the recorder handle is created by recorder_create_videorecorder(), camera state will be changed to #CAMERA_STATE_CREATED.
  /// @see	recorder_prepare()
  /// @see	recorder_cancel()
  /// @see	recorder_commit()
  int recorder_unprepare(
    recorder_h recorder,
  ) {
    return _recorder_unprepare(
      recorder,
    );
  }

  late final _recorder_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_unprepare');
  late final _recorder_unprepare =
      _recorder_unpreparePtr.asFunction<int Function(recorder_h)>();

  /// @brief Starts the recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks If file path has been set to an existing file, this file is removed automatically and updated by new one. \n
  /// In the video recorder, some preview format does not support record mode. It will return #RECORDER_ERROR_INVALID_OPERATION error. \n
  /// You should use default preview format or #CAMERA_PIXEL_FORMAT_NV12 in the record mode. \n
  /// When you want to record audio or video file, you need to add privilege according to rules below additionally. \n
  /// If you want to save contents to internal storage, you should add mediastorage privilege. \n
  /// If you want to save contents to external storage, you should add externalstorage privilege. \n
  /// The filename should be set before this function is invoked.
  /// @param[in]  recorder  The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_READY by recorder_prepare() or #RECORDER_STATE_PAUSED by recorder_pause(). \n
  /// The filename should be set by recorder_set_filename().
  /// @post The recorder state will be #RECORDER_STATE_RECORDING.
  /// @see	recorder_pause()
  /// @see	recorder_commit()
  /// @see	recorder_cancel()
  /// @see	recorder_set_audio_encoder()
  /// @see	recorder_set_filename()
  /// @see	recorder_set_file_format()
  /// @see	recorder_recording_status_cb()
  /// @see	recorder_set_filename()
  int recorder_start(
    recorder_h recorder,
  ) {
    return _recorder_start(
      recorder,
    );
  }

  late final _recorder_startPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_start');
  late final _recorder_start =
      _recorder_startPtr.asFunction<int Function(recorder_h)>();

  /// @brief Pauses the recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks Recording can be resumed with recorder_start().
  /// @param[in]  recorder  The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_RECORDING.
  /// @post The recorder state will be #RECORDER_STATE_PAUSED.
  /// @see recorder_pause()
  /// @see recorder_commit()
  /// @see recorder_cancel()
  int recorder_pause(
    recorder_h recorder,
  ) {
    return _recorder_pause(
      recorder,
    );
  }

  late final _recorder_pausePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_pause');
  late final _recorder_pause =
      _recorder_pausePtr.asFunction<int Function(recorder_h)>();

  /// @brief Stops recording and saves the result.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks When you want to record audio or video file, you need to add privilege according to rules below additionally. \n
  /// If you want to save contents to internal storage, you should add mediastorage privilege. \n
  /// If you want to save contents to external storage, you should add externalstorage privilege.
  /// @param[in]  recorder  The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_RECORDING set by recorder_start() or #RECORDER_STATE_PAUSED by recorder_pause().
  /// @post The recorder state will be #RECORDER_STATE_READY.
  /// @see recorder_pause()
  /// @see recorder_cancel()
  /// @see recorder_set_filename()
  /// @see	recorder_start()
  int recorder_commit(
    recorder_h recorder,
  ) {
    return _recorder_commit(
      recorder,
    );
  }

  late final _recorder_commitPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_commit');
  late final _recorder_commit =
      _recorder_commitPtr.asFunction<int Function(recorder_h)>();

  /// @brief Cancels the recording.
  /// @details The recording data is discarded and not written in the recording file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks When you want to record audio or video file, you need to add privilege according to rules below additionally. \n
  /// If you want to save contents to internal storage, you should add mediastorage privilege. \n
  /// If you want to save contents to external storage, you should add externalstorage privilege.
  /// @param[in]  recorder  The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_RECORDING set by recorder_start() or #RECORDER_STATE_PAUSED by recorder_pause().
  /// @post The recorder state will be #RECORDER_STATE_READY.
  /// @see recorder_pause()
  /// @see recorder_commit()
  /// @see recorder_cancel()
  /// @see recorder_start()
  int recorder_cancel(
    recorder_h recorder,
  ) {
    return _recorder_cancel(
      recorder,
    );
  }

  late final _recorder_cancelPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_cancel');
  late final _recorder_cancel =
      _recorder_cancelPtr.asFunction<int Function(recorder_h)>();

  /// @brief Gets the recorder's current state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder The handle to the media recorder
  /// @param[out] state    The current state of the recorder
  /// @return  @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  int recorder_get_state(
    recorder_h recorder,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _recorder_get_state(
      recorder,
      state,
    );
  }

  late final _recorder_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              recorder_h, ffi.Pointer<ffi.Int32>)>>('recorder_get_state');
  late final _recorder_get_state = _recorder_get_statePtr
      .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the peak audio input level that was sampled since the last call to this function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks @c 0 dB indicates maximum input level, @c -300 dB indicates minimum input level.
  /// @param[in]  recorder The handle to the media recorder
  /// @param[out] dB       The audio input level in dB
  /// @return  @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_RECORDING or #RECORDER_STATE_PAUSED.
  int recorder_get_audio_level(
    recorder_h recorder,
    ffi.Pointer<ffi.Double> dB,
  ) {
    return _recorder_get_audio_level(
      recorder,
      dB,
    );
  }

  late final _recorder_get_audio_levelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              ffi.Pointer<ffi.Double>)>>('recorder_get_audio_level');
  late final _recorder_get_audio_level = _recorder_get_audio_levelPtr
      .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Double>)>();

  /// @brief Sets the file path to record.
  /// @details This function sets file path which defines where newly recorded data should be stored.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If the same file already exists in the file system, then old file will be overwritten.
  /// @param[in]	recorder    The handle to the media recorder
  /// @param[in]	path        The recording file path
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY.
  /// @see	recorder_get_filename()
  int recorder_set_filename(
    recorder_h recorder,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _recorder_set_filename(
      recorder,
      path,
    );
  }

  late final _recorder_set_filenamePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              recorder_h, ffi.Pointer<ffi.Char>)>>('recorder_set_filename');
  late final _recorder_set_filename = _recorder_set_filenamePtr
      .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the file path to record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a path using free().
  /// @param[in]	recorder    The handle to the media recorder
  /// @param[out]	path        The recording file path
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_set_filename()
  int recorder_get_filename(
    recorder_h recorder,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _recorder_get_filename(
      recorder,
      path,
    );
  }

  late final _recorder_get_filenamePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('recorder_get_filename');
  late final _recorder_get_filename = _recorder_get_filenamePtr.asFunction<
      int Function(recorder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the file format for recording media stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Since 2.3.1, it could be returned #RECORDER_ERROR_INVALID_OPERATION \n
  /// when it's audio recorder and its state is #RECORDER_STATE_READY \n
  /// because of checking codec compatibility with current encoder.
  /// @param[in] recorder The handle to the media recorder
  /// @param[in] format   The media file format
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation (Since 2.3.1)
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY (for video recorder only).\n
  /// Since 2.3.1, this API also works for audio recorder when its state is #RECORDER_STATE_READY.
  /// @see recorder_get_file_format()
  /// @see recorder_foreach_supported_file_format()
  int recorder_set_file_format(
    recorder_h recorder,
    int format,
  ) {
    return _recorder_set_file_format(
      recorder,
      format,
    );
  }

  late final _recorder_set_file_formatPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int32)>>(
          'recorder_set_file_format');
  late final _recorder_set_file_format =
      _recorder_set_file_formatPtr.asFunction<int Function(recorder_h, int)>();

  /// @brief Gets the file format for recording media stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder  The handle to the media recorder
  /// @param[out] format   The media file format
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see recorder_set_file_format()
  /// @see recorder_foreach_supported_file_format()
  int recorder_get_file_format(
    recorder_h recorder,
    ffi.Pointer<ffi.Int32> format,
  ) {
    return _recorder_get_file_format(
      recorder,
      format,
    );
  }

  late final _recorder_get_file_formatPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              recorder_h, ffi.Pointer<ffi.Int32>)>>('recorder_get_file_format');
  late final _recorder_get_file_format = _recorder_get_file_formatPtr
      .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the recorder's sound manager stream information.
  /// @since_tizen 3.0
  /// @remarks You can set sound stream information including audio routing.
  /// For more details, please refer to @ref CAPI_MEDIA_SOUND_MANAGER_MODULE
  /// @param[in]	recorder    The handle to the media recorder
  /// @param[in]	stream_info The sound manager info
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY
  /// @see #sound_stream_info_h
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  int recorder_set_sound_stream_info(
    recorder_h recorder,
    sound_stream_info_h stream_info,
  ) {
    return _recorder_set_sound_stream_info(
      recorder,
      stream_info,
    );
  }

  late final _recorder_set_sound_stream_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              sound_stream_info_h)>>('recorder_set_sound_stream_info');
  late final _recorder_set_sound_stream_info =
      _recorder_set_sound_stream_infoPtr
          .asFunction<int Function(recorder_h, sound_stream_info_h)>();

  /// @brief Retrieves all supported file formats by invoking a specific callback for each supported file format.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder  The handle to the media recorder
  /// @param[in] callback  The iteration callback
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post  recorder_supported_file_format_cb() will be invoked.
  /// @see recorder_get_file_format()
  /// @see recorder_set_file_format()
  /// @see recorder_supported_file_format_cb()
  int recorder_foreach_supported_file_format(
    recorder_h recorder,
    recorder_supported_file_format_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_foreach_supported_file_format(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_foreach_supported_file_formatPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(recorder_h, recorder_supported_file_format_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'recorder_foreach_supported_file_format');
  late final _recorder_foreach_supported_file_format =
      _recorder_foreach_supported_file_formatPtr.asFunction<
          int Function(recorder_h, recorder_supported_file_format_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the audio codec for encoding an audio stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You can get available audio encoders by using recorder_foreach_supported_audio_encoder(). \n
  /// If set to #RECORDER_AUDIO_CODEC_DISABLE, the audio track is not created in recording files.\n
  /// Since 2.3.1, it could be returned #RECORDER_ERROR_INVALID_OPERATION \n
  /// when it's audio recorder and its state is #RECORDER_STATE_READY \n
  /// because of checking codec compatibility with current file format.
  /// @param[in] recorder The handle to the media recorder
  /// @param[in] codec    The audio codec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation (Since 2.3.1)
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY.
  /// @see	recorder_get_audio_encoder()
  /// @see recorder_foreach_supported_audio_encoder()
  int recorder_set_audio_encoder(
    recorder_h recorder,
    int codec,
  ) {
    return _recorder_set_audio_encoder(
      recorder,
      codec,
    );
  }

  late final _recorder_set_audio_encoderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int32)>>(
          'recorder_set_audio_encoder');
  late final _recorder_set_audio_encoder = _recorder_set_audio_encoderPtr
      .asFunction<int Function(recorder_h, int)>();

  /// @brief Gets the audio codec for encoding an audio stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder The handle to the media recorder
  /// @param[out] codec   The audio codec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_set_audio_encoder()
  /// @see recorder_foreach_supported_audio_encoder()
  int recorder_get_audio_encoder(
    recorder_h recorder,
    ffi.Pointer<ffi.Int32> codec,
  ) {
    return _recorder_get_audio_encoder(
      recorder,
      codec,
    );
  }

  late final _recorder_get_audio_encoderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              ffi.Pointer<ffi.Int32>)>>('recorder_get_audio_encoder');
  late final _recorder_get_audio_encoder = _recorder_get_audio_encoderPtr
      .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported audio encoders by invoking a specific callback for each supported audio encoder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder  The handle to the media recorder
  /// @param[in] callback  The iteration callback
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post  recorder_supported_audio_encoder_cb() will be invoked.
  /// @see	recorder_set_audio_encoder()
  /// @see	recorder_get_audio_encoder()
  /// @see	recorder_supported_audio_encoder_cb()
  int recorder_foreach_supported_audio_encoder(
    recorder_h recorder,
    recorder_supported_audio_encoder_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_foreach_supported_audio_encoder(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_foreach_supported_audio_encoderPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(recorder_h, recorder_supported_audio_encoder_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'recorder_foreach_supported_audio_encoder');
  late final _recorder_foreach_supported_audio_encoder =
      _recorder_foreach_supported_audio_encoderPtr.asFunction<
          int Function(recorder_h, recorder_supported_audio_encoder_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the resolution of the video recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This function should be called before recording (recorder_start()).
  /// @param[in] recorder  The handle to the media recorder
  /// @param[in] width     The video width
  /// @param[in] height    The video height
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre    The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY.
  /// @see	recorder_start()
  /// @see	recorder_get_video_resolution()
  /// @see	recorder_foreach_supported_video_resolution()
  int recorder_set_video_resolution(
    recorder_h recorder,
    int width,
    int height,
  ) {
    return _recorder_set_video_resolution(
      recorder,
      width,
      height,
    );
  }

  late final _recorder_set_video_resolutionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int, ffi.Int)>>(
      'recorder_set_video_resolution');
  late final _recorder_set_video_resolution = _recorder_set_video_resolutionPtr
      .asFunction<int Function(recorder_h, int, int)>();

  /// @brief Gets the resolution of the video recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder  The handle to the media recorder
  /// @param[out] width    The video width
  /// @param[out] height   The video height
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_set_video_resolution()
  /// @see	recorder_foreach_supported_video_resolution()
  int recorder_get_video_resolution(
    recorder_h recorder,
    ffi.Pointer<ffi.Int> width,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _recorder_get_video_resolution(
      recorder,
      width,
      height,
    );
  }

  late final _recorder_get_video_resolutionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('recorder_get_video_resolution');
  late final _recorder_get_video_resolution =
      _recorder_get_video_resolutionPtr.asFunction<
          int Function(
              recorder_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Retrieves all supported video resolutions by invoking callback function once for each supported video resolution.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder      The handle to the media recorder
  /// @param[in] foreach_cb    The callback function to be invoked
  /// @param[in] user_data     The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post	This function invokes recorder_supported_video_resolution_cb() repeatedly to retrieve each supported video resolution.
  /// @see	recorder_set_video_resolution()
  /// @see	recorder_get_video_resolution()
  /// @see	recorder_supported_video_resolution_cb()
  int recorder_foreach_supported_video_resolution(
    recorder_h recorder,
    recorder_supported_video_resolution_cb foreach_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_foreach_supported_video_resolution(
      recorder,
      foreach_cb,
      user_data,
    );
  }

  late final _recorder_foreach_supported_video_resolutionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  recorder_h,
                  recorder_supported_video_resolution_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'recorder_foreach_supported_video_resolution');
  late final _recorder_foreach_supported_video_resolution =
      _recorder_foreach_supported_video_resolutionPtr.asFunction<
          int Function(recorder_h, recorder_supported_video_resolution_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Sets the video codec for encoding video stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You can get available video encoders by using recorder_foreach_supported_video_encoder().
  /// @param[in] recorder The handle to the media recorder
  /// @param[in] codec    The video codec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY.
  /// @see recorder_get_video_encoder()
  /// @see recorder_foreach_supported_video_encoder()
  int recorder_set_video_encoder(
    recorder_h recorder,
    int codec,
  ) {
    return _recorder_set_video_encoder(
      recorder,
      codec,
    );
  }

  late final _recorder_set_video_encoderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int32)>>(
          'recorder_set_video_encoder');
  late final _recorder_set_video_encoder = _recorder_set_video_encoderPtr
      .asFunction<int Function(recorder_h, int)>();

  /// @brief Gets the video codec for encoding video stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder The handle to the media recorder
  /// @param[out] codec   The video codec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see recorder_set_video_encoder()
  /// @see recorder_foreach_supported_video_encoder()
  int recorder_get_video_encoder(
    recorder_h recorder,
    ffi.Pointer<ffi.Int32> codec,
  ) {
    return _recorder_get_video_encoder(
      recorder,
      codec,
    );
  }

  late final _recorder_get_video_encoderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              ffi.Pointer<ffi.Int32>)>>('recorder_get_video_encoder');
  late final _recorder_get_video_encoder = _recorder_get_video_encoderPtr
      .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Retrieves all supported video encoders by invoking a specific callback for each supported video encoder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder  The handle to the media recorder
  /// @param[in] callback  The iteration callback
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post  recorder_supported_video_encoder_cb() will be invoked.
  /// @see recorder_set_video_encoder()
  /// @see recorder_get_video_encoder()
  /// @see	recorder_supported_video_encoder_cb()
  int recorder_foreach_supported_video_encoder(
    recorder_h recorder,
    recorder_supported_video_encoder_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_foreach_supported_video_encoder(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_foreach_supported_video_encoderPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(recorder_h, recorder_supported_video_encoder_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'recorder_foreach_supported_video_encoder');
  late final _recorder_foreach_supported_video_encoder =
      _recorder_foreach_supported_video_encoderPtr.asFunction<
          int Function(recorder_h, recorder_supported_video_encoder_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Registers the callback function that will be invoked when the recorder state changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder  The handle to the media recorder
  /// @param[in] callback  The function pointer of user callback
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post  recorder_state_changed_cb() will be invoked.
  /// @see recorder_unset_state_changed_cb()
  /// @see recorder_state_changed_cb()
  int recorder_set_state_changed_cb(
    recorder_h recorder,
    recorder_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_set_state_changed_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h, recorder_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('recorder_set_state_changed_cb');
  late final _recorder_set_state_changed_cb =
      _recorder_set_state_changed_cbPtr.asFunction<
          int Function(
              recorder_h, recorder_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see recorder_set_state_changed_cb()
  int recorder_unset_state_changed_cb(
    recorder_h recorder,
  ) {
    return _recorder_unset_state_changed_cb(
      recorder,
    );
  }

  late final _recorder_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_unset_state_changed_cb');
  late final _recorder_unset_state_changed_cb =
      _recorder_unset_state_changed_cbPtr
          .asFunction<int Function(recorder_h)>();

  /// @brief Registers a callback function to be called when the media recorder is interrupted according to a policy.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder  The handle to the media recorder
  /// @param[in] callback  The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_unset_interrupted_cb()
  /// @see	recorder_interrupted_cb()
  int recorder_set_interrupted_cb(
    recorder_h recorder,
    recorder_interrupted_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_set_interrupted_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_set_interrupted_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h, recorder_interrupted_cb,
              ffi.Pointer<ffi.Void>)>>('recorder_set_interrupted_cb');
  late final _recorder_set_interrupted_cb =
      _recorder_set_interrupted_cbPtr.asFunction<
          int Function(
              recorder_h, recorder_interrupted_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	recorder    The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_set_interrupted_cb()
  int recorder_unset_interrupted_cb(
    recorder_h recorder,
  ) {
    return _recorder_unset_interrupted_cb(
      recorder,
    );
  }

  late final _recorder_unset_interrupted_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_unset_interrupted_cb');
  late final _recorder_unset_interrupted_cb =
      _recorder_unset_interrupted_cbPtr.asFunction<int Function(recorder_h)>();

  /// @brief Registers a callback function to be called when the media recorder interrupt is started according to a policy.
  /// @since_tizen 4.0
  /// @param[in] recorder	The handle to the media recorder
  /// @param[in] callback	  The callback function to register
  /// @param[in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see	recorder_unset_interrupt_started_cb()
  /// @see	recorder_interrupt_started_cb()
  int recorder_set_interrupt_started_cb(
    recorder_h recorder,
    recorder_interrupt_started_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_set_interrupt_started_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_set_interrupt_started_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h, recorder_interrupt_started_cb,
              ffi.Pointer<ffi.Void>)>>('recorder_set_interrupt_started_cb');
  late final _recorder_set_interrupt_started_cb =
      _recorder_set_interrupt_started_cbPtr.asFunction<
          int Function(recorder_h, recorder_interrupt_started_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 4.0
  /// @param[in]	recorder	The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see	recorder_set_interrupt_started_cb()
  int recorder_unset_interrupt_started_cb(
    recorder_h recorder,
  ) {
    return _recorder_unset_interrupt_started_cb(
      recorder,
    );
  }

  late final _recorder_unset_interrupt_started_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_unset_interrupt_started_cb');
  late final _recorder_unset_interrupt_started_cb =
      _recorder_unset_interrupt_started_cbPtr
          .asFunction<int Function(recorder_h)>();

  /// @brief Registers a callback function to be called when audio stream data is being delivered.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This callback function holds the same buffer that will be recorded. \n
  /// Therefore if an user changes the buffer, the result file will have the buffer. \n
  /// @remarks The callback is called via internal thread of Frameworks. Therefore do not invoke UI API, recorder_unprepare(), recorder_commit() and recorder_cancel() in callback.\n
  /// This callback function to be called in #RECORDER_STATE_RECORDING and #RECORDER_STATE_PAUSED state.
  ///
  /// @param[in] recorder    The handle to the recorder
  /// @param[in] callback    The callback function to register
  /// @param[in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre	The recorder state should be #RECORDER_STATE_READY or #RECORDER_STATE_CREATED.
  /// @see	recorder_unset_audio_stream_cb()
  /// @see	recorder_audio_stream_cb()
  int recorder_set_audio_stream_cb(
    recorder_h recorder,
    recorder_audio_stream_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_set_audio_stream_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_set_audio_stream_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h, recorder_audio_stream_cb,
              ffi.Pointer<ffi.Void>)>>('recorder_set_audio_stream_cb');
  late final _recorder_set_audio_stream_cb =
      _recorder_set_audio_stream_cbPtr.asFunction<
          int Function(
              recorder_h, recorder_audio_stream_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	recorder    The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see     recorder_set_audio_stream_cb()
  int recorder_unset_audio_stream_cb(
    recorder_h recorder,
  ) {
    return _recorder_unset_audio_stream_cb(
      recorder,
    );
  }

  late final _recorder_unset_audio_stream_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_unset_audio_stream_cb');
  late final _recorder_unset_audio_stream_cb =
      _recorder_unset_audio_stream_cbPtr.asFunction<int Function(recorder_h)>();

  /// @brief Registers a callback function to be called when muxed stream data is delivered.
  /// @since_tizen 4.0
  /// @remarks This callback receives the data that will be recorded, \n
  /// but any changes to this data will not affect the recorded file.
  /// @param[in] recorder    The handle to the recorder
  /// @param[in] callback    The callback function to register
  /// @param[in] user_data   The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre	The recorder state should be #RECORDER_STATE_READY or #RECORDER_STATE_CREATED.
  /// @see	recorder_unset_muxed_stream_cb()
  /// @see	recorder_muxed_stream_cb()
  int recorder_set_muxed_stream_cb(
    recorder_h recorder,
    recorder_muxed_stream_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_set_muxed_stream_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_set_muxed_stream_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h, recorder_muxed_stream_cb,
              ffi.Pointer<ffi.Void>)>>('recorder_set_muxed_stream_cb');
  late final _recorder_set_muxed_stream_cb =
      _recorder_set_muxed_stream_cbPtr.asFunction<
          int Function(
              recorder_h, recorder_muxed_stream_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 4.0
  /// @param[in]	recorder    The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre	The recorder state should be #RECORDER_STATE_READY or #RECORDER_STATE_CREATED.
  /// @see	recorder_set_muxed_stream_cb()
  int recorder_unset_muxed_stream_cb(
    recorder_h recorder,
  ) {
    return _recorder_unset_muxed_stream_cb(
      recorder,
    );
  }

  late final _recorder_unset_muxed_stream_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_unset_muxed_stream_cb');
  late final _recorder_unset_muxed_stream_cb =
      _recorder_unset_muxed_stream_cbPtr.asFunction<int Function(recorder_h)>();

  /// @brief Registers a callback function to be invoked when the recording information changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder   The handle to the media recorder
  /// @param[in]  callback   The function pointer of user callback
  /// @param[in]  user_data  The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post  recorder_recording_status_cb() will be invoked.
  /// @see	recorder_unset_recording_status_cb()
  /// @see	recorder_recording_status_cb()
  int recorder_set_recording_status_cb(
    recorder_h recorder,
    recorder_recording_status_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_set_recording_status_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_set_recording_status_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h, recorder_recording_status_cb,
              ffi.Pointer<ffi.Void>)>>('recorder_set_recording_status_cb');
  late final _recorder_set_recording_status_cb =
      _recorder_set_recording_status_cbPtr.asFunction<
          int Function(recorder_h, recorder_recording_status_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder    The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_set_recording_status_cb()
  int recorder_unset_recording_status_cb(
    recorder_h recorder,
  ) {
    return _recorder_unset_recording_status_cb(
      recorder,
    );
  }

  late final _recorder_unset_recording_status_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_unset_recording_status_cb');
  late final _recorder_unset_recording_status_cb =
      _recorder_unset_recording_status_cbPtr
          .asFunction<int Function(recorder_h)>();

  /// @brief Registers the callback function to be run when reached the recording limit.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	recorder    The handle to media recorder
  /// @param[in]	callback    The function pointer of user callback
  /// @param[in]	user_data   The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post  recorder_recording_limit_reached_cb() will be invoked.
  /// @see	recorder_unset_recording_limit_reached_cb()
  /// @see	recorder_attr_set_size_limit()
  /// @see	recorder_attr_set_time_limit()
  /// @see	recorder_recording_limit_reached_cb()
  int recorder_set_recording_limit_reached_cb(
    recorder_h recorder,
    recorder_recording_limit_reached_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_set_recording_limit_reached_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_set_recording_limit_reached_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(recorder_h, recorder_recording_limit_reached_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'recorder_set_recording_limit_reached_cb');
  late final _recorder_set_recording_limit_reached_cb =
      _recorder_set_recording_limit_reached_cbPtr.asFunction<
          int Function(recorder_h, recorder_recording_limit_reached_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder  The handle to the media recorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_set_recording_limit_reached_cb()
  int recorder_unset_recording_limit_reached_cb(
    recorder_h recorder,
  ) {
    return _recorder_unset_recording_limit_reached_cb(
      recorder,
    );
  }

  late final _recorder_unset_recording_limit_reached_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_unset_recording_limit_reached_cb');
  late final _recorder_unset_recording_limit_reached_cb =
      _recorder_unset_recording_limit_reached_cbPtr
          .asFunction<int Function(recorder_h)>();

  /// @brief Registers a callback function to be called when an asynchronous operation error occurred.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This callback informs critical error situation.\n
  /// When this callback is invoked, user should release the resource and terminate the application. \n
  /// These error codes will occur. \n
  /// #RECORDER_ERROR_DEVICE \n
  /// #RECORDER_ERROR_INVALID_OPERATION \n
  /// #RECORDER_ERROR_OUT_OF_MEMORY
  /// @param[in]	recorder    The handle to the recorder
  /// @param[in]	callback    The callback function to register
  /// @param[in]	user_data   The user data to be passed to the callback function
  /// @return  @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @post	This function will invoke recorder_error_cb() when an asynchronous operation error occur.
  /// @see	recorder_unset_error_cb()
  /// @see	recorder_error_cb()
  int recorder_set_error_cb(
    recorder_h recorder,
    recorder_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _recorder_set_error_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _recorder_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h, recorder_error_cb,
              ffi.Pointer<ffi.Void>)>>('recorder_set_error_cb');
  late final _recorder_set_error_cb = _recorder_set_error_cbPtr.asFunction<
      int Function(recorder_h, recorder_error_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	recorder    The handle to the recorder
  /// @return  @c on success, otherwise a negative error value
  /// @retval    #RECORDER_ERROR_NONE Successful
  /// @retval    #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_set_error_cb()
  int recorder_unset_error_cb(
    recorder_h recorder,
  ) {
    return _recorder_unset_error_cb(
      recorder,
    );
  }

  late final _recorder_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h)>>(
          'recorder_unset_error_cb');
  late final _recorder_unset_error_cb =
      _recorder_unset_error_cbPtr.asFunction<int Function(recorder_h)>();

  /// @brief Gets the state of recorder device.
  /// @since_tizen 3.0
  /// @param[in]  type     The recorder type
  /// @param[out] state    The current state of the device
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  int recorder_get_device_state(
    int type,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _recorder_get_device_state(
      type,
      state,
    );
  }

  late final _recorder_get_device_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Int32>)>>('recorder_get_device_state');
  late final _recorder_get_device_state = _recorder_get_device_statePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Registers a callback function to be called when the recorder device state changes.
  /// @since_tizen 3.0
  /// @param[in]  callback      The callback function to register
  /// @param[in]  user_data     The user data to be passed to the callback function
  /// @param[out] cb_id         The id of the registered callback
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @post This function will invoke recorder_device_state_changed_cb() when the recorder device's state changes.
  /// @see recorder_remove_device_state_changed_cb()
  /// @see recorder_device_state_changed_cb()
  int recorder_add_device_state_changed_cb(
    recorder_device_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> cb_id,
  ) {
    return _recorder_add_device_state_changed_cb(
      callback,
      user_data,
      cb_id,
    );
  }

  late final _recorder_add_device_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              recorder_device_state_changed_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('recorder_add_device_state_changed_cb');
  late final _recorder_add_device_state_changed_cb =
      _recorder_add_device_state_changed_cbPtr.asFunction<
          int Function(recorder_device_state_changed_cb, ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Unregisters a callback function.
  /// @since_tizen 3.0
  /// @param[in] cb_id The id of the registered callback
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @see recorder_add_device_state_changed_cb()
  int recorder_remove_device_state_changed_cb(
    int cb_id,
  ) {
    return _recorder_remove_device_state_changed_cb(
      cb_id,
    );
  }

  late final _recorder_remove_device_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'recorder_remove_device_state_changed_cb');
  late final _recorder_remove_device_state_changed_cb =
      _recorder_remove_device_state_changed_cbPtr
          .asFunction<int Function(int)>();

  /// @brief Sets the maximum size of a recording file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks After reaching the limitation, the recording data is discarded and not written in the recording file.
  /// @param[in] recorder The handle to the media recorder
  /// @param[in] kbyte    The maximum size of the recording file(KB) \n
  /// @c 0 means unlimited recording size.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY.
  /// @see	recorder_attr_get_size_limit()
  /// @see	recorder_attr_set_time_limit()
  int recorder_attr_set_size_limit(
    recorder_h recorder,
    int kbyte,
  ) {
    return _recorder_attr_set_size_limit(
      recorder,
      kbyte,
    );
  }

  late final _recorder_attr_set_size_limitPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int)>>(
          'recorder_attr_set_size_limit');
  late final _recorder_attr_set_size_limit = _recorder_attr_set_size_limitPtr
      .asFunction<int Function(recorder_h, int)>();

  /// @brief Gets the maximum size of a recording file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder The handle to the media recorder
  /// @param[out] kbyte    The maximum size of recording file (KB) \n
  /// @c 0 means unlimited recording size.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_set_size_limit()
  /// @see	recorder_attr_get_time_limit()
  int recorder_attr_get_size_limit(
    recorder_h recorder,
    ffi.Pointer<ffi.Int> kbyte,
  ) {
    return _recorder_attr_get_size_limit(
      recorder,
      kbyte,
    );
  }

  late final _recorder_attr_get_size_limitPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              ffi.Pointer<ffi.Int>)>>('recorder_attr_get_size_limit');
  late final _recorder_attr_get_size_limit = _recorder_attr_get_size_limitPtr
      .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the time limit of a recording file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks After reaching the limitation, the recording data is discarded and not written in the recording file.
  /// @param[in] recorder The handle to the media recorder
  /// @param[in] second   The time limit of the recording file (in seconds) \n
  /// @c 0 means unlimited recording size.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY.
  /// @see	recorder_attr_get_time_limit()
  /// @see	recorder_attr_set_size_limit()
  int recorder_attr_set_time_limit(
    recorder_h recorder,
    int second,
  ) {
    return _recorder_attr_set_time_limit(
      recorder,
      second,
    );
  }

  late final _recorder_attr_set_time_limitPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int)>>(
          'recorder_attr_set_time_limit');
  late final _recorder_attr_set_time_limit = _recorder_attr_set_time_limitPtr
      .asFunction<int Function(recorder_h, int)>();

  /// @brief Gets the time limit of a recording file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder  The handle to the media recorder
  /// @param[out] second    The time limit of the recording file (in seconds) \n
  /// @c 0 means unlimited recording time.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_set_time_limit()
  /// @see	recorder_attr_get_size_limit()
  int recorder_attr_get_time_limit(
    recorder_h recorder,
    ffi.Pointer<ffi.Int> second,
  ) {
    return _recorder_attr_get_time_limit(
      recorder,
      second,
    );
  }

  late final _recorder_attr_get_time_limitPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              ffi.Pointer<ffi.Int>)>>('recorder_attr_get_time_limit');
  late final _recorder_attr_get_time_limit = _recorder_attr_get_time_limitPtr
      .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the audio device for recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder The handle to the media recorder
  /// @param[in] device   The type of an audio device
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY (for video recorder only).\n
  /// Since 2.3.1, this API also works for audio recorder when its state is #RECORDER_STATE_READY.
  /// @see	recorder_attr_get_audio_device()
  int recorder_attr_set_audio_device(
    recorder_h recorder,
    int device,
  ) {
    return _recorder_attr_set_audio_device(
      recorder,
      device,
    );
  }

  late final _recorder_attr_set_audio_devicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int32)>>(
          'recorder_attr_set_audio_device');
  late final _recorder_attr_set_audio_device =
      _recorder_attr_set_audio_devicePtr
          .asFunction<int Function(recorder_h, int)>();

  /// @brief Gets the audio device for recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder The handle to the media recorder
  /// @param[out] device   The type of an audio device
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_set_audio_device()
  int recorder_attr_get_audio_device(
    recorder_h recorder,
    ffi.Pointer<ffi.Int32> device,
  ) {
    return _recorder_attr_get_audio_device(
      recorder,
      device,
    );
  }

  late final _recorder_attr_get_audio_devicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              ffi.Pointer<ffi.Int32>)>>('recorder_attr_get_audio_device');
  late final _recorder_attr_get_audio_device =
      _recorder_attr_get_audio_devicePtr
          .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the sampling rate of an audio stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder      The handle to the media recorder
  /// @param[in] samplerate    The sample rate in Hertz
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY (for video recorder only).\n
  /// Since 2.3.1, this API also works for audio recorder when its state is #RECORDER_STATE_READY.
  /// @see	recorder_attr_get_audio_samplerate()
  int recorder_attr_set_audio_samplerate(
    recorder_h recorder,
    int samplerate,
  ) {
    return _recorder_attr_set_audio_samplerate(
      recorder,
      samplerate,
    );
  }

  late final _recorder_attr_set_audio_sampleratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int)>>(
          'recorder_attr_set_audio_samplerate');
  late final _recorder_attr_set_audio_samplerate =
      _recorder_attr_set_audio_sampleratePtr
          .asFunction<int Function(recorder_h, int)>();

  /// @brief Gets the sampling rate of an audio stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder    The handle to the media recorder
  /// @param[out] samplerate  The sample rate in Hertz
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_set_audio_samplerate()
  int recorder_attr_get_audio_samplerate(
    recorder_h recorder,
    ffi.Pointer<ffi.Int> samplerate,
  ) {
    return _recorder_attr_get_audio_samplerate(
      recorder,
      samplerate,
    );
  }

  late final _recorder_attr_get_audio_sampleratePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              ffi.Pointer<ffi.Int>)>>('recorder_attr_get_audio_samplerate');
  late final _recorder_attr_get_audio_samplerate =
      _recorder_attr_get_audio_sampleratePtr
          .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the bitrate of an audio encoder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder  The handle to the media recorder
  /// @param[in] bitrate   The bitrate (for mms : 12200[bps], normal : 288000[bps])
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY.
  /// @see	recorder_attr_get_audio_encoder_bitrate()
  int recorder_attr_set_audio_encoder_bitrate(
    recorder_h recorder,
    int bitrate,
  ) {
    return _recorder_attr_set_audio_encoder_bitrate(
      recorder,
      bitrate,
    );
  }

  late final _recorder_attr_set_audio_encoder_bitratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int)>>(
          'recorder_attr_set_audio_encoder_bitrate');
  late final _recorder_attr_set_audio_encoder_bitrate =
      _recorder_attr_set_audio_encoder_bitratePtr
          .asFunction<int Function(recorder_h, int)>();

  /// @brief Sets the bitrate of a video encoder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder  The handle to the media recorder
  /// @param[in] bitrate   The bitrate in bits per second
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY.
  /// @see	recorder_attr_get_video_encoder_bitrate()
  int recorder_attr_set_video_encoder_bitrate(
    recorder_h recorder,
    int bitrate,
  ) {
    return _recorder_attr_set_video_encoder_bitrate(
      recorder,
      bitrate,
    );
  }

  late final _recorder_attr_set_video_encoder_bitratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int)>>(
          'recorder_attr_set_video_encoder_bitrate');
  late final _recorder_attr_set_video_encoder_bitrate =
      _recorder_attr_set_video_encoder_bitratePtr
          .asFunction<int Function(recorder_h, int)>();

  /// @brief Gets the bitrate of an audio encoder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder  The handle to the media recorder
  /// @param[out] bitrate   The bitrate in bits per second
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_set_audio_encoder_bitrate()
  int recorder_attr_get_audio_encoder_bitrate(
    recorder_h recorder,
    ffi.Pointer<ffi.Int> bitrate,
  ) {
    return _recorder_attr_get_audio_encoder_bitrate(
      recorder,
      bitrate,
    );
  }

  late final _recorder_attr_get_audio_encoder_bitratePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(recorder_h, ffi.Pointer<ffi.Int>)>>(
      'recorder_attr_get_audio_encoder_bitrate');
  late final _recorder_attr_get_audio_encoder_bitrate =
      _recorder_attr_get_audio_encoder_bitratePtr
          .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the bitrate of a video encoder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder  The handle to the media recorder
  /// @param[out] bitrate   The bitrate in bits per second
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_set_audio_encoder_bitrate()
  int recorder_attr_get_video_encoder_bitrate(
    recorder_h recorder,
    ffi.Pointer<ffi.Int> bitrate,
  ) {
    return _recorder_attr_get_video_encoder_bitrate(
      recorder,
      bitrate,
    );
  }

  late final _recorder_attr_get_video_encoder_bitratePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(recorder_h, ffi.Pointer<ffi.Int>)>>(
      'recorder_attr_get_video_encoder_bitrate');
  late final _recorder_attr_get_video_encoder_bitrate =
      _recorder_attr_get_video_encoder_bitratePtr
          .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the mute state of a recorder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder  The handle to the media recorder
  /// @param[in] enable    The mute state
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_is_muted()
  int recorder_attr_set_mute(
    recorder_h recorder,
    bool enable,
  ) {
    return _recorder_attr_set_mute(
      recorder,
      enable,
    );
  }

  late final _recorder_attr_set_mutePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Bool)>>(
          'recorder_attr_set_mute');
  late final _recorder_attr_set_mute =
      _recorder_attr_set_mutePtr.asFunction<int Function(recorder_h, bool)>();

  /// @brief Gets the mute state of a recorder.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] recorder The handle to the media recorder
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @return  @c true if the recorder is not recording any sound,
  /// otherwise @c false if the recorder is recording
  /// @exception #RECORDER_ERROR_NONE Successful
  /// @exception #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @exception #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @see	recorder_attr_set_mute()
  bool recorder_attr_is_muted(
    recorder_h recorder,
  ) {
    return _recorder_attr_is_muted(
      recorder,
    );
  }

  late final _recorder_attr_is_mutedPtr =
      _lookup<ffi.NativeFunction<ffi.Bool Function(recorder_h)>>(
          'recorder_attr_is_muted');
  late final _recorder_attr_is_muted =
      _recorder_attr_is_mutedPtr.asFunction<bool Function(recorder_h)>();

  /// @brief Sets the recording motion rate.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This attribute is valid only in a video recorder. \n
  /// If the rate bigger than @c 0 and smaller than @c 1, video is recorded in a slow motion mode. \n
  /// If the rate bigger than @c 1, video is recorded in a fast motion mode (time lapse recording).
  /// @remarks Audio data is not recorded. \n
  /// To reset slow motion recording, set the rate to @c 1.
  /// @param[in] recorder The handle to the media recorder
  /// @param[in] rate     The recording motion rate \n
  /// It is computed with fps. (@c 0<rate<@c 1 for slow motion, @c 1<rate for fast motion(time lapse recording), @c 1 to reset).
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY.
  /// @see	recorder_attr_get_recording_motion_rate()
  int recorder_attr_set_recording_motion_rate(
    recorder_h recorder,
    double rate,
  ) {
    return _recorder_attr_set_recording_motion_rate(
      recorder,
      rate,
    );
  }

  late final _recorder_attr_set_recording_motion_ratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Double)>>(
          'recorder_attr_set_recording_motion_rate');
  late final _recorder_attr_set_recording_motion_rate =
      _recorder_attr_set_recording_motion_ratePtr
          .asFunction<int Function(recorder_h, double)>();

  /// @brief Gets the recording motion rate.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This attribute is valid only in a video recorder. \n
  /// If the rate bigger than @c 0 and smaller than @c 1, video is recorded in a slow motion mode. \n
  /// If the rate bigger than @c 1, video is recorded in a fast motion mode (time lapse recording).
  /// @remarks Audio data is not recorded. \n
  /// To reset slow motion recording, set the rate to @c 1.
  /// @param[in]  recorder The handle to the media recorder
  /// @param[out] rate     The recording motion rate \n
  /// It is computed with fps.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_set_recording_motion_rate()
  int recorder_attr_get_recording_motion_rate(
    recorder_h recorder,
    ffi.Pointer<ffi.Double> rate,
  ) {
    return _recorder_attr_get_recording_motion_rate(
      recorder,
      rate,
    );
  }

  late final _recorder_attr_get_recording_motion_ratePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(recorder_h, ffi.Pointer<ffi.Double>)>>(
      'recorder_attr_get_recording_motion_rate');
  late final _recorder_attr_get_recording_motion_rate =
      _recorder_attr_get_recording_motion_ratePtr
          .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Double>)>();

  /// @brief Sets the number of the audio channel.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This attribute is applied only in RECORDER_STATE_CREATED state. \n
  /// For mono recording, setting channel to @c 1. \n
  /// For stereo recording, setting channel to @c 2.
  /// @param[in] recorder       The handle to the media recorder
  /// @param[in] channel_count  The number of the audio channel
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @pre The recorder state must be #RECORDER_STATE_CREATED or #RECORDER_STATE_READY (for video recorder only).\n
  /// Since 2.3.1, this API also works for audio recorder when its state is #RECORDER_STATE_READY.
  /// @see	recorder_attr_get_audio_channel()
  int recorder_attr_set_audio_channel(
    recorder_h recorder,
    int channel_count,
  ) {
    return _recorder_attr_set_audio_channel(
      recorder,
      channel_count,
    );
  }

  late final _recorder_attr_set_audio_channelPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int)>>(
          'recorder_attr_set_audio_channel');
  late final _recorder_attr_set_audio_channel =
      _recorder_attr_set_audio_channelPtr
          .asFunction<int Function(recorder_h, int)>();

  /// @brief Gets the number of the audio channel.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]  recorder         The handle to the media recorder
  /// @param[out] channel_count    The number of the audio channel
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_set_audio_channel()
  int recorder_attr_get_audio_channel(
    recorder_h recorder,
    ffi.Pointer<ffi.Int> channel_count,
  ) {
    return _recorder_attr_get_audio_channel(
      recorder,
      channel_count,
    );
  }

  late final _recorder_attr_get_audio_channelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              ffi.Pointer<ffi.Int>)>>('recorder_attr_get_audio_channel');
  late final _recorder_attr_get_audio_channel =
      _recorder_attr_get_audio_channelPtr
          .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the video orientation in a video metadata tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]	recorder    The handle to a media recorder
  /// @param[in]	orientation The information of the video orientation
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_get_orientation_tag()
  int recorder_attr_set_orientation_tag(
    recorder_h recorder,
    int orientation,
  ) {
    return _recorder_attr_set_orientation_tag(
      recorder,
      orientation,
    );
  }

  late final _recorder_attr_set_orientation_tagPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(recorder_h, ffi.Int32)>>(
          'recorder_attr_set_orientation_tag');
  late final _recorder_attr_set_orientation_tag =
      _recorder_attr_set_orientation_tagPtr
          .asFunction<int Function(recorder_h, int)>();

  /// @brief Gets the video orientation in a video metadata tag.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in]   recorder    The handle to a media recorder
  /// @param[out]  orientation The information of the video orientation
  /// @return  @c 0 on success, otherwise a negative error value
  /// @retval #RECORDER_ERROR_NONE Successful
  /// @retval #RECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #RECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @retval #RECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #RECORDER_ERROR_SERVICE_DISCONNECTED The socket to multimedia server is disconnected
  /// @see	recorder_attr_set_orientation_tag()
  int recorder_attr_get_orientation_tag(
    recorder_h recorder,
    ffi.Pointer<ffi.Int32> orientation,
  ) {
    return _recorder_attr_get_orientation_tag(
      recorder,
      orientation,
    );
  }

  late final _recorder_attr_get_orientation_tagPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(recorder_h,
              ffi.Pointer<ffi.Int32>)>>('recorder_attr_get_orientation_tag');
  late final _recorder_attr_get_orientation_tag =
      _recorder_attr_get_orientation_tagPtr
          .asFunction<int Function(recorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Creates a sound pool instance that can be used for sound sources
  /// loading/unloading.
  /// @details Up to 8 sound pools can be created. Several pools can be active
  /// at the same time. Streams can be in playing state only when pool is
  /// active. Memory is allocated for sound pool. User should aware that
  /// creation of more number of pools means more memory is allocated.
  /// @since_tizen 4.0
  /// @remarks When pool has been created, pool state is
  /// #SOUND_POOL_STATE_INACTIVE. To activate the pool use
  /// sound_pool_activate() function.
  /// When no longer needed, @a pool should be destroyed with sound_pool_destroy().
  ///
  /// @param[out] pool    The created sound pool handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER
  /// Invalid parameter (@a pool is NULL)
  /// @retval #SOUND_POOL_ERROR_OUT_OF_MEMORY
  /// Not enough memory to create sound pool
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION
  /// Maximal amount of sound pools is exceeded (maximum 8 pools allowed)
  ///
  /// @see sound_pool_destroy()
  int sound_pool_create(
    ffi.Pointer<sound_pool_h> pool,
  ) {
    return _sound_pool_create(
      pool,
    );
  }

  late final _sound_pool_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<sound_pool_h>)>>(
          'sound_pool_create');
  late final _sound_pool_create = _sound_pool_createPtr
      .asFunction<int Function(ffi.Pointer<sound_pool_h>)>();

  /// @brief Destroys a sound pool and cleans allocated memory.
  /// @details Stops all streams and unloads all sources associated with pool.
  ///
  /// @since_tizen 4.0
  /// @remarks @a pool should be destroyed with sound_pool_destroy().
  /// @param[in]  pool     The sound pool handle will be destroyed
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER
  /// Invalid parameter (@a pool is NULL or corrupted)
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Create sound pool handle by calling sound_pool_create()
  ///
  /// @see sound_pool_create()
  int sound_pool_destroy(
    sound_pool_h pool,
  ) {
    return _sound_pool_destroy(
      pool,
    );
  }

  late final _sound_pool_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sound_pool_h)>>(
          'sound_pool_destroy');
  late final _sound_pool_destroy =
      _sound_pool_destroyPtr.asFunction<int Function(sound_pool_h)>();

  /// @brief Loads sound source data from a file to the pool.
  /// @details After calling this routine the source can be accessed by its @a tag.
  /// @since_tizen 4.0
  /// @remarks Input data can be either raw or encoded.
  /// Each of loaded sources must have unique @a tag
  /// It is synchronous operation.
  ///
  /// @param[in]  pool         The sound pool handle
  /// @param[in]  file_name    The name of the file that contains sound data
  /// @param[in]  tag          Unique string that will be used to identify source
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER
  /// Invalid parameter (@a pool is NULL or corrupted, @a file_name is
  /// NULL, @a tag is NULL or @a tag/@a file_name length is too long)
  /// @retval #SOUND_POOL_ERROR_OUT_OF_MEMORY     Not enough memory to allocate source
  /// @retval #SOUND_POOL_ERROR_NO_SUCH_FILE      No file determined by @a file_name
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @post Unload source from the pool by calling sound_pool_unload_source()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_destroy()
  /// @see sound_pool_unload_source()
  int sound_pool_load_source_from_file(
    sound_pool_h pool,
    ffi.Pointer<ffi.Char> file_name,
    ffi.Pointer<ffi.Char> tag,
  ) {
    return _sound_pool_load_source_from_file(
      pool,
      file_name,
      tag,
    );
  }

  late final _sound_pool_load_source_from_filePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_pool_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('sound_pool_load_source_from_file');
  late final _sound_pool_load_source_from_file =
      _sound_pool_load_source_from_filePtr.asFunction<
          int Function(
              sound_pool_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Unloads source from the @a pool.
  /// @details Cleans memory. This operation is synchronous.
  /// @since_tizen 4.0
  /// @remarks The usage of @a tag name that was associated with unloaded source
  /// has no effect. It can be reused as well.
  ///
  /// @param[in]  pool    The sound pool handle
  /// @param[in]  tag     Unique string that identifies the source
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER
  /// Invalid parameter (@a pool is NULL or corrupted, @a tag is NULL)
  /// @retval #SOUND_POOL_ERROR_KEY_NOT_AVAILABLE No sources tagged by @a tag exist
  /// in the pool
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @pre Load source to the pool by calling sound_pool_load_source_from_file()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_load_source_from_file()
  int sound_pool_unload_source(
    sound_pool_h pool,
    ffi.Pointer<ffi.Char> tag,
  ) {
    return _sound_pool_unload_source(
      pool,
      tag,
    );
  }

  late final _sound_pool_unload_sourcePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_pool_h,
              ffi.Pointer<ffi.Char>)>>('sound_pool_unload_source');
  late final _sound_pool_unload_source = _sound_pool_unload_sourcePtr
      .asFunction<int Function(sound_pool_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Changes the current @a state of a @a pool to #SOUND_POOL_STATE_ACTIVE.
  /// @since_tizen 4.0
  /// @remarks When activation is performed, all suspended streams with highest
  /// priority in the pool will resume their playback. Paused streams will
  /// remain their state.
  ///
  /// @param[in]  pool     The sound pool handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted)
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation or sound pool
  /// is already in #SOUND_POOL_STATE_ACTIVE state
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_get_state()
  /// @see sound_pool_deactivate()
  /// @see sound_pool_state_e
  int sound_pool_activate(
    sound_pool_h pool,
  ) {
    return _sound_pool_activate(
      pool,
    );
  }

  late final _sound_pool_activatePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sound_pool_h)>>(
          'sound_pool_activate');
  late final _sound_pool_activate =
      _sound_pool_activatePtr.asFunction<int Function(sound_pool_h)>();

  /// @brief Changes the current @a state of a @a pool to #SOUND_POOL_STATE_INACTIVE.
  /// @since_tizen 4.0
  /// @remarks When deactivation is performed, all playing streams in the pool will
  /// be suspended (change state to #SOUND_POOL_STREAM_STATE_SUSPENDED).
  /// Paused streams will remain in their state.
  ///
  /// @param[in]  pool     The sound pool handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted)
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation or sound pool
  /// is already in @c #SOUND_POOL_STATE_INACTIVE state
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @pre @a pool has to be in #SOUND_POOL_STATE_ACTIVE state
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_get_state()
  /// @see sound_pool_activate()
  /// @see sound_pool_state_e
  int sound_pool_deactivate(
    sound_pool_h pool,
  ) {
    return _sound_pool_deactivate(
      pool,
    );
  }

  late final _sound_pool_deactivatePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sound_pool_h)>>(
          'sound_pool_deactivate');
  late final _sound_pool_deactivate =
      _sound_pool_deactivatePtr.asFunction<int Function(sound_pool_h)>();

  /// @brief Sets the pool's global volume parameter.
  /// @details Volume of all streams related to the @a pool will be scaled
  /// in accordance to global pool volume parameter
  /// (i.e. [stream real volume] = [global volume] * [stream volume],
  /// where [stream volume] is the volume parameter of arbitrary stream).
  ///
  /// @since_tizen 4.0
  /// @param[in]  pool      The sound pool handle
  /// @param[in]  volume    Pool global volume in 0.0~1.0 range
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted, or @a volume isn't in 0.0~1.0 range)
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  ///
  /// @see sound_pool_create()
  int sound_pool_set_volume(
    sound_pool_h pool,
    double volume,
  ) {
    return _sound_pool_set_volume(
      pool,
      volume,
    );
  }

  late final _sound_pool_set_volumePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sound_pool_h, ffi.Float)>>(
          'sound_pool_set_volume');
  late final _sound_pool_set_volume = _sound_pool_set_volumePtr
      .asFunction<int Function(sound_pool_h, double)>();

  /// @brief Gets the pool's global volume parameter.
  ///
  /// @since_tizen 4.0
  /// @param[in]   pool      The sound pool handle
  /// @param[out]  volume    Pool global volume in 0.0~1.0 range
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted, or @a volume is NULL)
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  ///
  /// @see sound_pool_create()
  int sound_pool_get_volume(
    sound_pool_h pool,
    ffi.Pointer<ffi.Float> volume,
  ) {
    return _sound_pool_get_volume(
      pool,
      volume,
    );
  }

  late final _sound_pool_get_volumePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sound_pool_h, ffi.Pointer<ffi.Float>)>>('sound_pool_get_volume');
  late final _sound_pool_get_volume = _sound_pool_get_volumePtr
      .asFunction<int Function(sound_pool_h, ffi.Pointer<ffi.Float>)>();

  /// @brief Gets the current @a state of @a pool.
  ///
  /// @since_tizen 4.0
  /// @param[in]  pool     The sound pool handle
  /// @param[out] state    Current state of @a pool
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER
  /// Invalid parameter (@a pool is NULL or corrupted, @a tag is NULL)
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_state_e
  int sound_pool_get_state(
    sound_pool_h pool,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _sound_pool_get_state(
      pool,
      state,
    );
  }

  late final _sound_pool_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sound_pool_h, ffi.Pointer<ffi.Int32>)>>('sound_pool_get_state');
  late final _sound_pool_get_state = _sound_pool_get_statePtr
      .asFunction<int Function(sound_pool_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the callback for handling sound @a pool state change.
  ///
  /// @since_tizen 4.0
  /// @param[in]  pool        The sound pool handle
  /// @param[in]  callback    The callback that will be called after pool state
  /// will be changed.  @a callback will be called
  /// synchronously
  /// @param[in]  user_data   The user data to be passed to the @a callback
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted, or @a callback is NULL)
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @post Use sound_pool_unset_state_changed_cb() function to unset the
  /// @a callback
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_pool_state_change_cb
  int sound_pool_set_state_changed_cb(
    sound_pool_h pool,
    sound_pool_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sound_pool_set_state_changed_cb(
      pool,
      callback,
      user_data,
    );
  }

  late final _sound_pool_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_pool_h, sound_pool_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('sound_pool_set_state_changed_cb');
  late final _sound_pool_set_state_changed_cb =
      _sound_pool_set_state_changed_cbPtr.asFunction<
          int Function(sound_pool_h, sound_pool_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets the callback for handling sound @a pool state change.
  ///
  /// @since_tizen 4.0
  /// @param[in]  pool     The sound pool handle
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted)
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @pre Set state change callback by calling
  /// sound_pool_set_state_changed_cb()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_set_state_changed_cb()
  int sound_pool_unset_state_changed_cb(
    sound_pool_h pool,
  ) {
    return _sound_pool_unset_state_changed_cb(
      pool,
    );
  }

  late final _sound_pool_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sound_pool_h)>>(
          'sound_pool_unset_state_changed_cb');
  late final _sound_pool_unset_state_changed_cb =
      _sound_pool_unset_state_changed_cbPtr
          .asFunction<int Function(sound_pool_h)>();

  /// @brief Plays a source by @a tag.
  /// @details Creates stream with @a id that can be used to change parameters and
  /// get additional information.
  /// Sets stream state to #SOUND_POOL_STREAM_STATE_PLAYING.
  /// If a callback is set with sound_pool_stream_play(), and another
  /// callback is set with sound_pool_stream_set_state_changed_cb(),
  /// the second callback will overwrite the first one.
  /// @since_tizen 4.0
  /// @remarks Resultant stream volume will depend on global pool volume.
  ///
  /// @param[in]  pool        The sound pool handle
  /// @param[in]  tag         Unique string that identifies source
  /// @param[in]  loop        Number of times stream will be repeated
  /// (pass 0 if stream should be repeated continuously)
  /// @param[in]  volume      Stream volume in 0.0~1.0 range
  /// @param[in]  priority    Stream priority (0 = lowest priority). Check
  /// sound_pool_stream_set_priority() documentation
  /// for details on prioritization rules.
  /// @param[in]  priority_policy    Stream priority policy.\n
  /// (#SOUND_POOL_STREAM_PRIORITY_POLICY_MUTE - Mute)\n
  /// (#SOUND_POOL_STREAM_PRIORITY_POLICY_SUSPENDED - Suspended)\n
  /// If priority_policy is set to Mute, the stream will be
  /// playing with mute even in the presence of high priority
  /// stream and it will not be Suspended.
  /// @param[in]  callback    The callback that will be called after stream state
  /// will be changed, or NULL if this callback call
  /// isn't needed. If @a callback is set, then it will
  /// be called asynchronously.
  /// @param[in]  user_data   The user data to be passed to the @a callback
  /// @param[out] id          Unique stream identifier that can be used to
  /// change parameters and get additional information
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted, @a tag is NULL, @a volume is out of
  /// 0.0~1.0 range, or @a id is NULL)
  /// @retval #SOUND_POOL_ERROR_KEY_NOT_AVAILABLE No sources tagged by @a tag exist
  /// in the pool
  /// @retval #SOUND_POOL_ERROR_OUT_OF_MEMORY Not enough memory to allocate new
  /// sound stream
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Create sound pool handle by calling sound_pool_create()
  /// @pre Load source to @a pool by calling sound_pool_load_source_from_file()
  /// @post When playback is finished normally (i.e. sound_pool_stream_stop()
  /// will be not used for stream termination) state will be changed to
  /// #SOUND_POOL_STREAM_STATE_FINISHED and memory will be cleared from the
  /// stream allocated resources automatically
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_load_source_from_file()
  /// @see sound_pool_set_volume()
  /// @see sound_pool_get_volume()
  int sound_pool_stream_play(
    sound_pool_h pool,
    ffi.Pointer<ffi.Char> tag,
    int loop,
    double volume,
    int priority,
    int priority_policy,
    sound_pool_stream_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.UnsignedInt> id,
  ) {
    return _sound_pool_stream_play(
      pool,
      tag,
      loop,
      volume,
      priority,
      priority_policy,
      callback,
      user_data,
      id,
    );
  }

  late final _sound_pool_stream_playPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sound_pool_h,
              ffi.Pointer<ffi.Char>,
              ffi.UnsignedInt,
              ffi.Float,
              ffi.UnsignedInt,
              ffi.Int32,
              sound_pool_stream_state_changed_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.UnsignedInt>)>>('sound_pool_stream_play');
  late final _sound_pool_stream_play = _sound_pool_stream_playPtr.asFunction<
      int Function(
          sound_pool_h,
          ffi.Pointer<ffi.Char>,
          int,
          double,
          int,
          int,
          sound_pool_stream_state_changed_cb,
          ffi.Pointer<ffi.Void>,
          ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Pauses a stream by @a id.
  /// @details Sets stream state to #SOUND_POOL_STREAM_STATE_PAUSED.
  /// @since_tizen 4.0
  /// @remarks Stream state has to be #SOUND_POOL_STREAM_STATE_PLAYING.
  ///
  /// @param[in]  pool    The sound pool handle
  /// @param[in]  id      Unique stream identifier
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted)
  /// @retval #SOUND_POOL_ERROR_KEY_NOT_AVAILABLE No streams identified by @a id
  /// exist in the pool
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation or stream is in
  /// the state which is not allowed for pause operation
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @pre Load source to @a pool by calling sound_pool_load_source_from_file()
  /// @pre Start stream playback by calling sound_pool_stream_play()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_load_source_from_file()
  /// @see sound_pool_stream_play()
  int sound_pool_stream_pause(
    sound_pool_h pool,
    int id,
  ) {
    return _sound_pool_stream_pause(
      pool,
      id,
    );
  }

  late final _sound_pool_stream_pausePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(sound_pool_h, ffi.UnsignedInt)>>(
      'sound_pool_stream_pause');
  late final _sound_pool_stream_pause =
      _sound_pool_stream_pausePtr.asFunction<int Function(sound_pool_h, int)>();

  /// @brief Resumes a stream by @a id.
  /// @details Sets stream state to #SOUND_POOL_STREAM_STATE_PLAYING.
  /// @since_tizen 4.0
  /// @remarks Stream state has to be #SOUND_POOL_STREAM_STATE_PAUSED.
  ///
  /// @param[in]  pool    The sound pool handle
  /// @param[in]  id      Unique stream identifier
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted)
  /// @retval #SOUND_POOL_ERROR_KEY_NOT_AVAILABLE No streams identified by @a id
  /// exist in the pool
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation or stream is in
  /// the state which is not allowed for resume operation
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @pre Load source to @a pool by calling sound_pool_load_source_from_file()
  /// @pre Start stream playback by calling sound_pool_stream_play()
  /// @pre Pause stream playback by calling sound_pool_stream_pause()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_load_source_from_file()
  /// @see sound_pool_stream_play()
  /// @see sound_pool_stream_pause()
  int sound_pool_stream_resume(
    sound_pool_h pool,
    int id,
  ) {
    return _sound_pool_stream_resume(
      pool,
      id,
    );
  }

  late final _sound_pool_stream_resumePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(sound_pool_h, ffi.UnsignedInt)>>(
      'sound_pool_stream_resume');
  late final _sound_pool_stream_resume = _sound_pool_stream_resumePtr
      .asFunction<int Function(sound_pool_h, int)>();

  /// @brief Stops a stream by @a id.
  /// @details Sets stream state to #SOUND_POOL_STREAM_STATE_STOPPED.
  /// After stream was stopped it can not be resumed and @a id value
  /// becomes invalid. Moreover, stream will never gets
  /// #SOUND_POOL_STREAM_STATE_FINISHED state as it will be terminated
  /// after this function call.
  ///
  /// @since_tizen 4.0
  /// @param[in]  pool    The sound pool handle
  /// @param[in]  id      Unique stream identifier
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted)
  /// @retval #SOUND_POOL_ERROR_KEY_NOT_AVAILABLE No streams identified by @a id
  /// exist in the pool
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation or stream is in
  /// the state which is not allowed for stop operation
  ///
  /// @pre Create sound pool handle by calling sound_pool_create()
  /// @pre Load source to @a pool by calling sound_pool_load_source_from_file()
  /// @pre Start stream playback by calling sound_pool_stream_play()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_load_source_from_file()
  /// @see sound_pool_stream_play()
  int sound_pool_stream_stop(
    sound_pool_h pool,
    int id,
  ) {
    return _sound_pool_stream_stop(
      pool,
      id,
    );
  }

  late final _sound_pool_stream_stopPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(sound_pool_h, ffi.UnsignedInt)>>(
      'sound_pool_stream_stop');
  late final _sound_pool_stream_stop =
      _sound_pool_stream_stopPtr.asFunction<int Function(sound_pool_h, int)>();

  /// @brief Sets the stream's volume parameters by stream @a id.
  /// @since_tizen 4.0
  /// @remarks Resultant stream volume will depend on global pool volume.
  ///
  /// @param[in]  pool      The sound pool handle
  /// @param[in]  id        Unique stream identifier
  /// @param[in]  volume    Stream volume in 0.0~1.0 range
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted, or @a volume isn't in 0.0~1.0 range)
  /// @retval #SOUND_POOL_ERROR_KEY_NOT_AVAILABLE No streams identified by @a id
  /// exist in the pool
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @pre Load source to @a pool by calling sound_pool_load_source_from_file()
  /// @pre Start stream playback by calling sound_pool_stream_play()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_load_source_from_file()
  /// @see sound_pool_stream_play()
  /// @see sound_pool_set_volume
  /// @see sound_pool_get_volume
  int sound_pool_stream_set_volume(
    sound_pool_h pool,
    int id,
    double volume,
  ) {
    return _sound_pool_stream_set_volume(
      pool,
      id,
      volume,
    );
  }

  late final _sound_pool_stream_set_volumePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_pool_h, ffi.UnsignedInt,
              ffi.Float)>>('sound_pool_stream_set_volume');
  late final _sound_pool_stream_set_volume = _sound_pool_stream_set_volumePtr
      .asFunction<int Function(sound_pool_h, int, double)>();

  /// @brief Gets the stream's volume parameters by stream @a id.
  ///
  /// @since_tizen 4.0
  /// @param[in]  pool      The sound pool handle
  /// @param[in]  id        Unique stream identifier
  /// @param[out] volume    Stream volume in 0.0~1.0 range
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted, or @a volume is NULL)
  /// @retval #SOUND_POOL_ERROR_KEY_NOT_AVAILABLE No streams identified by @a id
  /// exist in the pool
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @pre Load source to @a pool by calling sound_pool_load_source_from_file()
  /// @pre Start stream playback by calling sound_pool_stream_play()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_load_source_from_file()
  /// @see sound_pool_stream_play()
  int sound_pool_stream_get_volume(
    sound_pool_h pool,
    int id,
    ffi.Pointer<ffi.Float> volume,
  ) {
    return _sound_pool_stream_get_volume(
      pool,
      id,
      volume,
    );
  }

  late final _sound_pool_stream_get_volumePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_pool_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Float>)>>('sound_pool_stream_get_volume');
  late final _sound_pool_stream_get_volume = _sound_pool_stream_get_volumePtr
      .asFunction<int Function(sound_pool_h, int, ffi.Pointer<ffi.Float>)>();

  /// @brief Sets the stream's priority parameter by stream @a id.
  /// @since_tizen 4.0
  /// @details The below rules are applicable for streams with priority policy
  /// #SOUND_POOL_STREAM_PRIORITY_POLICY_SUSPENDED.
  /// Only streams with highest priority in the active Sound Pool can be
  /// played. If at least one stream with highest priority enters
  /// #SOUND_POOL_STREAM_STATE_PLAYING state, then all streams currently
  /// being played with lower priorities will be transferred to the
  /// #SOUND_POOL_STREAM_STATE_SUSPENDED state. If there are no more
  /// playing streams in a given priority group (group of streams with the
  /// same priority), then all previously suspended streams in the group
  /// with one level lower priority will be resumed.
  ///
  /// For example, if we have N suspended streams in 'LOW' group, M
  /// suspended streams in 'MEDIUM' group and K playing streams in 'HIGH'
  /// group. Then the following rules are valid: When all K streams in HIGH
  /// priority group will be finished, paused, or stopped and Sound Pool is
  /// in active state, only then M streams from MEDIUM priority group will
  /// be resumed. When all M+K streams from HIGH and MEDIUM priority groups
  /// are finished, paused or stopped and Sound Pool is in active state,
  /// only then N streams from LOW priority group will be resumed.
  /// Transferring at least one stream from higher priority group will lead
  /// to suspending of all the streams from lower priorities group(s).
  ///
  /// Priorities don't take any effect in inactive Sound Pools. But after
  /// pool activation, all mentioned rules will be applied.
  ///
  /// If stream priority policy is set to mute
  /// #SOUND_POOL_STREAM_PRIORITY_POLICY_MUTE, all above rules are not valid
  /// for the stream and it will be played with mute even in the presence
  /// of high priority steams.
  /// streams.
  /// @param[in]  pool        The sound pool handle
  /// @param[in]  id          Unique stream identifier
  /// @param[in]  priority    Stream priority (0 = lowest priority)
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted)
  /// @retval #SOUND_POOL_ERROR_KEY_NOT_AVAILABLE No streams identified by @a id
  /// exist in the pool
  /// @retval #SOUND_POOL_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @pre Load source to @a pool by calling sound_pool_load_source_from_file()
  /// @pre Start stream playback by calling sound_pool_stream_play()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_load_source_from_file()
  /// @see sound_pool_stream_play()
  int sound_pool_stream_set_priority(
    sound_pool_h pool,
    int id,
    int priority,
  ) {
    return _sound_pool_stream_set_priority(
      pool,
      id,
      priority,
    );
  }

  late final _sound_pool_stream_set_priorityPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_pool_h, ffi.UnsignedInt,
              ffi.UnsignedInt)>>('sound_pool_stream_set_priority');
  late final _sound_pool_stream_set_priority =
      _sound_pool_stream_set_priorityPtr
          .asFunction<int Function(sound_pool_h, int, int)>();

  /// @brief Gets the stream's priority parameter by stream @a id.
  ///
  /// @since_tizen 4.0
  /// @param[in]   pool        The sound pool handle
  /// @param[in]   id          Unique stream identifier
  /// @param[out]  priority    Stream priority (0 = lowest priority). Check
  /// sound_pool_stream_set_priority() documentation
  /// for details on prioritization rules.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted, or @a priority is NULL)
  /// @retval #SOUND_POOL_ERROR_KEY_NOT_AVAILABLE No streams identified by @a id
  /// exist in the pool
  ///
  /// @pre Create a sound @a pool handle by calling sound_pool_create()
  /// @pre Load source to @a pool by calling sound_pool_load_source_from_file()
  /// @pre Start stream playback by calling sound_pool_stream_play()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_load_source_from_file()
  /// @see sound_pool_stream_play()
  int sound_pool_stream_get_priority(
    sound_pool_h pool,
    int id,
    ffi.Pointer<ffi.UnsignedInt> priority,
  ) {
    return _sound_pool_stream_get_priority(
      pool,
      id,
      priority,
    );
  }

  late final _sound_pool_stream_get_priorityPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_pool_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.UnsignedInt>)>>('sound_pool_stream_get_priority');
  late final _sound_pool_stream_get_priority =
      _sound_pool_stream_get_priorityPtr.asFunction<
          int Function(sound_pool_h, int, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets the current @a state of stream by @a id.
  ///
  /// @since_tizen 4.0
  /// @param[in]  pool     The sound pool handle
  /// @param[in]  id       Unique stream identifier
  /// @param[out] state    Current state of stream
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #SOUND_POOL_ERROR_NONE              Successful
  /// @retval #SOUND_POOL_ERROR_INVALID_PARAMETER Invalid parameter
  /// (@a pool is NULL or corrupted, or @a state is NULL)
  /// @retval #SOUND_POOL_ERROR_KEY_NOT_AVAILABLE No streams identified by @a id
  /// exist in the pool
  ///
  /// @pre Create sound pool handle by calling sound_pool_create()
  /// @pre Load source to @a pool by calling sound_pool_load_source_from_file()
  /// @pre Start stream playback by calling sound_pool_stream_play()
  ///
  /// @see sound_pool_create()
  /// @see sound_pool_load_source_from_file()
  /// @see sound_pool_stream_play()
  /// @see sound_pool_stream_state_e
  int sound_pool_stream_get_state(
    sound_pool_h pool,
    int id,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _sound_pool_stream_get_state(
      pool,
      id,
      state,
    );
  }

  late final _sound_pool_stream_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sound_pool_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Int32>)>>('sound_pool_stream_get_state');
  late final _sound_pool_stream_get_state = _sound_pool_stream_get_statePtr
      .asFunction<int Function(sound_pool_h, int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Creates a streamrecorder handle to record a video or audio
  /// @since_tizen 3.0
  /// @remarks You must release @a recorder using streamrecorder_destroy().
  /// @param[out]  recorder	A handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #STREAMRECORDER_ERROR_INVALID_OPERATION Invalid operation
  int streamrecorder_create(
    ffi.Pointer<streamrecorder_h> recorder,
  ) {
    return _streamrecorder_create(
      recorder,
    );
  }

  late final _streamrecorder_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<streamrecorder_h>)>>(
      'streamrecorder_create');
  late final _streamrecorder_create = _streamrecorder_createPtr
      .asFunction<int Function(ffi.Pointer<streamrecorder_h>)>();

  /// @brief Destroys the streamrecorder handle
  /// @since_tizen 3.0
  /// @param[in]	recorder    The handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre  The recorder state should be #STREAMRECORDER_STATE_CREATED.
  /// @post The recorder state will be #STREAMRECORDER_STATE_NONE.
  int streamrecorder_destroy(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_destroy(
      recorder,
    );
  }

  late final _streamrecorder_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_destroy');
  late final _streamrecorder_destroy =
      _streamrecorder_destroyPtr.asFunction<int Function(streamrecorder_h)>();

  /// @brief Prepares the streamrecorder for recording.
  /// @since_tizen 3.0
  /// @remarks Before calling the function, it is required to properly set streamrecorder_enable_source_buffer(),
  /// audio encoder (streamrecorder_set_audio_encoder()),
  /// video encoder(streamrecorder_set_video_encoder()) and file format (streamrecorder_set_file_format()).
  /// @param[in]	recorder  The handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre  The recorder state should be #STREAMRECORDER_STATE_CREATED. \n
  /// The streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @post The streamrecorder state will be #STREAMRECORDER_STATE_PREPARED
  /// @see	streamrecorder_unprepare()
  /// @see	streamrecorder_set_audio_encoder()
  /// @see	streamrecorder_set_video_encoder()
  /// @see	streamrecorder_set_file_format()
  int streamrecorder_prepare(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_prepare(
      recorder,
    );
  }

  late final _streamrecorder_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_prepare');
  late final _streamrecorder_prepare =
      _streamrecorder_preparePtr.asFunction<int Function(streamrecorder_h)>();

  /// @brief Resets the streamrecorder.
  /// @since_tizen 3.0
  /// @param[in]  recorder  The handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre  The streamrecorder state should be #STREAMRECORDER_STATE_PREPARED set by streamrecorder_prepare(), streamrecorder_cancel() or streamrecorder_commit().
  /// @post The streamrecorder state will be #STREAMRECORDER_STATE_CREATED.
  /// @see	streamrecorder_prepare()
  /// @see	streamrecorder_cancel()
  /// @see	streamrecorder_commit()
  int streamrecorder_unprepare(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_unprepare(
      recorder,
    );
  }

  late final _streamrecorder_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_unprepare');
  late final _streamrecorder_unprepare =
      _streamrecorder_unpreparePtr.asFunction<int Function(streamrecorder_h)>();

  /// @brief Starts the recording.
  /// @since_tizen 3.0
  /// @remarks If file path has been set to an existing file, this file is removed automatically and updated by new one. \n
  /// When you want to record audio or video file, you need to add privilege according to rules below additionally. \n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  /// The filename should be set before this function is invoked.
  /// @param[in]  recorder  The handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #STREAMRECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_PREPARED by streamrecorder_prepare() or #STREAMRECORDER_STATE_PAUSED by streamrecorder_pause(). \n
  /// The filename should be set by streamrecorder_set_filename().
  /// @post The recorder state will be #STREAMRECORDER_STATE_RECORDING.
  /// @see	streamrecorder_pause()
  /// @see	streamrecorder_commit()
  /// @see	streamrecorder_cancel()
  /// @see	streamrecorder_set_audio_encoder()
  /// @see	streamrecorder_set_filename()
  /// @see	streamrecorder_set_file_format()
  /// @see	streamrecorder_recording_status_cb()
  /// @see	streamrecorder_set_filename()
  int streamrecorder_start(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_start(
      recorder,
    );
  }

  late final _streamrecorder_startPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_start');
  late final _streamrecorder_start =
      _streamrecorder_startPtr.asFunction<int Function(streamrecorder_h)>();

  /// @brief Pauses the recording.
  /// @since_tizen 3.0
  /// @remarks Recording can be resumed with streamrecorder_start().
  /// @param[in]  recorder  The handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_RECORDING.
  /// @post The streamrecorder state will be #STREAMRECORDER_STATE_PAUSED.
  /// @see streamrecorder_pause()
  /// @see streamrecorder_commit()
  /// @see streamrecorder_cancel()
  int streamrecorder_pause(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_pause(
      recorder,
    );
  }

  late final _streamrecorder_pausePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_pause');
  late final _streamrecorder_pause =
      _streamrecorder_pausePtr.asFunction<int Function(streamrecorder_h)>();

  /// @brief Stops recording and saves the result.
  /// @since_tizen 3.0
  /// @remarks When you want to record audio or video file, you need to add privilege according to rules below additionally. \n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  /// @param[in]  recorder  The handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #STREAMRECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_RECORDING set by streamrecorder_start() or #STREAMRECORDER_STATE_PAUSED by streamrecorder_pause().
  /// @post The streamrecorder state will be #STREAMRECORDER_STATE_PREPARED.
  /// @see streamrecorder_pause()
  /// @see streamrecorder_cancel()
  /// @see streamrecorder_set_filename()
  /// @see streamrecorder_start()
  int streamrecorder_commit(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_commit(
      recorder,
    );
  }

  late final _streamrecorder_commitPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_commit');
  late final _streamrecorder_commit =
      _streamrecorder_commitPtr.asFunction<int Function(streamrecorder_h)>();

  /// @brief Cancels the recording.
  /// @details The recording data is discarded and not written in the recording file.
  /// @since_tizen 3.0
  /// @remarks When you want to record audio or video file, you need to add privilege according to rules below additionally. \n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  /// @param[in]  recorder  The handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #STREAMRECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_RECORDING set by streamrecorder_start() or #STREAMRECORDER_STATE_PAUSED by streamrecorder_pause().
  /// @post The streamrecorder state will be #STREAMRECORDER_STATE_PREPARED.
  /// @see streamrecorder_pause()
  /// @see streamrecorder_commit()
  /// @see streamrecorder_cancel()
  /// @see streamrecorder_start()
  int streamrecorder_cancel(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_cancel(
      recorder,
    );
  }

  late final _streamrecorder_cancelPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_cancel');
  late final _streamrecorder_cancel =
      _streamrecorder_cancelPtr.asFunction<int Function(streamrecorder_h)>();

  /// @brief Pushes buffer to StreamRecorder to record audio/video
  /// @since_tizen 3.0
  /// @remarks When you want to record audio or video file, you need to add privilege according to rules below additionally. \n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  /// @param[in]	recorder	The handle to the streamrecorder
  /// @param[in]	inbuf The media packet containing buffer and other associated values
  /// @return  @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_PERMISSION_DENIED The access to the resources can not be granted
  int streamrecorder_push_stream_buffer(
    streamrecorder_h recorder,
    media_packet_h inbuf,
  ) {
    return _streamrecorder_push_stream_buffer(
      recorder,
      inbuf,
    );
  }

  late final _streamrecorder_push_stream_bufferPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h,
              media_packet_h)>>('streamrecorder_push_stream_buffer');
  late final _streamrecorder_push_stream_buffer =
      _streamrecorder_push_stream_bufferPtr
          .asFunction<int Function(streamrecorder_h, media_packet_h)>();

  /// @brief Sets the video source as live buffer to be used for recording
  /// @since_tizen 3.0
  /// @remarks if you want to enable video or audio or both recording, call before streamrecorder_prepare()
  /// @param[in]  recorder  A handle to the streamrecorder
  /// @param[in]  type The type of source input
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre The streamrecorder state must be only #STREAMRECORDER_STATE_CREATED
  int streamrecorder_enable_source_buffer(
    streamrecorder_h recorder,
    int type,
  ) {
    return _streamrecorder_enable_source_buffer(
      recorder,
      type,
    );
  }

  late final _streamrecorder_enable_source_bufferPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(streamrecorder_h, ffi.Int32)>>(
      'streamrecorder_enable_source_buffer');
  late final _streamrecorder_enable_source_buffer =
      _streamrecorder_enable_source_bufferPtr
          .asFunction<int Function(streamrecorder_h, int)>();

  /// @brief Gets the streamrecorder's current state.
  /// @since_tizen 3.0
  /// @param[in]  recorder The handle to the streamrecorder
  /// @param[out]	state  The current state of the streamrecorder
  /// @return  @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  int streamrecorder_get_state(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _streamrecorder_get_state(
      recorder,
      state,
    );
  }

  late final _streamrecorder_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h,
              ffi.Pointer<ffi.Int32>)>>('streamrecorder_get_state');
  late final _streamrecorder_get_state = _streamrecorder_get_statePtr
      .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the file path to record.
  /// @details This function sets file path which defines where newly recorded data should be stored.
  /// @since_tizen 3.0
  /// @remarks If the same file already exists in the file system, then old file will be overwritten.
  /// @param[in]	recorder	The handle to the streamrecorder
  /// @param[in]	path The recording file path
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_CREATED. \n
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see streamrecorder_get_filename()
  int streamrecorder_set_filename(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _streamrecorder_set_filename(
      recorder,
      path,
    );
  }

  late final _streamrecorder_set_filenamePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h,
              ffi.Pointer<ffi.Char>)>>('streamrecorder_set_filename');
  late final _streamrecorder_set_filename = _streamrecorder_set_filenamePtr
      .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the file path to record.
  /// @since_tizen 3.0
  /// @remarks You must release @a path using free().
  /// @param[in]	recorder    The handle to the streamrecorder
  /// @param[out]	path    The recording file path
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_set_filename()
  int streamrecorder_get_filename(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _streamrecorder_get_filename(
      recorder,
      path,
    );
  }

  late final _streamrecorder_get_filenamePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  streamrecorder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'streamrecorder_get_filename');
  late final _streamrecorder_get_filename =
      _streamrecorder_get_filenamePtr.asFunction<
          int Function(streamrecorder_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the file format for recording media stream.
  /// @since_tizen 3.0
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[in] format   The media file format
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #STREAMRECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_CREATED. \n
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see streamrecorder_get_file_format()
  /// @see streamrecorder_foreach_supported_file_format()
  int streamrecorder_set_file_format(
    streamrecorder_h recorder,
    int format,
  ) {
    return _streamrecorder_set_file_format(
      recorder,
      format,
    );
  }

  late final _streamrecorder_set_file_formatPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(streamrecorder_h, ffi.Int32)>>(
      'streamrecorder_set_file_format');
  late final _streamrecorder_set_file_format =
      _streamrecorder_set_file_formatPtr
          .asFunction<int Function(streamrecorder_h, int)>();

  /// @brief Gets the file format for recording media stream.
  /// @since_tizen 3.0
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[out] format   The media file format
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre The streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see streamrecorder_set_file_format()
  /// @see streamrecorder_foreach_supported_file_format()
  int streamrecorder_get_file_format(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int32> format,
  ) {
    return _streamrecorder_get_file_format(
      recorder,
      format,
    );
  }

  late final _streamrecorder_get_file_formatPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h,
              ffi.Pointer<ffi.Int32>)>>('streamrecorder_get_file_format');
  late final _streamrecorder_get_file_format =
      _streamrecorder_get_file_formatPtr
          .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the audio codec for encoding an audio stream.
  /// @since_tizen 3.0
  /// @remarks You can get available audio encoders by using streamrecorder_foreach_supported_audio_encoder(). \n
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[in] codec    The audio codec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #STREAMRECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @retval #STREAMRECORDER_ERROR_INVALID_OPERATION Invalid operation
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_CREATED. \n
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_get_audio_encoder()
  /// @see streamrecorder_foreach_supported_audio_encoder()
  int streamrecorder_set_audio_encoder(
    streamrecorder_h recorder,
    int codec,
  ) {
    return _streamrecorder_set_audio_encoder(
      recorder,
      codec,
    );
  }

  late final _streamrecorder_set_audio_encoderPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(streamrecorder_h, ffi.Int32)>>(
      'streamrecorder_set_audio_encoder');
  late final _streamrecorder_set_audio_encoder =
      _streamrecorder_set_audio_encoderPtr
          .asFunction<int Function(streamrecorder_h, int)>();

  /// @brief Gets the audio codec for encoding an audio stream.
  /// @since_tizen 3.0
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[out] codec   The audio codec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @pre The streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_set_audio_encoder()
  /// @see streamrecorder_foreach_supported_audio_encoder()
  int streamrecorder_get_audio_encoder(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int32> codec,
  ) {
    return _streamrecorder_get_audio_encoder(
      recorder,
      codec,
    );
  }

  late final _streamrecorder_get_audio_encoderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h,
              ffi.Pointer<ffi.Int32>)>>('streamrecorder_get_audio_encoder');
  late final _streamrecorder_get_audio_encoder =
      _streamrecorder_get_audio_encoderPtr
          .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the resolution of the video recording.
  /// @since_tizen 3.0
  /// @remarks This function should be called before recording (streamrecorder_start()).
  /// @param[in] recorder	The handle to the streamrecorder
  /// @param[in] width	The input width
  /// @param[in] height	The input height
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #STREAMRECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @pre    The streamrecorder state must be #STREAMRECORDER_STATE_CREATED. \n
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_start()
  /// @see	streamrecorder_get_video_resolution()
  /// @see	streamrecorder_foreach_supported_video_resolution()
  int streamrecorder_set_video_resolution(
    streamrecorder_h recorder,
    int width,
    int height,
  ) {
    return _streamrecorder_set_video_resolution(
      recorder,
      width,
      height,
    );
  }

  late final _streamrecorder_set_video_resolutionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h, ffi.Int,
              ffi.Int)>>('streamrecorder_set_video_resolution');
  late final _streamrecorder_set_video_resolution =
      _streamrecorder_set_video_resolutionPtr
          .asFunction<int Function(streamrecorder_h, int, int)>();

  /// @brief Gets the resolution of the video recording.
  /// @since_tizen 3.0
  /// @param[in] recorder	The handle to the streamrecorder
  /// @param[out] width	The video width
  /// @param[out] height	The video height
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @pre The streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_set_video_resolution()
  /// @see	streamrecorder_foreach_supported_video_resolution()
  int streamrecorder_get_video_resolution(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int> width,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _streamrecorder_get_video_resolution(
      recorder,
      width,
      height,
    );
  }

  late final _streamrecorder_get_video_resolutionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('streamrecorder_get_video_resolution');
  late final _streamrecorder_get_video_resolution =
      _streamrecorder_get_video_resolutionPtr.asFunction<
          int Function(
              streamrecorder_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the video codec for encoding video stream.
  /// @since_tizen 3.0
  /// @remarks You can get available video encoders by using recorder_foreach_supported_video_encoder().
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[in] codec    The video codec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @retval #STREAMRECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_CREATED. \n
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see streamrecorder_get_video_encoder()
  /// @see streamrecorder_foreach_supported_video_encoder()
  int streamrecorder_set_video_encoder(
    streamrecorder_h recorder,
    int codec,
  ) {
    return _streamrecorder_set_video_encoder(
      recorder,
      codec,
    );
  }

  late final _streamrecorder_set_video_encoderPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(streamrecorder_h, ffi.Int32)>>(
      'streamrecorder_set_video_encoder');
  late final _streamrecorder_set_video_encoder =
      _streamrecorder_set_video_encoderPtr
          .asFunction<int Function(streamrecorder_h, int)>();

  /// @brief Gets the video codec for encoding video stream.
  /// @since_tizen 3.0
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[out] codec   The video codec
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_NOT_SUPPORTED The feature is not supported
  /// @pre The streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see streamrecorder_set_video_encoder()
  /// @see streamrecorder_foreach_supported_video_encoder()
  int streamrecorder_get_video_encoder(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int32> codec,
  ) {
    return _streamrecorder_get_video_encoder(
      recorder,
      codec,
    );
  }

  late final _streamrecorder_get_video_encoderPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h,
              ffi.Pointer<ffi.Int32>)>>('streamrecorder_get_video_encoder');
  late final _streamrecorder_get_video_encoder =
      _streamrecorder_get_video_encoderPtr
          .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the recording frame rate.
  /// @since_tizen 3.0
  /// @remarks This function should be called before prepared state.
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[in] framerate The frame rate for recording
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @see streamrecorder_get_video_framerate()
  int streamrecorder_set_video_framerate(
    streamrecorder_h recorder,
    int framerate,
  ) {
    return _streamrecorder_set_video_framerate(
      recorder,
      framerate,
    );
  }

  late final _streamrecorder_set_video_frameratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h, ffi.Int)>>(
          'streamrecorder_set_video_framerate');
  late final _streamrecorder_set_video_framerate =
      _streamrecorder_set_video_frameratePtr
          .asFunction<int Function(streamrecorder_h, int)>();

  /// @brief Gets the recording frame rate.
  /// @since_tizen 3.0
  /// @param[in] recorder The handle to the camera
  /// @param[out] framerate The frame rate for recording that already is set
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see streamrecorder_set_video_framerate()
  int streamrecorder_get_video_framerate(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int> framerate,
  ) {
    return _streamrecorder_get_video_framerate(
      recorder,
      framerate,
    );
  }

  late final _streamrecorder_get_video_frameratePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h,
              ffi.Pointer<ffi.Int>)>>('streamrecorder_get_video_framerate');
  late final _streamrecorder_get_video_framerate =
      _streamrecorder_get_video_frameratePtr
          .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the video source format.
  /// @since_tizen 3.0
  /// @remarks This function should be called before prepared state.
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[in] format The color type of video source
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @see streamrecorder_get_video_source_format()
  int streamrecorder_set_video_source_format(
    streamrecorder_h recorder,
    int format,
  ) {
    return _streamrecorder_set_video_source_format(
      recorder,
      format,
    );
  }

  late final _streamrecorder_set_video_source_formatPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(streamrecorder_h, ffi.Int32)>>(
      'streamrecorder_set_video_source_format');
  late final _streamrecorder_set_video_source_format =
      _streamrecorder_set_video_source_formatPtr
          .asFunction<int Function(streamrecorder_h, int)>();

  /// @brief Gets the video source format.
  /// @since_tizen 3.0
  /// @remarks This function should be called before prepared state.
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[out] format The color type of video source that already is set
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see streamrecorder_set_video_source_format()
  int streamrecorder_get_video_source_format(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int32> format,
  ) {
    return _streamrecorder_get_video_source_format(
      recorder,
      format,
    );
  }

  late final _streamrecorder_get_video_source_formatPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(streamrecorder_h, ffi.Pointer<ffi.Int32>)>>(
      'streamrecorder_get_video_source_format');
  late final _streamrecorder_get_video_source_format =
      _streamrecorder_get_video_source_formatPtr
          .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the maximum size of a recording file.
  /// @since_tizen 3.0
  /// @remarks After reaching the limitation, the recording data is discarded and not written in the recording file.
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[in] type The recording limit type
  /// @param[in] limit If limit type is STREAMRECORDER_RECORDING_LIMIT_TYPE_SIZE, the limit value is the maximum size of the recording file(KB), \n
  /// otherwise limit value is the maximum time of the recording file (in seconds) \n
  /// @c 0 means unlimited recording size or time.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_CREATED. \n
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_get_recording_limit()
  int streamrecorder_set_recording_limit(
    streamrecorder_h recorder,
    int type,
    int limit,
  ) {
    return _streamrecorder_set_recording_limit(
      recorder,
      type,
      limit,
    );
  }

  late final _streamrecorder_set_recording_limitPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h, ffi.Int32,
              ffi.Int)>>('streamrecorder_set_recording_limit');
  late final _streamrecorder_set_recording_limit =
      _streamrecorder_set_recording_limitPtr
          .asFunction<int Function(streamrecorder_h, int, int)>();

  /// @brief Gets the maximum size of a recording file.
  /// @since_tizen 3.0
  /// @param[in] recorder The handle to the streamrecorder
  /// @param[in] type The recording limit type
  /// @param[out] limit If limit type is STREAMRECORDER_RECORDING_LIMIT_TYPE_SIZE, the limit value is the maximum size of the recording file(KB), \n
  /// otherwise limit value is the maximum time of the recording file (in seconds) \n
  /// @c 0 means unlimited recording size or time.
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre The streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_set_recording_limit()
  int streamrecorder_get_recording_limit(
    streamrecorder_h recorder,
    int type,
    ffi.Pointer<ffi.Int> limit,
  ) {
    return _streamrecorder_get_recording_limit(
      recorder,
      type,
      limit,
    );
  }

  late final _streamrecorder_get_recording_limitPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h, ffi.Int32,
              ffi.Pointer<ffi.Int>)>>('streamrecorder_get_recording_limit');
  late final _streamrecorder_get_recording_limit =
      _streamrecorder_get_recording_limitPtr.asFunction<
          int Function(streamrecorder_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the sampling rate of an audio stream.
  /// @since_tizen 3.0
  /// @param[in] recorder    The handle to the streamrecorder
  /// @param[in] samplerate The sample rate in Hertz
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_CREATED. \n
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_get_audio_samplerate()
  int streamrecorder_set_audio_samplerate(
    streamrecorder_h recorder,
    int samplerate,
  ) {
    return _streamrecorder_set_audio_samplerate(
      recorder,
      samplerate,
    );
  }

  late final _streamrecorder_set_audio_sampleratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h, ffi.Int)>>(
          'streamrecorder_set_audio_samplerate');
  late final _streamrecorder_set_audio_samplerate =
      _streamrecorder_set_audio_sampleratePtr
          .asFunction<int Function(streamrecorder_h, int)>();

  /// @brief Gets the sampling rate of an audio stream.
  /// @since_tizen 3.0
  /// @param[in]  recorder    The handle to the streamrecorder
  /// @param[out] samplerate  The sample rate in Hertz
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre The streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_set_audio_samplerate()
  int streamrecorder_get_audio_samplerate(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int> samplerate,
  ) {
    return _streamrecorder_get_audio_samplerate(
      recorder,
      samplerate,
    );
  }

  late final _streamrecorder_get_audio_sampleratePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h,
              ffi.Pointer<ffi.Int>)>>('streamrecorder_get_audio_samplerate');
  late final _streamrecorder_get_audio_samplerate =
      _streamrecorder_get_audio_sampleratePtr
          .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the bitrate of an audio encoder.
  /// @since_tizen 3.0
  /// @param[in] recorder  The handle to the streamrecorder
  /// @param[in] bitrate   The bitrate (for mms : 12200[bps], normal : 288000[bps])
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_CREATED. \n
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_get_audio_encoder_bitrate()
  int streamrecorder_set_audio_encoder_bitrate(
    streamrecorder_h recorder,
    int bitrate,
  ) {
    return _streamrecorder_set_audio_encoder_bitrate(
      recorder,
      bitrate,
    );
  }

  late final _streamrecorder_set_audio_encoder_bitratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h, ffi.Int)>>(
          'streamrecorder_set_audio_encoder_bitrate');
  late final _streamrecorder_set_audio_encoder_bitrate =
      _streamrecorder_set_audio_encoder_bitratePtr
          .asFunction<int Function(streamrecorder_h, int)>();

  /// @brief Sets the bitrate of a video encoder.
  /// @since_tizen 3.0
  /// @param[in] recorder  The handle to the streamrecorder
  /// @param[in] bitrate   The bitrate in bits per second
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_CREATED. \n
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_get_video_encoder_bitrate()
  int streamrecorder_set_video_encoder_bitrate(
    streamrecorder_h recorder,
    int bitrate,
  ) {
    return _streamrecorder_set_video_encoder_bitrate(
      recorder,
      bitrate,
    );
  }

  late final _streamrecorder_set_video_encoder_bitratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h, ffi.Int)>>(
          'streamrecorder_set_video_encoder_bitrate');
  late final _streamrecorder_set_video_encoder_bitrate =
      _streamrecorder_set_video_encoder_bitratePtr
          .asFunction<int Function(streamrecorder_h, int)>();

  /// @brief Gets the bitrate of an audio encoder.
  /// @since_tizen 3.0
  /// @param[in]  recorder  The handle to the streamrecorder
  /// @param[out] bitrate   The bitrate in bits per second
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre The streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_set_audio_encoder_bitrate()
  int streamrecorder_get_audio_encoder_bitrate(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int> bitrate,
  ) {
    return _streamrecorder_get_audio_encoder_bitrate(
      recorder,
      bitrate,
    );
  }

  late final _streamrecorder_get_audio_encoder_bitratePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(streamrecorder_h, ffi.Pointer<ffi.Int>)>>(
      'streamrecorder_get_audio_encoder_bitrate');
  late final _streamrecorder_get_audio_encoder_bitrate =
      _streamrecorder_get_audio_encoder_bitratePtr
          .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the bitrate of a video encoder.
  /// @since_tizen 3.0
  /// @param[in]  recorder  The handle to the streamrecorder
  /// @param[out] bitrate   The bitrate in bits per second
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre The streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_set_audio_encoder_bitrate()
  int streamrecorder_get_video_encoder_bitrate(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int> bitrate,
  ) {
    return _streamrecorder_get_video_encoder_bitrate(
      recorder,
      bitrate,
    );
  }

  late final _streamrecorder_get_video_encoder_bitratePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(streamrecorder_h, ffi.Pointer<ffi.Int>)>>(
      'streamrecorder_get_video_encoder_bitrate');
  late final _streamrecorder_get_video_encoder_bitrate =
      _streamrecorder_get_video_encoder_bitratePtr
          .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the number of the audio channel.
  /// @since_tizen 3.0
  /// @remarks This attribute is applied only in STREAMRECORDER_STATE_CREATED state. \n
  /// For mono recording, setting channel to @c 1. \n
  /// For stereo recording, setting channel to @c 2.
  /// @param[in] recorder       The handle to the streamrecorder
  /// @param[in] channel_count  The number of the audio channel
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STREAMRECORDER_ERROR_INVALID_STATE Invalid state
  /// @pre The streamrecorder state must be #STREAMRECORDER_STATE_CREATED.\n
  /// streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_get_audio_channel()
  int streamrecorder_set_audio_channel(
    streamrecorder_h recorder,
    int channel_count,
  ) {
    return _streamrecorder_set_audio_channel(
      recorder,
      channel_count,
    );
  }

  late final _streamrecorder_set_audio_channelPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h, ffi.Int)>>(
          'streamrecorder_set_audio_channel');
  late final _streamrecorder_set_audio_channel =
      _streamrecorder_set_audio_channelPtr
          .asFunction<int Function(streamrecorder_h, int)>();

  /// @brief Gets the number of the audio channel.
  /// @since_tizen 3.0
  /// @param[in] recorder  The handle to the streamrecorder
  /// @param[out] channel_count  The number of the audio channel
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre The streamrecorder_enable_source_buffer() should be invoked before this function.
  /// @see	streamrecorder_set_audio_channel()
  int streamrecorder_get_audio_channel(
    streamrecorder_h recorder,
    ffi.Pointer<ffi.Int> channel_count,
  ) {
    return _streamrecorder_get_audio_channel(
      recorder,
      channel_count,
    );
  }

  late final _streamrecorder_get_audio_channelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h,
              ffi.Pointer<ffi.Int>)>>('streamrecorder_get_audio_channel');
  late final _streamrecorder_get_audio_channel =
      _streamrecorder_get_audio_channelPtr
          .asFunction<int Function(streamrecorder_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Retrieves all supported file formats by invoking a specific callback for each supported file format.
  /// @since_tizen 3.0
  /// @param[in] recorder  The handle to the streamrecorder
  /// @param[in] callback The iteration callback
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post  streamrecorder_supported_file_format_cb() will be invoked.
  /// @see streamrecorder_get_file_format()
  /// @see streamrecorder_set_file_format()
  /// @see streamrecorder_supported_file_format_cb()
  int streamrecorder_foreach_supported_file_format(
    streamrecorder_h recorder,
    streamrecorder_supported_file_format_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _streamrecorder_foreach_supported_file_format(
      recorder,
      callback,
      user_data,
    );
  }

  late final _streamrecorder_foreach_supported_file_formatPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  streamrecorder_h,
                  streamrecorder_supported_file_format_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'streamrecorder_foreach_supported_file_format');
  late final _streamrecorder_foreach_supported_file_format =
      _streamrecorder_foreach_supported_file_formatPtr.asFunction<
          int Function(
              streamrecorder_h,
              streamrecorder_supported_file_format_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves all supported audio encoders by invoking a specific callback for each supported audio encoder.
  /// @since_tizen 3.0
  /// @param[in] recorder  The handle to the streamrecorder
  /// @param[in] callback	The iteration callback
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post  streamrecorder_supported_audio_encoder_cb() will be invoked.
  /// @see	streamrecorder_set_audio_encoder()
  /// @see	streamrecorder_get_audio_encoder()
  /// @see	streamrecorder_supported_audio_encoder_cb()
  int streamrecorder_foreach_supported_audio_encoder(
    streamrecorder_h recorder,
    streamrecorder_supported_audio_encoder_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _streamrecorder_foreach_supported_audio_encoder(
      recorder,
      callback,
      user_data,
    );
  }

  late final _streamrecorder_foreach_supported_audio_encoderPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  streamrecorder_h,
                  streamrecorder_supported_audio_encoder_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'streamrecorder_foreach_supported_audio_encoder');
  late final _streamrecorder_foreach_supported_audio_encoder =
      _streamrecorder_foreach_supported_audio_encoderPtr.asFunction<
          int Function(
              streamrecorder_h,
              streamrecorder_supported_audio_encoder_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves all supported video encoders by invoking a specific callback for each supported video encoder.
  /// @since_tizen 3.0
  /// @param[in] recorder	The handle to the streamrecorder
  /// @param[in] callback	The iteration callback
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post  streamrecorder_supported_video_encoder_cb() will be invoked.
  /// @see streamrecorder_set_video_encoder()
  /// @see streamrecorder_get_video_encoder()
  /// @see	streamrecorder_supported_video_encoder_cb()
  int streamrecorder_foreach_supported_video_encoder(
    streamrecorder_h recorder,
    streamrecorder_supported_video_encoder_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _streamrecorder_foreach_supported_video_encoder(
      recorder,
      callback,
      user_data,
    );
  }

  late final _streamrecorder_foreach_supported_video_encoderPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  streamrecorder_h,
                  streamrecorder_supported_video_encoder_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'streamrecorder_foreach_supported_video_encoder');
  late final _streamrecorder_foreach_supported_video_encoder =
      _streamrecorder_foreach_supported_video_encoderPtr.asFunction<
          int Function(
              streamrecorder_h,
              streamrecorder_supported_video_encoder_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves all supported video resolutions by invoking callback function once for each supported video resolution.
  /// @since_tizen 3.0
  /// @param[in] recorder	The handle to the streamrecorder
  /// @param[in] foreach_cb	The callback function to be invoked
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post	This function invokes streamrecorder_supported_video_resolution_cb() repeatedly to retrieve each supported video resolution.
  /// @see	streamrecorder_set_video_resolution()
  /// @see	streamrecorder_get_video_resolution()
  /// @see	streamrecorder_supported_video_resolution_cb()
  int streamrecorder_foreach_supported_video_resolution(
    streamrecorder_h recorder,
    streamrecorder_supported_video_resolution_cb foreach_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _streamrecorder_foreach_supported_video_resolution(
      recorder,
      foreach_cb,
      user_data,
    );
  }

  late final _streamrecorder_foreach_supported_video_resolutionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  streamrecorder_h,
                  streamrecorder_supported_video_resolution_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'streamrecorder_foreach_supported_video_resolution');
  late final _streamrecorder_foreach_supported_video_resolution =
      _streamrecorder_foreach_supported_video_resolutionPtr.asFunction<
          int Function(
              streamrecorder_h,
              streamrecorder_supported_video_resolution_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Registers the callback function that will be invoked when the streamrecorder get some notification.
  /// @since_tizen 3.0
  /// @param[in] recorder	The handle to the streamrecorder
  /// @param[in] callback	The function pointer of user callback
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post  streamrecorder_notify_cb() will be invoked.
  /// @see streamrecorder_unset_notify_cb()
  /// @see streamrecorder_notify_cb()
  int streamrecorder_set_notify_cb(
    streamrecorder_h recorder,
    streamrecorder_notify_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _streamrecorder_set_notify_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _streamrecorder_set_notify_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h, streamrecorder_notify_cb,
              ffi.Pointer<ffi.Void>)>>('streamrecorder_set_notify_cb');
  late final _streamrecorder_set_notify_cb =
      _streamrecorder_set_notify_cbPtr.asFunction<
          int Function(streamrecorder_h, streamrecorder_notify_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 3.0
  /// @param[in]  recorder The handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see streamrecorder_set_notify_cb()
  int streamrecorder_unset_notify_cb(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_unset_notify_cb(
      recorder,
    );
  }

  late final _streamrecorder_unset_notify_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_unset_notify_cb');
  late final _streamrecorder_unset_notify_cb =
      _streamrecorder_unset_notify_cbPtr
          .asFunction<int Function(streamrecorder_h)>();

  /// @brief Registers a callback function to be invoked when the recording information changes.
  /// @since_tizen 3.0
  /// @param[in]  recorder   The handle to the streamrecorder
  /// @param[in]  callback   The function pointer of user callback
  /// @param[in]  user_data  The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post  streamrecorder_recording_status_cb() will be invoked.
  /// @see	streamrecorder_unset_recording_status_cb()
  /// @see	streamrecorder_recording_status_cb()
  int streamrecorder_set_recording_status_cb(
    streamrecorder_h recorder,
    streamrecorder_recording_status_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _streamrecorder_set_recording_status_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _streamrecorder_set_recording_status_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(streamrecorder_h,
                  streamrecorder_recording_status_cb, ffi.Pointer<ffi.Void>)>>(
      'streamrecorder_set_recording_status_cb');
  late final _streamrecorder_set_recording_status_cb =
      _streamrecorder_set_recording_status_cbPtr.asFunction<
          int Function(streamrecorder_h, streamrecorder_recording_status_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 3.0
  /// @param[in]  recorder    The handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see	streamrecorder_set_recording_status_cb()
  int streamrecorder_unset_recording_status_cb(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_unset_recording_status_cb(
      recorder,
    );
  }

  late final _streamrecorder_unset_recording_status_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_unset_recording_status_cb');
  late final _streamrecorder_unset_recording_status_cb =
      _streamrecorder_unset_recording_status_cbPtr
          .asFunction<int Function(streamrecorder_h)>();

  /// @brief Registers the callback function to be run when reached the recording limit.
  /// @since_tizen 3.0
  /// @param[in]	recorder	The handle to treamrecorder
  /// @param[in]	callback	The function pointer of user callback
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post  streamrecorder_recording_limit_reached_cb() will be invoked.
  /// @see	streamrecorder_unset_recording_limit_reached_cb()
  /// @see	streamrecorder_set_size_limit()
  /// @see	streamrecorder_set_time_limit()
  /// @see	streamrecorder_recording_limit_reached_cb()
  int streamrecorder_set_recording_limit_reached_cb(
    streamrecorder_h recorder,
    streamrecorder_recording_limit_reached_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _streamrecorder_set_recording_limit_reached_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _streamrecorder_set_recording_limit_reached_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  streamrecorder_h,
                  streamrecorder_recording_limit_reached_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'streamrecorder_set_recording_limit_reached_cb');
  late final _streamrecorder_set_recording_limit_reached_cb =
      _streamrecorder_set_recording_limit_reached_cbPtr.asFunction<
          int Function(
              streamrecorder_h,
              streamrecorder_recording_limit_reached_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 3.0
  /// @param[in]  recorder  The handle to the streamrecorder
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see	streamrecorder_set_recording_limit_reached_cb()
  int streamrecorder_unset_recording_limit_reached_cb(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_unset_recording_limit_reached_cb(
      recorder,
    );
  }

  late final _streamrecorder_unset_recording_limit_reached_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_unset_recording_limit_reached_cb');
  late final _streamrecorder_unset_recording_limit_reached_cb =
      _streamrecorder_unset_recording_limit_reached_cbPtr
          .asFunction<int Function(streamrecorder_h)>();

  /// @brief Registers a callback function to be called when an asynchronous operation error occurred.
  /// @since_tizen 3.0
  /// @remarks This callback informs critical error situation.\n
  /// When this callback is invoked, user should release the resource and terminate the application. \n
  /// These error codes will occur. \n
  /// #STREAMRECORDER_ERROR_INVALID_OPERATION \n
  /// #STREAMRECORDER_ERROR_OUT_OF_MEMORY
  /// @param[in]	recorder	The handle to the streamrecorder
  /// @param[in]	callback	The callback function to register
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @return  @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post	This function will invoke streamrecorder_error_cb() when an asynchronous operation error occur.
  /// @see	streamrecorder_unset_error_cb()
  /// @see	streamrecorder_error_cb()
  int streamrecorder_set_error_cb(
    streamrecorder_h recorder,
    streamrecorder_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _streamrecorder_set_error_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _streamrecorder_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(streamrecorder_h, streamrecorder_error_cb,
              ffi.Pointer<ffi.Void>)>>('streamrecorder_set_error_cb');
  late final _streamrecorder_set_error_cb =
      _streamrecorder_set_error_cbPtr.asFunction<
          int Function(streamrecorder_h, streamrecorder_error_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 3.0
  /// @param[in]	recorder	The handle to the streamrecorder
  /// @return  @c on success, otherwise a negative error value
  /// @retval    #STREAMRECORDER_ERROR_NONE Successful
  /// @retval    #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see	streamrecorder_set_error_cb()
  int streamrecorder_unset_error_cb(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_unset_error_cb(
      recorder,
    );
  }

  late final _streamrecorder_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_unset_error_cb');
  late final _streamrecorder_unset_error_cb = _streamrecorder_unset_error_cbPtr
      .asFunction<int Function(streamrecorder_h)>();

  /// @brief Registers a callback function to be called when asynchronous buffers are consumed.
  /// @since_tizen 3.0
  /// @remarks This callback informs to user dealloc buffer.\n
  /// When this callback is invoked, user should release the buffer or media packet. \n
  /// @param[in]	recorder	The handle to the streamrecorder
  /// @param[in]	callback	The callback function to register
  /// @param[in]	user_data	The user data to be passed to the callback function
  /// @return  @c 0 on success, otherwise a negative error value
  /// @retval #STREAMRECORDER_ERROR_NONE Successful
  /// @retval #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see	streamrecorder_unset_buffer_consume_completed_cb()
  /// @see	streamrecorder_push_stream_buffer()
  int streamrecorder_set_buffer_consume_completed_cb(
    streamrecorder_h recorder,
    streamrecorder_consume_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _streamrecorder_set_buffer_consume_completed_cb(
      recorder,
      callback,
      user_data,
    );
  }

  late final _streamrecorder_set_buffer_consume_completed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(streamrecorder_h,
                  streamrecorder_consume_completed_cb, ffi.Pointer<ffi.Void>)>>(
      'streamrecorder_set_buffer_consume_completed_cb');
  late final _streamrecorder_set_buffer_consume_completed_cb =
      _streamrecorder_set_buffer_consume_completed_cbPtr.asFunction<
          int Function(streamrecorder_h, streamrecorder_consume_completed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 3.0
  /// @param[in]	recorder	The handle to the streamrecorder
  /// @return  @c on success, otherwise a negative error value
  /// @retval    #STREAMRECORDER_ERROR_NONE Successful
  /// @retval    #STREAMRECORDER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see	streamrecorder_set_buffer_consume_completed_cb()
  int streamrecorder_unset_buffer_consume_completed_cb(
    streamrecorder_h recorder,
  ) {
    return _streamrecorder_unset_buffer_consume_completed_cb(
      recorder,
    );
  }

  late final _streamrecorder_unset_buffer_consume_completed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(streamrecorder_h)>>(
          'streamrecorder_unset_buffer_consume_completed_cb');
  late final _streamrecorder_unset_buffer_consume_completed_cb =
      _streamrecorder_unset_buffer_consume_completed_cbPtr
          .asFunction<int Function(streamrecorder_h)>();

  /// @brief Creates thumbnail info handle.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a thumb info using thumbnail_util_destroy().
  ///
  /// @param[in] thumb The handle to thumbnail info
  ///
  /// @return @c 0 on success, otherwise a negative error value
  ///
  /// @retval #THUMBNAIL_UTIL_ERROR_NONE Successful
  /// @retval #THUMBNAIL_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #THUMBNAIL_UTIL_ERROR_OUT_OF_MEMORY Not enough memory is available
  /// @retval #THUMBNAIL_UTIL_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see thumbnail_util_destroy()
  int thumbnail_util_create(
    ffi.Pointer<thumbnail_h> thumb,
  ) {
    return _thumbnail_util_create(
      thumb,
    );
  }

  late final _thumbnail_util_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<thumbnail_h>)>>(
          'thumbnail_util_create');
  late final _thumbnail_util_create = _thumbnail_util_createPtr
      .asFunction<int Function(ffi.Pointer<thumbnail_h>)>();

  /// @brief Extracts the thumbnail for the given media, asynchronously.
  /// @details This function extracts the thumbnail for given media item and calls registered
  /// callback function for completion of extracting the thumbnail.\n
  /// You can distinguish generated thumbnails by @a request_id. Therefore, the @a request_id must be maintained until the request is completed. \n
  /// And the @a request_id is also used to cancel the request.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @a request_id using free(). \n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage. \n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage. \n
  /// If you don't set the size, the thumbnail size will be set default size. Default size is 320x240. \n
  /// Color space of the generated thumbnail is BGRA. \n
  /// Since 3.0, http://tizen.org/privilege/content.write privilege is not required. \n
  ///
  /// @param[in] thumb     The thumbnail info handle
  /// @param[in] callback  The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  /// @param[out] request_id The request id for the thumbnail extraction request
  ///
  /// @return @c 0 on success, otherwise a negative error value
  ///
  /// @retval #THUMBNAIL_UTIL_ERROR_NONE              Successful
  /// @retval #THUMBNAIL_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #THUMBNAIL_UTIL_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Create a thumbnail info handle by calling thumbnail_util_create(). \n
  /// The content path that you want to generate thumbnail must be set by calling thumbnail_util_set_path().
  /// @post Thumbnail extraction result except canceled is provided by thumbnail_extracted_cb().
  /// @see thumbnail_util_create()
  /// @see thumbnail_util_set_path()
  /// @see thumbnail_util_set_size()
  /// @see thumbnail_extracted_cb()
  /// @see thumbnail_util_cancel()
  /// @see thumbnail_util_cancel_all()
  /// @see thumbnail_util_destroy()
  int thumbnail_util_extract(
    thumbnail_h thumb,
    thumbnail_extracted_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Pointer<ffi.Char>> request_id,
  ) {
    return _thumbnail_util_extract(
      thumb,
      callback,
      user_data,
      request_id,
    );
  }

  late final _thumbnail_util_extractPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              thumbnail_h,
              thumbnail_extracted_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('thumbnail_util_extract');
  late final _thumbnail_util_extract = _thumbnail_util_extractPtr.asFunction<
      int Function(thumbnail_h, thumbnail_extracted_cb, ffi.Pointer<ffi.Void>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the path of original media file.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] thumb     The thumbnail info handle
  /// @param[in] path        The path of the original media file
  ///
  /// @return @c 0 on success, otherwise a negative error value
  ///
  /// @retval #THUMBNAIL_UTIL_ERROR_NONE              Successful
  /// @retval #THUMBNAIL_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #THUMBNAIL_UTIL_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Create a thumbnail info handle by calling thumbnail_util_create().
  /// @see thumbnail_util_create()
  /// @see thumbnail_util_set_size()
  /// @see thumbnail_util_destroy()
  int thumbnail_util_set_path(
    thumbnail_h thumb,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _thumbnail_util_set_path(
      thumb,
      path,
    );
  }

  late final _thumbnail_util_set_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              thumbnail_h, ffi.Pointer<ffi.Char>)>>('thumbnail_util_set_path');
  late final _thumbnail_util_set_path = _thumbnail_util_set_pathPtr
      .asFunction<int Function(thumbnail_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the size of thumbnail to be extracted.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks If you don't set the size, the thumbnail size will be set default size. Default size is 320x240. \n
  /// If the set width is not a multiple of 8, it can be changed by inner process. the width will be a multiple of 8 greater than the set value.
  ///
  /// @param[in] thumb    The thumbnail info handle
  /// @param[in] width      The width of the thumbnail
  /// @param[in] height     The height of the thumbnail
  ///
  /// @return @c 0 on success, otherwise a negative error value
  ///
  /// @retval #THUMBNAIL_UTIL_ERROR_NONE              Successful
  /// @retval #THUMBNAIL_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #THUMBNAIL_UTIL_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Create a thumbnail info handle by calling thumbnail_util_create().
  /// @see thumbnail_util_create()
  /// @see thumbnail_util_set_path()
  /// @see thumbnail_util_destroy()
  int thumbnail_util_set_size(
    thumbnail_h thumb,
    int width,
    int height,
  ) {
    return _thumbnail_util_set_size(
      thumb,
      width,
      height,
    );
  }

  late final _thumbnail_util_set_sizePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(thumbnail_h, ffi.Int, ffi.Int)>>(
      'thumbnail_util_set_size');
  late final _thumbnail_util_set_size = _thumbnail_util_set_sizePtr
      .asFunction<int Function(thumbnail_h, int, int)>();

  /// @brief Cancels the thumbnail extraction request for the given media.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks If there is no item you want to cancel, this API return MEDIA_CONTENT_ERROR_INVALID_OPERATION
  ///
  /// @param[in] thumb         The media thumbnail info handle
  /// @param[in] request_id   The generated request id by thumbnail extraction request
  ///
  /// @return @c 0 on success, otherwise a negative error value
  ///
  /// @retval #THUMBNAIL_UTIL_ERROR_NONE              Successful
  /// @retval #THUMBNAIL_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #THUMBNAIL_UTIL_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre It is available before thumbnail_extracted_cb() is called.
  /// @see thumbnail_util_extract()
  int thumbnail_util_cancel(
    thumbnail_h thumb,
    ffi.Pointer<ffi.Char> request_id,
  ) {
    return _thumbnail_util_cancel(
      thumb,
      request_id,
    );
  }

  late final _thumbnail_util_cancelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              thumbnail_h, ffi.Pointer<ffi.Char>)>>('thumbnail_util_cancel');
  late final _thumbnail_util_cancel = _thumbnail_util_cancelPtr
      .asFunction<int Function(thumbnail_h, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. Use thumbnail_util_cancel() instead.
  /// @brief Cancels all thumbnail extraction requests associated with the given thumbnail info handle.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks If there is no item you want to cancel, this API return MEDIA_CONTENT_ERROR_INVALID_OPERATION
  ///
  /// @param[in] thumb The media thumbnail info handle
  ///
  /// @return @c 0 on success, otherwise a negative error value
  ///
  /// @retval #THUMBNAIL_UTIL_ERROR_NONE              Successful
  /// @retval #THUMBNAIL_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #THUMBNAIL_UTIL_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre It is available before thumbnail_extracted_cb() is called.
  /// @see thumbnail_util_extract()
  int thumbnail_util_cancel_all(
    thumbnail_h thumb,
  ) {
    return _thumbnail_util_cancel_all(
      thumb,
    );
  }

  late final _thumbnail_util_cancel_allPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(thumbnail_h)>>(
          'thumbnail_util_cancel_all');
  late final _thumbnail_util_cancel_all =
      _thumbnail_util_cancel_allPtr.asFunction<int Function(thumbnail_h)>();

  /// @brief Destroys thumbnail info handle.
  /// @details The function frees all resources related to the thumbnail info handle. This handle
  /// can no longer be used to perform any operation. New thumbnail info handle has to
  /// be created before the next usage.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in]  thumb  The thumbnail info handle
  ///
  /// @return @c 0 on success, otherwise a negative error value
  ///
  /// @retval #THUMBNAIL_UTIL_ERROR_NONE              Successful
  /// @retval #THUMBNAIL_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #THUMBNAIL_UTIL_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @pre Create a thumbnail info handle by calling thumbnail_util_create().
  /// @see thumbnail_util_create()
  int thumbnail_util_destroy(
    thumbnail_h thumb,
  ) {
    return _thumbnail_util_destroy(
      thumb,
    );
  }

  late final _thumbnail_util_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(thumbnail_h)>>(
          'thumbnail_util_destroy');
  late final _thumbnail_util_destroy =
      _thumbnail_util_destroyPtr.asFunction<int Function(thumbnail_h)>();

  /// @deprecated Deprecated since 3.0. Use tone_player_start_new() instead.
  /// @brief Plays a tone.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Sound can be mixed with other sounds if you don't control the sound session in sound-manager module since 3.0.\n
  /// You can refer to @ref CAPI_MEDIA_SOUND_MANAGER_MODULE.
  ///
  /// @param[in] tone	The tone type to play
  /// @param[in] type	The sound type
  /// @param[in] duration_ms	The tone duration in milliseconds \n
  /// @c -1 indicates an infinite duration.
  /// @param[out] id	The tone player ID ( can be set to @c NULL )
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TONE_PLAYER_ERROR_NONE Successful
  /// @retval #TONE_PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TONE_PLAYER_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see tone_player_stop()
  int tone_player_start(
    int tone,
    int type,
    int duration_ms,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _tone_player_start(
      tone,
      type,
      duration_ms,
      id,
    );
  }

  late final _tone_player_startPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Int32, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('tone_player_start');
  late final _tone_player_start = _tone_player_startPtr
      .asFunction<int Function(int, int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Plays a tone with stream information of sound-manager.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks Voice Recognition stream type is not supported in this API.
  ///
  /// @param[in] tone	The tone type to play
  /// @param[in] stream_info	The sound stream information handle
  /// @param[in] duration_ms	The tone duration in milliseconds \n
  /// @c -1 indicates an infinite duration.
  /// @param[out] id	The tone player ID ( can be set to @c NULL )
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TONE_PLAYER_ERROR_NONE Successful
  /// @retval #TONE_PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TONE_PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #TONE_PLAYER_ERROR_NOT_SUPPORTED_TYPE Not supported stream type
  ///
  /// @see tone_player_stop()
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  int tone_player_start_new(
    int tone,
    sound_stream_info_h stream_info,
    int duration_ms,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _tone_player_start_new(
      tone,
      stream_info,
      duration_ms,
      id,
    );
  }

  late final _tone_player_start_newPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, sound_stream_info_h, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('tone_player_start_new');
  late final _tone_player_start_new = _tone_player_start_newPtr.asFunction<
      int Function(int, sound_stream_info_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Stops playing the tone.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] id	The tone player ID to stop
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #TONE_PLAYER_ERROR_NONE Successful
  /// @retval #TONE_PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TONE_PLAYER_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see tone_player_start()
  int tone_player_stop(
    int id,
  ) {
    return _tone_player_stop(
      id,
    );
  }

  late final _tone_player_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'tone_player_stop');
  late final _tone_player_stop =
      _tone_player_stopPtr.asFunction<int Function(int)>();

  /// @brief Creates a handle to video util.
  /// @since_tizen 2.3
  ///
  /// @details This function creates a handle to video util.
  ///
  /// @remarks You must release the @a video util handle using video_util_destroy().\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param[out] handle A handle to video util
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see video_util_destroy()
  int video_util_create(
    ffi.Pointer<video_util_h> handle,
  ) {
    return _video_util_create(
      handle,
    );
  }

  late final _video_util_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<video_util_h>)>>(
          'video_util_create');
  late final _video_util_create = _video_util_createPtr
      .asFunction<int Function(ffi.Pointer<video_util_h>)>();

  /// @brief Destroys a handle to video util.
  /// @since_tizen 2.3
  ///
  /// @details The function frees all resources related to the video util handle. The video util
  /// handle no longer can be used to perform any operation. A new video util handle
  /// has to be created before the next usage.
  ///
  /// @remarks http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.\n
  ///
  /// @param[in] handle The handle to video util
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see video_util_create()
  int video_util_destroy(
    video_util_h handle,
  ) {
    return _video_util_destroy(
      handle,
    );
  }

  late final _video_util_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_util_h)>>(
          'video_util_destroy');
  late final _video_util_destroy =
      _video_util_destroyPtr.asFunction<int Function(video_util_h)>();

  /// @brief Sets the video util's file path.
  /// @since_tizen 2.3
  ///
  /// @details This function sets the source @a path to transcode.
  ///
  /// @remarks http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param[in] handle The handle to video util
  /// @param[in] path The source file path
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see video_util_create()
  /// @see video_util_destroy()
  int video_util_set_file_path(
    video_util_h handle,
    ffi.Pointer<ffi.Char> path,
  ) {
    return _video_util_set_file_path(
      handle,
      path,
    );
  }

  late final _video_util_set_file_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(video_util_h,
              ffi.Pointer<ffi.Char>)>>('video_util_set_file_path');
  late final _video_util_set_file_path = _video_util_set_file_pathPtr
      .asFunction<int Function(video_util_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the video util's accurate mode.
  /// @since_tizen 2.3
  ///
  /// @remarks If you do not set this, the default value is @c false.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param[in] handle The handle to video util
  /// @param[in] mode Set @c true if the user can get an accurated frame for given the duration in video_util_start_transcoding(),
  /// otherwise set @c false if user can only get the nearest i-frame
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see video_util_create()
  /// @see video_util_destroy()
  int video_util_set_accurate_mode(
    video_util_h handle,
    bool mode,
  ) {
    return _video_util_set_accurate_mode(
      handle,
      mode,
    );
  }

  late final _video_util_set_accurate_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_util_h, ffi.Bool)>>(
          'video_util_set_accurate_mode');
  late final _video_util_set_accurate_mode = _video_util_set_accurate_modePtr
      .asFunction<int Function(video_util_h, bool)>();

  /// @brief Sets the video codec for encoding video stream.
  /// @since_tizen 2.3
  ///
  /// @remarks You can get available list of video codec by using video_util_foreach_supported_video_codec().\n
  /// If you do not set this, the default codec is #VIDEO_UTIL_VIDEO_CODEC_MPEG4.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param[in] handle The handle to video util
  /// @param[in] codec The video codec
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED_FORMAT Not supported format
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see video_util_create()
  /// @see video_util_destroy()
  /// @see video_util_foreach_supported_video_codec()
  int video_util_set_video_codec(
    video_util_h handle,
    int codec,
  ) {
    return _video_util_set_video_codec(
      handle,
      codec,
    );
  }

  late final _video_util_set_video_codecPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_util_h, ffi.Int32)>>(
          'video_util_set_video_codec');
  late final _video_util_set_video_codec = _video_util_set_video_codecPtr
      .asFunction<int Function(video_util_h, int)>();

  /// @brief Sets the audio codec for encoding audio stream.
  /// @since_tizen 2.3
  ///
  /// @remarks You can get available list of audio codec by using video_util_foreach_supported_audio_codec().\n
  /// If you do not set this, the default codec is #VIDEO_UTIL_AUDIO_CODEC_AAC.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param[in] handle The handle to video util
  /// @param[in] codec The audio codec
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED_FORMAT Not supported format
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see video_util_create()
  /// @see video_util_destroy()
  /// @see video_util_foreach_supported_audio_codec()
  int video_util_set_audio_codec(
    video_util_h handle,
    int codec,
  ) {
    return _video_util_set_audio_codec(
      handle,
      codec,
    );
  }

  late final _video_util_set_audio_codecPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_util_h, ffi.Int32)>>(
          'video_util_set_audio_codec');
  late final _video_util_set_audio_codec = _video_util_set_audio_codecPtr
      .asFunction<int Function(video_util_h, int)>();

  /// @brief Sets the file format for transcoding media stream.
  /// @since_tizen 2.3
  ///
  /// @remarks You can get available list of media formats by using video_util_foreach_supported_file_format().\n
  /// If you do not set this, the default file format is #VIDEO_UTIL_FILE_FORMAT_3GP.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param[in] handle The handle to video util
  /// @param[in] format The media file format
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see video_util_create()
  /// @see video_util_destroy()
  /// @see video_util_foreach_supported_file_format()
  int video_util_set_file_format(
    video_util_h handle,
    int format,
  ) {
    return _video_util_set_file_format(
      handle,
      format,
    );
  }

  late final _video_util_set_file_formatPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_util_h, ffi.Int32)>>(
          'video_util_set_file_format');
  late final _video_util_set_file_format = _video_util_set_file_formatPtr
      .asFunction<int Function(video_util_h, int)>();

  /// @brief Sets the resolution(width and height).
  /// @since_tizen 2.3
  ///
  /// @remarks If you do not set, the default resolution is original size.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param[in] handle The handle to video util
  /// @param[in] width The media's width \n
  /// If the width is 0, it set original size.(minimum value is 128)
  /// @param[in] height The media's height \n
  /// If the height is 0, it set original size.(minimum value is 96)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see video_util_create()
  /// @see video_util_destroy()
  int video_util_set_resolution(
    video_util_h handle,
    int width,
    int height,
  ) {
    return _video_util_set_resolution(
      handle,
      width,
      height,
    );
  }

  late final _video_util_set_resolutionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(video_util_h, ffi.Int, ffi.Int)>>(
      'video_util_set_resolution');
  late final _video_util_set_resolution = _video_util_set_resolutionPtr
      .asFunction<int Function(video_util_h, int, int)>();

  /// @brief Sets the frame rate.
  /// @since_tizen 2.3
  ///
  /// @remarks If fps is set @c 0, the default is original fps from source.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param[in] handle The handle to video util
  ///
  /// @param[in] fps The frame rate(minimum value is 5, maximum value is 30)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see video_util_create()
  /// @see video_util_destroy()
  int video_util_set_fps(
    video_util_h handle,
    int fps,
  ) {
    return _video_util_set_fps(
      handle,
      fps,
    );
  }

  late final _video_util_set_fpsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_util_h, ffi.Int)>>(
          'video_util_set_fps');
  late final _video_util_set_fps =
      _video_util_set_fpsPtr.asFunction<int Function(video_util_h, int)>();

  /// @brief Transcodes the video for given video util handle.
  /// @since_tizen 2.3
  ///
  /// @details This function starts the transcoding from start time and for given duration.\n
  /// #video_util_transcoding_progress_cb() function is called during the video transcoding regularly after some interval.\n
  /// #video_util_transcoding_completed_cb() function is called and the transcoded video will be saved at the given output path when transcoding is finished.
  ///
  /// @remarks If there already exists same file in file system, then old file will be overwritten.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param[in] handle The handle to video util
  /// @param[in] start The start position to transcode
  /// @param[in] duration The duration in seconds \n
  /// if duration is @c 0, transcoding happens until end of the video.
  /// @param[out] out_path The file path to save
  /// @param[in] progress_cb The callback function to be invoked
  /// @param[in] completed_cb The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see video_util_create()
  /// @see video_util_destroy()
  /// @see video_util_transcoding_progress_cb()
  /// @see video_util_transcoding_completed_cb()
  /// @see video_util_get_progress_transcoding()
  /// @see video_util_cancel_transcoding()
  int video_util_start_transcoding(
    video_util_h handle,
    int start,
    int duration,
    ffi.Pointer<ffi.Char> out_path,
    video_util_transcoding_progress_cb progress_cb,
    video_util_transcoding_completed_cb completed_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _video_util_start_transcoding(
      handle,
      start,
      duration,
      out_path,
      progress_cb,
      completed_cb,
      user_data,
    );
  }

  late final _video_util_start_transcodingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              video_util_h,
              ffi.UnsignedLong,
              ffi.UnsignedLong,
              ffi.Pointer<ffi.Char>,
              video_util_transcoding_progress_cb,
              video_util_transcoding_completed_cb,
              ffi.Pointer<ffi.Void>)>>('video_util_start_transcoding');
  late final _video_util_start_transcoding =
      _video_util_start_transcodingPtr.asFunction<
          int Function(
              video_util_h,
              int,
              int,
              ffi.Pointer<ffi.Char>,
              video_util_transcoding_progress_cb,
              video_util_transcoding_completed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Cancels transcoding the video for given video util handle.
  /// @since_tizen 2.3
  ///
  ///
  /// @details This function cancels the transcoding for given video util handle.\n.
  ///
  /// @remarks If this function is invoked during transcoding, the data transcoded is discard.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param[in] handle The handle to video util
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see video_util_create()
  /// @see video_util_destroy()
  /// @see video_util_start_transcoding()
  int video_util_cancel_transcoding(
    video_util_h handle,
  ) {
    return _video_util_cancel_transcoding(
      handle,
    );
  }

  late final _video_util_cancel_transcodingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(video_util_h)>>(
          'video_util_cancel_transcoding');
  late final _video_util_cancel_transcoding = _video_util_cancel_transcodingPtr
      .asFunction<int Function(video_util_h)>();

  /// @brief Retreives the current position and duration of the video transcoding.
  /// @since_tizen 2.3
  ///
  ///
  /// @remarks http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.\n
  ///
  /// @param[in] handle The handle to video util
  /// @param[out] current_position Current position of transcoding
  /// @param[out] duration The duration is in seconds.\n
  /// If duration is 0, transcoding happens until end of the video
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre video_util_start_transcoding().
  ///
  /// @see video_util_create()
  /// @see video_util_destroy()
  int video_util_get_progress_transcoding(
    video_util_h handle,
    ffi.Pointer<ffi.UnsignedLong> current_position,
    ffi.Pointer<ffi.UnsignedLong> duration,
  ) {
    return _video_util_get_progress_transcoding(
      handle,
      current_position,
      duration,
    );
  }

  late final _video_util_get_progress_transcodingPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(video_util_h, ffi.Pointer<ffi.UnsignedLong>,
                  ffi.Pointer<ffi.UnsignedLong>)>>(
      'video_util_get_progress_transcoding');
  late final _video_util_get_progress_transcoding =
      _video_util_get_progress_transcodingPtr.asFunction<
          int Function(video_util_h, ffi.Pointer<ffi.UnsignedLong>,
              ffi.Pointer<ffi.UnsignedLong>)>();

  /// @brief Retrieves all supported media formats by invoking a specific callback for each supported media format.
  /// @since_tizen 2.3
  ///
  /// @remarks The callback invocation depends on the codec.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.\n
  ///
  /// @param[in] handle The handle to video util
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED_FORMAT Not supported format
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  /// @post  video_util_supported_file_format_cb() will be invoked.
  ///
  /// @see video_util_set_file_format()
  /// @see video_util_supported_file_format_cb()
  int video_util_foreach_supported_file_format(
    video_util_h handle,
    video_util_supported_file_format_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _video_util_foreach_supported_file_format(
      handle,
      callback,
      user_data,
    );
  }

  late final _video_util_foreach_supported_file_formatPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(video_util_h,
                  video_util_supported_file_format_cb, ffi.Pointer<ffi.Void>)>>(
      'video_util_foreach_supported_file_format');
  late final _video_util_foreach_supported_file_format =
      _video_util_foreach_supported_file_formatPtr.asFunction<
          int Function(video_util_h, video_util_supported_file_format_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves all supported video encoders by invoking a specific callback for each supported video encoder.
  /// @since_tizen 2.3
  ///
  /// @remarks The callback invocation depends on the file format.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.\n
  ///
  /// @param[in] handle The handle to video util
  /// @param[in] callback The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED_FORMAT Not supported format
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  /// @post  video_util_supported_video_encoder_cb() will be invoked.
  /// @see video_util_set_video_codec()
  /// @see video_util_supported_video_encoder_cb()
  int video_util_foreach_supported_video_codec(
    video_util_h handle,
    video_util_supported_video_encoder_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _video_util_foreach_supported_video_codec(
      handle,
      callback,
      user_data,
    );
  }

  late final _video_util_foreach_supported_video_codecPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  video_util_h,
                  video_util_supported_video_encoder_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'video_util_foreach_supported_video_codec');
  late final _video_util_foreach_supported_video_codec =
      _video_util_foreach_supported_video_codecPtr.asFunction<
          int Function(video_util_h, video_util_supported_video_encoder_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves all supported audio encoders by invoking a specific callback for each supported audio encoder.
  /// @since_tizen 2.3
  ///
  /// @remarks The callback invocation depends on the file format.\n
  /// http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.\n
  ///
  /// @param[in] handle The handle to video util
  /// @param[in] callback The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #VIDEO_UTIL_ERROR_NONE Successful
  /// @retval #VIDEO_UTIL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VIDEO_UTIL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED_FORMAT Not supported format
  /// @retval #VIDEO_UTIL_ERROR_NOT_SUPPORTED Not supported
  /// @post  video_util_supported_audio_encoder_cb() will be invoked.
  /// @see video_util_supported_audio_encoder_cb()
  int video_util_foreach_supported_audio_codec(
    video_util_h handle,
    video_util_supported_audio_encoder_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _video_util_foreach_supported_audio_codec(
      handle,
      callback,
      user_data,
    );
  }

  late final _video_util_foreach_supported_audio_codecPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  video_util_h,
                  video_util_supported_audio_encoder_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'video_util_foreach_supported_audio_codec');
  late final _video_util_foreach_supported_audio_codec =
      _video_util_foreach_supported_audio_codecPtr.asFunction<
          int Function(video_util_h, video_util_supported_audio_encoder_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 3.0. Use wav_player_start_with_stream_info() instead.
  /// @brief Plays a WAV file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Sound can be mixed with other sounds if you don't control the sound session in sound-manager module since 3.0.\n
  /// You can refer to @ref CAPI_MEDIA_SOUND_MANAGER_MODULE.
  ///
  /// @param[in] path	The file path to play
  /// @param[in] type	The sound type
  /// @param[in] callback	The callback function to invoke when a WAV file is finished playing
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @param[out] id	The WAV player ID ( can be set to NULL )
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #WAV_PLAYER_ERROR_NONE Successful
  /// @retval #WAV_PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #WAV_PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #WAV_PLAYER_ERROR_FORMAT_NOT_SUPPORTED Not supported format
  ///
  /// @post	It invokes wav_player_playback_completed_cb() when a WAV file has finished playing.
  /// @see wav_player_stop()
  /// @see wav_player_playback_completed_cb()
  int wav_player_start(
    ffi.Pointer<ffi.Char> path,
    int type,
    wav_player_playback_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _wav_player_start(
      path,
      type,
      callback,
      user_data,
      id,
    );
  }

  late final _wav_player_startPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              wav_player_playback_completed_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('wav_player_start');
  late final _wav_player_start = _wav_player_startPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, int, wav_player_playback_completed_cb,
          ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Int>)>();

  /// @brief Plays a WAV file with stream information of sound-manager.
  /// @since_tizen 3.0
  ///
  /// @remarks Voice Recognition and VOIP stream types are not supported in this API.
  ///
  /// @param[in] path	The file path to play
  /// @param[in] stream_info	The sound stream information handle
  /// @param[in] callback	The callback function to be invoked when a WAV file is no longer being played
  /// @param[in] user_data	The user data to be passed to the callback function
  /// @param[out] id	The WAV player ID (can be set to @c NULL)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #WAV_PLAYER_ERROR_NONE Successful
  /// @retval #WAV_PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #WAV_PLAYER_ERROR_INVALID_OPERATION Invalid operation
  /// @retval #WAV_PLAYER_ERROR_FORMAT_NOT_SUPPORTED Not supported format
  /// @retval #WAV_PLAYER_ERROR_NOT_SUPPORTED_TYPE Not supported stream type
  ///
  /// @post	It invokes wav_player_playback_completed_cb() when a WAV file is no longer being played.
  /// @see wav_player_stop()
  /// @see wav_player_playback_completed_cb()
  /// @see sound_manager_create_stream_information()
  /// @see sound_manager_destroy_stream_information()
  int wav_player_start_new(
    ffi.Pointer<ffi.Char> path,
    sound_stream_info_h stream_info,
    wav_player_playback_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _wav_player_start_new(
      path,
      stream_info,
      callback,
      user_data,
      id,
    );
  }

  late final _wav_player_start_newPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              sound_stream_info_h,
              wav_player_playback_completed_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('wav_player_start_new');
  late final _wav_player_start_new = _wav_player_start_newPtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>,
          sound_stream_info_h,
          wav_player_playback_completed_cb,
          ffi.Pointer<ffi.Void>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Stops playing the WAV file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] id	The WAV player ID to stop
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #WAV_PLAYER_ERROR_NONE Successful
  /// @retval #WAV_PLAYER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #WAV_PLAYER_ERROR_INVALID_OPERATION Invalid operation
  ///
  /// @see	wav_player_start()
  int wav_player_stop(
    int id,
  ) {
    return _wav_player_stop(
      id,
    );
  }

  late final _wav_player_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>('wav_player_stop');
  late final _wav_player_stop =
      _wav_player_stopPtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_MODULE
  /// @brief Initializes the Bluetooth API.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @remarks This function must be called before Bluetooth API starts. \n
  /// You must free all resources of the Bluetooth service by calling bt_deinitialize() if Bluetooth service is no longer needed.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see  bt_deinitialize()
  int bt_initialize() {
    return _bt_initialize();
  }

  late final _bt_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('bt_initialize');
  late final _bt_initialize = _bt_initializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_MODULE
  /// @brief Releases all resources of the Bluetooth API.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @remarks This function must be called if Bluetooth API is no longer needed.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre Bluetooth API must be initialized with bt_initialize().
  ///
  /// @see bt_initialize()
  int bt_deinitialize() {
    return _bt_deinitialize();
  }

  late final _bt_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('bt_deinitialize');
  late final _bt_deinitialize =
      _bt_deinitializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_MODULE
  /// @brief Gets the specification name for the given UUID.
  /// @since_tizen 3.0
  ///
  /// @remarks The @a name must be released using free().
  ///
  /// @param[in] uuid The UUID
  /// @param[out] name The specification name defined at www.bluetooth.com
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_get_uuid()
  int bt_get_uuid_name(
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _bt_get_uuid_name(
      uuid,
      name,
    );
  }

  late final _bt_get_uuid_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('bt_get_uuid_name');
  late final _bt_get_uuid_name = _bt_get_uuid_namePtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Gets the current state of local Bluetooth adapter.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[out] adapter_state The current adapter state
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_initialize()
  int bt_adapter_get_state(
    ffi.Pointer<ffi.Int32> adapter_state,
  ) {
    return _bt_adapter_get_state(
      adapter_state,
    );
  }

  late final _bt_adapter_get_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'bt_adapter_get_state');
  late final _bt_adapter_get_state = _bt_adapter_get_statePtr
      .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Gets the address of local Bluetooth adapter.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @remarks The @a local_address must be released with free() by you.
  ///
  /// @param[out] local_address The device address of local Bluetooth adapter
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_OPERATION_FAILED Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @see bt_adapter_get_name()
  int bt_adapter_get_address(
    ffi.Pointer<ffi.Pointer<ffi.Char>> local_address,
  ) {
    return _bt_adapter_get_address(
      local_address,
    );
  }

  late final _bt_adapter_get_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('bt_adapter_get_address');
  late final _bt_adapter_get_address = _bt_adapter_get_addressPtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Gets the name of local Bluetooth adapter.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @details Use this function to get the friendly name associated with Bluetooth
  /// device, retrieved by the remote Bluetooth devices.
  ///
  /// @remarks The @a local_name must be released with free() by you.
  ///
  /// @param[out] local_name  The local device name
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  ///
  /// @see bt_adapter_set_name()
  int bt_adapter_get_name(
    ffi.Pointer<ffi.Pointer<ffi.Char>> local_name,
  ) {
    return _bt_adapter_get_name(
      local_name,
    );
  }

  late final _bt_adapter_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('bt_adapter_get_name');
  late final _bt_adapter_get_name = _bt_adapter_get_namePtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Sets the name of local Bluetooth adapter.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] local_name The name of the Bluetooth device. \n
  /// The maximum length is 248 characters.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post bt_adapter_name_changed_cb() will be invoked if this function returns #BT_ERROR_NONE.
  ///
  /// @see bt_adapter_get_name()
  /// @see bt_adapter_name_changed_cb()
  /// @see bt_adapter_set_name_changed_cb()
  /// @see bt_adapter_unset_name_changed_cb()
  int bt_adapter_set_name(
    ffi.Pointer<ffi.Char> local_name,
  ) {
    return _bt_adapter_set_name(
      local_name,
    );
  }

  late final _bt_adapter_set_namePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_adapter_set_name');
  late final _bt_adapter_set_name =
      _bt_adapter_set_namePtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup  CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief  Gets the visibility mode of local Bluetooth adapter.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[out] mode  The visibility mode of the Bluetooth device
  /// @param[out] duration  The duration until the visibility mode is changed to #BT_ADAPTER_VISIBILITY_MODE_NON_DISCOVERABLE (in seconds).
  /// @a duration is valid only if @a mode is #BT_ADAPTER_VISIBILITY_MODE_LIMITED_DISCOVERABLE. This value can be NULL.
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  int bt_adapter_get_visibility(
    ffi.Pointer<ffi.Int32> mode,
    ffi.Pointer<ffi.Int> duration,
  ) {
    return _bt_adapter_get_visibility(
      mode,
      duration,
    );
  }

  late final _bt_adapter_get_visibilityPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Int>)>>('bt_adapter_get_visibility');
  late final _bt_adapter_get_visibility = _bt_adapter_get_visibilityPtr
      .asFunction<int Function(ffi.Pointer<ffi.Int32>, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Starts the device discovery, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @details If a device is discovered, bt_adapter_device_discovery_state_changed_cb() will be invoked
  /// with #BT_ADAPTER_DEVICE_DISCOVERY_FOUND, and then bt_adapter_device_discovery_state_changed_cb()
  /// will be called with #BT_ADAPTER_DEVICE_DISCOVERY_FINISHED in case of the completion or cancellation of the discovery.
  ///
  /// @remarks To connect to peer Bluetooth device, you need to know its Bluetooth address. \n
  /// The device discovery can be stopped by bt_adapter_stop_device_discovery().
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation is now in progress
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post This function invokes bt_adapter_device_discovery_state_changed_cb().
  ///
  /// @see bt_adapter_is_discovering()
  /// @see bt_adapter_stop_device_discovery()
  /// @see bt_adapter_device_discovery_state_changed_cb()
  /// @see bt_adapter_set_device_discovery_state_changed_cb()
  /// @see bt_adapter_unset_device_discovery_state_changed_cb()
  int bt_adapter_start_device_discovery() {
    return _bt_adapter_start_device_discovery();
  }

  late final _bt_adapter_start_device_discoveryPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_start_device_discovery');
  late final _bt_adapter_start_device_discovery =
      _bt_adapter_start_device_discoveryPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Stops the device discovery, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @remarks The device discovery process will take 10 ~ 20 seconds to get all the devices in vicinity.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOT_IN_PROGRESS  Operation is not in progress
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The device discovery must be in progress with bt_adapter_start_device_discovery().
  /// @post This function invokes bt_adapter_device_discovery_state_changed_cb().
  ///
  /// @see bt_adapter_is_discovering()
  /// @see bt_adapter_start_device_discovery()
  /// @see bt_adapter_set_device_discovery_state_changed_cb()
  /// @see bt_adapter_unset_device_discovery_state_changed_cb()
  /// @see bt_adapter_device_discovery_state_changed_cb()
  int bt_adapter_stop_device_discovery() {
    return _bt_adapter_stop_device_discovery();
  }

  late final _bt_adapter_stop_device_discoveryPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_stop_device_discovery');
  late final _bt_adapter_stop_device_discovery =
      _bt_adapter_stop_device_discoveryPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Checks for the device discovery is in progress or not.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @remarks If Bluetooth discovery is in progress, other operations are not allowed and
  /// you have to either stop the discovery operation, or wait for it to be finished,
  /// before performing other operations.
  ///
  /// @param[out] is_discovering The discovering status: (@c true = in progress , @c  false = not in progress )
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  ///
  /// @see bt_adapter_start_device_discovery()
  /// @see bt_adapter_stop_device_discovery()
  int bt_adapter_is_discovering(
    ffi.Pointer<ffi.Bool> is_discovering,
  ) {
    return _bt_adapter_is_discovering(
      is_discovering,
    );
  }

  late final _bt_adapter_is_discoveringPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Bool>)>>(
          'bt_adapter_is_discovering');
  late final _bt_adapter_is_discovering = _bt_adapter_is_discoveringPtr
      .asFunction<int Function(ffi.Pointer<ffi.Bool>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief Get the service mask from the uuid list.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in] uuids The UUID list of the device.
  /// @param[in] no_of_service The number of the UUID list count.
  /// @param[out] service_mask_list Service mask list converted from the given UUID list.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_service_class_t
  int bt_device_get_service_mask_from_uuid_list(
    ffi.Pointer<ffi.Pointer<ffi.Char>> uuids,
    int no_of_service,
    ffi.Pointer<ffi.Int32> service_mask_list,
  ) {
    return _bt_device_get_service_mask_from_uuid_list(
      uuids,
      no_of_service,
      service_mask_list,
    );
  }

  late final _bt_device_get_service_mask_from_uuid_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Int,
                  ffi.Pointer<ffi.Int32>)>>(
      'bt_device_get_service_mask_from_uuid_list');
  late final _bt_device_get_service_mask_from_uuid_list =
      _bt_device_get_service_mask_from_uuid_listPtr.asFunction<
          int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>, int,
              ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Retrieves the device information of all bonded devices.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param [in] callback The callback function to invoke
  /// @param [in] user_data The user data passed from the foreach function
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post This function invokes bt_adapter_bonded_device_cb().
  ///
  /// @see bt_adapter_bonded_device_cb()
  int bt_adapter_foreach_bonded_device(
    bt_adapter_bonded_device_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_adapter_foreach_bonded_device(
      callback,
      user_data,
    );
  }

  late final _bt_adapter_foreach_bonded_devicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_adapter_bonded_device_cb,
              ffi.Pointer<ffi.Void>)>>('bt_adapter_foreach_bonded_device');
  late final _bt_adapter_foreach_bonded_device =
      _bt_adapter_foreach_bonded_devicePtr.asFunction<
          int Function(bt_adapter_bonded_device_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Gets the device information of a bonded device.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks The @a device_info must be released with bt_adapter_free_device_info() by you .
  ///
  /// @param [in] remote_address The address of remote device
  /// @param [out] device_info The bonded device information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_BONDED  Remote device not bonded
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post This function invokes bt_adapter_bonded_device_cb().
  ///
  /// @see bt_adapter_bonded_device_cb()
  int bt_adapter_get_bonded_device_info(
    ffi.Pointer<ffi.Char> remote_address,
    ffi.Pointer<ffi.Pointer<bt_device_info_s>> device_info,
  ) {
    return _bt_adapter_get_bonded_device_info(
      remote_address,
      device_info,
    );
  }

  late final _bt_adapter_get_bonded_device_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<bt_device_info_s>>)>>(
      'bt_adapter_get_bonded_device_info');
  late final _bt_adapter_get_bonded_device_info =
      _bt_adapter_get_bonded_device_infoPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<bt_device_info_s>>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Frees device info.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param [in] device_info The bonded device information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_adapter_get_bonded_device_info()
  int bt_adapter_free_device_info(
    ffi.Pointer<bt_device_info_s> device_info,
  ) {
    return _bt_adapter_free_device_info(
      device_info,
    );
  }

  late final _bt_adapter_free_device_infoPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<bt_device_info_s>)>>(
      'bt_adapter_free_device_info');
  late final _bt_adapter_free_device_info = _bt_adapter_free_device_infoPtr
      .asFunction<int Function(ffi.Pointer<bt_device_info_s>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief Checks whether the UUID of service is used or not
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] service_uuid The UUID of service
  /// @param[out] used Indicates whether the service is used or not
  /// @return true on success, otherwise false.
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_adapter_is_service_used(
    ffi.Pointer<ffi.Char> service_uuid,
    ffi.Pointer<ffi.Bool> used,
  ) {
    return _bt_adapter_is_service_used(
      service_uuid,
      used,
    );
  }

  late final _bt_adapter_is_service_usedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('bt_adapter_is_service_used');
  late final _bt_adapter_is_service_used = _bt_adapter_is_service_usedPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief  Registers a callback function to be invoked when the Bluetooth adapter state changes.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in] callback	The callback function to invoke
  /// @param[in] user_data	The user data to be passed to the callback function
  ///
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post bt_adapter_state_changed_cb() will be invoked.
  ///
  /// @see bt_initialize()
  /// @see bt_adapter_state_changed_cb()
  /// @see bt_adapter_set_state_changed_cb()
  /// @see bt_adapter_unset_state_changed_cb()
  int bt_adapter_set_state_changed_cb(
    bt_adapter_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_adapter_set_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_adapter_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_adapter_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_adapter_set_state_changed_cb');
  late final _bt_adapter_set_state_changed_cb =
      _bt_adapter_set_state_changed_cbPtr.asFunction<
          int Function(bt_adapter_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief	Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_initialize()
  /// @see bt_adapter_set_state_changed_cb()
  int bt_adapter_unset_state_changed_cb() {
    return _bt_adapter_unset_state_changed_cb();
  }

  late final _bt_adapter_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_unset_state_changed_cb');
  late final _bt_adapter_unset_state_changed_cb =
      _bt_adapter_unset_state_changed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief  Registers a callback function to be invoked when the name of Bluetooth adapter changes.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post  bt_adapter_name_changed_cb() will be invoked.
  ///
  /// @see bt_initialize()
  /// @see bt_adapter_name_changed_cb()
  /// @see bt_adapter_unset_name_changed_cb()
  int bt_adapter_set_name_changed_cb(
    bt_adapter_name_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_adapter_set_name_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_adapter_set_name_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_adapter_name_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_adapter_set_name_changed_cb');
  late final _bt_adapter_set_name_changed_cb =
      _bt_adapter_set_name_changed_cbPtr.asFunction<
          int Function(bt_adapter_name_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief	Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_initialize()
  /// @see bt_adapter_set_name_changed_cb()
  int bt_adapter_unset_name_changed_cb() {
    return _bt_adapter_unset_name_changed_cb();
  }

  late final _bt_adapter_unset_name_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_unset_name_changed_cb');
  late final _bt_adapter_unset_name_changed_cb =
      _bt_adapter_unset_name_changed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief  Registers a callback function to be invoked when the visibility mode changes.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post bt_adapter_visibility_mode_changed_cb() will be invoked.
  ///
  /// @see bt_initialize()
  /// @see bt_adapter_visibility_mode_changed_cb()
  /// @see bt_adapter_unset_visibility_mode_changed_cb()
  int bt_adapter_set_visibility_mode_changed_cb(
    bt_adapter_visibility_mode_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_adapter_set_visibility_mode_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_adapter_set_visibility_mode_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_adapter_visibility_mode_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_adapter_set_visibility_mode_changed_cb');
  late final _bt_adapter_set_visibility_mode_changed_cb =
      _bt_adapter_set_visibility_mode_changed_cbPtr.asFunction<
          int Function(
              bt_adapter_visibility_mode_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup  CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief  Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see  bt_initialize()
  /// @see  bt_adapter_set_visibility_mode_changed_cb()
  int bt_adapter_unset_visibility_mode_changed_cb() {
    return _bt_adapter_unset_visibility_mode_changed_cb();
  }

  late final _bt_adapter_unset_visibility_mode_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_unset_visibility_mode_changed_cb');
  late final _bt_adapter_unset_visibility_mode_changed_cb =
      _bt_adapter_unset_visibility_mode_changed_cbPtr
          .asFunction<int Function()>();

  /// @ingroup  CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief  Registers a callback function to be invoked every second
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// until the visibility mode is changed from #BT_ADAPTER_VISIBILITY_MODE_LIMITED_DISCOVERABLE
  /// to #BT_ADAPTER_VISIBILITY_MODE_NON_DISCOVERABLE.
  /// @details  When you set visibility mode as #BT_ADAPTER_VISIBILITY_MODE_LIMITED_DISCOVERABLE,
  /// @a callback will be called every second until visibility mode is changed to #BT_ADAPTER_VISIBILITY_MODE_NON_DISCOVERABLE.
  /// @param[in]  callback  The callback function to register
  /// @param[in]  user_data  The user data to be passed to the callback function
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The Bluetooth service must be initialized by bt_initialize().
  /// @post  bt_adapter_visibility_duration_changed_cb() will be invoked.
  /// @see  bt_initialize()
  /// @see  bt_adapter_visibility_duration_changed_cb()
  /// @see  bt_adapter_unset_visibility_duration_changed_cb()
  int bt_adapter_set_visibility_duration_changed_cb(
    bt_adapter_visibility_duration_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_adapter_set_visibility_duration_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_adapter_set_visibility_duration_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_adapter_visibility_duration_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_adapter_set_visibility_duration_changed_cb');
  late final _bt_adapter_set_visibility_duration_changed_cb =
      _bt_adapter_set_visibility_duration_changed_cbPtr.asFunction<
          int Function(bt_adapter_visibility_duration_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup  CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief	 Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The Bluetooth service must be initialized with bt_initialize().
  /// @see  bt_initialize()
  /// @see  bt_adapter_set_visibility_duration_changed_cb()
  int bt_adapter_unset_visibility_duration_changed_cb() {
    return _bt_adapter_unset_visibility_duration_changed_cb();
  }

  late final _bt_adapter_unset_visibility_duration_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_unset_visibility_duration_changed_cb');
  late final _bt_adapter_unset_visibility_duration_changed_cb =
      _bt_adapter_unset_visibility_duration_changed_cbPtr
          .asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief  Registers a callback function to be invoked when the device discovery state changes.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post bt_adapter_device_discovery_state_changed_cb() will be invoked.
  ///
  /// @see bt_initialize()
  /// @see bt_adapter_device_discovery_state_changed_cb()
  /// @see bt_adapter_set_device_discovery_state_changed_cb()
  /// @see bt_adapter_unset_device_discovery_state_changed_cb()
  int bt_adapter_set_device_discovery_state_changed_cb(
    bt_adapter_device_discovery_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_adapter_set_device_discovery_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_adapter_set_device_discovery_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_adapter_device_discovery_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_adapter_set_device_discovery_state_changed_cb');
  late final _bt_adapter_set_device_discovery_state_changed_cb =
      _bt_adapter_set_device_discovery_state_changed_cbPtr.asFunction<
          int Function(bt_adapter_device_discovery_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
  /// @brief	Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_initialize()
  /// @see bt_adapter_set_device_discovery_state_changed_cb()
  int bt_adapter_unset_device_discovery_state_changed_cb() {
    return _bt_adapter_unset_device_discovery_state_changed_cb();
  }

  late final _bt_adapter_unset_device_discovery_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_unset_device_discovery_state_changed_cb');
  late final _bt_adapter_unset_device_discovery_state_changed_cb =
      _bt_adapter_unset_device_discovery_state_changed_cbPtr
          .asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OOB_MODULE
  /// @brief Get the Hash and Randmoizer value, synchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[out] hash The hash value received from the controller
  /// @param[out] randomizer The hash value received from the controller
  /// @param[out] hash_len The length of the hash value
  /// @param[out] randomizer_len The length of the randomizer value
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  int bt_adapter_get_local_oob_data(
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> hash,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> randomizer,
    ffi.Pointer<ffi.Int> hash_len,
    ffi.Pointer<ffi.Int> randomizer_len,
  ) {
    return _bt_adapter_get_local_oob_data(
      hash,
      randomizer,
      hash_len,
      randomizer_len,
    );
  }

  late final _bt_adapter_get_local_oob_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('bt_adapter_get_local_oob_data');
  late final _bt_adapter_get_local_oob_data =
      _bt_adapter_get_local_oob_dataPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OOB_MODULE
  /// @brief Sets the Hash and Randmoizer value, synchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] remote_address Remote device address
  /// @param[in] hash The hash value received from the controller
  /// @param[in] randomizer The hash value received from the controller
  /// @param[in] hash_len The length of the hash value. Allowed value is 16
  /// @param[in] randomizer_len The length of the randomizer value. Allowed value is 16
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  int bt_adapter_set_remote_oob_data(
    ffi.Pointer<ffi.Char> remote_address,
    ffi.Pointer<ffi.UnsignedChar> hash,
    ffi.Pointer<ffi.UnsignedChar> randomizer,
    int hash_len,
    int randomizer_len,
  ) {
    return _bt_adapter_set_remote_oob_data(
      remote_address,
      hash,
      randomizer,
      hash_len,
      randomizer_len,
    );
  }

  late final _bt_adapter_set_remote_oob_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Int,
              ffi.Int)>>('bt_adapter_set_remote_oob_data');
  late final _bt_adapter_set_remote_oob_data =
      _bt_adapter_set_remote_oob_dataPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.UnsignedChar>,
              ffi.Pointer<ffi.UnsignedChar>, int, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OOB_MODULE
  /// @brief Gets the Hash and Randmoizer value, synchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks The @a hash192, randomizer192, hash256 and randomizer256 must be released using free()
  ///
  /// @param[out] hash192 The hash value derived from the P-192 public key
  /// @param[out] randomizer192 The randomizer value associated with the P-192 public key
  /// @param[out] hash192_len The length of @a hash192
  /// @param[out] randomizer192_len The length of @a randomizer192
  /// @param[out] hash256 The hash value derived from the P-256 public key
  /// @param[out] randomizer256 The randomizer value associated with the P-256 public key
  /// @param[out] hash256_len The length of @a hash256
  /// @param[out] randomizer256_len The length of @a randomizer256
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  int bt_adapter_get_local_oob_ext_data(
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> hash192,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> randomizer192,
    ffi.Pointer<ffi.Int> hash192_len,
    ffi.Pointer<ffi.Int> randomizer192_len,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> hash256,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> randomizer256,
    ffi.Pointer<ffi.Int> hash256_len,
    ffi.Pointer<ffi.Int> randomizer256_len,
  ) {
    return _bt_adapter_get_local_oob_ext_data(
      hash192,
      randomizer192,
      hash192_len,
      randomizer192_len,
      hash256,
      randomizer256,
      hash256_len,
      randomizer256_len,
    );
  }

  late final _bt_adapter_get_local_oob_ext_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('bt_adapter_get_local_oob_ext_data');
  late final _bt_adapter_get_local_oob_ext_data =
      _bt_adapter_get_local_oob_ext_dataPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OOB_MODULE
  /// @brief Sets the Hash and Randmoizer value, synchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] remote_address Remote device address
  /// @param[in] hash192 The P-192 hash value received via OOB from remote device
  /// @param[in] randomizer192 The P-192 randomizer value received via OOB from remote device
  /// @param[in] hash192_len The length of @a hash192
  /// @param[in] randomizer192_len The length of @a randomizer192
  /// @param[in] hash256 The P-256 hash value received via OOB from remote device
  /// @param[in] randomizer256 The P-256 randomizer value received via OOB from remote device
  /// @param[in] hash256_len The length of @a hash256
  /// @param[in] randomizer256_len The length of @a randomizer256
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  int bt_adapter_set_remote_oob_ext_data(
    ffi.Pointer<ffi.Char> remote_address,
    ffi.Pointer<ffi.UnsignedChar> hash192,
    ffi.Pointer<ffi.UnsignedChar> randomizer192,
    int hash192_len,
    int randomizer192_len,
    ffi.Pointer<ffi.UnsignedChar> hash256,
    ffi.Pointer<ffi.UnsignedChar> randomizer256,
    int hash256_len,
    int randomizer256_len,
  ) {
    return _bt_adapter_set_remote_oob_ext_data(
      remote_address,
      hash192,
      randomizer192,
      hash192_len,
      randomizer192_len,
      hash256,
      randomizer256,
      hash256_len,
      randomizer256_len,
    );
  }

  late final _bt_adapter_set_remote_oob_ext_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Int,
              ffi.Int,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Int,
              ffi.Int)>>('bt_adapter_set_remote_oob_ext_data');
  late final _bt_adapter_set_remote_oob_ext_data =
      _bt_adapter_set_remote_oob_ext_dataPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Pointer<ffi.UnsignedChar>,
              int,
              int,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Pointer<ffi.UnsignedChar>,
              int,
              int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OOB_MODULE
  /// @brief Deletes the Hash and Randomizer value, synchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] remote_address Remote device address
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  int bt_adapter_remove_remote_oob_data(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_adapter_remove_remote_oob_data(
      remote_address,
    );
  }

  late final _bt_adapter_remove_remote_oob_dataPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_adapter_remove_remote_oob_data');
  late final _bt_adapter_remove_remote_oob_data =
      _bt_adapter_remove_remote_oob_dataPtr
          .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 2.3.1
  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Starts the LE device discovery.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @details If a LE device is discovered, bt_adapter_le_device_discovery_state_changed_cb()
  /// will be invoked with #BT_ADAPTER_LE_DEVICE_DISCOVERY_FOUND, and then bt_adapter_le_device_discovery_state_changed_cb()
  /// will be called with #BT_ADAPTER_LE_DEVICE_DISCOVERY_FINISHED in case of the completion or cancellation of the discovery.
  ///
  /// @remarks To connect to peer Bluetooth device, you need to know its Bluetooth address. \n
  /// The device discovery can be stopped by bt_adapter_le_stop_device_discovery().
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation is now in progress
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post This function invokes bt_adapter_le_device_discovery_state_changed_cb().
  ///
  /// @see bt_adapter_le_is_discovering()
  /// @see bt_adapter_le_device_discovery_state_changed_cb()
  /// @see bt_adapter_le_set_device_discovery_state_changed_cb()
  /// @see bt_adapter_le_unset_device_discovery_state_changed_cb()
  int bt_adapter_le_start_device_discovery() {
    return _bt_adapter_le_start_device_discovery();
  }

  late final _bt_adapter_le_start_device_discoveryPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_le_start_device_discovery');
  late final _bt_adapter_le_start_device_discovery =
      _bt_adapter_le_start_device_discoveryPtr.asFunction<int Function()>();

  /// @deprecated Deprecated since 2.3.1
  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Stops the LE device discovery, asynchronously.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOT_IN_PROGRESS  Operation is not in progress
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The device discovery must be in progress with bt_adapter_le_start_device_discovery().
  /// @post This function invokes bt_adapter_le_device_discovery_state_changed_cb().
  ///
  /// @see bt_adapter_le_is_discovering()
  /// @see bt_adapter_le_start_device_discovery()
  /// @see bt_adapter_le_set_device_discovery_state_changed_cb()
  /// @see bt_adapter_le_unset_device_discovery_state_changed_cb()
  /// @see bt_adapter_le_device_discovery_state_changed_cb()
  int bt_adapter_le_stop_device_discovery() {
    return _bt_adapter_le_stop_device_discovery();
  }

  late final _bt_adapter_le_stop_device_discoveryPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_le_stop_device_discovery');
  late final _bt_adapter_le_stop_device_discovery =
      _bt_adapter_le_stop_device_discoveryPtr.asFunction<int Function()>();

  /// @deprecated Deprecated since 2.3.1
  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Checks for the LE device discovery is in progress or not.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  ///
  /// @remarks If Bluetooth LE discovery is in progress, other operations are not allowed and
  /// you have to either stop the LE discovery operation, or wait for it to be finished,
  /// before performing other operations.
  ///
  /// @param[out] is_discovering The discovering status: (@c true = in progress , @c  false = not in progress )
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  ///
  /// @see bt_adapter_le_start_device_discovery()
  /// @see bt_adapter_le_stop_device_discovery()
  int bt_adapter_le_is_discovering(
    ffi.Pointer<ffi.Bool> is_discovering,
  ) {
    return _bt_adapter_le_is_discovering(
      is_discovering,
    );
  }

  late final _bt_adapter_le_is_discoveringPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Bool>)>>(
          'bt_adapter_le_is_discovering');
  late final _bt_adapter_le_is_discovering = _bt_adapter_le_is_discoveringPtr
      .asFunction<int Function(ffi.Pointer<ffi.Bool>)>();

  /// @deprecated Deprecated since 2.3.1
  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief  Registers a callback function to be invoked when the LE device discovery state changes.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  ///
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post bt_adapter_le_device_discovery_state_changed_cb() will be invoked.
  ///
  /// @see bt_initialize()
  /// @see bt_adapter_le_device_discovery_state_changed_cb()
  /// @see bt_adapter_le_unset_device_discovery_state_changed_cb()
  int bt_adapter_le_set_device_discovery_state_changed_cb(
    bt_adapter_le_device_discovery_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_adapter_le_set_device_discovery_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_adapter_le_set_device_discovery_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_adapter_le_device_discovery_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_adapter_le_set_device_discovery_state_changed_cb');
  late final _bt_adapter_le_set_device_discovery_state_changed_cb =
      _bt_adapter_le_set_device_discovery_state_changed_cbPtr.asFunction<
          int Function(bt_adapter_le_device_discovery_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 2.3.1
  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief	Unregisters the callback function.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  ///
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_initialize()
  /// @see bt_adapter_le_set_device_discovery_state_changed_cb()
  int bt_adapter_le_unset_device_discovery_state_changed_cb() {
    return _bt_adapter_le_unset_device_discovery_state_changed_cb();
  }

  late final _bt_adapter_le_unset_device_discovery_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_le_unset_device_discovery_state_changed_cb');
  late final _bt_adapter_le_unset_device_discovery_state_changed_cb =
      _bt_adapter_le_unset_device_discovery_state_changed_cbPtr
          .asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Starts the LE scan to find LE advertisement.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @details If a LE advertisement is found, bt_adapter_le_scan_result_cb() will be invoked.
  ///
  /// @param[in] cb The callback to report the result of this function
  /// @param[in] user_data The user data to be passed when callback is called
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation is now in progress
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post This function invokes bt_adapter_le_scan_result_cb().
  ///
  /// @see bt_adapter_le_scan_result_cb()
  int bt_adapter_le_start_scan(
    bt_adapter_le_scan_result_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_adapter_le_start_scan(
      cb,
      user_data,
    );
  }

  late final _bt_adapter_le_start_scanPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_adapter_le_scan_result_cb,
              ffi.Pointer<ffi.Void>)>>('bt_adapter_le_start_scan');
  late final _bt_adapter_le_start_scan =
      _bt_adapter_le_start_scanPtr.asFunction<
          int Function(bt_adapter_le_scan_result_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Stops the LE scan.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOT_IN_PROGRESS  Operation is not in progress
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The LE scan must be in progress with bt_adapter_le_start_scan().
  ///
  /// @see bt_adapter_le_start_scan()
  int bt_adapter_le_stop_scan() {
    return _bt_adapter_le_stop_scan();
  }

  late final _bt_adapter_le_stop_scanPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_le_stop_scan');
  late final _bt_adapter_le_stop_scan =
      _bt_adapter_le_stop_scanPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Gets the service UUID list from the scan result information
  /// @since_tizen 2.3.1
  ///
  /// @remarks The @a uuids must be iterated as count and each pointed data must be released with free().
  /// Then uuids must be released with free(). \n
  /// 16-bit service UUID or 128-bit service UUID is supported. (e.g. 180F, 0000180F-0000-1000-8000-00805F9B34FB)
  ///
  /// @param[in] info The scan result information
  /// @param[in] pkt_type The packet type
  /// @param[out] uuids The list of string of the service uuid
  /// @param[out] count The count of the service UUIDs
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_scan_result_cb()
  int bt_adapter_le_get_scan_result_service_uuids(
    ffi.Pointer<bt_adapter_le_device_scan_result_info_s> info,
    int pkt_type,
    ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>> uuids,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _bt_adapter_le_get_scan_result_service_uuids(
      info,
      pkt_type,
      uuids,
      count,
    );
  }

  late final _bt_adapter_le_get_scan_result_service_uuidsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
                  ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
                  ffi.Pointer<ffi.Int>)>>(
      'bt_adapter_le_get_scan_result_service_uuids');
  late final _bt_adapter_le_get_scan_result_service_uuids =
      _bt_adapter_le_get_scan_result_service_uuidsPtr.asFunction<
          int Function(
              ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
              int,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Gets the device name from the scan result information
  /// @since_tizen 2.3.1
  ///
  /// @remarks The @a name must be released with free() by you.
  ///
  /// @param[in] info The scan result information
  /// @param[in] pkt_type The packet type
  /// @param[out] name The device name
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_scan_result_cb()
  int bt_adapter_le_get_scan_result_device_name(
    ffi.Pointer<bt_adapter_le_device_scan_result_info_s> info,
    int pkt_type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _bt_adapter_le_get_scan_result_device_name(
      info,
      pkt_type,
      name,
    );
  }

  late final _bt_adapter_le_get_scan_result_device_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
                  ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'bt_adapter_le_get_scan_result_device_name');
  late final _bt_adapter_le_get_scan_result_device_name =
      _bt_adapter_le_get_scan_result_device_namePtr.asFunction<
          int Function(ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
              int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Gets the transmission power level from the scan result information
  /// @since_tizen 2.3.1
  ///
  /// @param[in] info The scan result information
  /// @param[in] pkt_type The packet type
  /// @param[out] power_level The transmission power level in dBm
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_scan_result_cb()
  int bt_adapter_le_get_scan_result_tx_power_level(
    ffi.Pointer<bt_adapter_le_device_scan_result_info_s> info,
    int pkt_type,
    ffi.Pointer<ffi.Int> power_level,
  ) {
    return _bt_adapter_le_get_scan_result_tx_power_level(
      info,
      pkt_type,
      power_level,
    );
  }

  late final _bt_adapter_le_get_scan_result_tx_power_levelPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
                  ffi.Int32,
                  ffi.Pointer<ffi.Int>)>>(
      'bt_adapter_le_get_scan_result_tx_power_level');
  late final _bt_adapter_le_get_scan_result_tx_power_level =
      _bt_adapter_le_get_scan_result_tx_power_levelPtr.asFunction<
          int Function(ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
              int, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Gets the service solicitation UUID list from the scan result information
  /// @since_tizen 2.3.1
  ///
  /// @remarks The @a uuids must be iterated as count and each pointed data must be released with free().
  /// Then uuids must be released with free(). \n
  /// 16-bit service solicitation UUID or 128-bit service solicitation UUID is supported.
  /// (e.g. 180F, 0000180F-0000-1000-8000-00805F9B34FB)
  ///
  /// @param[in] info The scan result information
  /// @param[in] pkt_type The packet type
  /// @param[out] uuids The list of string of the service solicitation uuid
  /// @param[out] count The count of the service UUIDs
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_scan_result_cb()
  int bt_adapter_le_get_scan_result_service_solicitation_uuids(
    ffi.Pointer<bt_adapter_le_device_scan_result_info_s> info,
    int pkt_type,
    ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>> uuids,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _bt_adapter_le_get_scan_result_service_solicitation_uuids(
      info,
      pkt_type,
      uuids,
      count,
    );
  }

  late final _bt_adapter_le_get_scan_result_service_solicitation_uuidsPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
                      ffi.Int32,
                      ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
                      ffi.Pointer<ffi.Int>)>>(
          'bt_adapter_le_get_scan_result_service_solicitation_uuids');
  late final _bt_adapter_le_get_scan_result_service_solicitation_uuids =
      _bt_adapter_le_get_scan_result_service_solicitation_uuidsPtr.asFunction<
          int Function(
              ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
              int,
              ffi.Pointer<ffi.Pointer<ffi.Pointer<ffi.Char>>>,
              ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Gets the service data list from the scan result information
  /// @since_tizen 2.3.1
  ///
  /// @remarks The @a data_list must be released with bt_adapter_le_free_service_data_list() by you .
  ///
  /// @param[in] info The scan result information
  /// @param[in] pkt_type The packet type
  /// @param[out] data_list The list of the service data
  /// @param[out] count The count of the service data list
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_scan_result_cb()
  int bt_adapter_le_get_scan_result_service_data_list(
    ffi.Pointer<bt_adapter_le_device_scan_result_info_s> info,
    int pkt_type,
    ffi.Pointer<ffi.Pointer<bt_adapter_le_service_data_s>> data_list,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _bt_adapter_le_get_scan_result_service_data_list(
      info,
      pkt_type,
      data_list,
      count,
    );
  }

  late final _bt_adapter_le_get_scan_result_service_data_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
                  ffi.Int32,
                  ffi.Pointer<ffi.Pointer<bt_adapter_le_service_data_s>>,
                  ffi.Pointer<ffi.Int>)>>(
      'bt_adapter_le_get_scan_result_service_data_list');
  late final _bt_adapter_le_get_scan_result_service_data_list =
      _bt_adapter_le_get_scan_result_service_data_listPtr.asFunction<
          int Function(
              ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
              int,
              ffi.Pointer<ffi.Pointer<bt_adapter_le_service_data_s>>,
              ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Frees service data list.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] data_list The list of the service data
  /// @param[in] count The count of the service data list
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_adapter_le_get_scan_result_service_data_list()
  int bt_adapter_le_free_service_data_list(
    ffi.Pointer<bt_adapter_le_service_data_s> data_list,
    int count,
  ) {
    return _bt_adapter_le_free_service_data_list(
      data_list,
      count,
    );
  }

  late final _bt_adapter_le_free_service_data_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<bt_adapter_le_service_data_s>,
              ffi.Int)>>('bt_adapter_le_free_service_data_list');
  late final _bt_adapter_le_free_service_data_list =
      _bt_adapter_le_free_service_data_listPtr.asFunction<
          int Function(ffi.Pointer<bt_adapter_le_service_data_s>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Gets the appearance from the scan result information
  /// @since_tizen 2.3.1
  ///
  /// @param[in] info The scan result information
  /// @param[in] pkt_type The packet type
  /// @param[out] appearance The appearance
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_scan_result_cb()
  int bt_adapter_le_get_scan_result_appearance(
    ffi.Pointer<bt_adapter_le_device_scan_result_info_s> info,
    int pkt_type,
    ffi.Pointer<ffi.Int> appearance,
  ) {
    return _bt_adapter_le_get_scan_result_appearance(
      info,
      pkt_type,
      appearance,
    );
  }

  late final _bt_adapter_le_get_scan_result_appearancePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
                  ffi.Int32,
                  ffi.Pointer<ffi.Int>)>>(
      'bt_adapter_le_get_scan_result_appearance');
  late final _bt_adapter_le_get_scan_result_appearance =
      _bt_adapter_le_get_scan_result_appearancePtr.asFunction<
          int Function(ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
              int, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Gets the manufacturer data from the scan result information
  /// @since_tizen 2.3.1
  ///
  /// @remarks The @a manufacturer_data must be released with free() by you.
  ///
  /// @param[in] info The scan result information
  /// @param[in] pkt_type The packet type
  /// @param[out] manufacturer_id The manufacturer ID
  /// @param[out] manufacturer_data The manufacturer data (byte array)
  /// @param[out] manufacturer_data_len The length of manufacturer data
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_scan_result_cb()
  int bt_adapter_le_get_scan_result_manufacturer_data(
    ffi.Pointer<bt_adapter_le_device_scan_result_info_s> info,
    int pkt_type,
    ffi.Pointer<ffi.Int> manufacturer_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> manufacturer_data,
    ffi.Pointer<ffi.Int> manufacturer_data_len,
  ) {
    return _bt_adapter_le_get_scan_result_manufacturer_data(
      info,
      pkt_type,
      manufacturer_id,
      manufacturer_data,
      manufacturer_data_len,
    );
  }

  late final _bt_adapter_le_get_scan_result_manufacturer_dataPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
                  ffi.Int32,
                  ffi.Pointer<ffi.Int>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>,
                  ffi.Pointer<ffi.Int>)>>(
      'bt_adapter_le_get_scan_result_manufacturer_data');
  late final _bt_adapter_le_get_scan_result_manufacturer_data =
      _bt_adapter_le_get_scan_result_manufacturer_dataPtr.asFunction<
          int Function(
              ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
              int,
              ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Gets iBeacon format's data from the scan result information.
  /// @since_tizen 4.0
  ///
  /// @remarks The @a ibeacon_info must be released with bt_adapter_le_free_ibeacon_report().
  ///
  /// @param[in] info The scan result information
  /// @param[in] pkt_type The packet type
  /// @param[out] ibeacon_info The iBeacon format's scan result data
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_scan_result_cb()
  int bt_adapter_le_get_scan_result_ibeacon_report(
    ffi.Pointer<bt_adapter_le_device_scan_result_info_s> info,
    int pkt_type,
    ffi.Pointer<ffi.Pointer<bt_adapter_le_ibeacon_scan_result_info_s>>
        ibeacon_info,
  ) {
    return _bt_adapter_le_get_scan_result_ibeacon_report(
      info,
      pkt_type,
      ibeacon_info,
    );
  }

  late final _bt_adapter_le_get_scan_result_ibeacon_reportPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
                  ffi.Int32,
                  ffi.Pointer<
                      ffi.Pointer<bt_adapter_le_ibeacon_scan_result_info_s>>)>>(
      'bt_adapter_le_get_scan_result_ibeacon_report');
  late final _bt_adapter_le_get_scan_result_ibeacon_report =
      _bt_adapter_le_get_scan_result_ibeacon_reportPtr.asFunction<
          int Function(
              ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
              int,
              ffi.Pointer<
                  ffi.Pointer<bt_adapter_le_ibeacon_scan_result_info_s>>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Frees iBeacon information.
  /// @since_tizen 4.0
  ///
  /// @param[in] ibeacon_info The iBeacon format's scan result data
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_adapter_le_get_scan_result_service_data_list()
  int bt_adapter_le_free_ibeacon_report(
    ffi.Pointer<bt_adapter_le_ibeacon_scan_result_info_s> ibeacon_info,
  ) {
    return _bt_adapter_le_free_ibeacon_report(
      ibeacon_info,
    );
  }

  late final _bt_adapter_le_free_ibeacon_reportPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<bt_adapter_le_ibeacon_scan_result_info_s>)>>(
      'bt_adapter_le_free_ibeacon_report');
  late final _bt_adapter_le_free_ibeacon_report =
      _bt_adapter_le_free_ibeacon_reportPtr.asFunction<
          int Function(
              ffi.Pointer<bt_adapter_le_ibeacon_scan_result_info_s>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Create advertiser to advertise device's existence or respond to LE scanning request.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[out] advertiser The handle of advertiser
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_destroy_advertiser()
  int bt_adapter_le_create_advertiser(
    ffi.Pointer<bt_advertiser_h> advertiser,
  ) {
    return _bt_adapter_le_create_advertiser(
      advertiser,
    );
  }

  late final _bt_adapter_le_create_advertiserPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<bt_advertiser_h>)>>(
      'bt_adapter_le_create_advertiser');
  late final _bt_adapter_le_create_advertiser =
      _bt_adapter_le_create_advertiserPtr
          .asFunction<int Function(ffi.Pointer<bt_advertiser_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Destroy advertiser.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[out] advertiser The handle of advertiser
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_create_advertiser()
  int bt_adapter_le_destroy_advertiser(
    bt_advertiser_h advertiser,
  ) {
    return _bt_adapter_le_destroy_advertiser(
      advertiser,
    );
  }

  late final _bt_adapter_le_destroy_advertiserPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_advertiser_h)>>(
          'bt_adapter_le_destroy_advertiser');
  late final _bt_adapter_le_destroy_advertiser =
      _bt_adapter_le_destroy_advertiserPtr
          .asFunction<int Function(bt_advertiser_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_IPSP_MODULE
  /// @brief Initializes the Bluetooth IPSP (Internet Protocol Support Profile) service.
  /// @since_tizen 4.0
  /// @param[in] callback The callback called when the initialization is finished
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  int bt_ipsp_initialize(
    bt_ipsp_init_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_ipsp_initialize(
      callback,
      user_data,
    );
  }

  late final _bt_ipsp_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_ipsp_init_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_ipsp_initialize');
  late final _bt_ipsp_initialize = _bt_ipsp_initializePtr.asFunction<
      int Function(bt_ipsp_init_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_IPSP_MODULE
  /// @brief Deinitializes the Bluetooth IPSP (Internet Protocol Support Profile) service.
  /// @since_tizen 4.0
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  int bt_ipsp_deinitialize() {
    return _bt_ipsp_deinitialize();
  }

  late final _bt_ipsp_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('bt_ipsp_deinitialize');
  late final _bt_ipsp_deinitialize =
      _bt_ipsp_deinitializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_IPSP_MODULE
  /// @brief Connects to a remote device's IPSP service over LE, asynchronously.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] remote_address  The remote address
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @post bt_ipsp_set_connection_state_changed_cb() will be invoked.
  /// @see bt_ipsp_set_connection_state_changed_cb()
  int bt_ipsp_connect(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_ipsp_connect(
      remote_address,
    );
  }

  late final _bt_ipsp_connectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_ipsp_connect');
  late final _bt_ipsp_connect =
      _bt_ipsp_connectPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_IPSP_MODULE
  /// @brief Disonneicts from a remote device's IPSP service, asynchronously.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] remote_address  The remote address
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The remote device must be connected by bt_ipsp_connect().
  /// @post bt_ipsp_set_connection_state_changed_cb() will be invoked.
  /// @see bt_ipsp_connect()
  /// @see bt_ipsp_set_connection_state_changed_cb()
  int bt_ipsp_disconnect(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_ipsp_disconnect(
      remote_address,
    );
  }

  late final _bt_ipsp_disconnectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_ipsp_disconnect');
  late final _bt_ipsp_disconnect =
      _bt_ipsp_disconnectPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_IPSP_MODULE
  /// @brief  Registers a callback function that will be invoked when the connection state changes.
  /// @since_tizen 4.0
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  int bt_ipsp_set_connection_state_changed_cb(
    bt_ipsp_connection_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_ipsp_set_connection_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_ipsp_set_connection_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_ipsp_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'bt_ipsp_set_connection_state_changed_cb');
  late final _bt_ipsp_set_connection_state_changed_cb =
      _bt_ipsp_set_connection_state_changed_cbPtr.asFunction<
          int Function(
              bt_ipsp_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_IPSP_MODULE
  /// @brief	Unregisters the callback function called when the connection state changes.
  /// @since_tizen 4.0
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  int bt_ipsp_unset_connection_state_changed_cb() {
    return _bt_ipsp_unset_connection_state_changed_cb();
  }

  late final _bt_ipsp_unset_connection_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_ipsp_unset_connection_state_changed_cb');
  late final _bt_ipsp_unset_connection_state_changed_cb =
      _bt_ipsp_unset_connection_state_changed_cbPtr
          .asFunction<int Function()>();

  /// @deprecated Deprecated since 2.3.1
  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Set the data to be advertised or responded to scan request from LE scanning device.
  /// The maximum advertised or responded data size is 31 bytes
  /// including data type and system wide data.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  ///
  /// @remarks In case the data_type is local name or tx power level, you don't need to input data
  /// because the data value is written automatically by system.
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] pkt_type The packet type
  /// @param[in] data_type The data type that is included in packet
  /// @param[in] data The data to be advertised or be responded to scan request from LE scanning device, no need in case of LOCAL_NAME or TX_POWER_LEVEL
  /// @param[in] data_size The size of data to be set.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_QUOTA_EXCEEDED  Quota exceeded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_clear_advertising_data()
  int bt_adapter_le_add_advertising_data(
    bt_advertiser_h advertiser,
    int pkt_type,
    int data_type,
    ffi.Pointer<ffi.Void> data,
    int data_size,
  ) {
    return _bt_adapter_le_add_advertising_data(
      advertiser,
      pkt_type,
      data_type,
      data,
      data_size,
    );
  }

  late final _bt_adapter_le_add_advertising_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_advertiser_h,
              ffi.Int32,
              ffi.Int32,
              ffi.Pointer<ffi.Void>,
              ffi.UnsignedInt)>>('bt_adapter_le_add_advertising_data');
  late final _bt_adapter_le_add_advertising_data =
      _bt_adapter_le_add_advertising_dataPtr.asFunction<
          int Function(
              bt_advertiser_h, int, int, ffi.Pointer<ffi.Void>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Add a service UUID to advertise or scan response data.
  /// The maximum advertised or responded data size is 31 bytes
  /// including data type and system wide data.
  /// @since_tizen 2.3.1
  ///
  /// @remarks 16-bit UUID or 128-bit UUID is supported. (e.g. 180F, 0000180F-0000-1000-8000-00805F9B34FB)
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] pkt_type The packet type
  /// @param[in] uuid The string of the service UUID.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_QUOTA_EXCEEDED  Quota exceeded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_clear_advertising_data()
  int bt_adapter_le_add_advertising_service_uuid(
    bt_advertiser_h advertiser,
    int pkt_type,
    ffi.Pointer<ffi.Char> uuid,
  ) {
    return _bt_adapter_le_add_advertising_service_uuid(
      advertiser,
      pkt_type,
      uuid,
    );
  }

  late final _bt_adapter_le_add_advertising_service_uuidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_advertiser_h, ffi.Int32, ffi.Pointer<ffi.Char>)>>(
      'bt_adapter_le_add_advertising_service_uuid');
  late final _bt_adapter_le_add_advertising_service_uuid =
      _bt_adapter_le_add_advertising_service_uuidPtr.asFunction<
          int Function(bt_advertiser_h, int, ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Add a service solicitation UUID to advertise or scan response data.
  /// The maximum advertised or responded data size is 31 bytes
  /// including data type and system wide data.
  /// @since_tizen 2.3.1
  ///
  /// @remarks 16-bit service solicitation UUID or 128-bit service solicitation UUID is supported.
  /// (e.g. 180F, 0000180F-0000-1000-8000-00805F9B34FB)
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] pkt_type The packet type
  /// @param[in] uuid The string of the service solicitation UUID.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_QUOTA_EXCEEDED  Quota exceeded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_clear_advertising_data()
  int bt_adapter_le_add_advertising_service_solicitation_uuid(
    bt_advertiser_h advertiser,
    int pkt_type,
    ffi.Pointer<ffi.Char> uuid,
  ) {
    return _bt_adapter_le_add_advertising_service_solicitation_uuid(
      advertiser,
      pkt_type,
      uuid,
    );
  }

  late final _bt_adapter_le_add_advertising_service_solicitation_uuidPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      bt_advertiser_h, ffi.Int32, ffi.Pointer<ffi.Char>)>>(
          'bt_adapter_le_add_advertising_service_solicitation_uuid');
  late final _bt_adapter_le_add_advertising_service_solicitation_uuid =
      _bt_adapter_le_add_advertising_service_solicitation_uuidPtr.asFunction<
          int Function(bt_advertiser_h, int, ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Add service data to advertise or scan response data.
  /// The maximum advertised or responded data size is 31 bytes
  /// including data type and system wide data.
  /// @since_tizen 2.3.1
  ///
  /// @remarks 16-bit UUID is supported. (e.g. 180F)
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] pkt_type The packet type
  /// @param[in] uuid 16-bit UUID of the service
  /// @param[in] service_data The service data
  /// @param[in] service_data_len The data length of service data
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_QUOTA_EXCEEDED  Quota exceeded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_clear_advertising_data()
  int bt_adapter_le_add_advertising_service_data(
    bt_advertiser_h advertiser,
    int pkt_type,
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<ffi.Char> service_data,
    int service_data_len,
  ) {
    return _bt_adapter_le_add_advertising_service_data(
      advertiser,
      pkt_type,
      uuid,
      service_data,
      service_data_len,
    );
  }

  late final _bt_adapter_le_add_advertising_service_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_advertiser_h,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Int)>>('bt_adapter_le_add_advertising_service_data');
  late final _bt_adapter_le_add_advertising_service_data =
      _bt_adapter_le_add_advertising_service_dataPtr.asFunction<
          int Function(bt_advertiser_h, int, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the external appearance of this device to advertise or scan response data.
  /// Please refer to the adopted Bluetooth specification for the the appearance.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] pkt_type The packet type
  /// @param[in] appearance The external appearance of device
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_QUOTA_EXCEEDED  Quota exceeded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_clear_advertising_data()
  int bt_adapter_le_set_advertising_appearance(
    bt_advertiser_h advertiser,
    int pkt_type,
    int appearance,
  ) {
    return _bt_adapter_le_set_advertising_appearance(
      advertiser,
      pkt_type,
      appearance,
    );
  }

  late final _bt_adapter_le_set_advertising_appearancePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_advertiser_h, ffi.Int32,
              ffi.Int)>>('bt_adapter_le_set_advertising_appearance');
  late final _bt_adapter_le_set_advertising_appearance =
      _bt_adapter_le_set_advertising_appearancePtr
          .asFunction<int Function(bt_advertiser_h, int, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Add manufacturer specific data to advertise or scan response data.
  /// Please refer to the Bluetooth Assigned Numbers provided by the Bluetooth SIG for a list of existing company identifiers.
  /// The maximum advertised or responded data size is 31 bytes
  /// including data type and system wide data.
  /// @since_tizen 2.3.1
  ///
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] pkt_type The packet type
  /// @param[in] manufacturer_id Manufacturer identifier
  /// @param[in] manufacturer_data The manufacturer specific data
  /// @param[in] manufacturer_data_len The data length of manufacturer data
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_QUOTA_EXCEEDED  Quota exceeded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_clear_advertising_data()
  int bt_adapter_le_add_advertising_manufacturer_data(
    bt_advertiser_h advertiser,
    int pkt_type,
    int manufacturer_id,
    ffi.Pointer<ffi.Char> manufacturer_data,
    int manufacturer_data_len,
  ) {
    return _bt_adapter_le_add_advertising_manufacturer_data(
      advertiser,
      pkt_type,
      manufacturer_id,
      manufacturer_data,
      manufacturer_data_len,
    );
  }

  late final _bt_adapter_le_add_advertising_manufacturer_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_advertiser_h,
              ffi.Int32,
              ffi.Int,
              ffi.Pointer<ffi.Char>,
              ffi.Int)>>('bt_adapter_le_add_advertising_manufacturer_data');
  late final _bt_adapter_le_add_advertising_manufacturer_data =
      _bt_adapter_le_add_advertising_manufacturer_dataPtr.asFunction<
          int Function(
              bt_advertiser_h, int, int, ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Set whether the device name should be included in advertise or scan response data.
  /// The maximum advertised or responded data size is 31 bytes
  /// including data type and system wide data.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] pkt_type The packet type
  /// @param[in] include_name Whether the device name should be included
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_QUOTA_EXCEEDED  Quota exceeded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_clear_advertising_data()
  int bt_adapter_le_set_advertising_device_name(
    bt_advertiser_h advertiser,
    int pkt_type,
    bool include_name,
  ) {
    return _bt_adapter_le_set_advertising_device_name(
      advertiser,
      pkt_type,
      include_name,
    );
  }

  late final _bt_adapter_le_set_advertising_device_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_advertiser_h, ffi.Int32,
              ffi.Bool)>>('bt_adapter_le_set_advertising_device_name');
  late final _bt_adapter_le_set_advertising_device_name =
      _bt_adapter_le_set_advertising_device_namePtr
          .asFunction<int Function(bt_advertiser_h, int, bool)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Set whether the transmission power level should be included in advertise or scan response data.
  /// The maximum advertised or responded data size is 31 bytes
  /// including data type and system wide data.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] pkt_type The packet type
  /// @param[in] include_tx_power Whether the transmission power level should be included
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_QUOTA_EXCEEDED  Quota exceeded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_clear_advertising_data()
  int bt_adapter_le_set_advertising_tx_power_level(
    bt_advertiser_h advertiser,
    int pkt_type,
    bool include_tx_power,
  ) {
    return _bt_adapter_le_set_advertising_tx_power_level(
      advertiser,
      pkt_type,
      include_tx_power,
    );
  }

  late final _bt_adapter_le_set_advertising_tx_power_levelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_advertiser_h, ffi.Int32,
              ffi.Bool)>>('bt_adapter_le_set_advertising_tx_power_level');
  late final _bt_adapter_le_set_advertising_tx_power_level =
      _bt_adapter_le_set_advertising_tx_power_levelPtr
          .asFunction<int Function(bt_advertiser_h, int, bool)>();

  /// @deprecated Deprecated since 2.3.1
  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Unset the data to be advertised or responded to scan request from LE scanning device.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] pkt_type The packet type
  /// @param[in] data_type The data type to be removed from selected packet
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_add_advertising_data()
  /// @see bt_adapter_le_clear_advertising_data()
  int bt_adapter_le_remove_advertising_data(
    bt_advertiser_h advertiser,
    int pkt_type,
    int data_type,
  ) {
    return _bt_adapter_le_remove_advertising_data(
      advertiser,
      pkt_type,
      data_type,
    );
  }

  late final _bt_adapter_le_remove_advertising_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_advertiser_h, ffi.Int32,
              ffi.Int32)>>('bt_adapter_le_remove_advertising_data');
  late final _bt_adapter_le_remove_advertising_data =
      _bt_adapter_le_remove_advertising_dataPtr
          .asFunction<int Function(bt_advertiser_h, int, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Clear all data to be advertised or responded to scan request from LE scanning device.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] pkt_type The packet type to be cleared
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_add_advertising_data()
  int bt_adapter_le_clear_advertising_data(
    bt_advertiser_h advertiser,
    int pkt_type,
  ) {
    return _bt_adapter_le_clear_advertising_data(
      advertiser,
      pkt_type,
    );
  }

  late final _bt_adapter_le_clear_advertising_dataPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_advertiser_h, ffi.Int32)>>(
          'bt_adapter_le_clear_advertising_data');
  late final _bt_adapter_le_clear_advertising_data =
      _bt_adapter_le_clear_advertising_dataPtr
          .asFunction<int Function(bt_advertiser_h, int)>();

  /// @deprecated Deprecated since 2.3.1
  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Start advertising with passed advertiser and advertising parameters.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @details Once Bluetooth advertising is started, nearby Bluetooth LE(Low Energy) supported
  /// devices can know this device's existence. And one of them can make a connection request,
  /// if it is allowed.
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] adv_params The parameters of advertising \n
  /// If NULL is passed, default values which are defined in driver / controller are used.
  /// @param[in] cb The callback to report the result of this function
  /// @param[in] user_data The user data to be passed when callback is called
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation is now in progress
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post This function invokes bt_adapter_le_advertising_state_changed_cb().
  ///
  /// @see bt_adapter_le_stop_advertising()
  /// @see bt_adapter_le_advertising_state_changed_cb()
  int bt_adapter_le_start_advertising(
    bt_advertiser_h advertiser,
    ffi.Pointer<bt_adapter_le_advertising_params_s> adv_params,
    bt_adapter_le_advertising_state_changed_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_adapter_le_start_advertising(
      advertiser,
      adv_params,
      cb,
      user_data,
    );
  }

  late final _bt_adapter_le_start_advertisingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_advertiser_h,
              ffi.Pointer<bt_adapter_le_advertising_params_s>,
              bt_adapter_le_advertising_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_adapter_le_start_advertising');
  late final _bt_adapter_le_start_advertising =
      _bt_adapter_le_start_advertisingPtr.asFunction<
          int Function(
              bt_advertiser_h,
              ffi.Pointer<bt_adapter_le_advertising_params_s>,
              bt_adapter_le_advertising_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Stops the advertising.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] advertiser The handle of advertiser
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOT_IN_PROGRESS  Operation is not in progress
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The advertising must be going on with bt_adapter_le_start_advertising_new().
  /// @post This function invokes bt_adapter_le_advertising_state_changed_cb().
  ///
  /// @see bt_adapter_le_start_advertising_new()
  /// @see bt_adapter_le_advertising_state_changed_cb()
  int bt_adapter_le_stop_advertising(
    bt_advertiser_h advertiser,
  ) {
    return _bt_adapter_le_stop_advertising(
      advertiser,
    );
  }

  late final _bt_adapter_le_stop_advertisingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_advertiser_h)>>(
          'bt_adapter_le_stop_advertising');
  late final _bt_adapter_le_stop_advertising =
      _bt_adapter_le_stop_advertisingPtr
          .asFunction<int Function(bt_advertiser_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Start advertising with passed advertiser and advertising parameters.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @details Once Bluetooth advertising is started, nearby Bluetooth LE(Low Energy) supported
  /// devices can know this device's existence. And one of them can make a connection request,
  /// if it is allowed.
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] cb The callback to report the result of this function
  /// @param[in] user_data The user data to be passed when callback is called
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation is now in progress
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post This function invokes bt_adapter_le_advertising_state_changed_cb().
  ///
  /// @see bt_adapter_le_stop_advertising()
  /// @see bt_adapter_le_advertising_state_changed_cb()
  int bt_adapter_le_start_advertising_new(
    bt_advertiser_h advertiser,
    bt_adapter_le_advertising_state_changed_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_adapter_le_start_advertising_new(
      advertiser,
      cb,
      user_data,
    );
  }

  late final _bt_adapter_le_start_advertising_newPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_advertiser_h,
              bt_adapter_le_advertising_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_adapter_le_start_advertising_new');
  late final _bt_adapter_le_start_advertising_new =
      _bt_adapter_le_start_advertising_newPtr.asFunction<
          int Function(
              bt_advertiser_h,
              bt_adapter_le_advertising_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Set advertising mode to control the advertising power and latency.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] mode The mode of advertising
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation is now in progress
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_start_advertising_new()
  int bt_adapter_le_set_advertising_mode(
    bt_advertiser_h advertiser,
    int mode,
  ) {
    return _bt_adapter_le_set_advertising_mode(
      advertiser,
      mode,
    );
  }

  late final _bt_adapter_le_set_advertising_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_advertiser_h, ffi.Int32)>>(
          'bt_adapter_le_set_advertising_mode');
  late final _bt_adapter_le_set_advertising_mode =
      _bt_adapter_le_set_advertising_modePtr
          .asFunction<int Function(bt_advertiser_h, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Set whether the advertising type should be connectable or non-connectable
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] advertiser The handle of advertiser
  /// @param[in] connectable The type of advertising
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation is now in progress
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_start_advertising_new()
  int bt_adapter_le_set_advertising_connectable(
    bt_advertiser_h advertiser,
    bool connectable,
  ) {
    return _bt_adapter_le_set_advertising_connectable(
      advertiser,
      connectable,
    );
  }

  late final _bt_adapter_le_set_advertising_connectablePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_advertiser_h, ffi.Bool)>>(
          'bt_adapter_le_set_advertising_connectable');
  late final _bt_adapter_le_set_advertising_connectable =
      _bt_adapter_le_set_advertising_connectablePtr
          .asFunction<int Function(bt_advertiser_h, bool)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets Bluetooth LE scan mode
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] scan_mode The scan mode
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_NOT_ENABLED Adapter is not enabled
  /// @retval #BT_ERROR_INVALID_PARAMETER Parameter is invalid
  /// @retval #BT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state of local bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  int bt_adapter_le_set_scan_mode(
    int scan_mode,
  ) {
    return _bt_adapter_le_set_scan_mode(
      scan_mode,
    );
  }

  late final _bt_adapter_le_set_scan_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_adapter_le_set_scan_mode');
  late final _bt_adapter_le_set_scan_mode =
      _bt_adapter_le_set_scan_modePtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief Creates a bond with a remote Bluetooth device, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks A bond can be destroyed by bt_device_destroy_bond().\n
  /// The bonding request can be cancelled by bt_device_cancel_bonding().
  ///
  /// @param[in] remote_address The address of the remote Bluetooth device with which the bond should be created
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_RESOURCE_BUSY  Device or resource busy
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The remote device must be discoverable with bt_adapter_start_device_discovery().
  /// @post This function invokes bt_device_bond_created_cb().
  ///
  /// @see bt_adapter_start_device_discovery()
  /// @see bt_device_bond_created_cb()
  /// @see bt_device_cancel_bonding()
  /// @see bt_device_destroy_bond()
  /// @see bt_device_set_bond_created_cb()
  /// @see bt_device_unset_bond_created_cb()
  int bt_device_create_bond(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_device_create_bond(
      remote_address,
    );
  }

  late final _bt_device_create_bondPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_device_create_bond');
  late final _bt_device_create_bond = _bt_device_create_bondPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief Cancels the bonding process.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks Use this function when the remote Bluetooth device is not responding to the
  /// bond request or you wish to cancel the bonding request.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOT_IN_PROGRESS  Operation not in progress
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The creating a bond must be in progress by bt_device_create_bond().
  ///
  /// @see bt_device_create_bond()
  /// @see bt_device_bond_created_cb()
  /// @see bt_device_set_bond_created_cb()
  /// @see bt_device_unset_bond_created_cb()
  int bt_device_cancel_bonding() {
    return _bt_device_cancel_bonding();
  }

  late final _bt_device_cancel_bondingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_device_cancel_bonding');
  late final _bt_device_cancel_bonding =
      _bt_device_cancel_bondingPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief Destroys the bond, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] remote_address The address of the remote Bluetooth device to remove bonding
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_RESOURCE_BUSY  Device or resource busy
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_BONDED  Remote device not bonded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The bond with the remote device must be created with bt_device_create_bond().
  /// @post This function invokes bt_device_bond_destroyed_cb().
  ///
  /// @see bt_device_create_bond()
  /// @see bt_device_bond_destroyed_cb()
  /// @see bt_device_set_bond_destroyed_cb()
  /// @see bt_device_unset_bond_destroyed_cb()
  int bt_device_destroy_bond(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_device_destroy_bond(
      remote_address,
    );
  }

  late final _bt_device_destroy_bondPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_device_destroy_bond');
  late final _bt_device_destroy_bond = _bt_device_destroy_bondPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief Sets an alias for the bonded device.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] remote_address The address of the remote Bluetooth device
  /// @param[in] alias The alias of the remote Bluetooth device
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_BONDED  Remote device not bonded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The bond with the remote device must be created with bt_device_create_bond().
  ///
  /// @see bt_device_create_bond()
  int bt_device_set_alias(
    ffi.Pointer<ffi.Char> remote_address,
    ffi.Pointer<ffi.Char> alias,
  ) {
    return _bt_device_set_alias(
      remote_address,
      alias,
    );
  }

  late final _bt_device_set_aliasPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('bt_device_set_alias');
  late final _bt_device_set_alias = _bt_device_set_aliasPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief Sets the authorization of a bonded device, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks Once a device is authorized, you don't need to receive a confirmation.
  ///
  /// @param[in] remote_address The address of the remote Bluetooth device to authorize
  /// @param[in] authorization_state The Bluetooth authorization state
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_BONDED  Remote device not bonded
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The bond with the remote device must be created with bt_device_create_bond().
  /// @post bt_device_authorization_changed_cb() will be invoked.
  ///
  /// @see bt_device_create_bond()
  /// @see bt_device_authorization_changed_cb()
  /// @see bt_device_set_authorization_changed_cb()
  /// @see bt_device_unset_authorization_changed_cb()
  int bt_device_set_authorization(
    ffi.Pointer<ffi.Char> remote_address,
    int authorization_state,
  ) {
    return _bt_device_set_authorization(
      remote_address,
      authorization_state,
    );
  }

  late final _bt_device_set_authorizationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Int32)>>('bt_device_set_authorization');
  late final _bt_device_set_authorization = _bt_device_set_authorizationPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief Starts the search for services supported by the specified device, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks If creating a bond succeeds, which means bt_device_bond_created_cb() is called with result #BT_ERROR_NONE,
  /// then you don't need to run this function.\n
  /// The service search takes a couple of seconds to complete normally. \n
  ///
  /// @param[in] remote_address The address of the remote Bluetooth device whose services need to be checked
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_BONDED  Remote device not bonded
  /// @retval #BT_ERROR_SERVICE_SEARCH_FAILED  Service search failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The remote device must be discoverable with bt_adapter_start_device_discovery().
  /// @pre The bond with the remote device must be created with bt_device_create_bond().
  /// @post This function invokes bt_device_service_searched_cb().
  ///
  /// @see bt_adapter_start_device_discovery()
  /// @see bt_device_create_bond()
  /// @see bt_device_bond_created_cb()
  /// @see bt_device_service_searched_cb()
  /// @see bt_device_set_service_searched_cb()
  /// @see bt_device_unset_service_searched_cb()
  int bt_device_start_service_search(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_device_start_service_search(
      remote_address,
    );
  }

  late final _bt_device_start_service_searchPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_device_start_service_search');
  late final _bt_device_start_service_search =
      _bt_device_start_service_searchPtr
          .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief Gets the connected profiles.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] remote_address The address of the remote device
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post bt_device_connected_profile() will be invoked.
  /// @see bt_device_connected_profile()
  int bt_device_foreach_connected_profiles(
    ffi.Pointer<ffi.Char> remote_address,
    bt_device_connected_profile callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_device_foreach_connected_profiles(
      remote_address,
      callback,
      user_data,
    );
  }

  late final _bt_device_foreach_connected_profilesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, bt_device_connected_profile,
              ffi.Pointer<ffi.Void>)>>('bt_device_foreach_connected_profiles');
  late final _bt_device_foreach_connected_profiles =
      _bt_device_foreach_connected_profilesPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, bt_device_connected_profile,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief Gets the profile connected status.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] remote_address The address of the remote device
  /// @param[in] bt_profile wish to know bt_profile
  /// @param[out] connected_status the connected status
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_BONDED	Remote device not bonded
  /// @retval #BT_ERROR_OPERATION_FAILED	Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  int bt_device_is_profile_connected(
    ffi.Pointer<ffi.Char> remote_address,
    int bt_profile,
    ffi.Pointer<ffi.Bool> connected_status,
  ) {
    return _bt_device_is_profile_connected(
      remote_address,
      bt_profile,
      connected_status,
    );
  }

  late final _bt_device_is_profile_connectedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int32,
              ffi.Pointer<ffi.Bool>)>>('bt_device_is_profile_connected');
  late final _bt_device_is_profile_connected =
      _bt_device_is_profile_connectedPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, ffi.Pointer<ffi.Bool>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief Updates a LE connection mode
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] remote_address The address of the remote Bluetooth device
  /// @param[in] mode The LE connection mode
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_device_update_le_connection_mode(
    ffi.Pointer<ffi.Char> remote_address,
    int mode,
  ) {
    return _bt_device_update_le_connection_mode(
      remote_address,
      mode,
    );
  }

  late final _bt_device_update_le_connection_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Int32)>>('bt_device_update_le_connection_mode');
  late final _bt_device_update_le_connection_mode =
      _bt_device_update_le_connection_modePtr
          .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief  Registers a callback function to be invoked when the bond creates.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post  bt_device_bond_created_cb() will be invoked.
  /// @see bt_initialize()
  /// @see bt_device_bond_created_cb()
  /// @see bt_device_unset_bond_created_cb()
  int bt_device_set_bond_created_cb(
    bt_device_bond_created_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_device_set_bond_created_cb(
      callback,
      user_data,
    );
  }

  late final _bt_device_set_bond_created_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_device_bond_created_cb,
              ffi.Pointer<ffi.Void>)>>('bt_device_set_bond_created_cb');
  late final _bt_device_set_bond_created_cb =
      _bt_device_set_bond_created_cbPtr.asFunction<
          int Function(bt_device_bond_created_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief	Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_device_set_bond_created_cb()
  int bt_device_unset_bond_created_cb() {
    return _bt_device_unset_bond_created_cb();
  }

  late final _bt_device_unset_bond_created_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_device_unset_bond_created_cb');
  late final _bt_device_unset_bond_created_cb =
      _bt_device_unset_bond_created_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief  Registers a callback function to be invoked when the bond destroys.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post  bt_device_bond_destroyed_cb() will be invoked.
  /// @see bt_initialize()
  /// @see bt_device_bond_destroyed_cb()
  /// @see bt_device_unset_bond_destroyed_cb()
  int bt_device_set_bond_destroyed_cb(
    bt_device_bond_destroyed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_device_set_bond_destroyed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_device_set_bond_destroyed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_device_bond_destroyed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_device_set_bond_destroyed_cb');
  late final _bt_device_set_bond_destroyed_cb =
      _bt_device_set_bond_destroyed_cbPtr.asFunction<
          int Function(bt_device_bond_destroyed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief	Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_device_set_bond_destroyed_cb()
  int bt_device_unset_bond_destroyed_cb() {
    return _bt_device_unset_bond_destroyed_cb();
  }

  late final _bt_device_unset_bond_destroyed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_device_unset_bond_destroyed_cb');
  late final _bt_device_unset_bond_destroyed_cb =
      _bt_device_unset_bond_destroyed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief  Registers a callback function to be invoked when the authorization of device changes.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post  bt_device_authorization_changed_cb() will be invoked.
  /// @see bt_initialize()
  /// @see bt_device_authorization_changed_cb()
  /// @see bt_device_set_authorization_changed_cb()
  /// @see bt_device_unset_authorization_changed_cb()
  int bt_device_set_authorization_changed_cb(
    bt_device_authorization_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_device_set_authorization_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_device_set_authorization_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_device_authorization_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'bt_device_set_authorization_changed_cb');
  late final _bt_device_set_authorization_changed_cb =
      _bt_device_set_authorization_changed_cbPtr.asFunction<
          int Function(
              bt_device_authorization_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief	Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_device_set_authorization_changed_cb()
  int bt_device_unset_authorization_changed_cb() {
    return _bt_device_unset_authorization_changed_cb();
  }

  late final _bt_device_unset_authorization_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_device_unset_authorization_changed_cb');
  late final _bt_device_unset_authorization_changed_cb =
      _bt_device_unset_authorization_changed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief  Registers a callback function to be invoked when the process of service search finishes.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post  bt_device_service_searched_cb() will be invoked.
  /// @see bt_initialize()
  /// @see bt_device_service_searched_cb()
  /// @see bt_device_unset_service_searched_cb()
  int bt_device_set_service_searched_cb(
    bt_device_service_searched_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_device_set_service_searched_cb(
      callback,
      user_data,
    );
  }

  late final _bt_device_set_service_searched_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_device_service_searched_cb,
              ffi.Pointer<ffi.Void>)>>('bt_device_set_service_searched_cb');
  late final _bt_device_set_service_searched_cb =
      _bt_device_set_service_searched_cbPtr.asFunction<
          int Function(bt_device_service_searched_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief	Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_device_set_service_searched_cb()
  int bt_device_unset_service_searched_cb() {
    return _bt_device_unset_service_searched_cb();
  }

  late final _bt_device_unset_service_searched_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_device_unset_service_searched_cb');
  late final _bt_device_unset_service_searched_cb =
      _bt_device_unset_service_searched_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief  Registers a callback function to be invoked when the connection state is changed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post bt_device_connection_state_changed_cb() will be invoked.
  /// @see bt_initialize()
  /// @see bt_device_connection_state_changed_cb()
  /// @see bt_device_unset_connection_state_changed_cb()
  int bt_device_set_connection_state_changed_cb(
    bt_device_connection_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_device_set_connection_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_device_set_connection_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_device_connection_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_device_set_connection_state_changed_cb');
  late final _bt_device_set_connection_state_changed_cb =
      _bt_device_set_connection_state_changed_cbPtr.asFunction<
          int Function(
              bt_device_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
  /// @brief	Unregisters the callback function to be invoked when the connection state is changed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_device_set_connection_state_changed_cb()
  int bt_device_unset_connection_state_changed_cb() {
    return _bt_device_unset_connection_state_changed_cb();
  }

  late final _bt_device_unset_connection_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_device_unset_connection_state_changed_cb');
  late final _bt_device_unset_connection_state_changed_cb =
      _bt_device_unset_connection_state_changed_cbPtr
          .asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief Registers a rfcomm server socket with a specific UUID.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks A socket can be destroyed by bt_socket_destroy_rfcomm().
  ///
  /// @param[in] service_uuid The UUID of service to provide
  /// @param[out] socket_fd The file descriptor of socket to listen
  /// @return 0 on success, otherwise a negative error value.
  ///
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  ///
  /// @see bt_socket_listen_and_accept_rfcomm()
  /// @see bt_socket_destroy_rfcomm()
  int bt_socket_create_rfcomm(
    ffi.Pointer<ffi.Char> service_uuid,
    ffi.Pointer<ffi.Int> socket_fd,
  ) {
    return _bt_socket_create_rfcomm(
      service_uuid,
      socket_fd,
    );
  }

  late final _bt_socket_create_rfcommPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('bt_socket_create_rfcomm');
  late final _bt_socket_create_rfcomm = _bt_socket_create_rfcommPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief Removes the rfcomm server socket which was created using bt_socket_create_rfcomm().
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @remarks If callback function bt_socket_connection_state_changed_cb() is set and the remote Bluetooth device is connected,
  /// then bt_socket_connection_state_changed_cb() will be called when this function is finished successfully.
  ///
  /// @param[in] socket_fd The file descriptor of socket (which was created using bt_socket_create_rfcomm()) to destroy
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The socket must be created with bt_socket_create_rfcomm().
  /// @post If callback function bt_socket_connection_state_changed_cb() is set and the remote Bluetooth device is connected,
  /// then bt_socket_connection_state_changed_cb() will be called.
  /// @see bt_socket_create_rfcomm()
  /// @see bt_socket_connection_state_changed_cb()
  /// @see bt_socket_set_connection_state_changed_cb()
  /// @see bt_socket_unset_connection_state_changed_cb()
  int bt_socket_destroy_rfcomm(
    int socket_fd,
  ) {
    return _bt_socket_destroy_rfcomm(
      socket_fd,
    );
  }

  late final _bt_socket_destroy_rfcommPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'bt_socket_destroy_rfcomm');
  late final _bt_socket_destroy_rfcomm =
      _bt_socket_destroy_rfcommPtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief Starts listening on passed rfcomm socket and accepts connection requests.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @details Pop-up is shown automatically when a RFCOMM connection is requested.
  /// bt_socket_connection_state_changed_cb() will be called with
  /// #BT_SOCKET_CONNECTED if you click "yes" and connection is finished successfully.
  /// @param[in] socket_fd The file descriptor of socket on which start to listen
  /// @param[in] max_pending_connections The maximum number of pending connections
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The socket must be created with bt_socket_create_rfcomm().
  /// @post If callback function bt_socket_connection_state_changed_cb() is set,
  /// then bt_socket_connection_state_changed_cb() will be called when the remote Bluetooth device is connected.
  /// @see bt_socket_create_rfcomm()
  /// @see bt_socket_connection_state_changed_cb()
  /// @see bt_socket_set_connection_state_changed_cb()
  /// @see bt_socket_unset_connection_state_changed_cb()
  int bt_socket_listen_and_accept_rfcomm(
    int socket_fd,
    int max_pending_connections,
  ) {
    return _bt_socket_listen_and_accept_rfcomm(
      socket_fd,
      max_pending_connections,
    );
  }

  late final _bt_socket_listen_and_accept_rfcommPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'bt_socket_listen_and_accept_rfcomm');
  late final _bt_socket_listen_and_accept_rfcomm =
      _bt_socket_listen_and_accept_rfcommPtr
          .asFunction<int Function(int, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief Connects to a specific RFCOMM based service on a remote Bluetooth device UUID, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks A connection can be disconnected by bt_socket_disconnect_rfcomm().
  ///
  /// @param[in] remote_address The address of the remote Bluetooth device
  /// @param[in] service_uuid The UUID of service provided by the remote Bluetooth device
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @pre The remote device must be discoverable with bt_adapter_start_device_discovery().
  /// @pre The bond with the remote device must be created with bt_device_create_bond().
  /// @post This function invokes bt_socket_connection_state_changed_cb().
  ///
  /// @see bt_device_create_bond()
  /// @see bt_adapter_start_device_discovery()
  /// @see bt_device_start_service_search()
  /// @see bt_socket_disconnect_rfcomm()
  /// @see bt_socket_connection_state_changed_cb()
  /// @see bt_socket_set_connection_state_changed_cb()
  /// @see bt_socket_unset_connection_state_changed_cb()
  int bt_socket_connect_rfcomm(
    ffi.Pointer<ffi.Char> remote_address,
    ffi.Pointer<ffi.Char> service_uuid,
  ) {
    return _bt_socket_connect_rfcomm(
      remote_address,
      service_uuid,
    );
  }

  late final _bt_socket_connect_rfcommPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('bt_socket_connect_rfcomm');
  late final _bt_socket_connect_rfcomm = _bt_socket_connect_rfcommPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief Disconnects the RFCOMM connection with the given file descriptor of connected socket.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] socket_fd  The file descriptor of socket to close which was received using bt_socket_connection_state_changed_cb().
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The connection must be established.
  ///
  /// @see bt_socket_connection_state_changed_cb()
  /// @see bt_socket_set_connection_state_changed_cb()
  /// @see bt_socket_unset_connection_state_changed_cb()
  int bt_socket_disconnect_rfcomm(
    int socket_fd,
  ) {
    return _bt_socket_disconnect_rfcomm(
      socket_fd,
    );
  }

  late final _bt_socket_disconnect_rfcommPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'bt_socket_disconnect_rfcomm');
  late final _bt_socket_disconnect_rfcomm =
      _bt_socket_disconnect_rfcommPtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief Sends data to the connected device.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @remark The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  ///
  /// @param[in] socket_fd The file descriptor of connected socket which was received using bt_socket_connection_state_changed_cb()
  /// @param[in] data The data to be sent
  /// @param[in] length The length of data to be sent
  ///
  /// @return the number of bytes written (zero indicates nothing was written).
  /// @retval On error, -1 is returned, and errno is set appropriately. See write 2 man page.
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  /// @exception BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @exception BT_ERROR_AGAIN  Resource temporarily unavailable
  ///
  /// @pre The connection must be established.
  ///
  /// @see bt_socket_connection_state_changed_cb()
  /// @see bt_socket_set_connection_state_changed_cb()
  /// @see bt_socket_unset_connection_state_changed_cb()
  int bt_socket_send_data(
    int socket_fd,
    ffi.Pointer<ffi.Char> data,
    int length,
  ) {
    return _bt_socket_send_data(
      socket_fd,
      data,
      length,
    );
  }

  late final _bt_socket_send_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<ffi.Char>, ffi.Int)>>('bt_socket_send_data');
  late final _bt_socket_send_data = _bt_socket_send_dataPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief  Register a callback function that will be invoked when you receive data.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post  bt_socket_data_received_cb() will be invoked.
  /// @see bt_initialize()
  /// @see bt_socket_data_received_cb()
  /// @see bt_socket_set_data_received_cb()
  /// @see bt_socket_unset_data_received_cb()
  int bt_socket_set_data_received_cb(
    bt_socket_data_received_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_socket_set_data_received_cb(
      callback,
      user_data,
    );
  }

  late final _bt_socket_set_data_received_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_socket_data_received_cb,
              ffi.Pointer<ffi.Void>)>>('bt_socket_set_data_received_cb');
  late final _bt_socket_set_data_received_cb =
      _bt_socket_set_data_received_cbPtr.asFunction<
          int Function(bt_socket_data_received_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief	Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_socket_data_received_cb()
  /// @see bt_socket_set_data_received_cb()
  int bt_socket_unset_data_received_cb() {
    return _bt_socket_unset_data_received_cb();
  }

  late final _bt_socket_unset_data_received_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_socket_unset_data_received_cb');
  late final _bt_socket_unset_data_received_cb =
      _bt_socket_unset_data_received_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief  Register a callback function that will be invoked when a RFCOMM connection is requested.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post bt_socket_connection_requested_cb() will be invoked.
  /// @see bt_initialize()
  /// @see bt_socket_unset_connection_requested_cb()
  int bt_socket_set_connection_requested_cb(
    bt_socket_connection_requested_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_socket_set_connection_requested_cb(
      callback,
      user_data,
    );
  }

  late final _bt_socket_set_connection_requested_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_socket_connection_requested_cb,
              ffi.Pointer<ffi.Void>)>>('bt_socket_set_connection_requested_cb');
  late final _bt_socket_set_connection_requested_cb =
      _bt_socket_set_connection_requested_cbPtr.asFunction<
          int Function(
              bt_socket_connection_requested_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup  CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief  Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre  The Bluetooth service must be initialized with bt_initialize().
  /// @see  bt_initialize()
  /// @see  bt_socket_set_connection_requested_cb()
  /// @see  bt_socket_connection_requested_cb()
  int bt_socket_unset_connection_requested_cb() {
    return _bt_socket_unset_connection_requested_cb();
  }

  late final _bt_socket_unset_connection_requested_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_socket_unset_connection_requested_cb');
  late final _bt_socket_unset_connection_requested_cb =
      _bt_socket_unset_connection_requested_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief  Register a callback function that will be invoked when the connection state changes.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post bt_socket_connection_state_changed_cb() will be invoked.
  /// @see bt_initialize()
  /// @see bt_socket_connection_state_changed_cb()
  /// @see bt_socket_unset_connection_state_changed_cb()
  int bt_socket_set_connection_state_changed_cb(
    bt_socket_connection_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_socket_set_connection_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_socket_set_connection_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_socket_connection_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_socket_set_connection_state_changed_cb');
  late final _bt_socket_set_connection_state_changed_cb =
      _bt_socket_set_connection_state_changed_cbPtr.asFunction<
          int Function(
              bt_socket_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
  /// @brief	Unregisters the callback function.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_socket_connection_state_changed_cb()
  /// @see bt_socket_set_connection_state_changed_cb()
  int bt_socket_unset_connection_state_changed_cb() {
    return _bt_socket_unset_connection_state_changed_cb();
  }

  late final _bt_socket_unset_connection_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_socket_unset_connection_state_changed_cb');
  late final _bt_socket_unset_connection_state_changed_cb =
      _bt_socket_unset_connection_state_changed_cbPtr
          .asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_SERVER_MODULE
  /// @brief Initializes the Bluetooth OPP server requested by bt_opp_server_connection_requested_cb().
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @details No popup appears when an OPP connection is requested from a remote device.
  /// Instead, @a connection_requested_cb() will be called.
  /// At that time, you can call either bt_opp_server_accept() or bt_opp_server_reject().
  /// @remarks This function must be called to start Bluetooth OPP server. \n
  /// You must free all resources of the Bluetooth service by calling bt_opp_server_deinitialize() if Bluetooth OPP service is no longer needed.
  /// @param[in] destination  The destination path
  /// @param[in] connection_requested_cb  The callback called when an OPP connection is requested
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_RESOURCE_BUSY  Device or resource busy
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see  bt_opp_server_connection_requested_cb()
  /// @see  bt_opp_server_deinitialize()
  /// @see  bt_opp_server_accept()
  /// @see  bt_opp_server_reject()
  int bt_opp_server_initialize_by_connection_request(
    ffi.Pointer<ffi.Char> destination,
    bt_opp_server_connection_requested_cb connection_requested_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_opp_server_initialize_by_connection_request(
      destination,
      connection_requested_cb,
      user_data,
    );
  }

  late final _bt_opp_server_initialize_by_connection_requestPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>,
                  bt_opp_server_connection_requested_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_opp_server_initialize_by_connection_request');
  late final _bt_opp_server_initialize_by_connection_request =
      _bt_opp_server_initialize_by_connection_requestPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>,
              bt_opp_server_connection_requested_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_SERVER_MODULE
  /// @brief Deinitializes the Bluetooth OPP server.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see  bt_opp_server_deinitialize()
  int bt_opp_server_deinitialize() {
    return _bt_opp_server_deinitialize();
  }

  late final _bt_opp_server_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_opp_server_deinitialize');
  late final _bt_opp_server_deinitialize =
      _bt_opp_server_deinitializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_SERVER_MODULE
  /// @brief Accepts the push request from the remote device.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @remarks If you initialize OPP server by bt_opp_server_initialize_by_connection_request(), then name is ignored.
  /// You can cancel the pushes by bt_opp_server_cancel_transfer() with transfer_id.
  /// @param[in] progress_cb  The callback called when a file is being transferred
  /// @param[in] finished_cb  The callback called when a transfer is finished
  /// @param[in] name  The name to store. This can be NULL if you initialize OPP server by bt_opp_server_initialize_by_connection_request().
  /// @param[in] user_data The user data to be passed to the callback function
  /// @param[out]  transfer_id  The ID of transfer
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation now in progress
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see  bt_opp_server_reject()
  int bt_opp_server_accept(
    bt_opp_server_transfer_progress_cb progress_cb,
    bt_opp_server_transfer_finished_cb finished_cb,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> transfer_id,
  ) {
    return _bt_opp_server_accept(
      progress_cb,
      finished_cb,
      name,
      user_data,
      transfer_id,
    );
  }

  late final _bt_opp_server_acceptPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_opp_server_transfer_progress_cb,
              bt_opp_server_transfer_finished_cb,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('bt_opp_server_accept');
  late final _bt_opp_server_accept = _bt_opp_server_acceptPtr.asFunction<
      int Function(
          bt_opp_server_transfer_progress_cb,
          bt_opp_server_transfer_finished_cb,
          ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Void>,
          ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_SERVER_MODULE
  /// @brief Rejects the push request from the remote device.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see  bt_opp_server_accept()
  int bt_opp_server_reject() {
    return _bt_opp_server_reject();
  }

  late final _bt_opp_server_rejectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('bt_opp_server_reject');
  late final _bt_opp_server_reject =
      _bt_opp_server_rejectPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_SERVER_MODULE
  /// @brief Cancels the transfer.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] transfer_id  The ID of transfer
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see  bt_opp_server_accept()
  int bt_opp_server_cancel_transfer(
    int transfer_id,
  ) {
    return _bt_opp_server_cancel_transfer(
      transfer_id,
    );
  }

  late final _bt_opp_server_cancel_transferPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'bt_opp_server_cancel_transfer');
  late final _bt_opp_server_cancel_transfer =
      _bt_opp_server_cancel_transferPtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_SERVER_MODULE
  /// @brief Sets the destination path of file to be pushed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] destination  The destination path of file to be pushed
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  int bt_opp_server_set_destination(
    ffi.Pointer<ffi.Char> destination,
  ) {
    return _bt_opp_server_set_destination(
      destination,
    );
  }

  late final _bt_opp_server_set_destinationPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_opp_server_set_destination');
  late final _bt_opp_server_set_destination = _bt_opp_server_set_destinationPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_CLIENT_MODULE
  /// @brief Initializes the Bluetooth OPP client.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks This function must be called before Bluetooth OPP client starts. \n
  /// You must free all resources of the Bluetooth service by calling bt_opp_client_deinitialize()
  /// if Bluetooth OPP service is no longer needed.
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_RESOURCE_BUSY  Device or resource busy
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see  bt_opp_client_deinitialize()
  int bt_opp_client_initialize() {
    return _bt_opp_client_initialize();
  }

  late final _bt_opp_client_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_opp_client_initialize');
  late final _bt_opp_client_initialize =
      _bt_opp_client_initializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_CLIENT_MODULE
  /// @brief Deinitializes the Bluetooth OPP client.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see  bt_opp_client_initialize()
  int bt_opp_client_deinitialize() {
    return _bt_opp_client_deinitialize();
  }

  late final _bt_opp_client_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_opp_client_deinitialize');
  late final _bt_opp_client_deinitialize =
      _bt_opp_client_deinitializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_CLIENT_MODULE
  /// @brief Adds file to be pushed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] file  The path of file to be pushed
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see  bt_opp_client_clear_files()
  /// @see  bt_opp_client_push_files()
  int bt_opp_client_add_file(
    ffi.Pointer<ffi.Char> file,
  ) {
    return _bt_opp_client_add_file(
      file,
    );
  }

  late final _bt_opp_client_add_filePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_opp_client_add_file');
  late final _bt_opp_client_add_file = _bt_opp_client_add_filePtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_CLIENT_MODULE
  /// @brief Adds file to be pushed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see  bt_opp_client_add_file()
  /// @see  bt_opp_client_push_files()
  int bt_opp_client_clear_files() {
    return _bt_opp_client_clear_files();
  }

  late final _bt_opp_client_clear_filesPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_opp_client_clear_files');
  late final _bt_opp_client_clear_files =
      _bt_opp_client_clear_filesPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_CLIENT_MODULE
  /// @brief Pushes the file to the remote device, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @details At first, bt_opp_client_push_responded_cb() will be called when OPP server responds to the push request.
  /// After connection is established, bt_opp_client_push_progress_cb() will be called repeatedly until a file is transferred completely.
  /// If you send several files, then bt_opp_client_push_progress_cb() with another file will be called repeatedly until the file is transferred completely.
  /// bt_opp_client_push_finished_cb() will be called when the push request is finished.
  /// @param[in] remote_address The remote address
  /// @param[in] responded_cb  The callback called when OPP server responds to the push request
  /// @param[in] progress_cb  The callback called when each file is being transferred
  /// @param[in] finished_cb  The callback called when the push request is finished
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation now in progress
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see bt_opp_client_initialize()
  /// @see bt_opp_client_cancel_push
  int bt_opp_client_push_files(
    ffi.Pointer<ffi.Char> remote_address,
    bt_opp_client_push_responded_cb responded_cb,
    bt_opp_client_push_progress_cb progress_cb,
    bt_opp_client_push_finished_cb finished_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_opp_client_push_files(
      remote_address,
      responded_cb,
      progress_cb,
      finished_cb,
      user_data,
    );
  }

  late final _bt_opp_client_push_filesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              bt_opp_client_push_responded_cb,
              bt_opp_client_push_progress_cb,
              bt_opp_client_push_finished_cb,
              ffi.Pointer<ffi.Void>)>>('bt_opp_client_push_files');
  late final _bt_opp_client_push_files =
      _bt_opp_client_push_filesPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              bt_opp_client_push_responded_cb,
              bt_opp_client_push_progress_cb,
              bt_opp_client_push_finished_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_CLIENT_MODULE
  /// @brief Cancels the push request in progress, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre bt_opp_client_push_files() must be called.
  /// @post bt_opp_client_push_finished_cb() will be invoked with result #BT_ERROR_CANCELLED,
  /// which is a parameter of bt_opp_client_push_files().
  /// @see bt_opp_client_initialize()
  /// @see bt_opp_client_push_files()
  int bt_opp_client_cancel_push() {
    return _bt_opp_client_cancel_push();
  }

  late final _bt_opp_client_cancel_pushPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_opp_client_cancel_push');
  late final _bt_opp_client_cancel_push =
      _bt_opp_client_cancel_pushPtr.asFunction<int Function()>();

  /// @ingroup @if WEARABLE CAPI_NETWORK_BLUETOOTH_HID_HOST_MODULE CAPI @else_NETWORK_BLUETOOTH_HID_MODULE @endif
  /// @brief Initializes the Bluetooth HID(Human Interface Device) Host.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks This function must be called before Bluetooth HID Host starts. \n
  /// You must free all resources of the Bluetooth service by calling bt_hid_host_deinitialize()
  /// if Bluetooth HID Host service is no longer needed.
  /// @param[in] connection_cb  The callback called when the connection state is changed
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see  bt_hid_host_deinitialize()
  int bt_hid_host_initialize(
    bt_hid_host_connection_state_changed_cb connection_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_hid_host_initialize(
      connection_cb,
      user_data,
    );
  }

  late final _bt_hid_host_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_hid_host_connection_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_hid_host_initialize');
  late final _bt_hid_host_initialize = _bt_hid_host_initializePtr.asFunction<
      int Function(
          bt_hid_host_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup @if WEARABLE CAPI_NETWORK_BLUETOOTH_HID_HOST_MODULE CAPI @else_NETWORK_BLUETOOTH_HID_MODULE @endif
  /// @brief Deinitializes the Bluetooth HID(Human Interface Device) Host.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth HID service must be initialized with bt_hid_host_initialize().
  /// @see  bt_hid_host_initialize()
  int bt_hid_host_deinitialize() {
    return _bt_hid_host_deinitialize();
  }

  late final _bt_hid_host_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_hid_host_deinitialize');
  late final _bt_hid_host_deinitialize =
      _bt_hid_host_deinitializePtr.asFunction<int Function()>();

  /// @ingroup @if WEARABLE CAPI_NETWORK_BLUETOOTH_HID_HOST_MODULE CAPI @else_NETWORK_BLUETOOTH_HID_MODULE @endif
  /// @brief Connects the remote device with the HID(Human Interface Device) service, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] remote_address  The remote address
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The local device must be bonded with the remote device by bt_device_create_bond().
  /// @pre The Bluetooth HID service must be initialized with bt_hid_host_initialize().
  /// @post bt_hid_host_connection_state_changed_cb() will be invoked.
  /// @see bt_hid_host_disconnect()
  /// @see bt_hid_host_connection_state_changed_cb()
  int bt_hid_host_connect(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_hid_host_connect(
      remote_address,
    );
  }

  late final _bt_hid_host_connectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_hid_host_connect');
  late final _bt_hid_host_connect =
      _bt_hid_host_connectPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup @if WEARABLE CAPI_NETWORK_BLUETOOTH_HID_HOST_MODULE CAPI @else_NETWORK_BLUETOOTH_HID_MODULE @endif
  /// @brief Disconnects the remote device with the HID(Human Interface Device) service, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] remote_address  The remote address
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The remote device must be connected by bt_hid_host_connect().
  /// @post bt_hid_host_connection_state_changed_cb() will be invoked.
  /// @see bt_hid_host_connect()
  /// @see bt_hid_host_connection_state_changed_cb()
  int bt_hid_host_disconnect(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_hid_host_disconnect(
      remote_address,
    );
  }

  late final _bt_hid_host_disconnectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_hid_host_disconnect');
  late final _bt_hid_host_disconnect = _bt_hid_host_disconnectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
  /// @brief Activates the Bluetooth HID Device role.
  /// @since_tizen @if WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks This function must be called to register HID UUID.
  /// Only then a remote device is able to identify this one as a HID device.
  ///
  /// @param[in] callback  The callback called when the connection state is changed
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Already activated
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_hid_device_deactivate()
  int bt_hid_device_activate(
    bt_hid_device_connection_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_hid_device_activate(
      callback,
      user_data,
    );
  }

  late final _bt_hid_device_activatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_hid_device_connection_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_hid_device_activate');
  late final _bt_hid_device_activate = _bt_hid_device_activatePtr.asFunction<
      int Function(
          bt_hid_device_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
  /// @brief Deactivates the Bluetooth HID Device role.
  /// @since_tizen @if WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks This function must be called to deregister the HID UUID.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOT_IN_PROGRESS  Not activated
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_hid_device_activate()
  int bt_hid_device_deactivate() {
    return _bt_hid_device_deactivate();
  }

  late final _bt_hid_device_deactivatePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_hid_device_deactivate');
  late final _bt_hid_device_deactivate =
      _bt_hid_device_deactivatePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
  /// @brief Initiates the HID device connection with the Device role, asynchronously.
  /// @since_tizen @if WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks This function must be called to Initiate the HID device role connection.
  ///
  /// @param[in] remote_address The remote device's address.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_NOT_IN_PROGRESS  Not activated
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_ALREADY_DONE   Already connected
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @pre The local device must be bonded with the remote device by bt_device_create_bond().
  /// @see bt_initialize()
  /// @see bt_hid_device_activate()
  int bt_hid_device_connect(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_hid_device_connect(
      remote_address,
    );
  }

  late final _bt_hid_device_connectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_hid_device_connect');
  late final _bt_hid_device_connect = _bt_hid_device_connectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
  /// @brief Disconnects from the HID Host device, asynchronously.
  /// @since_tizen @if WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] remote_address The remote device's address.
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_hid_device_connection_state_changed_cb()
  int bt_hid_device_disconnect(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_hid_device_disconnect(
      remote_address,
    );
  }

  late final _bt_hid_device_disconnectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_hid_device_disconnect');
  late final _bt_hid_device_disconnect = _bt_hid_device_disconnectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
  /// @brief Sends the mouse event data to the remote device.
  /// @since_tizen @if WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] remote_address The remote device's address.
  /// @param[in] mouse_data The mouse data to be passed to the remote device.
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The HID connection must be established.
  /// @see bt_hid_device_connection_state_changed_cb()
  int bt_hid_device_send_mouse_event(
    ffi.Pointer<ffi.Char> remote_address,
    ffi.Pointer<bt_hid_mouse_data_s> mouse_data,
  ) {
    return _bt_hid_device_send_mouse_event(
      remote_address,
      mouse_data,
    );
  }

  late final _bt_hid_device_send_mouse_eventPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<bt_hid_mouse_data_s>)>>(
      'bt_hid_device_send_mouse_event');
  late final _bt_hid_device_send_mouse_event =
      _bt_hid_device_send_mouse_eventPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<bt_hid_mouse_data_s>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
  /// @brief Sends the keyboard event data to the remote device.
  /// @since_tizen @if WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] remote_address The remote device's address.
  /// @param[in] key_data The key data to be passed to the remote device
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The HID connection must be established.
  /// @see bt_hid_device_connection_state_changed_cb()
  int bt_hid_device_send_key_event(
    ffi.Pointer<ffi.Char> remote_address,
    ffi.Pointer<bt_hid_key_data_s> key_data,
  ) {
    return _bt_hid_device_send_key_event(
      remote_address,
      key_data,
    );
  }

  late final _bt_hid_device_send_key_eventPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<bt_hid_key_data_s>)>>('bt_hid_device_send_key_event');
  late final _bt_hid_device_send_key_event =
      _bt_hid_device_send_key_eventPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<bt_hid_key_data_s>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
  /// @brief Sets the callback called when the device receives data from the HID Host.
  /// @since_tizen @if WEARABLE 3.0 @endif
  ///
  /// @param[in] callback The callback function to be set when data is received.
  /// @param[in] user_data The user data to be passed to the callback.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see bt_hid_device_connection_state_changed_cb()
  int bt_hid_device_set_data_received_cb(
    bt_hid_device_data_received_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_hid_device_set_data_received_cb(
      callback,
      user_data,
    );
  }

  late final _bt_hid_device_set_data_received_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_hid_device_data_received_cb,
              ffi.Pointer<ffi.Void>)>>('bt_hid_device_set_data_received_cb');
  late final _bt_hid_device_set_data_received_cb =
      _bt_hid_device_set_data_received_cbPtr.asFunction<
          int Function(
              bt_hid_device_data_received_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
  /// @brief Unsets the data received callback.
  /// @since_tizen @if WEARABLE 3.0 @endif
  ///
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @see bt_hid_device_connection_state_changed_cb()
  int bt_hid_device_unset_data_received_cb() {
    return _bt_hid_device_unset_data_received_cb();
  }

  late final _bt_hid_device_unset_data_received_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_hid_device_unset_data_received_cb');
  late final _bt_hid_device_unset_data_received_cb =
      _bt_hid_device_unset_data_received_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
  /// @brief Responds to reports from the HID Host.
  /// @since_tizen @if WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] remote_address The remote device's address.
  /// @param[in] header_type The response header type
  /// @param[in] param_type The response parameter type
  /// @param[in] data The response data
  /// @param[in] data_len The length of the response data
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The HID connection must be established.
  /// @see bt_hid_device_connection_state_changed_cb()
  int bt_hid_device_reply_to_report(
    ffi.Pointer<ffi.Char> remote_address,
    int header_type,
    int param_type,
    ffi.Pointer<ffi.Char> data,
    int data_len,
  ) {
    return _bt_hid_device_reply_to_report(
      remote_address,
      header_type,
      param_type,
      data,
      data_len,
    );
  }

  late final _bt_hid_device_reply_to_reportPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.UnsignedInt)>>('bt_hid_device_reply_to_report');
  late final _bt_hid_device_reply_to_report =
      _bt_hid_device_reply_to_reportPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, int, int, ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AUDIO_MODULE
  /// @brief Initializes the Bluetooth profiles related with audio.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @remarks This function must be called before Bluetooth profiles related with audio starts. \n
  /// You must free all resources of the this service by calling bt_audio_deinitialize()
  /// if Bluetooth profiles related with audio service is no longer needed.
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_audio_deinitialize()
  int bt_audio_initialize() {
    return _bt_audio_initialize();
  }

  late final _bt_audio_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('bt_audio_initialize');
  late final _bt_audio_initialize =
      _bt_audio_initializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AUDIO_MODULE
  /// @brief Deinitializes the Bluetooth profiles related with audio.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED   Not supported
  ///
  /// @pre The Bluetooth audio service must be initialized with bt_audio_initialize().
  /// @see bt_audio_initialize()
  int bt_audio_deinitialize() {
    return _bt_audio_deinitialize();
  }

  late final _bt_audio_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('bt_audio_deinitialize');
  late final _bt_audio_deinitialize =
      _bt_audio_deinitializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AUDIO_MODULE
  /// @brief Connects the remote device with the given audio profile, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @details If you input type as #BT_AUDIO_PROFILE_TYPE_ALL and connection request succeeds, then bt_audio_connection_state_changed_cb() will be called twice
  /// when #BT_AUDIO_PROFILE_TYPE_HSP_HFP is connected and #BT_AUDIO_PROFILE_TYPE_A2DP is connected.
  /// @param[in] remote_address  The remote address
  /// @param[in] type  The type of audio profile
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth audio service must be initialized with bt_audio_initialize().
  /// @pre The local device must be bonded with the remote device by bt_device_create_bond().
  /// @post bt_audio_connection_state_changed_cb() will be invoked.
  /// @see bt_audio_disconnect()
  /// @see bt_audio_connection_state_changed_cb()
  int bt_audio_connect(
    ffi.Pointer<ffi.Char> remote_address,
    int type,
  ) {
    return _bt_audio_connect(
      remote_address,
      type,
    );
  }

  late final _bt_audio_connectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>, ffi.Int32)>>('bt_audio_connect');
  late final _bt_audio_connect = _bt_audio_connectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AUDIO_MODULE
  /// @brief Disconnects the remote device with the given audio profile, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @details If you input type as #BT_AUDIO_PROFILE_TYPE_ALL and disconnection request succeeds, then bt_audio_connection_state_changed_cb() will be called twice
  /// when #BT_AUDIO_PROFILE_TYPE_HSP_HFP is disconnected and #BT_AUDIO_PROFILE_TYPE_A2DP is disconnected.
  /// @param[in] remote_address  The remote address
  /// @param[in] type  The type of audio profile
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected by bt_audio_connect().
  /// @post bt_audio_connection_state_changed_cb() will be invoked.
  /// @see bt_audio_connect()
  /// @see bt_audio_connection_state_changed_cb()
  int bt_audio_disconnect(
    ffi.Pointer<ffi.Char> remote_address,
    int type,
  ) {
    return _bt_audio_disconnect(
      remote_address,
      type,
    );
  }

  late final _bt_audio_disconnectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>, ffi.Int32)>>('bt_audio_disconnect');
  late final _bt_audio_disconnect = _bt_audio_disconnectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AUDIO_MODULE
  /// @brief  Registers a callback function that will be invoked when the connection state is changed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth audio service must be initialized with bt_audio_initialize().
  /// @see bt_audio_initialize()
  /// @see bt_audio_connection_state_changed_cb()
  int bt_audio_set_connection_state_changed_cb(
    bt_audio_connection_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_audio_set_connection_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_audio_set_connection_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_audio_connection_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_audio_set_connection_state_changed_cb');
  late final _bt_audio_set_connection_state_changed_cb =
      _bt_audio_set_connection_state_changed_cbPtr.asFunction<
          int Function(
              bt_audio_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AUDIO_MODULE
  /// @brief  Unregisters a callback function that will be invoked when the connection state is changed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth audio service must be initialized with bt_audio_initialize().
  /// @see bt_audio_initialize()
  /// @see bt_audio_connection_state_changed_cb()
  /// @see bt_audio_set_connection_state_changed_cb()
  int bt_audio_unset_connection_state_changed_cb() {
    return _bt_audio_unset_connection_state_changed_cb();
  }

  late final _bt_audio_unset_connection_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_audio_unset_connection_state_changed_cb');
  late final _bt_audio_unset_connection_state_changed_cb =
      _bt_audio_unset_connection_state_changed_cbPtr
          .asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_TARGET_MODULE
  /// @brief Initializes the Bluetooth AVRCP (Audio/Video Remote Control Profile) target service.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @remarks This function must be called before any other AVRCP target functions are called. \n
  /// You must free all resources of the this service by calling bt_avrcp_target_deinitialize()
  /// if Bluetooth AVRCP service is no longer needed.
  /// @param[in] callback The callback function called when the connection state is changed
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_avrcp_target_deinitialize()
  int bt_avrcp_target_initialize(
    bt_avrcp_target_connection_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_avrcp_target_initialize(
      callback,
      user_data,
    );
  }

  late final _bt_avrcp_target_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_avrcp_target_connection_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_avrcp_target_initialize');
  late final _bt_avrcp_target_initialize =
      _bt_avrcp_target_initializePtr.asFunction<
          int Function(bt_avrcp_target_connection_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_TARGET_MODULE
  /// @brief Deinitializes the Bluetooth AVRCP (Audio/Video Remote Control Profile) target service.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth audio service must be initialized with bt_avrcp_target_initialize().
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_target_deinitialize() {
    return _bt_avrcp_target_deinitialize();
  }

  late final _bt_avrcp_target_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_avrcp_target_deinitialize');
  late final _bt_avrcp_target_deinitialize =
      _bt_avrcp_target_deinitializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_TARGET_MODULE
  /// @brief  Notifies the equalizer state to the remote device.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] state The state of equalizer
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_target_notify_equalizer_state(
    int state,
  ) {
    return _bt_avrcp_target_notify_equalizer_state(
      state,
    );
  }

  late final _bt_avrcp_target_notify_equalizer_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_avrcp_target_notify_equalizer_state');
  late final _bt_avrcp_target_notify_equalizer_state =
      _bt_avrcp_target_notify_equalizer_statePtr
          .asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_TARGET_MODULE
  /// @brief  Notifies the repeat mode to the remote device.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] mode The repeat mode
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_target_notify_repeat_mode(
    int mode,
  ) {
    return _bt_avrcp_target_notify_repeat_mode(
      mode,
    );
  }

  late final _bt_avrcp_target_notify_repeat_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_avrcp_target_notify_repeat_mode');
  late final _bt_avrcp_target_notify_repeat_mode =
      _bt_avrcp_target_notify_repeat_modePtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_TARGET_MODULE
  /// @brief  Notifies the shuffle mode to the remote device.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] mode The repeat mode
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_target_notify_shuffle_mode(
    int mode,
  ) {
    return _bt_avrcp_target_notify_shuffle_mode(
      mode,
    );
  }

  late final _bt_avrcp_target_notify_shuffle_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_avrcp_target_notify_shuffle_mode');
  late final _bt_avrcp_target_notify_shuffle_mode =
      _bt_avrcp_target_notify_shuffle_modePtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_TARGET_MODULE
  /// @brief  Notifies the scan mode to the remote device.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] mode The scan mode
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_target_notify_scan_mode(
    int mode,
  ) {
    return _bt_avrcp_target_notify_scan_mode(
      mode,
    );
  }

  late final _bt_avrcp_target_notify_scan_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_avrcp_target_notify_scan_mode');
  late final _bt_avrcp_target_notify_scan_mode =
      _bt_avrcp_target_notify_scan_modePtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_TARGET_MODULE
  /// @brief  Notifies the player state to the remote device.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] state The player state
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_target_notify_player_state(
    int state,
  ) {
    return _bt_avrcp_target_notify_player_state(
      state,
    );
  }

  late final _bt_avrcp_target_notify_player_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_avrcp_target_notify_player_state');
  late final _bt_avrcp_target_notify_player_state =
      _bt_avrcp_target_notify_player_statePtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_TARGET_MODULE
  /// @brief  Notifies the current position of song to the remote device.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] position The current position in milliseconds
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_target_notify_position(
    int position,
  ) {
    return _bt_avrcp_target_notify_position(
      position,
    );
  }

  late final _bt_avrcp_target_notify_positionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.UnsignedInt)>>(
          'bt_avrcp_target_notify_position');
  late final _bt_avrcp_target_notify_position =
      _bt_avrcp_target_notify_positionPtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_TARGET_MODULE
  /// @brief  Notifies the track to the remote device.
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] title The title of track
  /// @param[in] artist The artist of track
  /// @param[in] album The album of track
  /// @param[in] genre The genre of track
  /// @param[in] track_num The track number
  /// @param[in] total_tracks The number of all tracks
  /// @param[in] duration The duration of track in milliseconds
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_target_notify_track(
    ffi.Pointer<ffi.Char> title,
    ffi.Pointer<ffi.Char> artist,
    ffi.Pointer<ffi.Char> album,
    ffi.Pointer<ffi.Char> genre,
    int track_num,
    int total_tracks,
    int duration,
  ) {
    return _bt_avrcp_target_notify_track(
      title,
      artist,
      album,
      genre,
      track_num,
      total_tracks,
      duration,
    );
  }

  late final _bt_avrcp_target_notify_trackPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.UnsignedInt,
              ffi.UnsignedInt,
              ffi.UnsignedInt)>>('bt_avrcp_target_notify_track');
  late final _bt_avrcp_target_notify_track =
      _bt_avrcp_target_notify_trackPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, int, int, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Registers a callback function that will be invoked when the equalizer state is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_unset_equalizer_state_changed_cb()
  int bt_avrcp_set_equalizer_state_changed_cb(
    bt_avrcp_equalizer_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_avrcp_set_equalizer_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_avrcp_set_equalizer_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_avrcp_equalizer_state_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'bt_avrcp_set_equalizer_state_changed_cb');
  late final _bt_avrcp_set_equalizer_state_changed_cb =
      _bt_avrcp_set_equalizer_state_changed_cbPtr.asFunction<
          int Function(
              bt_avrcp_equalizer_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Unregisters a callback function that will be invoked when the equalizer state is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_set_equalizer_state_changed_cb()
  int bt_avrcp_unset_equalizer_state_changed_cb() {
    return _bt_avrcp_unset_equalizer_state_changed_cb();
  }

  late final _bt_avrcp_unset_equalizer_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_avrcp_unset_equalizer_state_changed_cb');
  late final _bt_avrcp_unset_equalizer_state_changed_cb =
      _bt_avrcp_unset_equalizer_state_changed_cbPtr
          .asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Registers a callback function that will be invoked when the repeat mode is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_unset_repeat_mode_changed_cb()
  int bt_avrcp_set_repeat_mode_changed_cb(
    bt_avrcp_repeat_mode_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_avrcp_set_repeat_mode_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_avrcp_set_repeat_mode_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_avrcp_repeat_mode_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_avrcp_set_repeat_mode_changed_cb');
  late final _bt_avrcp_set_repeat_mode_changed_cb =
      _bt_avrcp_set_repeat_mode_changed_cbPtr.asFunction<
          int Function(
              bt_avrcp_repeat_mode_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Unregisters a callback function that will be invoked when the repeat mode is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_set_repeat_mode_changed_cb()
  int bt_avrcp_unset_repeat_mode_changed_cb() {
    return _bt_avrcp_unset_repeat_mode_changed_cb();
  }

  late final _bt_avrcp_unset_repeat_mode_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_avrcp_unset_repeat_mode_changed_cb');
  late final _bt_avrcp_unset_repeat_mode_changed_cb =
      _bt_avrcp_unset_repeat_mode_changed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Registers a callback function that will be invoked when the shuffle mode is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_unset_shuffle_mode_changed_cb()
  int bt_avrcp_set_shuffle_mode_changed_cb(
    bt_avrcp_shuffle_mode_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_avrcp_set_shuffle_mode_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_avrcp_set_shuffle_mode_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_avrcp_shuffle_mode_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_avrcp_set_shuffle_mode_changed_cb');
  late final _bt_avrcp_set_shuffle_mode_changed_cb =
      _bt_avrcp_set_shuffle_mode_changed_cbPtr.asFunction<
          int Function(
              bt_avrcp_shuffle_mode_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Unregisters a callback function that will be invoked when the shuffle mode is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_set_shuffle_mode_changed_cb()
  int bt_avrcp_unset_shuffle_mode_changed_cb() {
    return _bt_avrcp_unset_shuffle_mode_changed_cb();
  }

  late final _bt_avrcp_unset_shuffle_mode_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_avrcp_unset_shuffle_mode_changed_cb');
  late final _bt_avrcp_unset_shuffle_mode_changed_cb =
      _bt_avrcp_unset_shuffle_mode_changed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Registers a callback function that will be invoked when the scan mode is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_unset_scan_mode_changed_cb()
  int bt_avrcp_set_scan_mode_changed_cb(
    bt_avrcp_scan_mode_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_avrcp_set_scan_mode_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_avrcp_set_scan_mode_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_avrcp_scan_mode_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_avrcp_set_scan_mode_changed_cb');
  late final _bt_avrcp_set_scan_mode_changed_cb =
      _bt_avrcp_set_scan_mode_changed_cbPtr.asFunction<
          int Function(bt_avrcp_scan_mode_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Unregisters a callback function that will be invoked when the scan mode is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_set_scan_mode_changed_cb()
  int bt_avrcp_unset_scan_mode_changed_cb() {
    return _bt_avrcp_unset_scan_mode_changed_cb();
  }

  late final _bt_avrcp_unset_scan_mode_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_avrcp_unset_scan_mode_changed_cb');
  late final _bt_avrcp_unset_scan_mode_changed_cb =
      _bt_avrcp_unset_scan_mode_changed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Registers a callback function that will be invoked when the song position is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen 3.0
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_set_position_changed_cb()
  int bt_avrcp_set_position_changed_cb(
    bt_avrcp_position_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_avrcp_set_position_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_avrcp_set_position_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_avrcp_position_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_avrcp_set_position_changed_cb');
  late final _bt_avrcp_set_position_changed_cb =
      _bt_avrcp_set_position_changed_cbPtr.asFunction<
          int Function(bt_avrcp_position_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Unregisters a callback function that will be invoked when the song position is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen 3.0
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_set_position_changed_cb()
  int bt_avrcp_unset_position_changed_cb() {
    return _bt_avrcp_unset_position_changed_cb();
  }

  late final _bt_avrcp_unset_position_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_avrcp_unset_position_changed_cb');
  late final _bt_avrcp_unset_position_changed_cb =
      _bt_avrcp_unset_position_changed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Registers a callback function that will be invoked when the Play status is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen 3.0
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_unset_play_status_changed_cb()
  int bt_avrcp_set_play_status_changed_cb(
    bt_avrcp_play_status_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_avrcp_set_play_status_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_avrcp_set_play_status_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_avrcp_play_status_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_avrcp_set_play_status_changed_cb');
  late final _bt_avrcp_set_play_status_changed_cb =
      _bt_avrcp_set_play_status_changed_cbPtr.asFunction<
          int Function(
              bt_avrcp_play_status_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Unregisters a callback function that will be invoked when the Play status is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen 3.0
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_unset_play_status_changed_cb()
  int bt_avrcp_unset_play_status_changed_cb() {
    return _bt_avrcp_unset_play_status_changed_cb();
  }

  late final _bt_avrcp_unset_play_status_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_avrcp_unset_play_status_changed_cb');
  late final _bt_avrcp_unset_play_status_changed_cb =
      _bt_avrcp_unset_play_status_changed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Registers a callback function that will be invoked when the track metadata is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen 3.0
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_unset_track_info_changed_cb()
  int bt_avrcp_set_track_info_changed_cb(
    bt_avrcp_track_info_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_avrcp_set_track_info_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_avrcp_set_track_info_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_avrcp_track_info_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_avrcp_set_track_info_changed_cb');
  late final _bt_avrcp_set_track_info_changed_cb =
      _bt_avrcp_set_track_info_changed_cbPtr.asFunction<
          int Function(
              bt_avrcp_track_info_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
  /// @brief  Unregisters a callback function that will be invoked when the track metadata is changed. (e.g., by a TV remote control or other input devices)
  /// @since_tizen 3.0
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The AVRCP service must be initialized with bt_avrcp_target_initialize() or bt_avrcp_control_initialize().
  /// @see bt_avrcp_target_initialize()
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_set_track_info_changed_cb()
  int bt_avrcp_unset_track_info_changed_cb() {
    return _bt_avrcp_unset_track_info_changed_cb();
  }

  late final _bt_avrcp_unset_track_info_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_avrcp_unset_track_info_changed_cb');
  late final _bt_avrcp_unset_track_info_changed_cb =
      _bt_avrcp_unset_track_info_changed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief Initializes the Bluetooth AVRCP (Audio/Video Remote Control Profile) controller service.
  /// @since_tizen 3.0
  /// @remarks This function must be called before any other AVRCP controller functions are called. \n
  /// You must free all resources of the this service by calling bt_avrcp_control_deinitialize()
  /// if Bluetooth AVRCP service is no longer needed.
  /// @param[in] callback The callback function called when the connection state is changed
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_avrcp_control_deinitialize()
  int bt_avrcp_control_initialize(
    bt_avrcp_control_connection_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_avrcp_control_initialize(
      callback,
      user_data,
    );
  }

  late final _bt_avrcp_control_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_avrcp_control_connection_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_avrcp_control_initialize');
  late final _bt_avrcp_control_initialize =
      _bt_avrcp_control_initializePtr.asFunction<
          int Function(bt_avrcp_control_connection_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief Deinitializes the Bluetooth AVRCP (Audio/Video Remote Control Profile) controller service.
  /// @since_tizen 3.0
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  /// @pre The Bluetooth audio service must be initialized with bt_avrcp_control_initialize().
  /// @see bt_avrcp_control_initialize()
  int bt_avrcp_control_deinitialize() {
    return _bt_avrcp_control_deinitialize();
  }

  late final _bt_avrcp_control_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_avrcp_control_deinitialize');
  late final _bt_avrcp_control_deinitialize =
      _bt_avrcp_control_deinitializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief Connects the AVRCP (Audio/Video Remote Control Profile) target device.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] remote_address  The remote address
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  /// @pre The Bluetooth audio service must be initialized with bt_avrcp_control_initialize().
  /// @see bt_avrcp_control_initialize()
  int bt_avrcp_control_connect(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_avrcp_control_connect(
      remote_address,
    );
  }

  late final _bt_avrcp_control_connectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_avrcp_control_connect');
  late final _bt_avrcp_control_connect = _bt_avrcp_control_connectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief Disconnects from the AVRCP (Audio/Video Remote Control Profile) target device.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] remote_address  The remote address
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  /// @pre The Bluetooth audio service must be initialized with bt_avrcp_control_initialize().
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_control_connect()
  int bt_avrcp_control_disconnect(
    ffi.Pointer<ffi.Char> remote_address,
  ) {
    return _bt_avrcp_control_disconnect(
      remote_address,
    );
  }

  late final _bt_avrcp_control_disconnectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_avrcp_control_disconnect');
  late final _bt_avrcp_control_disconnect = _bt_avrcp_control_disconnectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief Sends a command to the target device.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] cmd The commands, one of: Play, Pause, Next, Rewind.
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  /// @pre The Bluetooth audio service must be initialized with bt_avrcp_control_initialize().
  /// @see bt_avrcp_control_initialize()
  /// @see bt_avrcp_control_connect()
  int bt_avrcp_control_send_player_command(
    int cmd,
  ) {
    return _bt_avrcp_control_send_player_command(
      cmd,
    );
  }

  late final _bt_avrcp_control_send_player_commandPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_avrcp_control_send_player_command');
  late final _bt_avrcp_control_send_player_command =
      _bt_avrcp_control_send_player_commandPtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Sends the equalizer state change request to the remote device.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] state The new equalizer state, one of: ON, OFF
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_set_equalizer_state(
    int state,
  ) {
    return _bt_avrcp_control_set_equalizer_state(
      state,
    );
  }

  late final _bt_avrcp_control_set_equalizer_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_avrcp_control_set_equalizer_state');
  late final _bt_avrcp_control_set_equalizer_state =
      _bt_avrcp_control_set_equalizer_statePtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Gets the the equalizer state of the remote device.
  /// @since_tizen 3.0
  /// @param[out] state The equalizer state, one of: ON, OFF
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_get_equalizer_state(
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _bt_avrcp_control_get_equalizer_state(
      state,
    );
  }

  late final _bt_avrcp_control_get_equalizer_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'bt_avrcp_control_get_equalizer_state');
  late final _bt_avrcp_control_get_equalizer_state =
      _bt_avrcp_control_get_equalizer_statePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Sends the repeat change request to the remote device.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] mode The new repeat mode, one of: OFF, SINGLE, ALL
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_set_repeat_mode(
    int mode,
  ) {
    return _bt_avrcp_control_set_repeat_mode(
      mode,
    );
  }

  late final _bt_avrcp_control_set_repeat_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_avrcp_control_set_repeat_mode');
  late final _bt_avrcp_control_set_repeat_mode =
      _bt_avrcp_control_set_repeat_modePtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Gets the repeat state of the remote device.
  /// @since_tizen 3.0
  /// @param[out] mode The repeat mode, one of: OFF, SINGLE, ALL
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_get_repeat_mode(
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _bt_avrcp_control_get_repeat_mode(
      mode,
    );
  }

  late final _bt_avrcp_control_get_repeat_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'bt_avrcp_control_get_repeat_mode');
  late final _bt_avrcp_control_get_repeat_mode =
      _bt_avrcp_control_get_repeat_modePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Sends the shuffle mode change request to the remote device.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] mode The new shuffle mode, one of: OFF, GROUP, ALL
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_set_shuffle_mode(
    int mode,
  ) {
    return _bt_avrcp_control_set_shuffle_mode(
      mode,
    );
  }

  late final _bt_avrcp_control_set_shuffle_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_avrcp_control_set_shuffle_mode');
  late final _bt_avrcp_control_set_shuffle_mode =
      _bt_avrcp_control_set_shuffle_modePtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Gets the shuffle mode of the remote device.
  /// @since_tizen 3.0
  /// @param[out] mode The shuffle mode, one of: OFF, GROUP, ALL
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_get_shuffle_mode(
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _bt_avrcp_control_get_shuffle_mode(
      mode,
    );
  }

  late final _bt_avrcp_control_get_shuffle_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'bt_avrcp_control_get_shuffle_mode');
  late final _bt_avrcp_control_get_shuffle_mode =
      _bt_avrcp_control_get_shuffle_modePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Sends the scan mode change request to the remote device.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] mode The new scan mode, one of: OFF, GROUP, ALL
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_set_scan_mode(
    int mode,
  ) {
    return _bt_avrcp_control_set_scan_mode(
      mode,
    );
  }

  late final _bt_avrcp_control_set_scan_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'bt_avrcp_control_set_scan_mode');
  late final _bt_avrcp_control_set_scan_mode =
      _bt_avrcp_control_set_scan_modePtr.asFunction<int Function(int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Gets the scan mode of the remote device.
  /// @since_tizen 3.0
  /// @param[out] mode The scan mode, one of: OFF, GROUP, ALL
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_get_scan_mode(
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _bt_avrcp_control_get_scan_mode(
      mode,
    );
  }

  late final _bt_avrcp_control_get_scan_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'bt_avrcp_control_get_scan_mode');
  late final _bt_avrcp_control_get_scan_mode =
      _bt_avrcp_control_get_scan_modePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Gets the position of the song played by the remote device.
  /// @since_tizen 3.0
  /// @param[out] position The position, in milliseconds
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_get_position(
    ffi.Pointer<ffi.UnsignedInt> position,
  ) {
    return _bt_avrcp_control_get_position(
      position,
    );
  }

  late final _bt_avrcp_control_get_positionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.UnsignedInt>)>>(
      'bt_avrcp_control_get_position');
  late final _bt_avrcp_control_get_position = _bt_avrcp_control_get_positionPtr
      .asFunction<int Function(ffi.Pointer<ffi.UnsignedInt>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Gets the play status of the remote device.
  /// @since_tizen 3.0
  /// @param[out] status The play status, one of: PLAYING, STOPPED...
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_get_play_status(
    ffi.Pointer<ffi.Int32> status,
  ) {
    return _bt_avrcp_control_get_play_status(
      status,
    );
  }

  late final _bt_avrcp_control_get_play_statusPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'bt_avrcp_control_get_play_status');
  late final _bt_avrcp_control_get_play_status =
      _bt_avrcp_control_get_play_statusPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Gets the metadata of the track played by the remote device.
  /// @since_tizen 3.0
  /// @remarks The @a track must be released using bt_avrcp_control_free_track_info()
  /// @param[out] track The track metadata.
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_avrcp_target_connection_state_changed_cb()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_get_track_info(
    ffi.Pointer<ffi.Pointer<bt_avrcp_metadata_attributes_info_s>> track,
  ) {
    return _bt_avrcp_control_get_track_info(
      track,
    );
  }

  late final _bt_avrcp_control_get_track_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<
                      ffi.Pointer<bt_avrcp_metadata_attributes_info_s>>)>>(
      'bt_avrcp_control_get_track_info');
  late final _bt_avrcp_control_get_track_info =
      _bt_avrcp_control_get_track_infoPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Pointer<bt_avrcp_metadata_attributes_info_s>>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_CONTROL_MODULE
  /// @brief  Frees the track metadata.
  /// @since_tizen 3.0
  /// @param[in] track The track metadata.
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  /// @pre track should point to valid metadata address.
  /// @see bt_avrcp_control_get_track_info()
  /// @see bt_avrcp_target_initialize()
  int bt_avrcp_control_free_track_info(
    ffi.Pointer<bt_avrcp_metadata_attributes_info_s> track,
  ) {
    return _bt_avrcp_control_free_track_info(
      track,
    );
  }

  late final _bt_avrcp_control_free_track_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<bt_avrcp_metadata_attributes_info_s>)>>(
      'bt_avrcp_control_free_track_info');
  late final _bt_avrcp_control_free_track_info =
      _bt_avrcp_control_free_track_infoPtr.asFunction<
          int Function(ffi.Pointer<bt_avrcp_metadata_attributes_info_s>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
  /// @brief Registers an application that acts as the @a Sink role of HDP(Health Device Profile).
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @remarks The @a app_id must be released with free() by you.
  /// @param[in] data_type  The data type of MDEP. This value is defined in ISO/IEEE 11073-20601 spec.
  /// For example, pulse oximeter is 0x1004 and blood pressure monitor is 0x1007.
  /// @param[out] app_id  The ID of application
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @see bt_hdp_unregister_sink_app()
  int bt_hdp_register_sink_app(
    int data_type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> app_id,
  ) {
    return _bt_hdp_register_sink_app(
      data_type,
      app_id,
    );
  }

  late final _bt_hdp_register_sink_appPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.UnsignedShort,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('bt_hdp_register_sink_app');
  late final _bt_hdp_register_sink_app = _bt_hdp_register_sink_appPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
  /// @brief Unregisters the given application that acts as the @a Sink role of HDP(Health Device Profile).
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] app_id  The ID of application
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_hdp_register_sink_app()
  int bt_hdp_unregister_sink_app(
    ffi.Pointer<ffi.Char> app_id,
  ) {
    return _bt_hdp_unregister_sink_app(
      app_id,
    );
  }

  late final _bt_hdp_unregister_sink_appPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_hdp_unregister_sink_app');
  late final _bt_hdp_unregister_sink_app = _bt_hdp_unregister_sink_appPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
  /// @brief Connects the remote device which acts as @a Source role, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] remote_address  The remote address
  /// @param[in] app_id  The ID of application
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Sink role of HDP must be registered with bt_hdp_register_sink_app().
  /// @pre The local device must be bonded with the remote device by bt_device_create_bond().
  /// @post bt_hdp_connected_cb() will be invoked.
  /// @see bt_hdp_disconnect()
  /// @see bt_hdp_set_connection_state_changed_cb()
  /// @see bt_hdp_unset_connection_state_changed_cb()
  int bt_hdp_connect_to_source(
    ffi.Pointer<ffi.Char> remote_address,
    ffi.Pointer<ffi.Char> app_id,
  ) {
    return _bt_hdp_connect_to_source(
      remote_address,
      app_id,
    );
  }

  late final _bt_hdp_connect_to_sourcePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('bt_hdp_connect_to_source');
  late final _bt_hdp_connect_to_source = _bt_hdp_connect_to_sourcePtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
  /// @brief Disconnects the remote device, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] remote_address  The remote address
  /// @param[in] channel  The connected data channel
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED  Remote device is not connected
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @post bt_hdp_disconnected_cb() will be invoked.
  /// @see bt_hdp_set_connection_state_changed_cb()
  /// @see bt_hdp_unset_connection_state_changed_cb()
  int bt_hdp_disconnect(
    ffi.Pointer<ffi.Char> remote_address,
    int channel,
  ) {
    return _bt_hdp_disconnect(
      remote_address,
      channel,
    );
  }

  late final _bt_hdp_disconnectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>, ffi.UnsignedInt)>>('bt_hdp_disconnect');
  late final _bt_hdp_disconnect = _bt_hdp_disconnectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
  /// @brief Sends the data to the remote device.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in] channel  The connected data channel
  /// @param[in] data  The data to send
  /// @param[in] size  The size of data to send (byte)
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The remote device must be connected.
  /// @see bt_hdp_data_received_cb()
  /// @see bt_hdp_set_data_received_cb()
  /// @see bt_hdp_unset_data_received_cb()
  int bt_hdp_send_data(
    int channel,
    ffi.Pointer<ffi.Char> data,
    int size,
  ) {
    return _bt_hdp_send_data(
      channel,
      data,
      size,
    );
  }

  late final _bt_hdp_send_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.UnsignedInt, ffi.Pointer<ffi.Char>,
              ffi.UnsignedInt)>>('bt_hdp_send_data');
  late final _bt_hdp_send_data = _bt_hdp_send_dataPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
  /// @brief  Registers a callback function that will be invoked when the connection state is changed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] connected_cb The callback function called when a connection is established
  /// @param[in] disconnected_cb The callback function called when a connection is disconnected
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_hdp_unset_connection_state_changed_cb()
  int bt_hdp_set_connection_state_changed_cb(
    bt_hdp_connected_cb connected_cb,
    bt_hdp_disconnected_cb disconnected_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_hdp_set_connection_state_changed_cb(
      connected_cb,
      disconnected_cb,
      user_data,
    );
  }

  late final _bt_hdp_set_connection_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_hdp_connected_cb, bt_hdp_disconnected_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_hdp_set_connection_state_changed_cb');
  late final _bt_hdp_set_connection_state_changed_cb =
      _bt_hdp_set_connection_state_changed_cbPtr.asFunction<
          int Function(bt_hdp_connected_cb, bt_hdp_disconnected_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
  /// @brief  Unregisters a callback function that will be invoked when the connection state is changed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_hdp_set_connection_state_changed_cb()
  int bt_hdp_unset_connection_state_changed_cb() {
    return _bt_hdp_unset_connection_state_changed_cb();
  }

  late final _bt_hdp_unset_connection_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_hdp_unset_connection_state_changed_cb');
  late final _bt_hdp_unset_connection_state_changed_cb =
      _bt_hdp_unset_connection_state_changed_cbPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
  /// @brief  Registers a callback function that will be invoked when you receive the data.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_hdp_unset_data_received_cb()
  int bt_hdp_set_data_received_cb(
    bt_hdp_data_received_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_hdp_set_data_received_cb(
      callback,
      user_data,
    );
  }

  late final _bt_hdp_set_data_received_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_hdp_data_received_cb,
              ffi.Pointer<ffi.Void>)>>('bt_hdp_set_data_received_cb');
  late final _bt_hdp_set_data_received_cb =
      _bt_hdp_set_data_received_cbPtr.asFunction<
          int Function(bt_hdp_data_received_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
  /// @brief  Unregisters a callback function that will be invoked when you receive the data.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_hdp_set_data_received_cb()
  int bt_hdp_unset_data_received_cb() {
    return _bt_hdp_unset_data_received_cb();
  }

  late final _bt_hdp_unset_data_received_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_hdp_unset_data_received_cb');
  late final _bt_hdp_unset_data_received_cb =
      _bt_hdp_unset_data_received_cbPtr.asFunction<int Function()>();

  /// @deprecated Deprecated since 2.3.1. Use bt_gatt_client_foreach_services or bt_gatt_client_get_service instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the primary services of GATT(Generic Attribute Profile).
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in]  remote_address  The address of the remote device
  /// @param[in]  callback  The callback function to invoke
  /// @param[in]  user_data  The user data to be passed to the callback function
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval  #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval  #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post  @a callback will be called if there are primary services.
  /// @see  bt_gatt_primary_service_cb()
  int bt_gatt_foreach_primary_services(
    ffi.Pointer<ffi.Char> remote_address,
    bt_gatt_primary_service_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_foreach_primary_services(
      remote_address,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_foreach_primary_servicesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, bt_gatt_primary_service_cb,
              ffi.Pointer<ffi.Void>)>>('bt_gatt_foreach_primary_services');
  late final _bt_gatt_foreach_primary_services =
      _bt_gatt_foreach_primary_servicesPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, bt_gatt_primary_service_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 2.3.1. This function call is not required because characteristic discovery is happened automatically.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Discovers the characteristics in service, asynchronously.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in]  service  The attribute handle of service
  /// @param[in]  callback  The result callback
  /// @param[in]  user_data  The user data to be passed to the callback function
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval  #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post  @a callback will be called.
  /// @see  bt_gatt_characteristics_discovered_cb()
  int bt_gatt_discover_characteristics(
    bt_gatt_attribute_h service,
    bt_gatt_characteristics_discovered_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_discover_characteristics(
      service,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_discover_characteristicsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_gatt_attribute_h,
              bt_gatt_characteristics_discovered_cb,
              ffi.Pointer<ffi.Void>)>>('bt_gatt_discover_characteristics');
  late final _bt_gatt_discover_characteristics =
      _bt_gatt_discover_characteristicsPtr.asFunction<
          int Function(bt_gatt_attribute_h,
              bt_gatt_characteristics_discovered_cb, ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 2.3.1. Use bt_gatt_get_uuid instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the UUID of service.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @remarks  @a uuid must be released with free() by you.
  /// @param[in]  service  The attribute handle of service
  /// @param[out]  uuid  The UUID of service
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval  #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval  #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  int bt_gatt_get_service_uuid(
    bt_gatt_attribute_h service,
    ffi.Pointer<ffi.Pointer<ffi.Char>> uuid,
  ) {
    return _bt_gatt_get_service_uuid(
      service,
      uuid,
    );
  }

  late final _bt_gatt_get_service_uuidPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_attribute_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('bt_gatt_get_service_uuid');
  late final _bt_gatt_get_service_uuid =
      _bt_gatt_get_service_uuidPtr.asFunction<
          int Function(
              bt_gatt_attribute_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @deprecated Deprecated since 2.3.1. Use bt_gatt_service_foreach_included_services or bt_gatt_service_get_included_service instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the included services in service.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in]  service  The attribute handle of service
  /// @param[in]  callback  The callback function to invoke
  /// @param[in]  user_data  The user data to be passed to the callback function
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval  #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval  #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post  @a callback will be called if there are included services.
  /// @see  bt_gatt_included_service_cb()
  int bt_gatt_foreach_included_services(
    bt_gatt_attribute_h service,
    bt_gatt_included_service_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_foreach_included_services(
      service,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_foreach_included_servicesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_attribute_h, bt_gatt_included_service_cb,
              ffi.Pointer<ffi.Void>)>>('bt_gatt_foreach_included_services');
  late final _bt_gatt_foreach_included_services =
      _bt_gatt_foreach_included_servicesPtr.asFunction<
          int Function(bt_gatt_attribute_h, bt_gatt_included_service_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 2.3.1. Use bt_gatt_client_set_characteristic_value_changed_cb instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Registers a callback function that will be invoked when a characteristic value is changed.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @param[in]  callback  The callback function to register
  /// @param[in]  user_data  The user data to be passed to the callback function
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The Bluetooth service must be initialized with bt_initialize().
  /// @see  bt_gatt_unset_characteristic_changed_cb()
  int bt_gatt_set_characteristic_changed_cb(
    bt_gatt_characteristic_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_set_characteristic_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_gatt_set_characteristic_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_characteristic_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_gatt_set_characteristic_changed_cb');
  late final _bt_gatt_set_characteristic_changed_cb =
      _bt_gatt_set_characteristic_changed_cbPtr.asFunction<
          int Function(
              bt_gatt_characteristic_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 2.3.1. Use bt_gatt_client_unset_characteristic_value_changed_cb instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Unregisters a callback function that will be invoked when a characteristic is changed.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_gatt_set_characteristic_changed_cb()
  int bt_gatt_unset_characteristic_changed_cb() {
    return _bt_gatt_unset_characteristic_changed_cb();
  }

  late final _bt_gatt_unset_characteristic_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_gatt_unset_characteristic_changed_cb');
  late final _bt_gatt_unset_characteristic_changed_cb =
      _bt_gatt_unset_characteristic_changed_cbPtr.asFunction<int Function()>();

  /// @deprecated Deprecated since 2.3.1. Use bt_gatt_client_set_characteristic_value_changed_cb instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Watches all the characteristic value changes of the service.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in]  service  The attribute handle of service
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The Bluetooth service must be initialized with bt_initialize().
  /// @see  bt_gatt_unset_characteristic_changed_cb()
  int bt_gatt_watch_characteristic_changes(
    bt_gatt_attribute_h service,
  ) {
    return _bt_gatt_watch_characteristic_changes(
      service,
    );
  }

  late final _bt_gatt_watch_characteristic_changesPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_attribute_h)>>(
          'bt_gatt_watch_characteristic_changes');
  late final _bt_gatt_watch_characteristic_changes =
      _bt_gatt_watch_characteristic_changesPtr
          .asFunction<int Function(bt_gatt_attribute_h)>();

  /// @deprecated Deprecated since 2.3.1. Use bt_gatt_client_unset_characteristic_value_changed_cb instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Remove watching of all the characteristic value changes of the service.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in]  service  The attribute handle of service
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_gatt_set_characteristic_changed_cb()
  int bt_gatt_unwatch_characteristic_changes(
    bt_gatt_attribute_h service,
  ) {
    return _bt_gatt_unwatch_characteristic_changes(
      service,
    );
  }

  late final _bt_gatt_unwatch_characteristic_changesPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_attribute_h)>>(
          'bt_gatt_unwatch_characteristic_changes');
  late final _bt_gatt_unwatch_characteristic_changes =
      _bt_gatt_unwatch_characteristic_changesPtr
          .asFunction<int Function(bt_gatt_attribute_h)>();

  /// @deprecated Deprecated since 2.3.1. Use bt_gatt_get_value or bt_gatt_get_uuid after bt_gatt_client_read_value instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the characteristic declaration.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @remarks  @a uuid and @a value must be released with free() by you.
  /// @param[in]  characteristic  The attribute handle of characteristic
  /// @param[out]  uuid  The UUID of service
  /// @param[out]  value  The value of characteristic (byte array)
  /// @param[out]  value_length  The length of value
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval  #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @see  bt_gatt_set_characteristic_value()
  int bt_gatt_get_characteristic_declaration(
    bt_gatt_attribute_h characteristic,
    ffi.Pointer<ffi.Pointer<ffi.Char>> uuid,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> value,
    ffi.Pointer<ffi.Int> value_length,
  ) {
    return _bt_gatt_get_characteristic_declaration(
      characteristic,
      uuid,
      value,
      value_length,
    );
  }

  late final _bt_gatt_get_characteristic_declarationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_gatt_attribute_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>>('bt_gatt_get_characteristic_declaration');
  late final _bt_gatt_get_characteristic_declaration =
      _bt_gatt_get_characteristic_declarationPtr.asFunction<
          int Function(
              bt_gatt_attribute_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>();

  /// @deprecated Deprecated since 2.3.1. Use bt_gatt_set_value and bt_gatt_client_write_value instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Sets the value of characteristic.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in]  characteristic  The attribute handle of characteristic
  /// @param[in]  value  The value of characteristic (byte array)
  /// @param[in]  value_length  The length of value
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval  #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @see  bt_gatt_get_characteristic_declaration()
  int bt_gatt_set_characteristic_value(
    bt_gatt_attribute_h characteristic,
    ffi.Pointer<ffi.UnsignedChar> value,
    int value_length,
  ) {
    return _bt_gatt_set_characteristic_value(
      characteristic,
      value,
      value_length,
    );
  }

  late final _bt_gatt_set_characteristic_valuePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_attribute_h, ffi.Pointer<ffi.UnsignedChar>,
              ffi.Int)>>('bt_gatt_set_characteristic_value');
  late final _bt_gatt_set_characteristic_value =
      _bt_gatt_set_characteristic_valuePtr.asFunction<
          int Function(
              bt_gatt_attribute_h, ffi.Pointer<ffi.UnsignedChar>, int)>();

  /// @deprecated Deprecated since 2.3.1. Use bt_gatt_set_value and bt_gatt_client_write_value instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Sets the value of characteristic request.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in]  characteristic  The attribute handle of characteristic
  /// @param[in]  value  The value of characteristic (byte array)
  /// @param[in]  value_length  The length of value
  /// @param[in]  callback  The result callback
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval  #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @see  bt_gatt_get_characteristic_declaration()
  int bt_gatt_set_characteristic_value_request(
    bt_gatt_attribute_h characteristic,
    ffi.Pointer<ffi.UnsignedChar> value,
    int value_length,
    bt_gatt_characteristic_write_cb callback,
  ) {
    return _bt_gatt_set_characteristic_value_request(
      characteristic,
      value,
      value_length,
      callback,
    );
  }

  late final _bt_gatt_set_characteristic_value_requestPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_attribute_h,
                  ffi.Pointer<ffi.UnsignedChar>,
                  ffi.Int,
                  bt_gatt_characteristic_write_cb)>>(
      'bt_gatt_set_characteristic_value_request');
  late final _bt_gatt_set_characteristic_value_request =
      _bt_gatt_set_characteristic_value_requestPtr.asFunction<
          int Function(bt_gatt_attribute_h, ffi.Pointer<ffi.UnsignedChar>, int,
              bt_gatt_characteristic_write_cb)>();

  /// @deprecated Deprecated since 2.3.1. GATT handle clone is not allowed. Instead, all handles for client role must be got from GATT client handle.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Clones the attribute handle.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @remarks  @a clone must be released with bt_gatt_destroy_attribute_handle().
  /// @param[out]  clone  The cloned attribute handle
  /// @param[in]  origin  The origin attribute handle
  /// @return  0 on success, otherwise negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see  bt_gatt_destroy_attribute_handle()
  int bt_gatt_clone_attribute_handle(
    ffi.Pointer<bt_gatt_attribute_h> clone,
    bt_gatt_attribute_h origin,
  ) {
    return _bt_gatt_clone_attribute_handle(
      clone,
      origin,
    );
  }

  late final _bt_gatt_clone_attribute_handlePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<bt_gatt_attribute_h>,
              bt_gatt_attribute_h)>>('bt_gatt_clone_attribute_handle');
  late final _bt_gatt_clone_attribute_handle =
      _bt_gatt_clone_attribute_handlePtr.asFunction<
          int Function(
              ffi.Pointer<bt_gatt_attribute_h>, bt_gatt_attribute_h)>();

  /// @deprecated Deprecated since 2.3.1. GATT handle clone and destroy are not allowed.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Destroys the attribute handle.
  /// @since_tizen @if WEARABLE  @else 2.3 @endif
  /// @param[in]  handle  The attribute handle
  /// @return  0 on success, otherwise negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see  bt_gatt_clone_attribute_handle()
  int bt_gatt_destroy_attribute_handle(
    bt_gatt_attribute_h handle,
  ) {
    return _bt_gatt_destroy_attribute_handle(
      handle,
    );
  }

  late final _bt_gatt_destroy_attribute_handlePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_attribute_h)>>(
          'bt_gatt_destroy_attribute_handle');
  late final _bt_gatt_destroy_attribute_handle =
      _bt_gatt_destroy_attribute_handlePtr
          .asFunction<int Function(bt_gatt_attribute_h)>();

  /// @deprecated Deprecated since 2.3.1. Use gatt_client_read_value instead.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Reads the value of characteristic from remote device.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in]  char_handle  The attribute handle of characteristic
  /// @param[in]  callback  The result callback
  /// @return	0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE	Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED	Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @see  bt_gatt_get_characteristic_declaration()
  int bt_gatt_read_characteristic_value(
    bt_gatt_attribute_h char_handle,
    bt_gatt_characteristic_read_cb callback,
  ) {
    return _bt_gatt_read_characteristic_value(
      char_handle,
      callback,
    );
  }

  late final _bt_gatt_read_characteristic_valuePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_attribute_h, bt_gatt_characteristic_read_cb)>>(
      'bt_gatt_read_characteristic_value');
  late final _bt_gatt_read_characteristic_value =
      _bt_gatt_read_characteristic_valuePtr.asFunction<
          int Function(bt_gatt_attribute_h, bt_gatt_characteristic_read_cb)>();

  /// @deprecated Deprecated since 2.3.1. This function call is not required because descriptor discovery is happened automatically.
  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Discovers the characteristic descriptors of a characteristic within its definition, asynchronously.
  /// @since_tizen @if WEARABLE @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  /// @param[in]  characteristic_handle  The attribute handle of characteristic
  /// @param[in]  callback  The result callback
  /// @param[in]  user_data  The user data to be passed to the callback function
  /// @return  0 on success, otherwise a negative error value.
  /// @retval  #BT_ERROR_NONE  Successful
  /// @retval  #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval  #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval  #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval  #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre  The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @post  @a callback will be called.
  /// @see  bt_gatt_characteristic_descriptor_discovered_cb()
  int bt_gatt_discover_characteristic_descriptor(
    bt_gatt_attribute_h characteristic_handle,
    bt_gatt_characteristic_descriptor_discovered_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_discover_characteristic_descriptor(
      characteristic_handle,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_discover_characteristic_descriptorPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_attribute_h,
                  bt_gatt_characteristic_descriptor_discovered_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_gatt_discover_characteristic_descriptor');
  late final _bt_gatt_discover_characteristic_descriptor =
      _bt_gatt_discover_characteristic_descriptorPtr.asFunction<
          int Function(
              bt_gatt_attribute_h,
              bt_gatt_characteristic_descriptor_discovered_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the value of a characteristic or descriptor's GATT handle.
  /// @since_tizen 2.3.1
  ///
  /// @remarks @a value must be released using free(). \n
  /// When @a gatt_handle is associated with bt_gatt_client_h, bt_gatt_client_read_value() must be used prior to this function \n
  /// in order to get the remote device's current value.
  ///
  /// @param[in] gatt_handle The handle of a characteristic or descriptor
  /// @param[out] value The value of @a gatt_handle. It is a byte stream type.
  /// @param[out] value_length The length of @a value
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_get_value(
    bt_gatt_h gatt_handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
    ffi.Pointer<ffi.Int> value_length,
  ) {
    return _bt_gatt_get_value(
      gatt_handle,
      value,
      value_length,
    );
  }

  late final _bt_gatt_get_valuePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int>)>>('bt_gatt_get_value');
  late final _bt_gatt_get_value = _bt_gatt_get_valuePtr.asFunction<
      int Function(bt_gatt_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
          ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the value of a characteristic or descriptor's GATT handle as an integer type.
  /// @since_tizen 2.3.1
  ///
  /// @remarks This function returns a locally saved value in @a gatt_handle. \n
  /// When @a gatt_handle is associated with bt_gatt_client_h, bt_gatt_client_read_value() must be used prior to this function \n
  /// in order to get the remote device's current value.
  ///
  /// @param[in] gatt_handle The handle of a characteristic or descriptor
  /// @param[in] type The type of a saved value in @a gatt_handle
  /// @param[in] offset The offset from where a value will be read from @a gatt_handle as an integer type
  /// @param[out] value The integer type's value of @a gatt_handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_get_int_value(
    bt_gatt_h gatt_handle,
    int type,
    int offset,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _bt_gatt_get_int_value(
      gatt_handle,
      type,
      offset,
      value,
    );
  }

  late final _bt_gatt_get_int_valuePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h, ffi.Int32, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('bt_gatt_get_int_value');
  late final _bt_gatt_get_int_value = _bt_gatt_get_int_valuePtr
      .asFunction<int Function(bt_gatt_h, int, int, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the value of a characteristic or descriptor's GATT handle as a float type.
  /// @since_tizen 2.3.1
  ///
  /// @remarks This function returns a locally saved value in @a gatt_handle. \n
  /// When @a gatt_handle is associated with bt_gatt_client_h, bt_gatt_client_read_value() must be used prior to this function \n
  /// in order to get the remote device's current value.
  ///
  /// @param[in] gatt_handle  The handle of a characteristic or descriptor
  /// @param[in] type The type of a saved value in @a gatt_handle
  /// @param[in] offset The offset from where a value will be read from @a gatt_handle as an integer type
  /// @param[out] value The float type's value of @a gatt_handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_get_float_value(
    bt_gatt_h gatt_handle,
    int type,
    int offset,
    ffi.Pointer<ffi.Float> value,
  ) {
    return _bt_gatt_get_float_value(
      gatt_handle,
      type,
      offset,
      value,
    );
  }

  late final _bt_gatt_get_float_valuePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h, ffi.Int32, ffi.Int,
              ffi.Pointer<ffi.Float>)>>('bt_gatt_get_float_value');
  late final _bt_gatt_get_float_value = _bt_gatt_get_float_valuePtr
      .asFunction<int Function(bt_gatt_h, int, int, ffi.Pointer<ffi.Float>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Updates the value of a characteristic or descriptor's GATT handle.
  /// @since_tizen 2.3.1
  ///
  /// @remarks This function updates a value of @a gatt_handle locally. \n
  /// When @a gatt_handle is associated with bt_gatt_client_h, bt_gatt_client_write_value() can be used after this function \n
  /// in order to update the remote device's value. \n
  ///
  /// @param[in] gatt_handle The handle of a characteristic or descriptor
  /// @param[in] value The value to be updated
  /// @param[in] value_length The length of @a value
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_set_value(
    bt_gatt_h gatt_handle,
    ffi.Pointer<ffi.Char> value,
    int value_length,
  ) {
    return _bt_gatt_set_value(
      gatt_handle,
      value,
      value_length,
    );
  }

  late final _bt_gatt_set_valuePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_gatt_h, ffi.Pointer<ffi.Char>, ffi.Int)>>('bt_gatt_set_value');
  late final _bt_gatt_set_value = _bt_gatt_set_valuePtr
      .asFunction<int Function(bt_gatt_h, ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Updates the value of a characteristic or descriptor's GATT handle using a integer type's value.
  /// @since_tizen 2.3.1
  ///
  /// @remarks This function updates a value of @a gatt_handle locally. \n
  /// When @a gatt_handle is associated with bt_gatt_client_h, bt_gatt_client_write_value() can be used after this function \n
  /// in order to update the remote device's value. \n
  ///
  /// @param[in] gatt_handle The handle of a characteristic or descriptor
  /// @param[in] type @a value will be saved in @a gatt_handle as this type
  /// @param[in] value The integer type's value to be updated
  /// @param[in] offset The offset from where @a value will be saved in @a gatt_handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_set_int_value(
    bt_gatt_h gatt_handle,
    int type,
    int value,
    int offset,
  ) {
    return _bt_gatt_set_int_value(
      gatt_handle,
      type,
      value,
      offset,
    );
  }

  late final _bt_gatt_set_int_valuePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h, ffi.Int32, ffi.Int,
              ffi.Int)>>('bt_gatt_set_int_value');
  late final _bt_gatt_set_int_value = _bt_gatt_set_int_valuePtr
      .asFunction<int Function(bt_gatt_h, int, int, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Updates the value of a characteristic or descriptor's GATT handle using a float type's value.
  /// @since_tizen 2.3.1
  ///
  /// @remarks This function updates a value of @a gatt_handle locally. \n
  /// When @a gatt_handle is associated with bt_gatt_client_h, bt_gatt_client_write_value() can be used after this function \n
  /// in order to update the remote device's value. \n
  ///
  /// @param[in] gatt_handle The handle of a characteristic or descriptor
  /// @param[in] type @a mantissa and @a exponent will be saved in @a gatt_handle as this type
  /// @param[in] mantissa The mantissa of float type's value to be updated
  /// @param[in] exponent The exponent of float type's value to be updated
  /// @param[in] offset The offset from where @a mantissa and @a exponent will be saved in @a gatt_handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_set_float_value(
    bt_gatt_h gatt_handle,
    int type,
    int mantissa,
    int exponent,
    int offset,
  ) {
    return _bt_gatt_set_float_value(
      gatt_handle,
      type,
      mantissa,
      exponent,
      offset,
    );
  }

  late final _bt_gatt_set_float_valuePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h, ffi.Int32, ffi.Int, ffi.Int,
              ffi.Int)>>('bt_gatt_set_float_value');
  late final _bt_gatt_set_float_value = _bt_gatt_set_float_valuePtr
      .asFunction<int Function(bt_gatt_h, int, int, int, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the UUID of a service, characteristic or descriptor's GATT handle.
  /// @since_tizen 2.3.1
  ///
  /// @remarks @a uuid must be released using free(). \n
  /// 16-bit UUID or 128-bit UUID is supported. (e.g. 2A19, 00002A19-0000-1000-8000-00805F9B34FB)
  ///
  /// @param[in] gatt_handle The handle of a service, characteristic or descriptor
  /// @param[out] uuid The string of the UUID of @a gatt_handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_get_uuid(
    bt_gatt_h gatt_handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> uuid,
  ) {
    return _bt_gatt_get_uuid(
      gatt_handle,
      uuid,
    );
  }

  late final _bt_gatt_get_uuidPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('bt_gatt_get_uuid');
  late final _bt_gatt_get_uuid = _bt_gatt_get_uuidPtr.asFunction<
      int Function(bt_gatt_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the type of GATT handle.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] gatt_handle The GATT handle
  /// @param[out] gatt_type The type of @a gatt_handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_get_type(
    bt_gatt_h gatt_handle,
    ffi.Pointer<ffi.Int32> gatt_type,
  ) {
    return _bt_gatt_get_type(
      gatt_handle,
      gatt_type,
    );
  }

  late final _bt_gatt_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_gatt_h, ffi.Pointer<ffi.Int32>)>>('bt_gatt_get_type');
  late final _bt_gatt_get_type = _bt_gatt_get_typePtr
      .asFunction<int Function(bt_gatt_h, ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Gets the GATT client handle which the specified service belongs to.
  /// @since_tizen 2.3.1
  ///
  /// @remark This function doesn't allocate new memory for GATT client handle.
  /// The returned GATT client handle is the same one which was got from bt_gatt_client_create().
  /// So if it is destroyed by bt_gatt_client_destroy(), all related GATT handles are freed also.
  ///
  /// @param[in] service The service's GATT handle
  /// @param[out] client The GATT client handle which @a service belongs to
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_create()
  int bt_gatt_service_get_client(
    bt_gatt_h service,
    ffi.Pointer<bt_gatt_client_h> client,
  ) {
    return _bt_gatt_service_get_client(
      service,
      client,
    );
  }

  late final _bt_gatt_service_get_clientPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h,
              ffi.Pointer<bt_gatt_client_h>)>>('bt_gatt_service_get_client');
  late final _bt_gatt_service_get_client = _bt_gatt_service_get_clientPtr
      .asFunction<int Function(bt_gatt_h, ffi.Pointer<bt_gatt_client_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets a characteristic's GATT handle which has specific UUID.
  /// @since_tizen 2.3.1
  ///
  /// @remark The returned GATT handle must not be freed by application.
  /// It will be freed when an associated client is destroyed by bt_gatt_client_destroy().
  /// If there are multiple characteristics which have same UUID, only the first matched one will be returned.
  ///
  /// @param[in] service The service's GATT handle
  /// @param[in] uuid The characteristic's GATT handle which has this UUID will be returned if it exists
  /// @param[out] characteristic The characteristic's GATT handle which has @a uuid if it exists
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_service_get_characteristic(
    bt_gatt_h service,
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<bt_gatt_h> characteristic,
  ) {
    return _bt_gatt_service_get_characteristic(
      service,
      uuid,
      characteristic,
    );
  }

  late final _bt_gatt_service_get_characteristicPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bt_gatt_h>)>>('bt_gatt_service_get_characteristic');
  late final _bt_gatt_service_get_characteristic =
      _bt_gatt_service_get_characteristicPtr.asFunction<
          int Function(
              bt_gatt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<bt_gatt_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Invokes @a callback function on each characteristic that belongs to the specified service.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] service The service's GATT handle
  /// @param[in] callback The function to be invoked on each characteristic
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_foreach_cb()
  int bt_gatt_service_foreach_characteristics(
    bt_gatt_h service,
    bt_gatt_foreach_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_service_foreach_characteristics(
      service,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_service_foreach_characteristicsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_h, bt_gatt_foreach_cb, ffi.Pointer<ffi.Void>)>>(
      'bt_gatt_service_foreach_characteristics');
  late final _bt_gatt_service_foreach_characteristics =
      _bt_gatt_service_foreach_characteristicsPtr.asFunction<
          int Function(bt_gatt_h, bt_gatt_foreach_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets an included service's GATT handle which has specific UUID.
  /// @since_tizen 2.3.1
  ///
  /// @remark The returned GATT handle must not be freed by application.
  /// It will be freed when an associated client is destroyed by bt_gatt_client_destroy().
  /// If there are multiple included services which have same UUID, only the first matched one will be returned.
  ///
  /// @param[in] service The service's GATT handle
  /// @param[in] uuid The included service's GATT handle which has this UUID will be returned if it exists
  /// @param[out] included_service The included service's GATT handle which has @a uuid if it exists
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_service_get_included_service(
    bt_gatt_h service,
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<bt_gatt_h> included_service,
  ) {
    return _bt_gatt_service_get_included_service(
      service,
      uuid,
      included_service,
    );
  }

  late final _bt_gatt_service_get_included_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bt_gatt_h>)>>('bt_gatt_service_get_included_service');
  late final _bt_gatt_service_get_included_service =
      _bt_gatt_service_get_included_servicePtr.asFunction<
          int Function(
              bt_gatt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<bt_gatt_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Invokes @a callback function on each included service that belongs to the specified service.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] service The service's GATT handle
  /// @param[in] callback The function to be invoked on each included service
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_foreach_cb()
  int bt_gatt_service_foreach_included_services(
    bt_gatt_h service,
    bt_gatt_foreach_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_service_foreach_included_services(
      service,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_service_foreach_included_servicesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_h, bt_gatt_foreach_cb, ffi.Pointer<ffi.Void>)>>(
      'bt_gatt_service_foreach_included_services');
  late final _bt_gatt_service_foreach_included_services =
      _bt_gatt_service_foreach_included_servicesPtr.asFunction<
          int Function(bt_gatt_h, bt_gatt_foreach_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the service's GATT handle which the specified characteristic belongs to.
  /// @since_tizen 2.3.1
  ///
  /// @remark The returned GATT handle must not be freed by application.
  /// It will be freed when an associated client is destroyed by bt_gatt_client_destroy().
  ///
  /// @param[in] characteristic The characteristic's GATT handle
  /// @param[out] service The service's GATT handle which @a characteristic belongs to
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_characteristic_get_service(
    bt_gatt_h characteristic,
    ffi.Pointer<bt_gatt_h> service,
  ) {
    return _bt_gatt_characteristic_get_service(
      characteristic,
      service,
    );
  }

  late final _bt_gatt_characteristic_get_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h,
              ffi.Pointer<bt_gatt_h>)>>('bt_gatt_characteristic_get_service');
  late final _bt_gatt_characteristic_get_service =
      _bt_gatt_characteristic_get_servicePtr
          .asFunction<int Function(bt_gatt_h, ffi.Pointer<bt_gatt_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the properties which a characteristic's GATT handle has.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] characteristic The characteristic's GATT handle
  /// @param[out] properties The properties which a characteristic's GATT handle has
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_property_e
  int bt_gatt_characteristic_get_properties(
    bt_gatt_h characteristic,
    ffi.Pointer<ffi.Int> properties,
  ) {
    return _bt_gatt_characteristic_get_properties(
      characteristic,
      properties,
    );
  }

  late final _bt_gatt_characteristic_get_propertiesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h,
              ffi.Pointer<ffi.Int>)>>('bt_gatt_characteristic_get_properties');
  late final _bt_gatt_characteristic_get_properties =
      _bt_gatt_characteristic_get_propertiesPtr
          .asFunction<int Function(bt_gatt_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief Gets the write type of the specified characteristic.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] characteristic The characteristic's GATT handle
  /// @param[out] write_type The write type of the specified characteristic
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_write_type_e
  int bt_gatt_characteristic_get_write_type(
    bt_gatt_h characteristic,
    ffi.Pointer<ffi.Int32> write_type,
  ) {
    return _bt_gatt_characteristic_get_write_type(
      characteristic,
      write_type,
    );
  }

  late final _bt_gatt_characteristic_get_write_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_gatt_h, ffi.Pointer<ffi.Int32>)>>(
      'bt_gatt_characteristic_get_write_type');
  late final _bt_gatt_characteristic_get_write_type =
      _bt_gatt_characteristic_get_write_typePtr
          .asFunction<int Function(bt_gatt_h, ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Updates the write type of the specified characteristic.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] characteristic The characteristic's GATT handle
  /// @param[in] write_type The write type to be updated
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_write_value()
  /// @see bt_gatt_write_type_e
  int bt_gatt_characteristic_set_write_type(
    bt_gatt_h characteristic,
    int write_type,
  ) {
    return _bt_gatt_characteristic_set_write_type(
      characteristic,
      write_type,
    );
  }

  late final _bt_gatt_characteristic_set_write_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_h, ffi.Int32)>>(
          'bt_gatt_characteristic_set_write_type');
  late final _bt_gatt_characteristic_set_write_type =
      _bt_gatt_characteristic_set_write_typePtr
          .asFunction<int Function(bt_gatt_h, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets a descriptor's GATT handle which has specific UUID.
  /// @since_tizen 2.3.1
  ///
  /// @remark The returned GATT handle must not be freed by application.
  /// It will be freed when an associated client is destroyed by bt_gatt_client_destroy().
  /// If there are multiple descriptors which have same UUID, only the first matched one will be returned.
  ///
  /// @param[in] characteristic The characteristic's GATT handle
  /// @param[in] uuid The descriptor's GATT handle which has this UUID will be returned if it exists
  /// @param[out] descriptor The descriptor's GATT handle which has @a uuid if it exists
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_characteristic_get_descriptor(
    bt_gatt_h characteristic,
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<bt_gatt_h> descriptor,
  ) {
    return _bt_gatt_characteristic_get_descriptor(
      characteristic,
      uuid,
      descriptor,
    );
  }

  late final _bt_gatt_characteristic_get_descriptorPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<bt_gatt_h>)>>(
      'bt_gatt_characteristic_get_descriptor');
  late final _bt_gatt_characteristic_get_descriptor =
      _bt_gatt_characteristic_get_descriptorPtr.asFunction<
          int Function(
              bt_gatt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<bt_gatt_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Invokes @a callback function on each descriptor that belongs to the specified characteristic.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] characteristic The characteristic's GATT handle
  /// @param[in] callback The function to be invoked on each descriptor
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_foreach_cb()
  int bt_gatt_characteristic_foreach_descriptors(
    bt_gatt_h characteristic,
    bt_gatt_foreach_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_characteristic_foreach_descriptors(
      characteristic,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_characteristic_foreach_descriptorsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_h, bt_gatt_foreach_cb, ffi.Pointer<ffi.Void>)>>(
      'bt_gatt_characteristic_foreach_descriptors');
  late final _bt_gatt_characteristic_foreach_descriptors =
      _bt_gatt_characteristic_foreach_descriptorsPtr.asFunction<
          int Function(bt_gatt_h, bt_gatt_foreach_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the characteristic's GATT handle which the specified descriptor belongs to.
  /// @since_tizen 2.3.1
  ///
  /// @remark The returned GATT handle must not be freed by application.
  /// It will be freed when an associated client is destroyed by bt_gatt_client_destroy().
  ///
  /// @param[in] descriptor The descriptor's GATT handle
  /// @param[out] characteristic The characteristic's GATT handle which @a descriptor belongs to
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_descriptor_get_characteristic(
    bt_gatt_h descriptor,
    ffi.Pointer<bt_gatt_h> characteristic,
  ) {
    return _bt_gatt_descriptor_get_characteristic(
      descriptor,
      characteristic,
    );
  }

  late final _bt_gatt_descriptor_get_characteristicPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_gatt_h, ffi.Pointer<bt_gatt_h>)>>(
      'bt_gatt_descriptor_get_characteristic');
  late final _bt_gatt_descriptor_get_characteristic =
      _bt_gatt_descriptor_get_characteristicPtr
          .asFunction<int Function(bt_gatt_h, ffi.Pointer<bt_gatt_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Creates the GATT client handle.
  /// @since_tizen 2.3.1
  ///
  /// @remark The GATT client handle must be freed by bt_gatt_client_destroy() after use
  ///
  /// @param[in] remote_address The address of the remote device
  /// @param[out] client The created GATT client's handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_ALREADY_DONE  Operation is already done
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_destroy()
  int bt_gatt_client_create(
    ffi.Pointer<ffi.Char> remote_address,
    ffi.Pointer<bt_gatt_client_h> client,
  ) {
    return _bt_gatt_client_create(
      remote_address,
      client,
    );
  }

  late final _bt_gatt_client_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<bt_gatt_client_h>)>>('bt_gatt_client_create');
  late final _bt_gatt_client_create = _bt_gatt_client_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<bt_gatt_client_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Destroys the GATT client's handle.
  /// @since_tizen 2.3.1
  ///
  /// @remark All related service, characteristic and descriptor's GATT handles are freed also
  ///
  /// @param[in] client The GATT client's handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_create()
  int bt_gatt_client_destroy(
    bt_gatt_client_h client,
  ) {
    return _bt_gatt_client_destroy(
      client,
    );
  }

  late final _bt_gatt_client_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_client_h)>>(
          'bt_gatt_client_destroy');
  late final _bt_gatt_client_destroy =
      _bt_gatt_client_destroyPtr.asFunction<int Function(bt_gatt_client_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Gets the address of remote device.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] client The created GATT client's handle
  /// @param[out] remote_address The address of the remote device which is associated with @a client
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_create()
  int bt_gatt_client_get_remote_address(
    bt_gatt_client_h client,
    ffi.Pointer<ffi.Pointer<ffi.Char>> remote_address,
  ) {
    return _bt_gatt_client_get_remote_address(
      client,
      remote_address,
    );
  }

  late final _bt_gatt_client_get_remote_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_client_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'bt_gatt_client_get_remote_address');
  late final _bt_gatt_client_get_remote_address =
      _bt_gatt_client_get_remote_addressPtr.asFunction<
          int Function(bt_gatt_client_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Reads the value of a characteristic or descriptor from the remote device asynchronously.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] gatt_handle The GATT handle of a characteristic or descriptor
  /// @param[in] callback When a read request is completed, this callback function will be called
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE	Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation now in progress
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_create()
  /// @see bt_gatt_client_request_completed_cb()
  int bt_gatt_client_read_value(
    bt_gatt_h gatt_handle,
    bt_gatt_client_request_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_client_read_value(
      gatt_handle,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_client_read_valuePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h, bt_gatt_client_request_completed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_gatt_client_read_value');
  late final _bt_gatt_client_read_value =
      _bt_gatt_client_read_valuePtr.asFunction<
          int Function(bt_gatt_h, bt_gatt_client_request_completed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Writes the value of a characteristic or descriptor to the remote device asynchronously.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] gatt_handle The GATT handle of a characteristic or descriptor
  /// @param[in] callback When a write request is completed, this callback function will be called
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE	Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Operation now in progress
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_create()
  /// @see bt_gatt_characteristic_set_write_type()
  /// @see bt_gatt_set_value()
  /// @see bt_gatt_set_int_value()
  /// @see bt_gatt_set_float_value()
  /// @see bt_gatt_client_request_completed_cb()
  int bt_gatt_client_write_value(
    bt_gatt_h gatt_handle,
    bt_gatt_client_request_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_client_write_value(
      gatt_handle,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_client_write_valuePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h, bt_gatt_client_request_completed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_gatt_client_write_value');
  late final _bt_gatt_client_write_value =
      _bt_gatt_client_write_valuePtr.asFunction<
          int Function(bt_gatt_h, bt_gatt_client_request_completed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief Requests a change of the ATT MTU value.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] client The created GATT client's handle
  /// @param[in] mtu The new MTU value
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  /// @see bt_gatt_client_set_att_mtu_changed_cb()
  int bt_gatt_client_request_att_mtu_change(
    bt_gatt_client_h client,
    int mtu,
  ) {
    return _bt_gatt_client_request_att_mtu_change(
      client,
      mtu,
    );
  }

  late final _bt_gatt_client_request_att_mtu_changePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_client_h,
              ffi.UnsignedInt)>>('bt_gatt_client_request_att_mtu_change');
  late final _bt_gatt_client_request_att_mtu_change =
      _bt_gatt_client_request_att_mtu_changePtr
          .asFunction<int Function(bt_gatt_client_h, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief Gets the ATT MTU value set for a connection.
  /// @since_tizen 4.0
  ///
  /// @param[in] client The created GATT client's handle
  /// @param[out] mtu The MTU value set for a connection
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED	Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED	Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  int bt_gatt_client_get_att_mtu(
    bt_gatt_client_h client,
    ffi.Pointer<ffi.UnsignedInt> mtu,
  ) {
    return _bt_gatt_client_get_att_mtu(
      client,
      mtu,
    );
  }

  late final _bt_gatt_client_get_att_mtuPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_client_h,
              ffi.Pointer<ffi.UnsignedInt>)>>('bt_gatt_client_get_att_mtu');
  late final _bt_gatt_client_get_att_mtu =
      _bt_gatt_client_get_att_mtuPtr.asFunction<
          int Function(bt_gatt_client_h, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Registers a callback function to be invoked when the ATT MTU is changed.
  /// @since_tizen 4.0
  /// @param[in] client The created GATT client's handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @post bt_device_connection_state_changed_cb() will be invoked.
  /// @see bt_initialize()
  /// @see bt_gatt_client_request_att_mtu_change()
  /// @see bt_gatt_client_unset_att_mtu_changed_cb()
  int bt_gatt_client_set_att_mtu_changed_cb(
    bt_gatt_client_h client,
    bt_gatt_client_att_mtu_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_client_set_att_mtu_changed_cb(
      client,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_client_set_att_mtu_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_client_h, bt_gatt_client_att_mtu_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_gatt_client_set_att_mtu_changed_cb');
  late final _bt_gatt_client_set_att_mtu_changed_cb =
      _bt_gatt_client_set_att_mtu_changed_cbPtr.asFunction<
          int Function(bt_gatt_client_h, bt_gatt_client_att_mtu_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief Unregisters the callback function to be invoked when the ATT MTU is changed.
  /// @since_tizen 4.0
  /// @param[in] client The created GATT client's handle
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @see bt_initialize()
  /// @see bt_gatt_client_request_att_mtu_change()
  /// @see bt_gatt_client_set_att_mtu_changed_cb()
  int bt_gatt_client_unset_att_mtu_changed_cb(
    bt_gatt_client_h client,
  ) {
    return _bt_gatt_client_unset_att_mtu_changed_cb(
      client,
    );
  }

  late final _bt_gatt_client_unset_att_mtu_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_client_h)>>(
          'bt_gatt_client_unset_att_mtu_changed_cb');
  late final _bt_gatt_client_unset_att_mtu_changed_cb =
      _bt_gatt_client_unset_att_mtu_changed_cbPtr
          .asFunction<int Function(bt_gatt_client_h)>();

  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Registers a callback function to be invoked when the characteristic value is changed on the remote device.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] characteristic The characteristic's GATT handle
  /// @param[in] callback The callback to be invoked when the value is changed and it is informed
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE	Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_characteristic_value_changed_cb()
  /// @see bt_gatt_client_unset_characteristic_value_change()
  int bt_gatt_client_set_characteristic_value_changed_cb(
    bt_gatt_h characteristic,
    bt_gatt_client_characteristic_value_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_client_set_characteristic_value_changed_cb(
      characteristic,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_client_set_characteristic_value_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_h,
                  bt_gatt_client_characteristic_value_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_gatt_client_set_characteristic_value_changed_cb');
  late final _bt_gatt_client_set_characteristic_value_changed_cb =
      _bt_gatt_client_set_characteristic_value_changed_cbPtr.asFunction<
          int Function(
              bt_gatt_h,
              bt_gatt_client_characteristic_value_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Unregisters a callback function to be invoked when the characteristic value is changed on the remote device.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] characteristic The characteristic's GATT handle, whose value change will not be informed
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE	Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_set_characteristic_value_changed_cb()
  int bt_gatt_client_unset_characteristic_value_changed_cb(
    bt_gatt_h characteristic,
  ) {
    return _bt_gatt_client_unset_characteristic_value_changed_cb(
      characteristic,
    );
  }

  late final _bt_gatt_client_unset_characteristic_value_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_h)>>(
          'bt_gatt_client_unset_characteristic_value_changed_cb');
  late final _bt_gatt_client_unset_characteristic_value_changed_cb =
      _bt_gatt_client_unset_characteristic_value_changed_cbPtr
          .asFunction<int Function(bt_gatt_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Gets a service's GATT handle which has specific UUID.
  /// @since_tizen 2.3.1
  ///
  /// @remark The returned GATT handle must not be freed by application.
  /// It will be freed when an associated client is destroyed by bt_gatt_client_destroy().
  /// If there are multiple services which have same UUID, only the first matched one will be returned.
  ///
  /// @param[in] client The GATT client's handle
  /// @param[in] uuid The service's GATT handle which has this UUID will be returned if it exists
  /// @param[out] service The service's GATT handle which has @a uuid if it exists
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_client_get_service(
    bt_gatt_client_h client,
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<bt_gatt_h> service,
  ) {
    return _bt_gatt_client_get_service(
      client,
      uuid,
      service,
    );
  }

  late final _bt_gatt_client_get_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_client_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bt_gatt_h>)>>('bt_gatt_client_get_service');
  late final _bt_gatt_client_get_service =
      _bt_gatt_client_get_servicePtr.asFunction<
          int Function(bt_gatt_client_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bt_gatt_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Invokes @a callback function on each service that belongs to the specified GATT client.
  /// @since_tizen 2.3.1
  ///
  /// @param[in] client The GATT client's handle
  /// @param[in] callback The function to be invoked on each service
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_foreach_cb()
  int bt_gatt_client_foreach_services(
    bt_gatt_client_h client,
    bt_gatt_foreach_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_client_foreach_services(
      client,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_client_foreach_servicesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_client_h, bt_gatt_foreach_cb,
              ffi.Pointer<ffi.Void>)>>('bt_gatt_client_foreach_services');
  late final _bt_gatt_client_foreach_services =
      _bt_gatt_client_foreach_servicesPtr.asFunction<
          int Function(
              bt_gatt_client_h, bt_gatt_foreach_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Registers a callback function to be invoked when service is changed from a remote device(GATT server).
  /// @since_tizen 3.0
  ///
  /// @param[in] client The GATT client's handle
  /// @param[in] callback The callback to be invoked
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_unset_service_changed_cb()
  int bt_gatt_client_set_service_changed_cb(
    bt_gatt_client_h client,
    bt_gatt_client_service_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_client_set_service_changed_cb(
      client,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_client_set_service_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_client_h, bt_gatt_client_service_changed_cb,
              ffi.Pointer<ffi.Void>)>>('bt_gatt_client_set_service_changed_cb');
  late final _bt_gatt_client_set_service_changed_cb =
      _bt_gatt_client_set_service_changed_cbPtr.asFunction<
          int Function(bt_gatt_client_h, bt_gatt_client_service_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief  Unregisters a callback function
  /// @since_tizen 3.0
  ///
  /// @param[in] client The GATT client's handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_client_set_service_changed_cb()
  int bt_gatt_client_unset_service_changed_cb(
    bt_gatt_client_h client,
  ) {
    return _bt_gatt_client_unset_service_changed_cb(
      client,
    );
  }

  late final _bt_gatt_client_unset_service_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_client_h)>>(
          'bt_gatt_client_unset_service_changed_cb');
  late final _bt_gatt_client_unset_service_changed_cb =
      _bt_gatt_client_unset_service_changed_cbPtr
          .asFunction<int Function(bt_gatt_client_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief Connect to a specific LE based service on a remote bluetooth device address, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks A connection can be disconnected by bt_gatt_disconnect().
  ///
  /// @param[in] address The address of the remote Bluetooth device.
  /// @param[in] auto_connect The flag of the auto connection.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED Not enabled
  /// @retval #BT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  /// @pre The remote device must support le connection.
  /// @post This function invokes bt_gatt_connection_state_changed_cb().
  ///
  /// @see bt_initialize()
  /// @see bt_gatt_disconnect()
  /// @see bt_gatt_set_connection_state_changed_cb()
  /// @see bt_gatt_unset_connection_state_changed_cb()
  /// @see bt_gatt_connection_state_changed_cb()
  int bt_gatt_connect(
    ffi.Pointer<ffi.Char> address,
    bool auto_connect,
  ) {
    return _bt_gatt_connect(
      address,
      auto_connect,
    );
  }

  late final _bt_gatt_connectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>, ffi.Bool)>>('bt_gatt_connect');
  late final _bt_gatt_connect = _bt_gatt_connectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, bool)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief Disconnect to LE connection with the given remote Bluetooth device address, asynchronously.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] address The address of the remote Bluetooth device
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED Not enabled
  /// @retval #BT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The connection must be established.
  /// @post This function invokes bt_gatt_connection_state_changed_cb().
  ///
  /// @see bt_initialize()
  /// @see bt_gatt_connect()
  /// @see bt_gatt_set_connection_state_changed_cb()
  /// @see bt_gatt_unset_connection_state_changed_cb()
  /// @see bt_gatt_connection_state_changed_cb()
  int bt_gatt_disconnect(
    ffi.Pointer<ffi.Char> address,
  ) {
    return _bt_gatt_disconnect(
      address,
    );
  }

  late final _bt_gatt_disconnectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_gatt_disconnect');
  late final _bt_gatt_disconnect =
      _bt_gatt_disconnectPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief Registers a callback function that will be invoked when the connection state is changed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in] callback The callback function to register.
  /// @param[in] user_data The user data to be passed  to the callback function.
  ///
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_connect()
  /// @see bt_gatt_disconnect()
  /// @see bt_gatt_unset_connection_state_changed_cb()
  int bt_gatt_set_connection_state_changed_cb(
    bt_gatt_connection_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_set_connection_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_gatt_set_connection_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'bt_gatt_set_connection_state_changed_cb');
  late final _bt_gatt_set_connection_state_changed_cb =
      _bt_gatt_set_connection_state_changed_cbPtr.asFunction<
          int Function(
              bt_gatt_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
  /// @brief Unregisters a callback function that will be invoked when the connection state is changed.
  /// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_connect()
  /// @see bt_gatt_disconnect()
  /// @see bt_gatt_connection_state_changed_cb()
  int bt_gatt_unset_connection_state_changed_cb() {
    return _bt_gatt_unset_connection_state_changed_cb();
  }

  late final _bt_gatt_unset_connection_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_gatt_unset_connection_state_changed_cb');
  late final _bt_gatt_unset_connection_state_changed_cb =
      _bt_gatt_unset_connection_state_changed_cbPtr
          .asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief Destroys the GATT handle of service.
  /// @since_tizen 3.0
  ///
  /// @param[in] gatt_handle The handle of service
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_service_create()
  int bt_gatt_service_destroy(
    bt_gatt_h gatt_handle,
  ) {
    return _bt_gatt_service_destroy(
      gatt_handle,
    );
  }

  late final _bt_gatt_service_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_h)>>(
          'bt_gatt_service_destroy');
  late final _bt_gatt_service_destroy =
      _bt_gatt_service_destroyPtr.asFunction<int Function(bt_gatt_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief Destroys the GATT handle of characteristic.
  /// @since_tizen 3.0
  ///
  /// @param[in] gatt_handle The handle of characteristic
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_characteristic_create()
  int bt_gatt_characteristic_destroy(
    bt_gatt_h gatt_handle,
  ) {
    return _bt_gatt_characteristic_destroy(
      gatt_handle,
    );
  }

  late final _bt_gatt_characteristic_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_h)>>(
          'bt_gatt_characteristic_destroy');
  late final _bt_gatt_characteristic_destroy =
      _bt_gatt_characteristic_destroyPtr.asFunction<int Function(bt_gatt_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief Destroys the GATT handle of descriptor.
  /// @since_tizen 3.0
  ///
  /// @param[in] gatt_handle The handle of descriptor
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_descriptor_create()
  int bt_gatt_descriptor_destroy(
    bt_gatt_h gatt_handle,
  ) {
    return _bt_gatt_descriptor_destroy(
      gatt_handle,
    );
  }

  late final _bt_gatt_descriptor_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_h)>>(
          'bt_gatt_descriptor_destroy');
  late final _bt_gatt_descriptor_destroy =
      _bt_gatt_descriptor_destroyPtr.asFunction<int Function(bt_gatt_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the permissions which a characteristic's GATT handle has.
  /// @since_tizen 3.0
  ///
  /// @remarks The @a permissions can be one or more values of #bt_gatt_permission_e, combined with bitwise 'or'.
  ///
  /// @param[in] gatt_handle The handle of a characteristic
  /// @param[out] permissions The permissions which a characteristic's GATT handle has
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_characteristic_create()
  /// @see bt_gatt_permission_e
  int bt_gatt_characteristic_get_permissions(
    bt_gatt_h gatt_handle,
    ffi.Pointer<ffi.Int> permissions,
  ) {
    return _bt_gatt_characteristic_get_permissions(
      gatt_handle,
      permissions,
    );
  }

  late final _bt_gatt_characteristic_get_permissionsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h,
              ffi.Pointer<ffi.Int>)>>('bt_gatt_characteristic_get_permissions');
  late final _bt_gatt_characteristic_get_permissions =
      _bt_gatt_characteristic_get_permissionsPtr
          .asFunction<int Function(bt_gatt_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Gets the permissions which a descriptor's GATT handle has.
  /// @since_tizen 3.0
  ///
  /// @remarks The @a permissions can be one or more values of #bt_gatt_permission_e, combined with bitwise 'or'.
  ///
  /// @param[in] gatt_handle The handle of a descriptor
  /// @param[out] permissions The permissions which a descriptor's GATT handle has
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_descriptor_create()
  /// @see bt_gatt_permission_e
  int bt_gatt_descriptor_get_permissions(
    bt_gatt_h gatt_handle,
    ffi.Pointer<ffi.Int> permissions,
  ) {
    return _bt_gatt_descriptor_get_permissions(
      gatt_handle,
      permissions,
    );
  }

  late final _bt_gatt_descriptor_get_permissionsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h,
              ffi.Pointer<ffi.Int>)>>('bt_gatt_descriptor_get_permissions');
  late final _bt_gatt_descriptor_get_permissions =
      _bt_gatt_descriptor_get_permissionsPtr
          .asFunction<int Function(bt_gatt_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Creates the GATT service.
  /// @since_tizen 3.0
  ///
  /// @remarks The @a service should be destroyed by using bt_gatt_service_destroy()
  ///
  /// @param[in] uuid The UUID of the service
  /// @param[in] type The type of the service
  /// @param[out] service The GATT handle of the created service
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_service_destroy()
  int bt_gatt_service_create(
    ffi.Pointer<ffi.Char> uuid,
    int type,
    ffi.Pointer<bt_gatt_h> service,
  ) {
    return _bt_gatt_service_create(
      uuid,
      type,
      service,
    );
  }

  late final _bt_gatt_service_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int32,
              ffi.Pointer<bt_gatt_h>)>>('bt_gatt_service_create');
  late final _bt_gatt_service_create = _bt_gatt_service_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, int, ffi.Pointer<bt_gatt_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Adds a characteristic to a specified service.
  /// @since_tizen 3.0
  ///
  /// @param[in] service The service's GATT handle
  /// @param[in] characteristic The characteristic's GATT handle to be added
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_service_create()
  /// @see bt_gatt_characteristic_create()
  int bt_gatt_service_add_characteristic(
    bt_gatt_h service,
    bt_gatt_h characteristic,
  ) {
    return _bt_gatt_service_add_characteristic(
      service,
      characteristic,
    );
  }

  late final _bt_gatt_service_add_characteristicPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_h, bt_gatt_h)>>(
          'bt_gatt_service_add_characteristic');
  late final _bt_gatt_service_add_characteristic =
      _bt_gatt_service_add_characteristicPtr
          .asFunction<int Function(bt_gatt_h, bt_gatt_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Adds a service to a specified service as included service.
  /// @since_tizen 3.0
  ///
  /// @param[in] service The service's GATT handle
  /// @param[in] included_service The service's GATT handle to be added as included service
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_service_create()
  int bt_gatt_service_add_included_service(
    bt_gatt_h service,
    bt_gatt_h included_service,
  ) {
    return _bt_gatt_service_add_included_service(
      service,
      included_service,
    );
  }

  late final _bt_gatt_service_add_included_servicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_h, bt_gatt_h)>>(
          'bt_gatt_service_add_included_service');
  late final _bt_gatt_service_add_included_service =
      _bt_gatt_service_add_included_servicePtr
          .asFunction<int Function(bt_gatt_h, bt_gatt_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Gets the GATT server handle to which the specified service belongs.
  /// @since_tizen 3.0
  ///
  /// @remarks The returned Server handle must not be freed by application.
  ///
  /// @param[in] service The service's GATT handle
  /// @param[out] server The GATT server handle to which @a service belongs
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_create()
  /// @see bt_gatt_service_create()
  /// @see bt_gatt_server_register_service()
  int bt_gatt_service_get_server(
    bt_gatt_h service,
    ffi.Pointer<bt_gatt_server_h> server,
  ) {
    return _bt_gatt_service_get_server(
      service,
      server,
    );
  }

  late final _bt_gatt_service_get_serverPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_h,
              ffi.Pointer<bt_gatt_server_h>)>>('bt_gatt_service_get_server');
  late final _bt_gatt_service_get_server = _bt_gatt_service_get_serverPtr
      .asFunction<int Function(bt_gatt_h, ffi.Pointer<bt_gatt_server_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Creates the GATT characteristic.
  /// @since_tizen 3.0
  ///
  /// @remarks The @a permissions can be one or more values of #bt_gatt_permission_e, combined with bitwise 'or'.
  /// @remarks The @a properties can be one or more values of #bt_gatt_property_e, combined with bitwise 'or'.
  /// @remarks The @a characteristic should be destroyed by using bt_gatt_characteristic_destroy().
  ///
  /// @param[in] uuid The UUID of the characteristic
  /// @param[in] permissions the permissions of the characteristic
  /// @param[in] properties The properties of the characteristic
  /// @param[in] value The value(byte stream) of the characteristic
  /// @param[in] value_length The length of @a value
  /// @param[out] characteristic The GATT handle of the created characteristic
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_characteristic_destroy()
  int bt_gatt_characteristic_create(
    ffi.Pointer<ffi.Char> uuid,
    int permissions,
    int properties,
    ffi.Pointer<ffi.Char> value,
    int value_length,
    ffi.Pointer<bt_gatt_h> characteristic,
  ) {
    return _bt_gatt_characteristic_create(
      uuid,
      permissions,
      properties,
      value,
      value_length,
      characteristic,
    );
  }

  late final _bt_gatt_characteristic_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Int,
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Pointer<bt_gatt_h>)>>('bt_gatt_characteristic_create');
  late final _bt_gatt_characteristic_create =
      _bt_gatt_characteristic_createPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, int, ffi.Pointer<ffi.Char>,
              int, ffi.Pointer<bt_gatt_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Adds a descriptor to a specified characteristic.
  /// @since_tizen 3.0
  ///
  /// @param[in] characteristic The GATT handle of the characteristic
  /// @param[in] descriptor The descriptor's GATT handle to be added
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_characteristic_create()
  /// @see bt_gatt_descriptor_create()
  int bt_gatt_characteristic_add_descriptor(
    bt_gatt_h characteristic,
    bt_gatt_h descriptor,
  ) {
    return _bt_gatt_characteristic_add_descriptor(
      characteristic,
      descriptor,
    );
  }

  late final _bt_gatt_characteristic_add_descriptorPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_h, bt_gatt_h)>>(
          'bt_gatt_characteristic_add_descriptor');
  late final _bt_gatt_characteristic_add_descriptor =
      _bt_gatt_characteristic_add_descriptorPtr
          .asFunction<int Function(bt_gatt_h, bt_gatt_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
  /// @brief  Creates the GATT characteristic descriptor.
  /// @since_tizen 3.0
  ///
  /// @remarks The @a permissions can be one or more values of #bt_gatt_permission_e, combined with bitwise 'or'.
  /// @remarks The @a descriptor should be destroyed by using bt_gatt_descriptor_destroy().
  ///
  /// @param[in] uuid The UUID of the descriptor
  /// @param[in] permissions The permissions of the descriptor
  /// @param[in] value The value(byte stream) associated with the descriptor
  /// @param[in] value_length The length of @a value
  /// @param[out] descriptor The GATT handle of the created characteristic descriptor
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_descriptor_destroy()
  int bt_gatt_descriptor_create(
    ffi.Pointer<ffi.Char> uuid,
    int permissions,
    ffi.Pointer<ffi.Char> value,
    int value_length,
    ffi.Pointer<bt_gatt_h> descriptor,
  ) {
    return _bt_gatt_descriptor_create(
      uuid,
      permissions,
      value,
      value_length,
      descriptor,
    );
  }

  late final _bt_gatt_descriptor_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Pointer<bt_gatt_h>)>>('bt_gatt_descriptor_create');
  late final _bt_gatt_descriptor_create =
      _bt_gatt_descriptor_createPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, ffi.Pointer<ffi.Char>, int,
              ffi.Pointer<bt_gatt_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief Initializes the GATT Server.
  /// @since_tizen 3.0
  ///
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre	The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @see	bt_gatt_server_deinitialize()
  int bt_gatt_server_initialize() {
    return _bt_gatt_server_initialize();
  }

  late final _bt_gatt_server_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_gatt_server_initialize');
  late final _bt_gatt_server_initialize =
      _bt_gatt_server_initializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief DeInitializes the GATT server.
  /// @since_tizen 3.0
  ///
  /// @return  0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE	Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre	The state of local Bluetooth must be #BT_ADAPTER_ENABLED.
  /// @see	bt_gatt_server_initialize()
  int bt_gatt_server_deinitialize() {
    return _bt_gatt_server_deinitialize();
  }

  late final _bt_gatt_server_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_gatt_server_deinitialize');
  late final _bt_gatt_server_deinitialize =
      _bt_gatt_server_deinitializePtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Creates the GATT server's handle.
  /// @since_tizen 3.0
  ///
  /// @remarks The @a server handle should be destroyed by using bt_gatt_server_destroy()
  ///
  /// @param[out] server The GATT server's handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_destroy()
  int bt_gatt_server_create(
    ffi.Pointer<bt_gatt_server_h> server,
  ) {
    return _bt_gatt_server_create(
      server,
    );
  }

  late final _bt_gatt_server_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<bt_gatt_server_h>)>>(
      'bt_gatt_server_create');
  late final _bt_gatt_server_create = _bt_gatt_server_createPtr
      .asFunction<int Function(ffi.Pointer<bt_gatt_server_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Destroys the GATT server's handle.
  /// @since_tizen 3.0
  ///
  /// @remarks All registered services to GATT server are unregistered
  ///
  /// @param[in] server The GATT server's handle
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_create()
  int bt_gatt_server_destroy(
    bt_gatt_server_h server,
  ) {
    return _bt_gatt_server_destroy(
      server,
    );
  }

  late final _bt_gatt_server_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_server_h)>>(
          'bt_gatt_server_destroy');
  late final _bt_gatt_server_destroy =
      _bt_gatt_server_destroyPtr.asFunction<int Function(bt_gatt_server_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Registers a callback function to be invoked when a read request for a specified characteristic or descriptor is issued from a remote device(GATT client).
  /// @since_tizen 3.0
  ///
  /// @param[in] gatt_handle The GATT handle of a characteristic or descriptor
  /// @param[in] callback The callback to be invoked
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_read_value_requested_cb()
  /// @see bt_gatt_server_send_response()
  int bt_gatt_server_set_read_value_requested_cb(
    bt_gatt_h gatt_handle,
    bt_gatt_server_read_value_requested_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_server_set_read_value_requested_cb(
      gatt_handle,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_server_set_read_value_requested_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_h,
                  bt_gatt_server_read_value_requested_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_gatt_server_set_read_value_requested_cb');
  late final _bt_gatt_server_set_read_value_requested_cb =
      _bt_gatt_server_set_read_value_requested_cbPtr.asFunction<
          int Function(bt_gatt_h, bt_gatt_server_read_value_requested_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Registers a callback function to be invoked when the remote device enables or disables the Notification/Indication for particular characteristics.
  /// @since_tizen 3.0
  ///
  /// @param[in] gatt_handle The GATT handle of a characteristic
  /// @param[in] callback The callback to be invoked
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return	0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  ///
  /// @see bt_gatt_server_characteristic_notification_state_changed_cb()
  int bt_gatt_server_set_characteristic_notification_state_change_cb(
    bt_gatt_h gatt_handle,
    bt_gatt_server_characteristic_notification_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_server_set_characteristic_notification_state_change_cb(
      gatt_handle,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_server_set_characteristic_notification_state_change_cbPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      bt_gatt_h,
                      bt_gatt_server_characteristic_notification_state_changed_cb,
                      ffi.Pointer<ffi.Void>)>>(
          'bt_gatt_server_set_characteristic_notification_state_change_cb');
  late final _bt_gatt_server_set_characteristic_notification_state_change_cb =
      _bt_gatt_server_set_characteristic_notification_state_change_cbPtr
          .asFunction<
              int Function(
                  bt_gatt_h,
                  bt_gatt_server_characteristic_notification_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Registers a callback function to be invoked when a value of a characteristic or descriptor has been changed by a remote device(GATT client)'s request.
  /// @since_tizen 3.0
  ///
  /// @param[in] gatt_handle The GATT handle of a characteristic or descriptor
  /// @param[in] callback The callback to be invoked
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_write_value_requested_cb()
  int bt_gatt_server_set_write_value_requested_cb(
    bt_gatt_h gatt_handle,
    bt_gatt_server_write_value_requested_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_server_set_write_value_requested_cb(
      gatt_handle,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_server_set_write_value_requested_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_gatt_h,
                  bt_gatt_server_write_value_requested_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'bt_gatt_server_set_write_value_requested_cb');
  late final _bt_gatt_server_set_write_value_requested_cb =
      _bt_gatt_server_set_write_value_requested_cbPtr.asFunction<
          int Function(bt_gatt_h, bt_gatt_server_write_value_requested_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Registers a specified service to the specified GATT server that the local device is hosting.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] server The GATT server that local device is hosting
  /// @param[in] service The service, which needs to be registered in @a server
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_ALREADY_DONE Operation is already done
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_create()
  /// @see bt_gatt_service_create()
  /// @see bt_gatt_server_start()
  /// @see bt_gatt_server_unregister_service()
  int bt_gatt_server_register_service(
    bt_gatt_server_h server,
    bt_gatt_h service,
  ) {
    return _bt_gatt_server_register_service(
      server,
      service,
    );
  }

  late final _bt_gatt_server_register_servicePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(bt_gatt_server_h, bt_gatt_h)>>(
      'bt_gatt_server_register_service');
  late final _bt_gatt_server_register_service =
      _bt_gatt_server_register_servicePtr
          .asFunction<int Function(bt_gatt_server_h, bt_gatt_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Unregisters a specified service from the specified GATT server that the local device is hosting.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] server The GATT server that local device is hosting
  /// @param[in] service The service, which needs to be unregistered from @a server
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_SERVICE_NOT_FOUND  Service not found
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_register_service()
  int bt_gatt_server_unregister_service(
    bt_gatt_server_h server,
    bt_gatt_h service,
  ) {
    return _bt_gatt_server_unregister_service(
      server,
      service,
    );
  }

  late final _bt_gatt_server_unregister_servicePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(bt_gatt_server_h, bt_gatt_h)>>(
      'bt_gatt_server_unregister_service');
  late final _bt_gatt_server_unregister_service =
      _bt_gatt_server_unregister_servicePtr
          .asFunction<int Function(bt_gatt_server_h, bt_gatt_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Unregisters all services from the specified GATT server that the local device is hosting.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] server The GATT server that local device is hosting
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_register_service()
  int bt_gatt_server_unregister_all_services(
    bt_gatt_server_h server,
  ) {
    return _bt_gatt_server_unregister_all_services(
      server,
    );
  }

  late final _bt_gatt_server_unregister_all_servicesPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_gatt_server_h)>>(
          'bt_gatt_server_unregister_all_services');
  late final _bt_gatt_server_unregister_all_services =
      _bt_gatt_server_unregister_all_servicesPtr
          .asFunction<int Function(bt_gatt_server_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Registers the application along with the GATT services of the application it is hosting.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_ALREADY_DONE Operation is already done
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_initialize()
  /// @see bt_gatt_server_create()
  /// @see bt_gatt_service_create()
  /// @see bt_gatt_server_unregister_service()
  int bt_gatt_server_start() {
    return _bt_gatt_server_start();
  }

  late final _bt_gatt_server_startPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('bt_gatt_server_start');
  late final _bt_gatt_server_start =
      _bt_gatt_server_startPtr.asFunction<int Function()>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Sends a response to the remote device as a result of a read/write request.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks Until this function is called, a read/write request is not finished.
  ///
  /// @param[in] request_id The identification of a read/write request
  /// @param[in] request_type The request type for read/write
  /// @param[in] offset The offset from where a value is read
  /// @param[in] resp_status The application error if any occurred or BT_ERROR_NONE for successful.
  /// @param[in] value The value to be sent. It will be sent from @a offset. If it is NULL, a requested GATT handle's value will be sent from @a offset.
  /// @param[in] value_length Value Length
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_read_value_requested_cb()
  int bt_gatt_server_send_response(
    int request_id,
    int request_type,
    int offset,
    int resp_status,
    ffi.Pointer<ffi.Char> value,
    int value_length,
  ) {
    return _bt_gatt_server_send_response(
      request_id,
      request_type,
      offset,
      resp_status,
      value,
      value_length,
    );
  }

  late final _bt_gatt_server_send_responsePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int32, ffi.Int, ffi.Int,
              ffi.Pointer<ffi.Char>, ffi.Int)>>('bt_gatt_server_send_response');
  late final _bt_gatt_server_send_response =
      _bt_gatt_server_send_responsePtr.asFunction<
          int Function(int, int, int, int, ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Notifies value change of the characteristic to the remote devices which enable a Client Characteristic Configuration Descriptor.
  /// @since_tizen 3.0
  ///
  /// @param[in] characteristic The characteristic which has a changed value
  /// @param[in] callback The function to be invoked on each remote device when a sending operation is done
  /// @param[in] device_address Remote device address to send notify or indicate and if set to NULL then notify/indicate all is enabled.
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_server_notification_sent_cb()
  int bt_gatt_server_notify_characteristic_changed_value(
    bt_gatt_h characteristic,
    bt_gatt_server_notification_sent_cb callback,
    ffi.Pointer<ffi.Char> device_address,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_server_notify_characteristic_changed_value(
      characteristic,
      callback,
      device_address,
      user_data,
    );
  }

  late final _bt_gatt_server_notify_characteristic_changed_valuePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_gatt_h, bt_gatt_server_notification_sent_cb,
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>(
      'bt_gatt_server_notify_characteristic_changed_value');
  late final _bt_gatt_server_notify_characteristic_changed_value =
      _bt_gatt_server_notify_characteristic_changed_valuePtr.asFunction<
          int Function(bt_gatt_h, bt_gatt_server_notification_sent_cb,
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Gets a service's GATT handle which has specific UUID.
  /// @since_tizen 3.0
  ///
  /// @remark The returned GATT handle must not be freed by application.
  /// It will be freed when an associated server is destroyed by bt_gatt_server_destroy().
  /// If there are multiple services which have same UUID, only the first matched one will be returned.
  ///
  /// @param[in] server The GATT server's handle
  /// @param[in] uuid The service's GATT handle which has this UUID will be returned if it exists
  /// @param[out] service The service's GATT handle which has @a uuid if it exists
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NO_DATA  No data available
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  int bt_gatt_server_get_service(
    bt_gatt_server_h server,
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<bt_gatt_h> service,
  ) {
    return _bt_gatt_server_get_service(
      server,
      uuid,
      service,
    );
  }

  late final _bt_gatt_server_get_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_server_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bt_gatt_h>)>>('bt_gatt_server_get_service');
  late final _bt_gatt_server_get_service =
      _bt_gatt_server_get_servicePtr.asFunction<
          int Function(bt_gatt_server_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<bt_gatt_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
  /// @brief  Invokes @a callback function on each service that belongs to the specified GATT server.
  /// @since_tizen 3.0
  ///
  /// @param[in] server The GATT server's handle
  /// @param[in] callback The function to be invoked on each service
  /// @param[in] user_data The user data to be passed to @a callback function
  /// @return  0 on success, otherwise a negative error value
  /// @retval #BT_ERROR_NONE Successful
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @see bt_gatt_foreach_cb()
  int bt_gatt_server_foreach_services(
    bt_gatt_server_h server,
    bt_gatt_foreach_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_gatt_server_foreach_services(
      server,
      callback,
      user_data,
    );
  }

  late final _bt_gatt_server_foreach_servicesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(bt_gatt_server_h, bt_gatt_foreach_cb,
              ffi.Pointer<ffi.Void>)>>('bt_gatt_server_foreach_services');
  late final _bt_gatt_server_foreach_services =
      _bt_gatt_server_foreach_servicesPtr.asFunction<
          int Function(
              bt_gatt_server_h, bt_gatt_foreach_cb, ffi.Pointer<ffi.Void>)>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief Initializes the Bluetooth PBAP Client.
  /// @details This initialization is necessary to call other PBAP client APIs.
  /// @since_tizen 3.0
  ///
  /// @remarks This function must be called to initialize Bluetooth PBAP client. You must free all resources of the Bluetooth service
  /// by calling bt_pbap_client_deinitialize() if Bluetooth PBAP Client is no longer needed.
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of the local Bluetooth adapter must be #BT_ADAPTER_ENABLED.
  ///
  /// @see  bt_pbap_client_deinitialize()
  /// @see  bt_pbap_client_connect()
  /// @see  bt_pbap_client_disconnect()
  /// @see  bt_pbap_client_get_phone_book_size()
  /// @see  bt_pbap_client_get_phone_book()
  /// @see  bt_pbap_client_get_list()
  /// @see  bt_pbap_client_pull_vcard()
  /// @see  bt_pbap_client_search_phone_book()
  int bt_pbap_client_initialize() {
    return _bt_pbap_client_initialize();
  }

  late final _bt_pbap_client_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_pbap_client_initialize');
  late final _bt_pbap_client_initialize =
      _bt_pbap_client_initializePtr.asFunction<int Function()>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief Deinitializes the Bluetooth PBAP Client.
  /// @details This deinitialization must be done to free resources when the PBAP client is not longer needed.
  /// @since_tizen 3.0
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOT_ENABLED  Not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of the local Bluetooth adapter must be #BT_ADAPTER_ENABLED.
  /// The PBAP client must be initialized with bt_pbap_client_initialize().
  /// @see  bt_pbap_client_deinitialize()
  /// @see  bt_pbap_client_connect()
  /// @see  bt_pbap_client_disconnect()
  /// @see  bt_pbap_client_get_phone_book_size()
  /// @see  bt_pbap_client_get_phone_book()
  /// @see  bt_pbap_client_get_list()
  /// @see  bt_pbap_client_pull_vcard()
  /// @see  bt_pbap_client_search_phone_book()
  int bt_pbap_client_deinitialize() {
    return _bt_pbap_client_deinitialize();
  }

  late final _bt_pbap_client_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_pbap_client_deinitialize');
  late final _bt_pbap_client_deinitialize =
      _bt_pbap_client_deinitializePtr.asFunction<int Function()>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief  Registers a callback function that will be invoked when the connection state is changed.
  /// @since_tizen 3.0
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The PBAP client must be initialized with bt_pbap_client_initialize().
  /// @see bt_pbap_client_initialize()
  int bt_pbap_client_set_connection_state_changed_cb(
    bt_pbap_connection_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_pbap_client_set_connection_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _bt_pbap_client_set_connection_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_pbap_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'bt_pbap_client_set_connection_state_changed_cb');
  late final _bt_pbap_client_set_connection_state_changed_cb =
      _bt_pbap_client_set_connection_state_changed_cbPtr.asFunction<
          int Function(
              bt_pbap_connection_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief  Unregisters a callback function that will be invoked when the connection state is changed.
  /// @since_tizen 3.0
  /// @return   0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The PBAP client must be initialized with bt_pbap_client_initialize().
  /// @see bt_pbap_client_initialize()
  int bt_pbap_client_unset_connection_state_changed_cb() {
    return _bt_pbap_client_unset_connection_state_changed_cb();
  }

  late final _bt_pbap_client_unset_connection_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_pbap_client_unset_connection_state_changed_cb');
  late final _bt_pbap_client_unset_connection_state_changed_cb =
      _bt_pbap_client_unset_connection_state_changed_cbPtr
          .asFunction<int Function()>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief Connects to PBAP server, asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] address The other device's address
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Adapter is not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of the local Bluetooth adapter must be #BT_ADAPTER_ENABLED.
  /// @pre The PBAP client must be initialized with bt_pbap_client_initialize().
  /// @pre The local device must be bonded with the remote device by bt_device_create_bond().
  /// @post bt_pbap_connection_state_changed_cb() will be invoked.
  /// @see bt_pbap_client_disconnect()
  /// @see bt_pbap_client_set_connection_state_changed_cb()
  int bt_pbap_client_connect(
    ffi.Pointer<ffi.Char> address,
  ) {
    return _bt_pbap_client_connect(
      address,
    );
  }

  late final _bt_pbap_client_connectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_pbap_client_connect');
  late final _bt_pbap_client_connect = _bt_pbap_client_connectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief Disconnects from PBAP server, asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] address The other device's address
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Adapter is not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of the local Bluetooth adapter must be #BT_ADAPTER_ENABLED.
  /// @pre The PBAP client must be initialized with bt_pbap_client_initialize().
  /// @pre PBAP connection must be created with bt_pbap_client_connect().
  /// @post bt_pbap_connection_state_changed_cb() will be invoked.
  /// @see bt_pbap_client_connect()
  /// @see bt_pbap_client_set_connection_state_changed_cb()
  int bt_pbap_client_disconnect(
    ffi.Pointer<ffi.Char> address,
  ) {
    return _bt_pbap_client_disconnect(
      address,
    );
  }

  late final _bt_pbap_client_disconnectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'bt_pbap_client_disconnect');
  late final _bt_pbap_client_disconnect = _bt_pbap_client_disconnectPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief Gets size of phone book from PBAP server, asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] address The other device's address
  /// @param[in] source Source of the phone book (Phone/SIM)
  /// @param[in] folder_type Type of folder
  /// @param[in] callback The callback function called when PBAP phone book size is returned.
  /// @param[in] user_data Data to be passed to the PBAP phone book size callback.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Adapter is not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of the local Bluetooth adapter must be #BT_ADAPTER_ENABLED.
  /// @pre The PBAP client must be initialized with bt_pbap_client_initialize().
  /// @pre PBAP connection must be created with bt_pbap_client_connect().
  ///
  /// @see bt_pbap_client_connect()
  int bt_pbap_client_get_phone_book_size(
    ffi.Pointer<ffi.Char> address,
    int source,
    int folder_type,
    bt_pbap_phone_book_size_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_pbap_client_get_phone_book_size(
      address,
      source,
      folder_type,
      callback,
      user_data,
    );
  }

  late final _bt_pbap_client_get_phone_book_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Int32,
              bt_pbap_phone_book_size_cb,
              ffi.Pointer<ffi.Void>)>>('bt_pbap_client_get_phone_book_size');
  late final _bt_pbap_client_get_phone_book_size =
      _bt_pbap_client_get_phone_book_sizePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, int,
              bt_pbap_phone_book_size_cb, ffi.Pointer<ffi.Void>)>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief Gets all contacts and call logs as vCard from PBAP server, asynchronously.
  /// @details The received phone book file will be saved in the platform downloads folder.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege http://tizen.org/privilege/bluetooth
  /// http://tizen.org/privilege/mediastorage
  ///
  /// @param[in] address The other device's address
  /// @param[in] source Source of phone book (Phone/SIM)
  /// @param[in] folder_type Type of folder
  /// @param[in] format The vCard format
  /// @param[in] order Specifies which field shall be used to sort vCards.
  /// @param[in] offset The number of vCards to be excluded, counting from the beginning
  /// @param[in] max_list_count The maximum number of vCards to be fetched
  /// @param[in] fields vCard fields to be fetched; one or more #bt_pbap_field_e values combined with bitwise 'or'
  /// @param[in] callback The callback function called when PBAP phone book is Pulled.
  /// @param[in] user_data Data to be passed to the PBAP phone book pulling callback.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Adapter is not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of the local Bluetooth adapter must be #BT_ADAPTER_ENABLED.
  /// @pre The PBAP client must be initialized with bt_pbap_client_initialize().
  /// @pre PBAP connection must be created with bt_pbap_client_connect().
  ///
  /// @see bt_pbap_client_connect()
  int bt_pbap_client_get_phone_book(
    ffi.Pointer<ffi.Char> address,
    int source,
    int folder_type,
    int format,
    int order,
    int offset,
    int max_list_count,
    int fields,
    bt_pbap_phone_book_received_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_pbap_client_get_phone_book(
      address,
      source,
      folder_type,
      format,
      order,
      offset,
      max_list_count,
      fields,
      callback,
      user_data,
    );
  }

  late final _bt_pbap_client_get_phone_bookPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Int32,
              ffi.Int32,
              ffi.Int32,
              ffi.UnsignedShort,
              ffi.UnsignedShort,
              ffi.UnsignedInt,
              bt_pbap_phone_book_received_cb,
              ffi.Pointer<ffi.Void>)>>('bt_pbap_client_get_phone_book');
  late final _bt_pbap_client_get_phone_book =
      _bt_pbap_client_get_phone_bookPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, int, int, int, int, int, int,
              bt_pbap_phone_book_received_cb, ffi.Pointer<ffi.Void>)>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief Gets contact and call log information from the PBAP server, asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] address The other device's address
  /// @param[in] source Source of phone book (Phone/SIM)
  /// @param[in] folder_type Type of folder
  /// @param[in] order Specifies which field shall be used to sort vCards.
  /// @param[in] offset vCards to be excluded from beginning.
  /// @param[in] max_list_count Maximum number of vCards to be fetched
  /// @param[in] callback The callback function called when PBAP List is returned.
  /// @param[in] user_data Data to be passed to the PBAP phone book pulling callback.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Adapter is not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of the local Bluetooth adapter must be #BT_ADAPTER_ENABLED.
  /// @pre The PBAP client must be initialized with bt_pbap_client_initialize().
  /// @pre PBAP connection must be created with bt_pbap_client_connect().
  ///
  /// @see bt_pbap_client_connect()
  int bt_pbap_client_get_list(
    ffi.Pointer<ffi.Char> address,
    int source,
    int folder_type,
    int order,
    int offset,
    int max_list_count,
    bt_pbap_list_vcards_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_pbap_client_get_list(
      address,
      source,
      folder_type,
      order,
      offset,
      max_list_count,
      callback,
      user_data,
    );
  }

  late final _bt_pbap_client_get_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Int32,
              ffi.Int32,
              ffi.UnsignedShort,
              ffi.UnsignedShort,
              bt_pbap_list_vcards_cb,
              ffi.Pointer<ffi.Void>)>>('bt_pbap_client_get_list');
  late final _bt_pbap_client_get_list = _bt_pbap_client_get_listPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, int, int, int, int, int,
          bt_pbap_list_vcards_cb, ffi.Pointer<ffi.Void>)>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief Gets the selected contact using the index parameter as vCard from PBAP server, asynchronously.
  /// @details The received phone book file will be saved in the platform downloads folder.
  /// The @a index value should be equal to the value of the @a index field in the #bt_pbap_vcard_info_s structure,
  /// which can be obtained with bt_pbap_client_get_list() or bt_pbap_client_search_phone_book().
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege http://tizen.org/privilege/bluetooth
  /// http://tizen.org/privilege/mediastorage
  ///
  /// @param[in] address The other device's address
  /// @param[in] source Source of phone book (Phone/SIM)
  /// @param[in] folder_type Type of folder
  /// @param[in] index The handle index of vCard to be fetched
  /// @param[in] format Format of vCard
  /// @param[in] fields vCard fields to be fetched; one or more #bt_pbap_field_e values combined with bitwise 'or'
  /// @param[in] callback The callback function called when PBAP phone book is Pulled.
  /// @param[in] user_data Data to be passed to the PBAP phone book Pulling callback.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Adapter is not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of the local Bluetooth adapter must be #BT_ADAPTER_ENABLED.
  /// @pre The PBAP client must be initialized with bt_pbap_client_initialize().
  /// @pre PBAP connection must be created with bt_pbap_client_connect().
  /// @pre The vCard information (#bt_pbap_vcard_info_s) must be obtained with bt_pbap_client_get_list() or bt_pbap_client_search_phone_book().
  /// @see bt_pbap_client_connect()
  /// @see bt_pbap_client_get_list()
  /// @see bt_pbap_client_search_phone_book()
  int bt_pbap_client_pull_vcard(
    ffi.Pointer<ffi.Char> address,
    int source,
    int folder_type,
    int index,
    int format,
    int fields,
    bt_pbap_phone_book_received_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_pbap_client_pull_vcard(
      address,
      source,
      folder_type,
      index,
      format,
      fields,
      callback,
      user_data,
    );
  }

  late final _bt_pbap_client_pull_vcardPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Int32,
              ffi.Int,
              ffi.Int32,
              ffi.UnsignedInt,
              bt_pbap_phone_book_received_cb,
              ffi.Pointer<ffi.Void>)>>('bt_pbap_client_pull_vcard');
  late final _bt_pbap_client_pull_vcard =
      _bt_pbap_client_pull_vcardPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, int, int, int, int,
              bt_pbap_phone_book_received_cb, ffi.Pointer<ffi.Void>)>();

  /// @WEARABLE_ONLY
  /// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
  /// @brief Finds and fetches the contact and call log information from the PBAP server, asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] address The other device's address
  /// @param[in] source Source of phone book (Phone/SIM)
  /// @param[in] folder_type Type of folder
  /// @param[in] search_attribute field to be search
  /// @param[in] search_value pattern to be searched for
  /// @param[in] order Specifies which field shall be used to sort vCards.
  /// @param[in] offset vCards to be excluded from beginning.
  /// @param[in] max_list_count Maximum number of vCards to be fetched
  /// @param[in] callback The callback function called when PBAP List is returned.
  /// @param[in] user_data Data to be passed to the PBAP phone book pulling callback.
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_ENABLED  Adapter is not enabled
  /// @retval #BT_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The state of the local Bluetooth adapter must be #BT_ADAPTER_ENABLED.
  /// @pre The PBAP client must be initialized with bt_pbap_client_initialize().
  /// @pre PBAP connection must be created with bt_pbap_client_connect().
  ///
  /// @see bt_pbap_client_connect()
  int bt_pbap_client_search_phone_book(
    ffi.Pointer<ffi.Char> address,
    int source,
    int folder_type,
    int search_attribute,
    ffi.Pointer<ffi.Char> search_value,
    int order,
    int offset,
    int max_list_count,
    bt_pbap_list_vcards_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _bt_pbap_client_search_phone_book(
      address,
      source,
      folder_type,
      search_attribute,
      search_value,
      order,
      offset,
      max_list_count,
      callback,
      user_data,
    );
  }

  late final _bt_pbap_client_search_phone_bookPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Int32,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.UnsignedShort,
              ffi.UnsignedShort,
              bt_pbap_list_vcards_cb,
              ffi.Pointer<ffi.Void>)>>('bt_pbap_client_search_phone_book');
  late final _bt_pbap_client_search_phone_book =
      _bt_pbap_client_search_phone_bookPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              int,
              int,
              int,
              ffi.Pointer<ffi.Char>,
              int,
              int,
              int,
              bt_pbap_list_vcards_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Creates a scan filter to find only LE advertisements which match specific requirements.
  /// @details If the filter's attribute is not set, then the filter will accept
  /// all values of that attribute. If an attribute is set, the filter
  /// will accept only advertisements which match the set attribute.
  ///
  /// For example, if device name is set with
  /// bt_adapter_le_scan_filter_set_device_name(), the filter will accept
  /// only advertisements from devices with the given name. If device name
  /// is not set, advertisements will be filtered without regard to device
  /// names.
  /// @since_tizen 4.0
  ///
  /// @remarks The @a scan_filter should be destroyed with bt_adapter_le_scan_filter_destroy().
  ///
  /// @param[out] scan_filter The scan filter handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_OUT_OF_MEMORY  Out of memory
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_scan_filter_destroy()
  int bt_adapter_le_scan_filter_create(
    ffi.Pointer<bt_scan_filter_h> scan_filter,
  ) {
    return _bt_adapter_le_scan_filter_create(
      scan_filter,
    );
  }

  late final _bt_adapter_le_scan_filter_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<bt_scan_filter_h>)>>(
      'bt_adapter_le_scan_filter_create');
  late final _bt_adapter_le_scan_filter_create =
      _bt_adapter_le_scan_filter_createPtr
          .asFunction<int Function(ffi.Pointer<bt_scan_filter_h>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Destroys a scan filter.
  /// @since_tizen 4.0
  ///
  /// @param[in] scan_filter The scan filter handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  ///
  /// @see bt_adapter_le_scan_filter_create()
  int bt_adapter_le_scan_filter_destroy(
    bt_scan_filter_h scan_filter,
  ) {
    return _bt_adapter_le_scan_filter_destroy(
      scan_filter,
    );
  }

  late final _bt_adapter_le_scan_filter_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_scan_filter_h)>>(
          'bt_adapter_le_scan_filter_destroy');
  late final _bt_adapter_le_scan_filter_destroy =
      _bt_adapter_le_scan_filter_destroyPtr
          .asFunction<int Function(bt_scan_filter_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the device address for the advertisements filter.
  /// @since_tizen 4.0
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] address The device address by which advertisements will be filtered
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_device_address(
    bt_scan_filter_h scan_filter,
    ffi.Pointer<ffi.Char> address,
  ) {
    return _bt_adapter_le_scan_filter_set_device_address(
      scan_filter,
      address,
    );
  }

  late final _bt_adapter_le_scan_filter_set_device_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>)>>(
      'bt_adapter_le_scan_filter_set_device_address');
  late final _bt_adapter_le_scan_filter_set_device_address =
      _bt_adapter_le_scan_filter_set_device_addressPtr
          .asFunction<int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the device name for the advertisements filter.
  /// @details Any previously set value will be overwritten.
  /// @since_tizen 4.0
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] name The device name by which advertisements will be filtered
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_device_name(
    bt_scan_filter_h scan_filter,
    ffi.Pointer<ffi.Char> name,
  ) {
    return _bt_adapter_le_scan_filter_set_device_name(
      scan_filter,
      name,
    );
  }

  late final _bt_adapter_le_scan_filter_set_device_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>)>>(
      'bt_adapter_le_scan_filter_set_device_name');
  late final _bt_adapter_le_scan_filter_set_device_name =
      _bt_adapter_le_scan_filter_set_device_namePtr
          .asFunction<int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the service UUID for the advertisements filter.
  /// @details Any previously set value will be overwritten.
  /// @since_tizen 4.0
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] uuid The service UUID by which advertisements will be filtered
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_service_uuid(
    bt_scan_filter_h scan_filter,
    ffi.Pointer<ffi.Char> uuid,
  ) {
    return _bt_adapter_le_scan_filter_set_service_uuid(
      scan_filter,
      uuid,
    );
  }

  late final _bt_adapter_le_scan_filter_set_service_uuidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>)>>(
      'bt_adapter_le_scan_filter_set_service_uuid');
  late final _bt_adapter_le_scan_filter_set_service_uuid =
      _bt_adapter_le_scan_filter_set_service_uuidPtr
          .asFunction<int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the service UUID and the mask for the advertisements filter,
  /// to use for filtering by partial data.
  /// @details Any previously set value will be overwritten. The mask works as follows:
  /// For each bit set to 1 in the mask, the corresponding bits in @a uuid
  /// and in the filtered data will have to be equal. If the mask bit is set to 0,
  /// the corresponding bits will be ignored.
  /// @since_tizen 4.0
  ///
  /// @remarks The @a mask and the service @a uuid must have equal lengths.
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] uuid The service UUID by which advertisements will be filtered
  /// @param[in] mask The mask to filter advertisements
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_service_uuid_with_mask(
    bt_scan_filter_h scan_filter,
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<ffi.Char> mask,
  ) {
    return _bt_adapter_le_scan_filter_set_service_uuid_with_mask(
      scan_filter,
      uuid,
      mask,
    );
  }

  late final _bt_adapter_le_scan_filter_set_service_uuid_with_maskPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>)>>(
      'bt_adapter_le_scan_filter_set_service_uuid_with_mask');
  late final _bt_adapter_le_scan_filter_set_service_uuid_with_mask =
      _bt_adapter_le_scan_filter_set_service_uuid_with_maskPtr.asFunction<
          int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the service solicitation UUID for the advertisements filter.
  /// @details Any previously set value will be overwritten.
  /// @since_tizen 4.0
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] uuid The service solicitation UUID by which advertisements will be filtered
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_service_solicitation_uuid(
    bt_scan_filter_h scan_filter,
    ffi.Pointer<ffi.Char> uuid,
  ) {
    return _bt_adapter_le_scan_filter_set_service_solicitation_uuid(
      scan_filter,
      uuid,
    );
  }

  late final _bt_adapter_le_scan_filter_set_service_solicitation_uuidPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>)>>(
          'bt_adapter_le_scan_filter_set_service_solicitation_uuid');
  late final _bt_adapter_le_scan_filter_set_service_solicitation_uuid =
      _bt_adapter_le_scan_filter_set_service_solicitation_uuidPtr
          .asFunction<int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the service solicitation UUID and the mask for the advertisements filter,
  /// to use for filtering by partial data.
  /// @details Any previously set value will be overwritten. The mask works as follows:
  /// For each bit set to 1 in the mask, the corresponding bits in @a uuid
  /// and in the filtered data will have to be equal. If the mask bit is set to 0,
  /// the corresponding bits will be ignored.
  /// @since_tizen 4.0
  ///
  /// @remarks The @a mask and the service solicitation @a uuid must have equal lengths.
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] uuid The service solicitation UUID by which advertisements will be filtered
  /// @param[in] mask The mask by which advertisements will be filtered
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_service_solicitation_uuid_with_mask(
    bt_scan_filter_h scan_filter,
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<ffi.Char> mask,
  ) {
    return _bt_adapter_le_scan_filter_set_service_solicitation_uuid_with_mask(
      scan_filter,
      uuid,
      mask,
    );
  }

  late final _bt_adapter_le_scan_filter_set_service_solicitation_uuid_with_maskPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>,
                      ffi.Pointer<ffi.Char>)>>(
          'bt_adapter_le_scan_filter_set_service_solicitation_uuid_with_mask');
  late final _bt_adapter_le_scan_filter_set_service_solicitation_uuid_with_mask =
      _bt_adapter_le_scan_filter_set_service_solicitation_uuid_with_maskPtr
          .asFunction<
              int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the service data for the advertisements filter.
  /// @details Any previously set value will be overwritten.
  /// @since_tizen 4.0
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] uuid The service UUID by which advertisements will be filtered
  /// @param[in] data The service data by which advertisements will be filtered
  /// @param[in] data_len The length of the service data
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_service_data(
    bt_scan_filter_h scan_filter,
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<ffi.Char> data,
    int data_len,
  ) {
    return _bt_adapter_le_scan_filter_set_service_data(
      scan_filter,
      uuid,
      data,
      data_len,
    );
  }

  late final _bt_adapter_le_scan_filter_set_service_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              bt_scan_filter_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.UnsignedInt)>>('bt_adapter_le_scan_filter_set_service_data');
  late final _bt_adapter_le_scan_filter_set_service_data =
      _bt_adapter_le_scan_filter_set_service_dataPtr.asFunction<
          int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the service data and the mask for the advertisements filter,
  /// to use for filtering by partial data.
  /// @details Any previously set value will be overwritten. The mask works as follows:
  /// For each bit set to 1 in the mask, the corresponding bits in @a data
  /// and in the filtered data will have to be equal. If the mask bit is set to 0,
  /// the corresponding bits will be ignored.
  /// @since_tizen 4.0
  ///
  /// @remarks The @a mask and the service @a data must have equal lengths.
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] uuid The service UUID by which advertisements will be filtered
  /// @param[in] data The service data by which advertisements will be filtered
  /// @param[in] data_len The length of the service data
  /// @param[in] mask The mask by which advertisements will be filtered
  /// @param[in] mask_len The length of the mask
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_service_data_with_mask(
    bt_scan_filter_h scan_filter,
    ffi.Pointer<ffi.Char> uuid,
    ffi.Pointer<ffi.Char> data,
    int data_len,
    ffi.Pointer<ffi.Char> mask,
    int mask_len,
  ) {
    return _bt_adapter_le_scan_filter_set_service_data_with_mask(
      scan_filter,
      uuid,
      data,
      data_len,
      mask,
      mask_len,
    );
  }

  late final _bt_adapter_le_scan_filter_set_service_data_with_maskPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  bt_scan_filter_h,
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ffi.UnsignedInt,
                  ffi.Pointer<ffi.Char>,
                  ffi.UnsignedInt)>>(
      'bt_adapter_le_scan_filter_set_service_data_with_mask');
  late final _bt_adapter_le_scan_filter_set_service_data_with_mask =
      _bt_adapter_le_scan_filter_set_service_data_with_maskPtr.asFunction<
          int Function(bt_scan_filter_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, int, ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the manufacturer data for the advertisements filter.
  /// @details Any previously set value will be overwritten.
  /// @since_tizen 4.0
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] manufacturer_id The manufacturer ID (0x0000 ~ 0xFFFF)
  /// @param[in] data The manufacturer data (byte array)
  /// @param[in] data_len The length of the manufacturer data
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_manufacturer_data(
    bt_scan_filter_h scan_filter,
    int manufacturer_id,
    ffi.Pointer<ffi.Char> data,
    int data_len,
  ) {
    return _bt_adapter_le_scan_filter_set_manufacturer_data(
      scan_filter,
      manufacturer_id,
      data,
      data_len,
    );
  }

  late final _bt_adapter_le_scan_filter_set_manufacturer_dataPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(bt_scan_filter_h, ffi.Int, ffi.Pointer<ffi.Char>,
                  ffi.UnsignedInt)>>(
      'bt_adapter_le_scan_filter_set_manufacturer_data');
  late final _bt_adapter_le_scan_filter_set_manufacturer_data =
      _bt_adapter_le_scan_filter_set_manufacturer_dataPtr.asFunction<
          int Function(bt_scan_filter_h, int, ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the manufacturer data and the mask for the advertisements filter,
  /// to use for filtering by partial data.
  /// @details Any previously set value will be overwritten. The mask works as follows:
  /// For each bit set to 1 in the mask, the corresponding bits in @a data
  /// and in the filtered data will have to be equal. If the mask bit is set to 0,
  /// the corresponding bits will be ignored.
  /// @since_tizen 4.0
  ///
  /// @remarks The @a mask and the manufacturer @a data must have equal lengths.
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] manufacturer_id The manufacturer ID (0x0000 ~ 0xFFFF)
  /// @param[in] data The manufacturer data (byte array)
  /// @param[in] data_len The length of the manufacturer data
  /// @param[in] mask The mask by which advertisements will be filtered
  /// @param[in] mask_len The length of the mask
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER	Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED	Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_manufacturer_data_with_mask(
    bt_scan_filter_h scan_filter,
    int manufacturer_id,
    ffi.Pointer<ffi.Char> data,
    int data_len,
    ffi.Pointer<ffi.Char> mask,
    int mask_len,
  ) {
    return _bt_adapter_le_scan_filter_set_manufacturer_data_with_mask(
      scan_filter,
      manufacturer_id,
      data,
      data_len,
      mask,
      mask_len,
    );
  }

  late final _bt_adapter_le_scan_filter_set_manufacturer_data_with_maskPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      bt_scan_filter_h,
                      ffi.Int,
                      ffi.Pointer<ffi.Char>,
                      ffi.UnsignedInt,
                      ffi.Pointer<ffi.Char>,
                      ffi.UnsignedInt)>>(
          'bt_adapter_le_scan_filter_set_manufacturer_data_with_mask');
  late final _bt_adapter_le_scan_filter_set_manufacturer_data_with_mask =
      _bt_adapter_le_scan_filter_set_manufacturer_data_with_maskPtr.asFunction<
          int Function(bt_scan_filter_h, int, ffi.Pointer<ffi.Char>, int,
              ffi.Pointer<ffi.Char>, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Sets the scan filter type for the advertisements filter.
  /// @details The filter type is used when searching only for iBeacon or proximity
  /// type's advertising data. If the type is not set, LE scanner will
  /// search devices as with regard to other filtered attributes.
  /// If the type is set, all other attributes set for the filter are ignored.
  /// @since_tizen 4.0
  ///
  /// @param[in] scan_filter The scan filter handle
  /// @param[in] mode The scan filter type
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_set_type(
    bt_scan_filter_h scan_filter,
    int mode,
  ) {
    return _bt_adapter_le_scan_filter_set_type(
      scan_filter,
      mode,
    );
  }

  late final _bt_adapter_le_scan_filter_set_typePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(bt_scan_filter_h, ffi.Int32)>>(
      'bt_adapter_le_scan_filter_set_type');
  late final _bt_adapter_le_scan_filter_set_type =
      _bt_adapter_le_scan_filter_set_typePtr
          .asFunction<int Function(bt_scan_filter_h, int)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Registers a scan filter to use for scanning.
  /// @details If the filter is registered, it cannot be changed.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @remarks Several scan filters can be registered. If an advertisement passes
  /// any of the registered scan filters, it will be included in the results.
  ///
  /// @param[in] scan_filter The scan filter handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Scan is in progress
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_register(
    bt_scan_filter_h scan_filter,
  ) {
    return _bt_adapter_le_scan_filter_register(
      scan_filter,
    );
  }

  late final _bt_adapter_le_scan_filter_registerPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_scan_filter_h)>>(
          'bt_adapter_le_scan_filter_register');
  late final _bt_adapter_le_scan_filter_register =
      _bt_adapter_le_scan_filter_registerPtr
          .asFunction<int Function(bt_scan_filter_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Unregisters all registered scan filters.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @param[in] scan_filter The scan filter handle
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Scan is in progress
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_unregister(
    bt_scan_filter_h scan_filter,
  ) {
    return _bt_adapter_le_scan_filter_unregister(
      scan_filter,
    );
  }

  late final _bt_adapter_le_scan_filter_unregisterPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(bt_scan_filter_h)>>(
          'bt_adapter_le_scan_filter_unregister');
  late final _bt_adapter_le_scan_filter_unregister =
      _bt_adapter_le_scan_filter_unregisterPtr
          .asFunction<int Function(bt_scan_filter_h)>();

  /// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
  /// @brief Unregisters all registered scan filters.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/bluetooth
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #BT_ERROR_NONE  Successful
  /// @retval #BT_ERROR_NOT_INITIALIZED  Not initialized
  /// @retval #BT_ERROR_NOW_IN_PROGRESS  Scan is in progress
  /// @retval #BT_ERROR_NOT_SUPPORTED  Not supported
  /// @retval #BT_ERROR_PERMISSION_DENIED  Permission denied
  ///
  /// @pre The Bluetooth service must be initialized with bt_initialize().
  int bt_adapter_le_scan_filter_unregister_all() {
    return _bt_adapter_le_scan_filter_unregister_all();
  }

  late final _bt_adapter_le_scan_filter_unregister_allPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'bt_adapter_le_scan_filter_unregister_all');
  late final _bt_adapter_le_scan_filter_unregister_all =
      _bt_adapter_le_scan_filter_unregister_allPtr.asFunction<int Function()>();

  /// @brief Creates a profile handle.
  /// @details The profile name, which you get from connection_profile_get_name()
  /// will include the keyword you set.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @remarks You must release @a profile using connection_profile_destroy().
  /// @param[in] type               The type of profile \n
  /// #CONNECTION_PROFILE_TYPE_CELLULAR and #CONNECTION_PROFILE_TYPE_WIFI are supported
  /// @param[in] keyword            The keyword included in profile name
  /// @param[out] profile           The handle of the profile
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  /// @see connection_profile_destroy()
  /// @see connection_profile_get_name()
  int connection_profile_create(
    int type,
    ffi.Pointer<ffi.Char> keyword,
    ffi.Pointer<connection_profile_h> profile,
  ) {
    return _connection_profile_create(
      type,
      keyword,
      profile,
    );
  }

  late final _connection_profile_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Pointer<ffi.Char>,
              ffi.Pointer<connection_profile_h>)>>('connection_profile_create');
  late final _connection_profile_create =
      _connection_profile_createPtr.asFunction<
          int Function(
              int, ffi.Pointer<ffi.Char>, ffi.Pointer<connection_profile_h>)>();

  /// @brief Destroys a profile handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out] profile           The handle to the profile
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @see connection_profile_create()
  int connection_profile_destroy(
    connection_profile_h profile,
  ) {
    return _connection_profile_destroy(
      profile,
    );
  }

  late final _connection_profile_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(connection_profile_h)>>(
          'connection_profile_destroy');
  late final _connection_profile_destroy = _connection_profile_destroyPtr
      .asFunction<int Function(connection_profile_h)>();

  /// @brief Clones a profile handle.
  /// @since_tizen 2.3
  /// @remarks You must release @a cloned_profile using connection_profile_destroy().
  /// @param[out] cloned_profile    The handle of the cloned profile
  /// @param[in] origin_profile     The handle of the origin profile
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  /// @see connection_profile_destroy()
  int connection_profile_clone(
    ffi.Pointer<connection_profile_h> cloned_profile,
    connection_profile_h origin_profile,
  ) {
    return _connection_profile_clone(
      cloned_profile,
      origin_profile,
    );
  }

  late final _connection_profile_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<connection_profile_h>,
              connection_profile_h)>>('connection_profile_clone');
  late final _connection_profile_clone =
      _connection_profile_clonePtr.asFunction<
          int Function(
              ffi.Pointer<connection_profile_h>, connection_profile_h)>();

  /// @brief Gets the profile ID.
  /// @details The separate profiles can have the same name.
  /// So, you must use this API instead of connection_profile_get_name()
  /// if you want to get the unique identification.
  /// In case you create a profile, this value will be determined when you add the profile.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a profile_id using free().
  /// @param[in] profile            The profile handle
  /// @param[out] profile_id        The ID of the profile
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  /// @see connection_profile_get_name()
  /// @see connection_add_profile()
  int connection_profile_get_id(
    connection_profile_h profile,
    ffi.Pointer<ffi.Pointer<ffi.Char>> profile_id,
  ) {
    return _connection_profile_get_id(
      profile,
      profile_id,
    );
  }

  late final _connection_profile_get_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_id');
  late final _connection_profile_get_id =
      _connection_profile_get_idPtr.asFunction<
          int Function(
              connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the profile name.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a profile_name using free().
  /// @param[in] profile           The profile handle
  /// @param[out] profile_name     The name of the profile
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  /// @see connection_profile_get_id()
  int connection_profile_get_name(
    connection_profile_h profile,
    ffi.Pointer<ffi.Pointer<ffi.Char>> profile_name,
  ) {
    return _connection_profile_get_name(
      profile,
      profile_name,
    );
  }

  late final _connection_profile_get_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_name');
  late final _connection_profile_get_name =
      _connection_profile_get_namePtr.asFunction<
          int Function(
              connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the network type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile           The profile handle
  /// @param[out] type             The type of the profile
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_profile_get_type(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _connection_profile_get_type(
      profile,
      type,
    );
  }

  late final _connection_profile_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Pointer<ffi.Int32>)>>('connection_profile_get_type');
  late final _connection_profile_get_type = _connection_profile_get_typePtr
      .asFunction<int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the name of the network interface, e.g. eth0 and pdp0.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a interface_name using free().
  /// @param[in] profile           The profile handle
  /// @param[out] interface_name   The name of the network interface
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  int connection_profile_get_network_interface_name(
    connection_profile_h profile,
    ffi.Pointer<ffi.Pointer<ffi.Char>> interface_name,
  ) {
    return _connection_profile_get_network_interface_name(
      profile,
      interface_name,
    );
  }

  late final _connection_profile_get_network_interface_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_network_interface_name');
  late final _connection_profile_get_network_interface_name =
      _connection_profile_get_network_interface_namePtr.asFunction<
          int Function(
              connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Refreshes the profile information.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @remarks You should call this function in order to get the current information
  /// because the profile information can be changed.
  /// @param[in] profile           The profile handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  int connection_profile_refresh(
    connection_profile_h profile,
  ) {
    return _connection_profile_refresh(
      profile,
    );
  }

  late final _connection_profile_refreshPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(connection_profile_h)>>(
          'connection_profile_refresh');
  late final _connection_profile_refresh = _connection_profile_refreshPtr
      .asFunction<int Function(connection_profile_h)>();

  /// @brief Gets the network type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile           The profile handle
  /// @param[out] state            The state of the profile
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_profile_get_state(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _connection_profile_get_state(
      profile,
      state,
    );
  }

  late final _connection_profile_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Pointer<ffi.Int32>)>>('connection_profile_get_state');
  late final _connection_profile_get_state = _connection_profile_get_statePtr
      .asFunction<int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the IP config type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[out] type             The type of the IP config
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_profile_get_ip_config_type(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _connection_profile_get_ip_config_type(
      profile,
      address_family,
      type,
    );
  }

  late final _connection_profile_get_ip_config_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Int32, ffi.Pointer<ffi.Int32>)>>(
      'connection_profile_get_ip_config_type');
  late final _connection_profile_get_ip_config_type =
      _connection_profile_get_ip_config_typePtr.asFunction<
          int Function(connection_profile_h, int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the IP address.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a ip_address using free().
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[out] ip_address       The IP address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY                  Out of memory
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  int connection_profile_get_ip_address(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> ip_address,
  ) {
    return _connection_profile_get_ip_address(
      profile,
      address_family,
      ip_address,
    );
  }

  late final _connection_profile_get_ip_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_ip_address');
  late final _connection_profile_get_ip_address =
      _connection_profile_get_ip_addressPtr.asFunction<
          int Function(
              connection_profile_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the Subnet Mask.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a subnet_mask using free().
  /// This function is supported only for IPv4 address family.
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[out] subnet_mask      The subnet mask
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY                  Out of memory
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  int connection_profile_get_subnet_mask(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> subnet_mask,
  ) {
    return _connection_profile_get_subnet_mask(
      profile,
      address_family,
      subnet_mask,
    );
  }

  late final _connection_profile_get_subnet_maskPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_subnet_mask');
  late final _connection_profile_get_subnet_mask =
      _connection_profile_get_subnet_maskPtr.asFunction<
          int Function(
              connection_profile_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the Gateway address.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a gateway_address using free().
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[out] gateway_address  The gateway address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY                  Out of memory
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  int connection_profile_get_gateway_address(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> gateway_address,
  ) {
    return _connection_profile_get_gateway_address(
      profile,
      address_family,
      gateway_address,
    );
  }

  late final _connection_profile_get_gateway_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_gateway_address');
  late final _connection_profile_get_gateway_address =
      _connection_profile_get_gateway_addressPtr.asFunction<
          int Function(
              connection_profile_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the DHCP Server address.
  /// @since_tizen 4.0
  /// @remarks You must release @a dhcp_server using free().
  /// This function is supported only for IPv4 address family.
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[out] dhcp_server      The DHCP Server address
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY                  Out of memory
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  int connection_profile_get_dhcp_server_address(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> dhcp_server,
  ) {
    return _connection_profile_get_dhcp_server_address(
      profile,
      address_family,
      dhcp_server,
    );
  }

  late final _connection_profile_get_dhcp_server_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_dhcp_server_address');
  late final _connection_profile_get_dhcp_server_address =
      _connection_profile_get_dhcp_server_addressPtr.asFunction<
          int Function(
              connection_profile_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the DHCP lease duration.
  /// @since_tizen 4.0
  /// @param[in] profile                   The profile handle
  /// @param[in] address_family            The address family
  /// @param[out] dhcp_lease_duration      The DHCP lease duration in seconds
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED                  Not supported
  int connection_profile_get_dhcp_lease_duration(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Int> dhcp_lease_duration,
  ) {
    return _connection_profile_get_dhcp_lease_duration(
      profile,
      address_family,
      dhcp_lease_duration,
    );
  }

  late final _connection_profile_get_dhcp_lease_durationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Int32, ffi.Pointer<ffi.Int>)>>(
      'connection_profile_get_dhcp_lease_duration');
  late final _connection_profile_get_dhcp_lease_duration =
      _connection_profile_get_dhcp_lease_durationPtr.asFunction<
          int Function(connection_profile_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the DNS address.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The allowance of the DNS address is @c 2. You must release @a dns_address using free().
  /// @param[in] profile           The profile handle
  /// @param[in] order             The order of DNS address \n
  /// It starts from 1, which means first DNS address
  /// @param[in] address_family    The address family
  /// @param[out] dns_address      The DNS address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY                  Out of memory
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  int connection_profile_get_dns_address(
    connection_profile_h profile,
    int order,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> dns_address,
  ) {
    return _connection_profile_get_dns_address(
      profile,
      order,
      address_family,
      dns_address,
    );
  }

  late final _connection_profile_get_dns_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Int, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_dns_address');
  late final _connection_profile_get_dns_address =
      _connection_profile_get_dns_addressPtr.asFunction<
          int Function(connection_profile_h, int, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the Proxy type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile           The profile handle
  /// @param[out] type             The type of the proxy
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_profile_get_proxy_type(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _connection_profile_get_proxy_type(
      profile,
      type,
    );
  }

  late final _connection_profile_get_proxy_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Pointer<ffi.Int32>)>>('connection_profile_get_proxy_type');
  late final _connection_profile_get_proxy_type =
      _connection_profile_get_proxy_typePtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the Proxy address.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a proxy_address using free().
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[out] proxy_address    The proxy address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY                  Out of memory
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  int connection_profile_get_proxy_address(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> proxy_address,
  ) {
    return _connection_profile_get_proxy_address(
      profile,
      address_family,
      proxy_address,
    );
  }

  late final _connection_profile_get_proxy_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_proxy_address');
  late final _connection_profile_get_proxy_address =
      _connection_profile_get_proxy_addressPtr.asFunction<
          int Function(
              connection_profile_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the IP config type.
  /// @details If you set IP config type to #CONNECTION_IP_CONFIG_TYPE_STATIC,
  /// then IP address, Gateway and Subnet mask will be set to the initial value "0.0.0.0".
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[in] type              The type of the IP config
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_profile_set_ip_config_type(
    connection_profile_h profile,
    int address_family,
    int type,
  ) {
    return _connection_profile_set_ip_config_type(
      profile,
      address_family,
      type,
    );
  }

  late final _connection_profile_set_ip_config_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h, ffi.Int32,
              ffi.Int32)>>('connection_profile_set_ip_config_type');
  late final _connection_profile_set_ip_config_type =
      _connection_profile_set_ip_config_typePtr
          .asFunction<int Function(connection_profile_h, int, int)>();

  /// @brief Sets the IP address.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a ip_address using free().
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[in] ip_address        The IP address \n
  /// If you set this value to @c NULL, then the existing value will be deleted
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  /// @see connection_update_profile()
  int connection_profile_set_ip_address(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Char> ip_address,
  ) {
    return _connection_profile_set_ip_address(
      profile,
      address_family,
      ip_address,
    );
  }

  late final _connection_profile_set_ip_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('connection_profile_set_ip_address');
  late final _connection_profile_set_ip_address =
      _connection_profile_set_ip_addressPtr.asFunction<
          int Function(connection_profile_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the Subnet Mask.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a subnet_mask using free().
  /// This function is supported only for IPv4 address family.
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[in] subnet_mask       The subnet mask \n
  /// If you set this value to @c NULL, then the existing value will be deleted
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  /// @see connection_update_profile()
  int connection_profile_set_subnet_mask(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Char> subnet_mask,
  ) {
    return _connection_profile_set_subnet_mask(
      profile,
      address_family,
      subnet_mask,
    );
  }

  late final _connection_profile_set_subnet_maskPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('connection_profile_set_subnet_mask');
  late final _connection_profile_set_subnet_mask =
      _connection_profile_set_subnet_maskPtr.asFunction<
          int Function(connection_profile_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the Gateway address.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a gateway_address using free().
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[in] gateway_address   The gateway address \n
  /// If you set this value to @c NULL, then the existing value will be deleted
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  /// @see connection_update_profile()
  int connection_profile_set_gateway_address(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Char> gateway_address,
  ) {
    return _connection_profile_set_gateway_address(
      profile,
      address_family,
      gateway_address,
    );
  }

  late final _connection_profile_set_gateway_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Int32, ffi.Pointer<ffi.Char>)>>(
      'connection_profile_set_gateway_address');
  late final _connection_profile_set_gateway_address =
      _connection_profile_set_gateway_addressPtr.asFunction<
          int Function(connection_profile_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the DNS address.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The allowance of the DNS address is @c 2.
  /// @remarks You must release @a dns_address using free().
  /// @param[in] profile           The profile handle
  /// @param[in] order             The order of the DNS address \n
  /// It starts from @c 1, which means first DNS address
  /// @param[in] address_family    The address family
  /// @param[in] dns_address       The DNS address \n
  /// If you set this value to NULL then the existing value will be deleted
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  /// @see connection_update_profile()
  int connection_profile_set_dns_address(
    connection_profile_h profile,
    int order,
    int address_family,
    ffi.Pointer<ffi.Char> dns_address,
  ) {
    return _connection_profile_set_dns_address(
      profile,
      order,
      address_family,
      dns_address,
    );
  }

  late final _connection_profile_set_dns_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h, ffi.Int, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('connection_profile_set_dns_address');
  late final _connection_profile_set_dns_address =
      _connection_profile_set_dns_addressPtr.asFunction<
          int Function(
              connection_profile_h, int, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the Proxy type.
  /// @details If you set the Proxy type to #CONNECTION_PROXY_TYPE_AUTO or
  /// #CONNECTION_PROXY_TYPE_MANUAL, then Proxy will be restored.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile           The profile handle
  /// @param[in] type              The type of the proxy
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @see connection_update_profile()
  int connection_profile_set_proxy_type(
    connection_profile_h profile,
    int type,
  ) {
    return _connection_profile_set_proxy_type(
      profile,
      type,
    );
  }

  late final _connection_profile_set_proxy_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Int32)>>('connection_profile_set_proxy_type');
  late final _connection_profile_set_proxy_type =
      _connection_profile_set_proxy_typePtr
          .asFunction<int Function(connection_profile_h, int)>();

  /// @brief Sets the Proxy address.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a proxy_address using free().
  /// @param[in] profile           The profile handle
  /// @param[in] address_family    The address family
  /// @param[in] proxy_address     The proxy address \n
  /// If you set this value to @c NULL, then the existing value will be deleted
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  /// @see connection_update_profile()
  int connection_profile_set_proxy_address(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Char> proxy_address,
  ) {
    return _connection_profile_set_proxy_address(
      profile,
      address_family,
      proxy_address,
    );
  }

  late final _connection_profile_set_proxy_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('connection_profile_set_proxy_address');
  late final _connection_profile_set_proxy_address =
      _connection_profile_set_proxy_addressPtr.asFunction<
          int Function(connection_profile_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Registers the callback that is called when the state of profile is changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile           The profile handle
  /// @param[in] callback          The callback function to be called
  /// @param[in] user_data         The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @post connection_opened_cb() is invoked when the state of profile is changed.
  /// @see connection_profile_state_changed_cb()
  /// @see connection_profile_unset_state_changed_cb()
  int connection_profile_set_state_changed_cb(
    connection_profile_h profile,
    connection_profile_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_profile_set_state_changed_cb(
      profile,
      callback,
      user_data,
    );
  }

  late final _connection_profile_set_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h,
                  connection_profile_state_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'connection_profile_set_state_changed_cb');
  late final _connection_profile_set_state_changed_cb =
      _connection_profile_set_state_changed_cbPtr.asFunction<
          int Function(connection_profile_h,
              connection_profile_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback that is called when the state of profile is changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile           The profile handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @see connection_profile_state_changed_cb()
  /// @see connection_profile_set_state_changed_cb()
  int connection_profile_unset_state_changed_cb(
    connection_profile_h profile,
  ) {
    return _connection_profile_unset_state_changed_cb(
      profile,
    );
  }

  late final _connection_profile_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(connection_profile_h)>>(
          'connection_profile_unset_state_changed_cb');
  late final _connection_profile_unset_state_changed_cb =
      _connection_profile_unset_state_changed_cbPtr
          .asFunction<int Function(connection_profile_h)>();

  /// @brief Gets the IPv6 network state.
  /// @since_tizen 4.0
  /// @param[in] profile           The profile handle
  /// @param[out] state            The profile state
  /// @return 0 on success, otherwise negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_profile_get_ipv6_state(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _connection_profile_get_ipv6_state(
      profile,
      state,
    );
  }

  late final _connection_profile_get_ipv6_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Pointer<ffi.Int32>)>>('connection_profile_get_ipv6_state');
  late final _connection_profile_get_ipv6_state =
      _connection_profile_get_ipv6_statePtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the DNS config type.
  /// @since_tizen 4.0
  /// @param[in] profile         The profile handle
  /// @param[in] address_family  The address family
  /// @param[in] type            The DNS config type
  /// @return 0 on success, otherwise negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_set_dns_config_type(
    connection_profile_h profile,
    int address_family,
    int type,
  ) {
    return _connection_profile_set_dns_config_type(
      profile,
      address_family,
      type,
    );
  }

  late final _connection_profile_set_dns_config_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h, ffi.Int32,
              ffi.Int32)>>('connection_profile_set_dns_config_type');
  late final _connection_profile_set_dns_config_type =
      _connection_profile_set_dns_config_typePtr
          .asFunction<int Function(connection_profile_h, int, int)>();

  /// @brief Gets the DNS config type.
  /// @since_tizen 4.0
  /// @param[in] profile         The profile handle
  /// @param[in] address_family  The address family
  /// @param[out] type           The DNS config type
  /// @return 0 on success, otherwise negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_dns_config_type(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _connection_profile_get_dns_config_type(
      profile,
      address_family,
      type,
    );
  }

  late final _connection_profile_get_dns_config_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Int32, ffi.Pointer<ffi.Int32>)>>(
      'connection_profile_get_dns_config_type');
  late final _connection_profile_get_dns_config_type =
      _connection_profile_get_dns_config_typePtr.asFunction<
          int Function(connection_profile_h, int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the network prefix length.
  /// @since_tizen 4.0
  /// @param[in] profile         The profile handle
  /// @param[in] address_family  The address family
  /// @param[out] prefix_len     The network prefix length \n
  /// In case of IPv4, it means netmask length
  /// (also called a prefix, e.g. 8, 16, 24, 32)
  /// @return 0 on success, otherwise negative error value.
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_prefix_length(
    connection_profile_h profile,
    int address_family,
    ffi.Pointer<ffi.Int> prefix_len,
  ) {
    return _connection_profile_get_prefix_length(
      profile,
      address_family,
      prefix_len,
    );
  }

  late final _connection_profile_get_prefix_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h, ffi.Int32,
              ffi.Pointer<ffi.Int>)>>('connection_profile_get_prefix_length');
  late final _connection_profile_get_prefix_length =
      _connection_profile_get_prefix_lengthPtr.asFunction<
          int Function(connection_profile_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the network prefix length.
  /// @since_tizen 4.0
  /// @param[in] profile         The profile handle
  /// @param[in] address_family  The address family
  /// @param[in] prefix_len      The network prefix length
  /// In case of IPv4, it means netmask length
  /// (also called a prefix, e.g. 8, 16, 24, 32)
  /// @return 0 on success, otherwise negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  /// @see connection_update_profile()
  int connection_profile_set_prefix_length(
    connection_profile_h profile,
    int address_family,
    int prefix_len,
  ) {
    return _connection_profile_set_prefix_length(
      profile,
      address_family,
      prefix_len,
    );
  }

  late final _connection_profile_set_prefix_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h, ffi.Int32,
              ffi.Int)>>('connection_profile_set_prefix_length');
  late final _connection_profile_set_prefix_length =
      _connection_profile_set_prefix_lengthPtr
          .asFunction<int Function(connection_profile_h, int, int)>();

  /// @brief Gets the ESSID (Extended Service Set Identifier).
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a essid using free().
  /// @param[in] profile         The profile handle
  /// @param[out] essid          The ESSID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_wifi_essid(
    connection_profile_h profile,
    ffi.Pointer<ffi.Pointer<ffi.Char>> essid,
  ) {
    return _connection_profile_get_wifi_essid(
      profile,
      essid,
    );
  }

  late final _connection_profile_get_wifi_essidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_wifi_essid');
  late final _connection_profile_get_wifi_essid =
      _connection_profile_get_wifi_essidPtr.asFunction<
          int Function(
              connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the BSSID (Basic Service Set Identifier).
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a bssid using free().
  /// @param[in] profile         The profile handle
  /// @param[out] bssid          The BSSID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_wifi_bssid(
    connection_profile_h profile,
    ffi.Pointer<ffi.Pointer<ffi.Char>> bssid,
  ) {
    return _connection_profile_get_wifi_bssid(
      profile,
      bssid,
    );
  }

  late final _connection_profile_get_wifi_bssidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_wifi_bssid');
  late final _connection_profile_get_wifi_bssid =
      _connection_profile_get_wifi_bssidPtr.asFunction<
          int Function(
              connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the RSSI.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[out] rssi           The RSSI
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_wifi_rssi(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int> rssi,
  ) {
    return _connection_profile_get_wifi_rssi(
      profile,
      rssi,
    );
  }

  late final _connection_profile_get_wifi_rssiPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Pointer<ffi.Int>)>>('connection_profile_get_wifi_rssi');
  late final _connection_profile_get_wifi_rssi =
      _connection_profile_get_wifi_rssiPtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the frequency (MHz).
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[out] frequency      The frequency
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_wifi_frequency(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int> frequency,
  ) {
    return _connection_profile_get_wifi_frequency(
      profile,
      frequency,
    );
  }

  late final _connection_profile_get_wifi_frequencyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Pointer<ffi.Int>)>>('connection_profile_get_wifi_frequency');
  late final _connection_profile_get_wifi_frequency =
      _connection_profile_get_wifi_frequencyPtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the max speed (Mbps).
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[out] max_speed      The max speed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_wifi_max_speed(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int> max_speed,
  ) {
    return _connection_profile_get_wifi_max_speed(
      profile,
      max_speed,
    );
  }

  late final _connection_profile_get_wifi_max_speedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Pointer<ffi.Int>)>>('connection_profile_get_wifi_max_speed');
  late final _connection_profile_get_wifi_max_speed =
      _connection_profile_get_wifi_max_speedPtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the security mode of Wi-Fi.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[out] type           The type of Wi-Fi security
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_wifi_security_type(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _connection_profile_get_wifi_security_type(
      profile,
      type,
    );
  }

  late final _connection_profile_get_wifi_security_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>>(
      'connection_profile_get_wifi_security_type');
  late final _connection_profile_get_wifi_security_type =
      _connection_profile_get_wifi_security_typePtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the security mode of Wi-Fi.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[out] type           The type of Wi-Fi security
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_wifi_encryption_type(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _connection_profile_get_wifi_encryption_type(
      profile,
      type,
    );
  }

  late final _connection_profile_get_wifi_encryption_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>>(
      'connection_profile_get_wifi_encryption_type');
  late final _connection_profile_get_wifi_encryption_type =
      _connection_profile_get_wifi_encryption_typePtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Checks whether passphrase is required.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks This function is not valid if security type is #CONNECTION_WIFI_SECURITY_TYPE_EAP.
  /// @param[in] profile         The profile handle
  /// @param[out] required       @c true if a passphrase is required,
  /// otherwise @c false if a passphrase is not required
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED Not supported
  int connection_profile_is_wifi_passphrase_required(
    connection_profile_h profile,
    ffi.Pointer<ffi.Bool> required1,
  ) {
    return _connection_profile_is_wifi_passphrase_required(
      profile,
      required1,
    );
  }

  late final _connection_profile_is_wifi_passphrase_requiredPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>>(
      'connection_profile_is_wifi_passphrase_required');
  late final _connection_profile_is_wifi_passphrase_required =
      _connection_profile_is_wifi_passphrase_requiredPtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the passphrase of the Wi-Fi WPA.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a passphrase using free().
  /// @param[in] profile         The profile handle
  /// @param[in] passphrase      The passphrase of Wi-Fi security
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  /// @see connection_update_profile()
  int connection_profile_set_wifi_passphrase(
    connection_profile_h profile,
    ffi.Pointer<ffi.Char> passphrase,
  ) {
    return _connection_profile_set_wifi_passphrase(
      profile,
      passphrase,
    );
  }

  late final _connection_profile_set_wifi_passphrasePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Char>)>>(
      'connection_profile_set_wifi_passphrase');
  late final _connection_profile_set_wifi_passphrase =
      _connection_profile_set_wifi_passphrasePtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Checks whether the WPS (Wi-Fi Protected Setup) is supported.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If WPS is supported, you can connect the access point with WPS by wifi_connect_with_wps().
  /// @param[in] profile         The profile handle
  /// @param[out] supported      @c true if WPS is supported,
  /// otherwise @c false if WPS is not supported
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_is_wifi_wps_supported(
    connection_profile_h profile,
    ffi.Pointer<ffi.Bool> supported,
  ) {
    return _connection_profile_is_wifi_wps_supported(
      profile,
      supported,
    );
  }

  late final _connection_profile_is_wifi_wps_supportedPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>>(
      'connection_profile_is_wifi_wps_supported');
  late final _connection_profile_is_wifi_wps_supported =
      _connection_profile_is_wifi_wps_supportedPtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the service type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[out] type           The type of the cellular service
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_cellular_service_type(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _connection_profile_get_cellular_service_type(
      profile,
      type,
    );
  }

  late final _connection_profile_get_cellular_service_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>>(
      'connection_profile_get_cellular_service_type');
  late final _connection_profile_get_cellular_service_type =
      _connection_profile_get_cellular_service_typePtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the APN (access point name).
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a apn using free().
  /// @param[in] profile         The profile handle
  /// @param[out] apn            The name of the APN
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_cellular_apn(
    connection_profile_h profile,
    ffi.Pointer<ffi.Pointer<ffi.Char>> apn,
  ) {
    return _connection_profile_get_cellular_apn(
      profile,
      apn,
    );
  }

  late final _connection_profile_get_cellular_apnPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_cellular_apn');
  late final _connection_profile_get_cellular_apn =
      _connection_profile_get_cellular_apnPtr.asFunction<
          int Function(
              connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the authentication information.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a user_name and @a password using free().
  /// @param[in] profile         The profile handle
  /// @param[out] type           The type of the authentication
  /// @param[out] user_name      The user name
  /// @param[out] password       The password
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_cellular_auth_info(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int32> type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> user_name,
    ffi.Pointer<ffi.Pointer<ffi.Char>> password,
  ) {
    return _connection_profile_get_cellular_auth_info(
      profile,
      type,
      user_name,
      password,
    );
  }

  late final _connection_profile_get_cellular_auth_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h,
                  ffi.Pointer<ffi.Int32>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_cellular_auth_info');
  late final _connection_profile_get_cellular_auth_info =
      _connection_profile_get_cellular_auth_infoPtr.asFunction<
          int Function(
              connection_profile_h,
              ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the home URL.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a home_url using free().
  /// @param[in] profile         The profile handle
  /// @param[out] home_url       The home URL
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_cellular_home_url(
    connection_profile_h profile,
    ffi.Pointer<ffi.Pointer<ffi.Char>> home_url,
  ) {
    return _connection_profile_get_cellular_home_url(
      profile,
      home_url,
    );
  }

  late final _connection_profile_get_cellular_home_urlPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_profile_get_cellular_home_url');
  late final _connection_profile_get_cellular_home_url =
      _connection_profile_get_cellular_home_urlPtr.asFunction<
          int Function(
              connection_profile_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the cellular pdn type.
  /// @since_tizen 3.0
  /// @param[in] profile         The profile handle
  /// @param[out] type           The cellular pdn type
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not suppported
  int connection_profile_get_cellular_pdn_type(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _connection_profile_get_cellular_pdn_type(
      profile,
      type,
    );
  }

  late final _connection_profile_get_cellular_pdn_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>>(
      'connection_profile_get_cellular_pdn_type');
  late final _connection_profile_get_cellular_pdn_type =
      _connection_profile_get_cellular_pdn_typePtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the cellular roam pdn type.
  /// @since_tizen 3.0
  /// @param[in] profile         The profile handle
  /// @param[out] type           The cellular pdn type
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_get_cellular_roam_pdn_type(
    connection_profile_h profile,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _connection_profile_get_cellular_roam_pdn_type(
      profile,
      type,
    );
  }

  late final _connection_profile_get_cellular_roam_pdn_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>>(
      'connection_profile_get_cellular_roam_pdn_type');
  late final _connection_profile_get_cellular_roam_pdn_type =
      _connection_profile_get_cellular_roam_pdn_typePtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Checks whether the connection is in roaming state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[out] is_roaming     @c true if the cellular is roaming,
  /// otherwise @c false if it is not roaming
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_is_cellular_roaming(
    connection_profile_h profile,
    ffi.Pointer<ffi.Bool> is_roaming,
  ) {
    return _connection_profile_is_cellular_roaming(
      profile,
      is_roaming,
    );
  }

  late final _connection_profile_is_cellular_roamingPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>>(
      'connection_profile_is_cellular_roaming');
  late final _connection_profile_is_cellular_roaming =
      _connection_profile_is_cellular_roamingPtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the profile is hidden.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[out] is_hidden      @c true if the profile is in hidden,
  /// otherwise @c false if the profile is not hidden
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_is_cellular_hidden(
    connection_profile_h profile,
    ffi.Pointer<ffi.Bool> is_hidden,
  ) {
    return _connection_profile_is_cellular_hidden(
      profile,
      is_hidden,
    );
  }

  late final _connection_profile_is_cellular_hiddenPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Pointer<ffi.Bool>)>>('connection_profile_is_cellular_hidden');
  late final _connection_profile_is_cellular_hidden =
      _connection_profile_is_cellular_hiddenPtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the profile is editable.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[out] is_editable    @c true if the profile is editable,
  /// otherwise @c false if the profile is not editable
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_is_cellular_editable(
    connection_profile_h profile,
    ffi.Pointer<ffi.Bool> is_editable,
  ) {
    return _connection_profile_is_cellular_editable(
      profile,
      is_editable,
    );
  }

  late final _connection_profile_is_cellular_editablePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>>(
      'connection_profile_is_cellular_editable');
  late final _connection_profile_is_cellular_editable =
      _connection_profile_is_cellular_editablePtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the profile is default.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[out] is_default     @c true if the profile is default,
  /// otherwise @c false if the profile is not default
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_is_cellular_default(
    connection_profile_h profile,
    ffi.Pointer<ffi.Bool> is_default,
  ) {
    return _connection_profile_is_cellular_default(
      profile,
      is_default,
    );
  }

  late final _connection_profile_is_cellular_defaultPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>>(
      'connection_profile_is_cellular_default');
  late final _connection_profile_is_cellular_default =
      _connection_profile_is_cellular_defaultPtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the service type.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile         The profile handle
  /// @param[in] service_type    The type of cellular service
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  /// @see connection_update_profile()
  int connection_profile_set_cellular_service_type(
    connection_profile_h profile,
    int service_type,
  ) {
    return _connection_profile_set_cellular_service_type(
      profile,
      service_type,
    );
  }

  late final _connection_profile_set_cellular_service_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Int32)>>('connection_profile_set_cellular_service_type');
  late final _connection_profile_set_cellular_service_type =
      _connection_profile_set_cellular_service_typePtr
          .asFunction<int Function(connection_profile_h, int)>();

  /// @brief Sets the APN (Access Point Name).
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a spn using free().
  /// @param[in] profile         The profile handle
  /// @param[in] apn             The name of APN
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  /// @see connection_update_profile()
  int connection_profile_set_cellular_apn(
    connection_profile_h profile,
    ffi.Pointer<ffi.Char> apn,
  ) {
    return _connection_profile_set_cellular_apn(
      profile,
      apn,
    );
  }

  late final _connection_profile_set_cellular_apnPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Pointer<ffi.Char>)>>('connection_profile_set_cellular_apn');
  late final _connection_profile_set_cellular_apn =
      _connection_profile_set_cellular_apnPtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the Authentication information.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a user_name using free().
  /// @param[in] profile         The profile handle
  /// @param[in] type            The type of the authentication
  /// @param[in] user_name       The user name
  /// @param[in] password        The password
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  /// @see connection_update_profile()
  int connection_profile_set_cellular_auth_info(
    connection_profile_h profile,
    int type,
    ffi.Pointer<ffi.Char> user_name,
    ffi.Pointer<ffi.Char> password,
  ) {
    return _connection_profile_set_cellular_auth_info(
      profile,
      type,
      user_name,
      password,
    );
  }

  late final _connection_profile_set_cellular_auth_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Int32,
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>>(
      'connection_profile_set_cellular_auth_info');
  late final _connection_profile_set_cellular_auth_info =
      _connection_profile_set_cellular_auth_infoPtr.asFunction<
          int Function(connection_profile_h, int, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the home URL.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a home_url using free().
  /// @param[in] profile         The profile handle
  /// @param[in] home_url        The home URL
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  /// @see connection_update_profile()
  int connection_profile_set_cellular_home_url(
    connection_profile_h profile,
    ffi.Pointer<ffi.Char> home_url,
  ) {
    return _connection_profile_set_cellular_home_url(
      profile,
      home_url,
    );
  }

  late final _connection_profile_set_cellular_home_urlPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_h, ffi.Pointer<ffi.Char>)>>(
      'connection_profile_set_cellular_home_url');
  late final _connection_profile_set_cellular_home_url =
      _connection_profile_set_cellular_home_urlPtr.asFunction<
          int Function(connection_profile_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the cellular pdn type.
  /// @since_tizen 3.0
  /// @param[in] profile         The profile handle
  /// @param[in] type            The cellular pdn type
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_set_cellular_pdn_type(
    connection_profile_h profile,
    int type,
  ) {
    return _connection_profile_set_cellular_pdn_type(
      profile,
      type,
    );
  }

  late final _connection_profile_set_cellular_pdn_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Int32)>>('connection_profile_set_cellular_pdn_type');
  late final _connection_profile_set_cellular_pdn_type =
      _connection_profile_set_cellular_pdn_typePtr
          .asFunction<int Function(connection_profile_h, int)>();

  /// @brief Sets the cellular roam pdn type.
  /// @since_tizen 3.0
  /// @param[in] profile         The profile handle
  /// @param[in] type            The cellular pdn type
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_profile_set_cellular_roam_pdn_type(
    connection_profile_h profile,
    int type,
  ) {
    return _connection_profile_set_cellular_roam_pdn_type(
      profile,
      type,
    );
  }

  late final _connection_profile_set_cellular_roam_pdn_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_profile_h,
              ffi.Int32)>>('connection_profile_set_cellular_roam_pdn_type');
  late final _connection_profile_set_cellular_roam_pdn_type =
      _connection_profile_set_cellular_roam_pdn_typePtr
          .asFunction<int Function(connection_profile_h, int)>();

  /// @brief Creates a handle for managing data connections.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @remarks You must release @a handle using connection_destroy().
  /// @param[out] connection       The connection handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @see connection_destroy()
  int connection_create(
    ffi.Pointer<connection_h> connection,
  ) {
    return _connection_create(
      connection,
    );
  }

  late final _connection_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<connection_h>)>>(
          'connection_create');
  late final _connection_create = _connection_createPtr
      .asFunction<int Function(ffi.Pointer<connection_h>)>();

  /// @brief Destroys the connection handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] connection        The connection handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @see connection_create()
  int connection_destroy(
    connection_h connection,
  ) {
    return _connection_destroy(
      connection,
    );
  }

  late final _connection_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(connection_h)>>(
          'connection_destroy');
  late final _connection_destroy =
      _connection_destroyPtr.asFunction<int Function(connection_h)>();

  /// @brief Gets the type of the current profile for data connection.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] connection        The connection handle
  /// @param[out] type             The type of the network
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_get_type(
    connection_h connection,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _connection_get_type(
      connection,
      type,
    );
  }

  late final _connection_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              connection_h, ffi.Pointer<ffi.Int32>)>>('connection_get_type');
  late final _connection_get_type = _connection_get_typePtr
      .asFunction<int Function(connection_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the IP address of the current connection.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a ip_address using free().
  /// @param[in] connection        The connection handle
  /// @param[in] address_family    The address family
  /// @param[out] ip_address       The pointer to the IP address string
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  int connection_get_ip_address(
    connection_h connection,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> ip_address,
  ) {
    return _connection_get_ip_address(
      connection,
      address_family,
      ip_address,
    );
  }

  late final _connection_get_ip_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_get_ip_address');
  late final _connection_get_ip_address =
      _connection_get_ip_addressPtr.asFunction<
          int Function(
              connection_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the proxy address of the current connection.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks You must release @a proxy using free().
  /// @param[in] connection        The connection handle
  /// @param[in] address_family    The address family
  /// @param[out] proxy            The proxy address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                           Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER              Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED               Operation failed
  /// @retval #CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED   Not supported address family
  int connection_get_proxy(
    connection_h connection,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> proxy,
  ) {
    return _connection_get_proxy(
      connection,
      address_family,
      proxy,
    );
  }

  late final _connection_get_proxyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h, ffi.Int32,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('connection_get_proxy');
  late final _connection_get_proxy = _connection_get_proxyPtr.asFunction<
      int Function(connection_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the MAC address of the Wi-Fi or ethernet.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks @a mac_addr must be released with free() by you.
  /// @param[in] connection        The handle of the connection
  /// @param[in] type              The type of current network connection
  /// @param[out] mac_addr         The MAC address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_INVALID_OPERATION     Invalid operation
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  int connection_get_mac_address(
    connection_h connection,
    int type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mac_addr,
  ) {
    return _connection_get_mac_address(
      connection,
      type,
      mac_addr,
    );
  }

  late final _connection_get_mac_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'connection_get_mac_address');
  late final _connection_get_mac_address =
      _connection_get_mac_addressPtr.asFunction<
          int Function(
              connection_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets if the current connection is metered.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] connection        The connection handle
  /// @param[out] is_metered       The value indicating whether it is metered
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_is_metered_network(
    connection_h connection,
    ffi.Pointer<ffi.Bool> is_metered,
  ) {
    return _connection_is_metered_network(
      connection,
      is_metered,
    );
  }

  late final _connection_is_metered_networkPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h,
              ffi.Pointer<ffi.Bool>)>>('connection_is_metered_network');
  late final _connection_is_metered_network = _connection_is_metered_networkPtr
      .asFunction<int Function(connection_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the state of cellular connection.
  /// @details The returned state is for the cellular connection state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] connection        The connection handle
  /// @param[out] state            The state of the cellular connection
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_get_cellular_state(
    connection_h connection,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _connection_get_cellular_state(
      connection,
      state,
    );
  }

  late final _connection_get_cellular_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h,
              ffi.Pointer<ffi.Int32>)>>('connection_get_cellular_state');
  late final _connection_get_cellular_state = _connection_get_cellular_statePtr
      .asFunction<int Function(connection_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the state of the Wi-Fi.
  /// @details The returned state is for the Wi-Fi connection state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] connection        The connection handle
  /// @param[out] state            The state of Wi-Fi connection
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_get_wifi_state(
    connection_h connection,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _connection_get_wifi_state(
      connection,
      state,
    );
  }

  late final _connection_get_wifi_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h,
              ffi.Pointer<ffi.Int32>)>>('connection_get_wifi_state');
  late final _connection_get_wifi_state = _connection_get_wifi_statePtr
      .asFunction<int Function(connection_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the state of the Ethernet.
  /// @details The returned state is for the Ethernet connection state.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] connection        The connection handle
  /// @param[out] state            The state of Ethernet connection
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_get_ethernet_state(
    connection_h connection,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _connection_get_ethernet_state(
      connection,
      state,
    );
  }

  late final _connection_get_ethernet_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h,
              ffi.Pointer<ffi.Int32>)>>('connection_get_ethernet_state');
  late final _connection_get_ethernet_state = _connection_get_ethernet_statePtr
      .asFunction<int Function(connection_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Checks for ethernet cable is attached or not.
  /// @details The returned state is for the ethernet cable state.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] connection        The handle of the connection
  /// @param[in] state             The state of ethernet cable
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  int connection_get_ethernet_cable_state(
    connection_h connection,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _connection_get_ethernet_cable_state(
      connection,
      state,
    );
  }

  late final _connection_get_ethernet_cable_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h,
              ffi.Pointer<ffi.Int32>)>>('connection_get_ethernet_cable_state');
  late final _connection_get_ethernet_cable_state =
      _connection_get_ethernet_cable_statePtr
          .asFunction<int Function(connection_h, ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since 4.0. Use connection_set_ethernet_cable_state_changed_cb() instead.
  /// @brief Registers callback for ethernet cable is plugged [in/out] event.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] connection        The handle of connection
  /// @param[in] callback          The callback function to be called
  /// @param[in] user_data         The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_set_ethernet_cable_state_chaged_cb(
    connection_h connection,
    connection_ethernet_cable_state_chaged_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_set_ethernet_cable_state_chaged_cb(
      connection,
      callback,
      user_data,
    );
  }

  late final _connection_set_ethernet_cable_state_chaged_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_h,
                  connection_ethernet_cable_state_chaged_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'connection_set_ethernet_cable_state_chaged_cb');
  late final _connection_set_ethernet_cable_state_chaged_cb =
      _connection_set_ethernet_cable_state_chaged_cbPtr.asFunction<
          int Function(connection_h, connection_ethernet_cable_state_chaged_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 4.0. Use connection_unset_ethernet_cable_state_changed_cb() instead.
  /// @brief Unregisters callback for ethernet cable is plugged [in/out] event.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] connection        The handle of connection
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_unset_ethernet_cable_state_chaged_cb(
    connection_h connection,
  ) {
    return _connection_unset_ethernet_cable_state_chaged_cb(
      connection,
    );
  }

  late final _connection_unset_ethernet_cable_state_chaged_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(connection_h)>>(
          'connection_unset_ethernet_cable_state_chaged_cb');
  late final _connection_unset_ethernet_cable_state_chaged_cb =
      _connection_unset_ethernet_cable_state_chaged_cbPtr
          .asFunction<int Function(connection_h)>();

  /// @brief Registers callback for ethernet cable is plugged [in/out] event.
  /// @since_tizen 4.0
  /// @param[in] connection        The handle of connection
  /// @param[in] callback          The callback function to be called
  /// @param[in] user_data         The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_set_ethernet_cable_state_changed_cb(
    connection_h connection,
    connection_ethernet_cable_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_set_ethernet_cable_state_changed_cb(
      connection,
      callback,
      user_data,
    );
  }

  late final _connection_set_ethernet_cable_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_h,
                  connection_ethernet_cable_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'connection_set_ethernet_cable_state_changed_cb');
  late final _connection_set_ethernet_cable_state_changed_cb =
      _connection_set_ethernet_cable_state_changed_cbPtr.asFunction<
          int Function(connection_h, connection_ethernet_cable_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters callback for ethernet cable is plugged [in/out] event.
  /// @since_tizen 4.0
  /// @param[in] connection        The handle of connection
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_unset_ethernet_cable_state_changed_cb(
    connection_h connection,
  ) {
    return _connection_unset_ethernet_cable_state_changed_cb(
      connection,
    );
  }

  late final _connection_unset_ethernet_cable_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(connection_h)>>(
          'connection_unset_ethernet_cable_state_changed_cb');
  late final _connection_unset_ethernet_cable_state_changed_cb =
      _connection_unset_ethernet_cable_state_changed_cbPtr
          .asFunction<int Function(connection_h)>();

  /// @brief Gets the state of the Bluetooth.
  /// @details The returned state is for the Bluetooth connection state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] connection        The connection handle
  /// @param[out] state            The state of the Bluetooth connection
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_get_bt_state(
    connection_h connection,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _connection_get_bt_state(
      connection,
      state,
    );
  }

  late final _connection_get_bt_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h,
              ffi.Pointer<ffi.Int32>)>>('connection_get_bt_state');
  late final _connection_get_bt_state = _connection_get_bt_statePtr
      .asFunction<int Function(connection_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Registers the callback that is called when the type of the current connection is changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] connection        The connection handle
  /// @param[in] callback          The callback function to be called
  /// @param[in] user_data         The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_set_type_changed_cb(
    connection_h connection,
    connection_type_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_set_type_changed_cb(
      connection,
      callback,
      user_data,
    );
  }

  late final _connection_set_type_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h, connection_type_changed_cb,
              ffi.Pointer<ffi.Void>)>>('connection_set_type_changed_cb');
  late final _connection_set_type_changed_cb =
      _connection_set_type_changed_cbPtr.asFunction<
          int Function(connection_h, connection_type_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback that is called when the type of current connection is changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] connection        The connection handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_unset_type_changed_cb(
    connection_h connection,
  ) {
    return _connection_unset_type_changed_cb(
      connection,
    );
  }

  late final _connection_unset_type_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(connection_h)>>(
          'connection_unset_type_changed_cb');
  late final _connection_unset_type_changed_cb =
      _connection_unset_type_changed_cbPtr
          .asFunction<int Function(connection_h)>();

  /// @brief Registers the callback that is called when the IP address is changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] connection        The connection handle
  /// @param[in] callback          The callback function to be called
  /// @param[in] user_data         The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_set_ip_address_changed_cb(
    connection_h connection,
    connection_address_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_set_ip_address_changed_cb(
      connection,
      callback,
      user_data,
    );
  }

  late final _connection_set_ip_address_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h, connection_address_changed_cb,
              ffi.Pointer<ffi.Void>)>>('connection_set_ip_address_changed_cb');
  late final _connection_set_ip_address_changed_cb =
      _connection_set_ip_address_changed_cbPtr.asFunction<
          int Function(connection_h, connection_address_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback that is called when the IP address is changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] connection        The connection handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_unset_ip_address_changed_cb(
    connection_h connection,
  ) {
    return _connection_unset_ip_address_changed_cb(
      connection,
    );
  }

  late final _connection_unset_ip_address_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(connection_h)>>(
          'connection_unset_ip_address_changed_cb');
  late final _connection_unset_ip_address_changed_cb =
      _connection_unset_ip_address_changed_cbPtr
          .asFunction<int Function(connection_h)>();

  /// @brief Registers the callback that is called when the proxy address is changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] connection        The connection handle
  /// @param[in] callback          The callback function to be called
  /// @param[in] user_data         The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_set_proxy_address_changed_cb(
    connection_h connection,
    connection_address_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_set_proxy_address_changed_cb(
      connection,
      callback,
      user_data,
    );
  }

  late final _connection_set_proxy_address_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_h, connection_address_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'connection_set_proxy_address_changed_cb');
  late final _connection_set_proxy_address_changed_cb =
      _connection_set_proxy_address_changed_cbPtr.asFunction<
          int Function(connection_h, connection_address_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback that is called when the proxy address is changed.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] connection        The connection handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  int connection_unset_proxy_address_changed_cb(
    connection_h connection,
  ) {
    return _connection_unset_proxy_address_changed_cb(
      connection,
    );
  }

  late final _connection_unset_proxy_address_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(connection_h)>>(
          'connection_unset_proxy_address_changed_cb');
  late final _connection_unset_proxy_address_changed_cb =
      _connection_unset_proxy_address_changed_cbPtr
          .asFunction<int Function(connection_h)>();

  /// @brief Adds a new profile which is created by connection_profile_create().
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile
  /// @remarks You can only add a profile of the cellular type.
  /// @param[in] connection        The connection handle
  /// @param[in] profile           The profile handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_add_profile(
    connection_h connection,
    connection_profile_h profile,
  ) {
    return _connection_add_profile(
      connection,
      profile,
    );
  }

  late final _connection_add_profilePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              connection_h, connection_profile_h)>>('connection_add_profile');
  late final _connection_add_profile = _connection_add_profilePtr
      .asFunction<int Function(connection_h, connection_profile_h)>();

  /// @brief Removes an existing profile.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This API needs both privileges.
  /// @param[in] connection        The connection handle
  /// @param[in] profile           The profile handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_remove_profile(
    connection_h connection,
    connection_profile_h profile,
  ) {
    return _connection_remove_profile(
      connection,
      profile,
    );
  }

  late final _connection_remove_profilePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h,
              connection_profile_h)>>('connection_remove_profile');
  late final _connection_remove_profile = _connection_remove_profilePtr
      .asFunction<int Function(connection_h, connection_profile_h)>();

  /// @brief Updates an existing profile.
  /// @details When a profile is changed, these changes will be not applied to the
  /// Connection Manager immediately.
  /// When you call this function, your changes affect the Connection Manager
  /// and the existing profile is updated.
  /// In addition, the existing profile will be updated if you call connection_open_profile().
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This API needs both privileges.
  /// @param[in] connection        The connection handle
  /// @param[in] profile           The profile handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  /// @see connection_open_profile()
  int connection_update_profile(
    connection_h connection,
    connection_profile_h profile,
  ) {
    return _connection_update_profile(
      connection,
      profile,
    );
  }

  late final _connection_update_profilePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h,
              connection_profile_h)>>('connection_update_profile');
  late final _connection_update_profile = _connection_update_profilePtr
      .asFunction<int Function(connection_h, connection_profile_h)>();

  /// @brief Gets a profiles iterator.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @remarks You must release @a profile_iterator using connection_destroy().
  /// @param[in] connection        The connection handle
  /// @param[in] type              The type of the connection iterator
  /// @param[out] profile_iterator The iterator of profile
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  int connection_get_profile_iterator(
    connection_h connection,
    int type,
    ffi.Pointer<connection_profile_iterator_h> profile_iterator,
  ) {
    return _connection_get_profile_iterator(
      connection,
      type,
      profile_iterator,
    );
  }

  late final _connection_get_profile_iteratorPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_h, ffi.Int32,
                  ffi.Pointer<connection_profile_iterator_h>)>>(
      'connection_get_profile_iterator');
  late final _connection_get_profile_iterator =
      _connection_get_profile_iteratorPtr.asFunction<
          int Function(
              connection_h, int, ffi.Pointer<connection_profile_iterator_h>)>();

  /// @brief Moves the profile iterator to the next position and gets a profile handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile_iterator  The iterator of profile
  /// @param[out] profile          The profile handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_ITERATOR_END          End of iteration
  int connection_profile_iterator_next(
    connection_profile_iterator_h profile_iterator,
    ffi.Pointer<connection_profile_h> profile,
  ) {
    return _connection_profile_iterator_next(
      profile_iterator,
      profile,
    );
  }

  late final _connection_profile_iterator_nextPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_profile_iterator_h,
                  ffi.Pointer<connection_profile_h>)>>(
      'connection_profile_iterator_next');
  late final _connection_profile_iterator_next =
      _connection_profile_iterator_nextPtr.asFunction<
          int Function(connection_profile_iterator_h,
              ffi.Pointer<connection_profile_h>)>();

  /// @brief Checks whether the next element of a profile iterator exists or not.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method.
  /// Error codes are described in Exception section.
  /// @param[in] profile_iterator  The iterator of profile
  /// @return @c true if next element exists,
  /// otherwise @c false if next element doesn't exist
  /// @exception #CONNECTION_ERROR_NONE                  Successful
  /// @exception #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  /// @see get_last_result()
  bool connection_profile_iterator_has_next(
    connection_profile_iterator_h profile_iterator,
  ) {
    return _connection_profile_iterator_has_next(
      profile_iterator,
    );
  }

  late final _connection_profile_iterator_has_nextPtr = _lookup<
          ffi.NativeFunction<ffi.Bool Function(connection_profile_iterator_h)>>(
      'connection_profile_iterator_has_next');
  late final _connection_profile_iterator_has_next =
      _connection_profile_iterator_has_nextPtr
          .asFunction<bool Function(connection_profile_iterator_h)>();

  /// @brief Destroys a profiles iterator.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] profile_iterator  The iterator of the profile
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  int connection_destroy_profile_iterator(
    connection_profile_iterator_h profile_iterator,
  ) {
    return _connection_destroy_profile_iterator(
      profile_iterator,
    );
  }

  late final _connection_destroy_profile_iteratorPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(connection_profile_iterator_h)>>(
      'connection_destroy_profile_iterator');
  late final _connection_destroy_profile_iterator =
      _connection_destroy_profile_iteratorPtr
          .asFunction<int Function(connection_profile_iterator_h)>();

  /// @brief Gets the name of the default profile.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @remarks You must release @a profile using connection_profile_destroy().
  /// @param[in] connection        The connection handle
  /// @param[out] profile          The profile handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_NO_CONNECTION         There is no connection
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  int connection_get_current_profile(
    connection_h connection,
    ffi.Pointer<connection_profile_h> profile,
  ) {
    return _connection_get_current_profile(
      connection,
      profile,
    );
  }

  late final _connection_get_current_profilePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_h, ffi.Pointer<connection_profile_h>)>>(
      'connection_get_current_profile');
  late final _connection_get_current_profile =
      _connection_get_current_profilePtr.asFunction<
          int Function(connection_h, ffi.Pointer<connection_profile_h>)>();

  /// @brief Gets the default profile which provides the given cellular service.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @remarks You must release @a profile using connection_profile_destroy().
  /// @param[in] connection        The connection handle
  /// @param[in] type              The type of cellular service \n
  /// #CONNECTION_CELLULAR_SERVICE_TYPE_APPLICATION is not permitted
  /// @param[out] profile          The profile handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OUT_OF_MEMORY         Out of memory
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_get_default_cellular_service_profile(
    connection_h connection,
    int type,
    ffi.Pointer<connection_profile_h> profile,
  ) {
    return _connection_get_default_cellular_service_profile(
      connection,
      type,
      profile,
    );
  }

  late final _connection_get_default_cellular_service_profilePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  connection_h, ffi.Int32, ffi.Pointer<connection_profile_h>)>>(
      'connection_get_default_cellular_service_profile');
  late final _connection_get_default_cellular_service_profile =
      _connection_get_default_cellular_service_profilePtr.asFunction<
          int Function(connection_h, int, ffi.Pointer<connection_profile_h>)>();

  /// @brief Sets the default profile which provides the given cellular service.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This API needs both privileges.
  /// @param[in] connection        The connection handle
  /// @param[in] type              The type of cellular service \n
  /// Only #CONNECTION_CELLULAR_SERVICE_TYPE_INTERNET and
  /// #CONNECTION_CELLULAR_SERVICE_TYPE_PREPAID_INTERNET are permitted
  /// @param[in] profile           The profile handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_set_default_cellular_service_profile(
    connection_h connection,
    int type,
    connection_profile_h profile,
  ) {
    return _connection_set_default_cellular_service_profile(
      connection,
      type,
      profile,
    );
  }

  late final _connection_set_default_cellular_service_profilePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(connection_h, ffi.Int32, connection_profile_h)>>(
      'connection_set_default_cellular_service_profile');
  late final _connection_set_default_cellular_service_profile =
      _connection_set_default_cellular_service_profilePtr
          .asFunction<int Function(connection_h, int, connection_profile_h)>();

  /// @brief Sets the default profile which provides the given cellular service, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This API needs both privileges.
  /// @param[in] connection        The connection handle
  /// @param[in] type              The type of cellular service \n
  /// Only #CONNECTION_CELLULAR_SERVICE_TYPE_INTERNET and
  /// #CONNECTION_CELLULAR_SERVICE_TYPE_PREPAID_INTERNET are permitted
  /// @param[in] profile The profile handle
  /// @param[in] callback The callback function to be called
  /// @param[in] user_data The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_set_default_cellular_service_profile_async(
    connection_h connection,
    int type,
    connection_profile_h profile,
    connection_set_default_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_set_default_cellular_service_profile_async(
      connection,
      type,
      profile,
      callback,
      user_data,
    );
  }

  late final _connection_set_default_cellular_service_profile_asyncPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      connection_h,
                      ffi.Int32,
                      connection_profile_h,
                      connection_set_default_cb,
                      ffi.Pointer<ffi.Void>)>>(
          'connection_set_default_cellular_service_profile_async');
  late final _connection_set_default_cellular_service_profile_async =
      _connection_set_default_cellular_service_profile_asyncPtr.asFunction<
          int Function(connection_h, int, connection_profile_h,
              connection_set_default_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Opens a connection of profile, asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This API needs both privileges.
  /// @param[in] connection        The connection handle
  /// @param[in] profile           The profile handle
  /// @param[in] callback          The callback function to be called
  /// @param[in] user_data         The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @post connection_opened_cb() will be invoked.
  /// @see connection_opened_cb()
  /// @see connection_close_profile()
  /// @see connection_profile_set_state_changed_cb()
  /// @see connection_profile_unset_state_changed_cb()
  /// @see connection_profile_state_changed_cb()
  int connection_open_profile(
    connection_h connection,
    connection_profile_h profile,
    connection_opened_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_open_profile(
      connection,
      profile,
      callback,
      user_data,
    );
  }

  late final _connection_open_profilePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              connection_h,
              connection_profile_h,
              connection_opened_cb,
              ffi.Pointer<ffi.Void>)>>('connection_open_profile');
  late final _connection_open_profile = _connection_open_profilePtr.asFunction<
      int Function(connection_h, connection_profile_h, connection_opened_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Closes a connection of profile.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  /// @param[in] connection        The connection handle
  /// @param[in] profile           The profile handle
  /// @param[in] callback          The callback function to be called
  /// @param[in] user_data         The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @post connection_closed_cb() will be invoked.
  /// @see connection_closed_cb()
  /// @see connection_open_profile()
  /// @see connection_profile_set_state_changed_cb()
  /// @see connection_profile_unset_state_changed_cb()
  /// @see connection_profile_state_changed_cb()
  int connection_close_profile(
    connection_h connection,
    connection_profile_h profile,
    connection_closed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_close_profile(
      connection,
      profile,
      callback,
      user_data,
    );
  }

  late final _connection_close_profilePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              connection_h,
              connection_profile_h,
              connection_closed_cb,
              ffi.Pointer<ffi.Void>)>>('connection_close_profile');
  late final _connection_close_profile =
      _connection_close_profilePtr.asFunction<
          int Function(connection_h, connection_profile_h, connection_closed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Resets the cellular profile.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This API needs both privileges.
  /// @param[in] connection        The connection handle
  /// @param[in] type              The type of reset
  /// @param[in] id                The subscriber identity module ID to reset
  /// (The sim index starts from 0.)
  /// @param[in] callback          The callback function to be called
  /// @param[in] user_data         The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  /// @post connection_reset_cb() will be invoked.
  int connection_reset_profile(
    connection_h connection,
    int type,
    int id,
    connection_reset_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_reset_profile(
      connection,
      type,
      id,
      callback,
      user_data,
    );
  }

  late final _connection_reset_profilePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              connection_h,
              ffi.Int32,
              ffi.Int,
              connection_reset_cb,
              ffi.Pointer<ffi.Void>)>>('connection_reset_profile');
  late final _connection_reset_profile =
      _connection_reset_profilePtr.asFunction<
          int Function(connection_h, int, int, connection_reset_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Adds a IPv4 route to the routing table.
  /// @details You can get the @a interface_name from
  /// connection_profile_get_network_interface_name() of opened profile.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  /// @param[in] connection        The connection handle
  /// @param[in] interface_name    The name of network interface
  /// @param[in] host_address      The IP address of the host
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_ALREADY_EXISTS        Already exists
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @see connection_profile_get_network_interface_name()
  int connection_add_route(
    connection_h connection,
    ffi.Pointer<ffi.Char> interface_name,
    ffi.Pointer<ffi.Char> host_address,
  ) {
    return _connection_add_route(
      connection,
      interface_name,
      host_address,
    );
  }

  late final _connection_add_routePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('connection_add_route');
  late final _connection_add_route = _connection_add_routePtr.asFunction<
      int Function(
          connection_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. Use connection_remove_route_entry() instead.
  /// @brief Removes a IPv4 route from the routing table.
  /// @details You can get the @a interface_name from
  /// connection_profile_get_network_interface_name() of opened profile.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  /// @param[in] connection        The connection handle
  /// @param[in] interface_name    The name of network interface
  /// @param[in] host_address      The IP address of the host
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @see connection_profile_get_network_interface_name()
  int connection_remove_route(
    connection_h connection,
    ffi.Pointer<ffi.Char> interface_name,
    ffi.Pointer<ffi.Char> host_address,
  ) {
    return _connection_remove_route(
      connection,
      interface_name,
      host_address,
    );
  }

  late final _connection_remove_routePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('connection_remove_route');
  late final _connection_remove_route = _connection_remove_routePtr.asFunction<
      int Function(
          connection_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. Use connection_add_route_entry() instead.
  /// @brief Adds a IPv6 route to the routing table.
  /// @details You can get the @a interface_name from
  /// connection_profile_get_network_interface_name() of opened profile.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  /// @param[in] connection        The connection handle
  /// @param[in] interface_name    The name of network interface
  /// @param[in] host_address      The IP address of the host
  /// @param[in] gateway           The gateway address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_ALREADY_EXISTS        Already exists
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @see connection_profile_get_network_interface_name()
  int connection_add_route_ipv6(
    connection_h connection,
    ffi.Pointer<ffi.Char> interface_name,
    ffi.Pointer<ffi.Char> host_address,
    ffi.Pointer<ffi.Char> gateway,
  ) {
    return _connection_add_route_ipv6(
      connection,
      interface_name,
      host_address,
      gateway,
    );
  }

  late final _connection_add_route_ipv6Ptr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              connection_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('connection_add_route_ipv6');
  late final _connection_add_route_ipv6 =
      _connection_add_route_ipv6Ptr.asFunction<
          int Function(connection_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @deprecated Deprecated since 4.0. Use connection_remove_route_entry() instead.
  /// @brief Removes a IPV6 route from the routing table.
  /// @details You can get the @a interface_name from
  /// connection_profile_get_network_interface_name() of opened profile.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  /// @param[in] connection        The connection handle
  /// @param[in] interface_name    The name of network interface
  /// @param[in] host_address      The IP address of the host
  /// @param[in] gateway           The gateway address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @see connection_profile_get_network_interface_name()
  int connection_remove_route_ipv6(
    connection_h connection,
    ffi.Pointer<ffi.Char> interface_name,
    ffi.Pointer<ffi.Char> host_address,
    ffi.Pointer<ffi.Char> gateway,
  ) {
    return _connection_remove_route_ipv6(
      connection,
      interface_name,
      host_address,
      gateway,
    );
  }

  late final _connection_remove_route_ipv6Ptr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              connection_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('connection_remove_route_ipv6');
  late final _connection_remove_route_ipv6 =
      _connection_remove_route_ipv6Ptr.asFunction<
          int Function(connection_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Adds a route to the routing table.
  /// @details You can get the @a interface_name from \n
  /// connection_profile_get_network_interface_name() of opened profile.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  /// @param[in] connection        The connection handle
  /// @param[in] address_family    The address family
  /// @param[in] interface_name    The name of network interface
  /// @param[in] host_address      The IP address of the host (e.g., single IP address such as
  /// 163.152.10.2,192.168.1.2), group's IP address (e.g., 163.152.10.0, 192.168.0.0)
  /// is not allowed
  /// @param[in] gateway           The gateway address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_ALREADY_EXISTS        Already exists
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @see connection_profile_get_network_interface_name()
  int connection_add_route_entry(
    connection_h connection,
    int address_family,
    ffi.Pointer<ffi.Char> interface_name,
    ffi.Pointer<ffi.Char> host_address,
    ffi.Pointer<ffi.Char> gateway,
  ) {
    return _connection_add_route_entry(
      connection,
      address_family,
      interface_name,
      host_address,
      gateway,
    );
  }

  late final _connection_add_route_entryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              connection_h,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('connection_add_route_entry');
  late final _connection_add_route_entry =
      _connection_add_route_entryPtr.asFunction<
          int Function(connection_h, int, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Removes a route from the routing table.
  /// @details You can get the @a interface_name from \n
  /// connection_profile_get_network_interface_name() of opened profile.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  /// @param[in] connection        The connection handle
  /// @param[in] address_family    The address family
  /// @param[in] interface_name    The name of network interface
  /// @param[in] host_address      The IP address of the host (e.g., single IP address such as
  /// 163.152.10.2,192.168.1.2), group's IP address (e.g., 163.152.10.0, 192.168.0.0)
  /// is not allowed
  /// @param[in] gateway           The gateway address
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @see connection_profile_get_network_interface_name()
  int connection_remove_route_entry(
    connection_h connection,
    int address_family,
    ffi.Pointer<ffi.Char> interface_name,
    ffi.Pointer<ffi.Char> host_address,
    ffi.Pointer<ffi.Char> gateway,
  ) {
    return _connection_remove_route_entry(
      connection,
      address_family,
      interface_name,
      host_address,
      gateway,
    );
  }

  late final _connection_remove_route_entryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              connection_h,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('connection_remove_route_entry');
  late final _connection_remove_route_entry =
      _connection_remove_route_entryPtr.asFunction<
          int Function(connection_h, int, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets all IPv6 addresses assigned to the network interface.
  /// @since_tizen 4.0
  /// @param[in] connection       The connection handle
  /// @param[in] connection_type  The connection type
  /// @param[in] callback         The callback to be called for each IPv6 address
  /// @param[in] user_data        The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value.
  /// @retval #CONNECTION_ERROR_NONE               Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED      Not supported
  int connection_foreach_ipv6_address(
    connection_h connection,
    int connection_type,
    connection_ipv6_address_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _connection_foreach_ipv6_address(
      connection,
      connection_type,
      callback,
      user_data,
    );
  }

  late final _connection_foreach_ipv6_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h, ffi.Int32, connection_ipv6_address_cb,
              ffi.Pointer<ffi.Void>)>>('connection_foreach_ipv6_address');
  late final _connection_foreach_ipv6_address =
      _connection_foreach_ipv6_addressPtr.asFunction<
          int Function(connection_h, int, connection_ipv6_address_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the statistics information.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] connection The connection handle
  /// @param[in] connection_type   The type of connection \n
  /// Only CONNECTION_TYPE_WIFI and CONNECTION_TYPE_CELLULAR are supported
  /// @param[in] statistics_type   The type of statistics
  /// @param[out] size             The received data size of the last cellular packet data connection (bytes)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_get_statistics(
    connection_h connection,
    int connection_type,
    int statistics_type,
    ffi.Pointer<ffi.LongLong> size,
  ) {
    return _connection_get_statistics(
      connection,
      connection_type,
      statistics_type,
      size,
    );
  }

  late final _connection_get_statisticsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h, ffi.Int32, ffi.Int32,
              ffi.Pointer<ffi.LongLong>)>>('connection_get_statistics');
  late final _connection_get_statistics =
      _connection_get_statisticsPtr.asFunction<
          int Function(connection_h, int, int, ffi.Pointer<ffi.LongLong>)>();

  /// @brief Resets the statistics information.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  /// @param[in] connection        The connection handle
  /// @param[in] connection_type   The type of connection \n
  /// Only CONNECTION_TYPE_WIFI and CONNECTION_TYPE_CELLULAR are supported
  /// @param[in] statistics_type   The type of statistics
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONNECTION_ERROR_NONE                  Successful
  /// @retval #CONNECTION_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #CONNECTION_ERROR_OPERATION_FAILED      Operation failed
  /// @retval #CONNECTION_ERROR_PERMISSION_DENIED     Permission denied
  /// @retval #CONNECTION_ERROR_NOT_SUPPORTED         Not supported
  int connection_reset_statistics(
    connection_h connection,
    int connection_type,
    int statistics_type,
  ) {
    return _connection_reset_statistics(
      connection,
      connection_type,
      statistics_type,
    );
  }

  late final _connection_reset_statisticsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(connection_h, ffi.Int32,
              ffi.Int32)>>('connection_reset_statistics');
  late final _connection_reset_statistics = _connection_reset_statisticsPtr
      .asFunction<int Function(connection_h, int, int)>();

  /// @brief Initializes DNSSD.
  /// @since_tizen 3.0
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  int dnssd_initialize() {
    return _dnssd_initialize();
  }

  late final _dnssd_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('dnssd_initialize');
  late final _dnssd_initialize =
      _dnssd_initializePtr.asFunction<int Function()>();

  /// @brief Deinitializes DNSSD.
  /// @since_tizen 3.0
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_INVALID_OPERATION Invalid Operation
  /// @pre DNS-SD service must be initialized by dnssd_initialize().
  int dnssd_deinitialize() {
    return _dnssd_deinitialize();
  }

  late final _dnssd_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('dnssd_deinitialize');
  late final _dnssd_deinitialize =
      _dnssd_deinitializePtr.asFunction<int Function()>();

  /// @brief Creates a DNSSD local service handle.
  /// @since_tizen 3.0
  /// @remarks You must release @a dnssd_service using dnssd_destroy_local_service().
  /// @param[in] service_type The DNSSD service type. It is expressed as type
  /// followed by protocol, separated by a dot(e.g. "_ftp._tcp"). It
  /// must begin with an underscore, followed by 1-15 characters which
  /// may be letters, digits, or hyphens. The transport protocol must be
  /// "_tcp" or "_udp". New service types should be registered at
  /// http://www.dns-sd.org/ServiceTypes.html.
  /// @param[out] dnssd_service The DNSSD local handle
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @see dnssd_destroy_local_service()
  /// @pre This API needs dnssd_initialize() before use
  int dnssd_create_local_service(
    ffi.Pointer<ffi.Char> service_type,
    ffi.Pointer<dnssd_service_h> dnssd_service,
  ) {
    return _dnssd_create_local_service(
      service_type,
      dnssd_service,
    );
  }

  late final _dnssd_create_local_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<dnssd_service_h>)>>('dnssd_create_local_service');
  late final _dnssd_create_local_service =
      _dnssd_create_local_servicePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<dnssd_service_h>)>();

  /// @brief Destroys the DNSSD local service handle.
  /// @details Destroying a local service doesn't deregister local service. If
  /// local service was registered using dnssd_register_local_service(),
  /// then it must be deregistered using dnssd_deregister_local_service()
  /// before destroying the local service.
  /// @since_tizen 3.0
  /// @remarks You must destroy only local services created using dnssd_create_local_service().
  /// @param[in] dnssd_service The DNSSD local service handle
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @see dnssd_create_local_service()
  /// @pre This API needs dnssd_create_local_service() before use.
  int dnssd_destroy_local_service(
    int dnssd_service,
  ) {
    return _dnssd_destroy_local_service(
      dnssd_service,
    );
  }

  late final _dnssd_destroy_local_servicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(dnssd_service_h)>>(
          'dnssd_destroy_local_service');
  late final _dnssd_destroy_local_service =
      _dnssd_destroy_local_servicePtr.asFunction<int Function(int)>();

  /// @brief Sets the name of DNSSD local service.
  /// @details Application should set name after creating local service using
  /// dnssd_create_local_service() and before registering the local
  /// service using dnssd_register_local_service().
  /// @since_tizen 3.0
  /// @remarks You must pass only local services created using dnssd_create_local_service().
  /// @param[in] local_service The DNSSD local service handle
  /// @param[in] service_name The name of DNSSD local service
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_OUT_OF_MEMORY Out of Memory
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @see dnssd_create_local_service()
  /// @pre This API needs dnssd_create_local_service() before use.
  int dnssd_service_set_name(
    int local_service,
    ffi.Pointer<ffi.Char> service_name,
  ) {
    return _dnssd_service_set_name(
      local_service,
      service_name,
    );
  }

  late final _dnssd_service_set_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(dnssd_service_h,
              ffi.Pointer<ffi.Char>)>>('dnssd_service_set_name');
  late final _dnssd_service_set_name = _dnssd_service_set_namePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the port number of DNSSD local service.
  /// @details Application should set port after creating local service using
  /// dnssd_create_local_service() and before registering the local
  /// service using dnssd_register_local_service().
  /// @since_tizen 3.0
  /// @remarks You must pass only local services created using dnssd_create_local_service().
  /// @param[in] local_service The DNSSD local service handle
  /// @param[in] port The port number of DNSSD local service
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @see dnssd_create_local_service()
  /// @pre This API needs dnssd_create_local_service() before use.
  int dnssd_service_set_port(
    int local_service,
    int port,
  ) {
    return _dnssd_service_set_port(
      local_service,
      port,
    );
  }

  late final _dnssd_service_set_portPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(dnssd_service_h, ffi.Int)>>(
          'dnssd_service_set_port');
  late final _dnssd_service_set_port =
      _dnssd_service_set_portPtr.asFunction<int Function(int, int)>();

  /// @brief Adds the TXT record.
  /// @details TXT record gives additional information about the service.
  /// Some services discovered via dnssd_start_browsing_service() may
  /// need more than just IP address and port number to completely
  /// identify the service instance. For example, A web server typically
  /// has multiple pages, each identified by its own URL.
  /// So additional data is stored in a TXT record. Check Section 6 of
  /// http://files.dns-sd.org/draft-cheshire-dnsext-dns-sd.txt
  /// for details. TXT record of known service types can be found at
  /// http://www.dns-sd.org/ServiceTypes.html. TXT record is stored in a
  /// structured form using key/value pairs.
  /// @since_tizen 3.0
  /// @remarks You must pass only local services created using dnssd_create_local_service().
  /// @param[in] local_service The DNSSD local service handle
  /// @param[in] key The key of the TXT record. A null-terminated string which only
  /// contains printable ASCII values (0x20-0x7E), excluding '=' (0x3D).
  /// Keys should be 9 characters or fewer excluding NULL. Keys are case
  /// insensitivie. Keys for known service types can be found at
  /// http://www.dns-sd.org/ServiceTypes.html. For details, see section
  /// 6.4 of http://files.dns-sd.org/draft-cheshire-dnsext-dns-sd.txt.
  /// @param[in] length The length of the value of the TXT record in bytes. The
  /// total size of a typical DNS-SD TXT record is intended to be small
  /// (upto 200 bytes). For details, see section 6.2 of
  /// http://files.dns-sd.org/draft-cheshire-dnsext-dns-sd.txt
  /// @param[in] value The value of the TXT record. It can be any binary value. For
  /// value that represents textual data, UTF-8 is STRONGLY recommended.
  /// For value that represents textual data, value_length should NOT
  /// include the terminating null (if any) at the end of the string. If
  /// NULL, then "key" will be added with no value. If non-NULL but
  /// value_length is zero, then "key=" will be added with empty value.
  /// For details see section 6.5 of
  /// http://files.dns-sd.org/draft-cheshire-dnsext-dns-sd.txt
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_SERVICE_NOT_RUNNING Service Not Running
  /// @retval #DNSSD_ERROR_ALREADY_REGISTERED Already Registered
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @retval #DNSSD_ERROR_OUT_OF_MEMORY Out of Memory
  /// @see dnssd_create_local_service()
  /// @pre This API needs dnssd_create_local_service() before use.
  int dnssd_service_add_txt_record(
    int local_service,
    ffi.Pointer<ffi.Char> key,
    int length,
    ffi.Pointer<ffi.Void> value,
  ) {
    return _dnssd_service_add_txt_record(
      local_service,
      key,
      length,
      value,
    );
  }

  late final _dnssd_service_add_txt_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              dnssd_service_h,
              ffi.Pointer<ffi.Char>,
              ffi.UnsignedShort,
              ffi.Pointer<ffi.Void>)>>('dnssd_service_add_txt_record');
  late final _dnssd_service_add_txt_record =
      _dnssd_service_add_txt_recordPtr.asFunction<
          int Function(
              int, ffi.Pointer<ffi.Char>, int, ffi.Pointer<ffi.Void>)>();

  /// @brief Removes the TXT record.
  /// @since_tizen 3.0
  /// @remarks You must pass only local services created using dnssd_create_local_service().
  /// @param[in] local_service The DNSSD local service handle
  /// @param[in] key The key of the TXT record to be removed
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_SERVICE_NOT_RUNNING Service Not Running
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @see dnssd_create_local_service()
  /// @see dnssd_service_add_txt_record()
  /// @pre This API needs dnssd_create_local_service() before use.
  int dnssd_service_remove_txt_record(
    int local_service,
    ffi.Pointer<ffi.Char> key,
  ) {
    return _dnssd_service_remove_txt_record(
      local_service,
      key,
    );
  }

  late final _dnssd_service_remove_txt_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(dnssd_service_h,
              ffi.Pointer<ffi.Char>)>>('dnssd_service_remove_txt_record');
  late final _dnssd_service_remove_txt_record =
      _dnssd_service_remove_txt_recordPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets/updates the DNS resource record.
  /// @details If the resource record for the type has been previously added using
  /// dnssd_service_set_record(), then the record will be updated. DNS
  /// resource record can be set only after local_service is registered
  /// using dnssd_register_local_service(). Data is added using
  /// dnssd_service_add_txt_record() and then obtained using
  /// dnssd_service_get_all_txt_record() to pass here.
  /// @since_tizen 3.0
  /// @remarks You must pass only local services created using dnssd_create_local_service().
  /// @param[in] local_service The DNSSD local service handle
  /// @param[in] type The resource record type. For details see, RFC 1035 and RFC 2782
  /// @param[in] length The length of the resource record in bytes
  /// @param[in] data The data contained in resource record to be added
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_SERVICE_NOT_RUNNING Service Not Running
  /// @retval #DNSSD_ERROR_ALREADY_REGISTERED Already Registered
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @retval #DNSSD_ERROR_OUT_OF_MEMORY Out of Memory
  /// @see dnssd_create_local_service()
  /// @pre This API needs dnssd_create_local_service() before use.
  int dnssd_service_set_record(
    int local_service,
    int type,
    int length,
    ffi.Pointer<ffi.Void> data,
  ) {
    return _dnssd_service_set_record(
      local_service,
      type,
      length,
      data,
    );
  }

  late final _dnssd_service_set_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              dnssd_service_h,
              ffi.UnsignedShort,
              ffi.UnsignedShort,
              ffi.Pointer<ffi.Void>)>>('dnssd_service_set_record');
  late final _dnssd_service_set_record = _dnssd_service_set_recordPtr
      .asFunction<int Function(int, int, int, ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets the DNS resource record. DNS resource record for the given type
  /// must be set using dnssd_service_set_record().
  /// @since_tizen 3.0
  /// @remarks You must pass only local services created using dnssd_create_local_service().
  /// @param[in] local_service The DNSSD local service handle
  /// @param[in] type The resource record type. For details, see RFC 1035 and RFC 2782
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_SERVICE_NOT_RUNNING Service Not Running
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @see dnssd_create_local_service()
  /// @pre This API needs dnssd_create_local_service() before use.
  int dnssd_service_unset_record(
    int local_service,
    int type,
  ) {
    return _dnssd_service_unset_record(
      local_service,
      type,
    );
  }

  late final _dnssd_service_unset_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(dnssd_service_h,
              ffi.UnsignedShort)>>('dnssd_service_unset_record');
  late final _dnssd_service_unset_record =
      _dnssd_service_unset_recordPtr.asFunction<int Function(int, int)>();

  /// @brief Registers the DNSSD local service for publishing.
  /// @since_tizen 3.0
  /// @remarks You must pass only local services created using dnssd_create_local_service().
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] local_service The DNSSD local service handle
  /// @param[in] register_cb The callback function to be called
  /// @param[in] user_data The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_SERVICE_NOT_RUNNING Service Not Running
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @retval #DNSSD_ERROR_PERMISSION_DENIED Permission Denied
  /// @see dnssd_create_local_service()
  /// @pre This API needs dnssd_create_local_service() before use.
  int dnssd_register_local_service(
    int local_service,
    dnssd_registered_cb register_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _dnssd_register_local_service(
      local_service,
      register_cb,
      user_data,
    );
  }

  late final _dnssd_register_local_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(dnssd_service_h, dnssd_registered_cb,
              ffi.Pointer<ffi.Void>)>>('dnssd_register_local_service');
  late final _dnssd_register_local_service =
      _dnssd_register_local_servicePtr.asFunction<
          int Function(int, dnssd_registered_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Deregisters the DNSSD local service.
  /// @since_tizen 3.0
  /// @remarks You must pass only local services registered using dnssd_register_local_service().
  /// @param[in] local_service The DNSSD local service handle
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_SERVICE_NOT_RUNNING Service Not Running
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @see dnssd_create_local_service()
  /// @see dnssd_register_local_service()
  /// @pre This API needs dnssd_register_local_service() before use.
  int dnssd_deregister_local_service(
    int local_service,
  ) {
    return _dnssd_deregister_local_service(
      local_service,
    );
  }

  late final _dnssd_deregister_local_servicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(dnssd_service_h)>>(
          'dnssd_deregister_local_service');
  late final _dnssd_deregister_local_service =
      _dnssd_deregister_local_servicePtr.asFunction<int Function(int)>();

  /// @brief Starts browsing the DNSSD remote service.
  /// @details found_cb would be called only if there are any services available of
  /// service_type provided in the argument. Application will keep
  /// browsing for available/unavailable services until it calls
  /// dnssd_stop_browsing_service().
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] service_type The DNSSD service type to browse. It is expressed
  /// as type followed by protocol, separated by a dot(e.g. "_ftp._tcp").
  /// It must begin with an underscore, followed by 1-15 characters
  /// which may be letters, digits, or hyphens. The transport protocol
  /// must be "_tcp" or "_udp". New service types should be registered
  /// at http://www.dns-sd.org/ServiceTypes.html
  /// @param[out] dnssd_service The DNSSD browse service handle
  /// @param[in] found_cb The callback function to be called
  /// @param[in] user_data The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_SERVICE_NOT_RUNNING Service Not Running
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @retval #DNSSD_ERROR_PERMISSION_DENIED Permission Denied
  /// @pre This API needs dnssd_initialize() before use.
  int dnssd_start_browsing_service(
    ffi.Pointer<ffi.Char> service_type,
    ffi.Pointer<dnssd_browser_h> dnssd_service,
    dnssd_found_cb found_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _dnssd_start_browsing_service(
      service_type,
      dnssd_service,
      found_cb,
      user_data,
    );
  }

  late final _dnssd_start_browsing_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<dnssd_browser_h>,
              dnssd_found_cb,
              ffi.Pointer<ffi.Void>)>>('dnssd_start_browsing_service');
  late final _dnssd_start_browsing_service =
      _dnssd_start_browsing_servicePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<dnssd_browser_h>,
              dnssd_found_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Stops browsing the DNSSD remote service.
  /// @since_tizen 3.0
  /// @param[in] dnssd_service The DNSSD browse service handle returned by
  /// dnssd_start_browsing_service()
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_SERVICE_NOT_RUNNING Service Not Running
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  /// @pre This API needs dnssd_start_browsing_service() before use.
  int dnssd_stop_browsing_service(
    int dnssd_service,
  ) {
    return _dnssd_stop_browsing_service(
      dnssd_service,
    );
  }

  late final _dnssd_stop_browsing_servicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(dnssd_browser_h)>>(
          'dnssd_stop_browsing_service');
  late final _dnssd_stop_browsing_service =
      _dnssd_stop_browsing_servicePtr.asFunction<int Function(int)>();

  /// @brief Gets the type of DNSSD local/remote service.
  /// @since_tizen 3.0
  /// @remarks You must release @a service_type using free().
  /// @param[in] dnssd_service The DNSSD local/remote service handle
  /// @param[out] service_type The type of DNSSD service. It is expressed as type
  /// followed by protocol, separated by a dot(e.g. "_ftp._tcp"). It
  /// must begin with an underscore, followed by 1-15 characters which
  /// may be letters, digits, or hyphens. The transport protocol must be
  /// "_tcp" or "_udp". New service types should be registered at
  /// http://www.dns-sd.org/ServiceTypes.html
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_OUT_OF_MEMORY Out of Memory
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  int dnssd_service_get_type(
    int dnssd_service,
    ffi.Pointer<ffi.Pointer<ffi.Char>> service_type,
  ) {
    return _dnssd_service_get_type(
      dnssd_service,
      service_type,
    );
  }

  late final _dnssd_service_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(dnssd_service_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('dnssd_service_get_type');
  late final _dnssd_service_get_type = _dnssd_service_get_typePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the name of DNSSD local/remote service.
  /// @since_tizen 3.0
  /// @remarks You must release @a service_name using free().
  /// @param[in] dnssd_service The DNSSD local/remote service handle
  /// @param[out] service_name The name of DNSSD service
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_OUT_OF_MEMORY Out of Memory
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  int dnssd_service_get_name(
    int dnssd_service,
    ffi.Pointer<ffi.Pointer<ffi.Char>> service_name,
  ) {
    return _dnssd_service_get_name(
      dnssd_service,
      service_name,
    );
  }

  late final _dnssd_service_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(dnssd_service_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('dnssd_service_get_name');
  late final _dnssd_service_get_name = _dnssd_service_get_namePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the IP of DNSSD remote service.
  /// @since_tizen 3.0
  /// @remarks You must release @a ip_v4_address, @a ip_v6_address using free().
  /// @param[in] dnssd_service The DNSSD remote service handle
  /// @param[out] ip_v4_address The IP version 4 address of DNSSD service. If there
  /// is no IPv4 Address, then it would contain NULL and should not be freed
  /// @param[out] ip_v6_address The IP version 6 address of DNSSD service. If there
  /// is no IPv6 Address, then it would contain NULL and should not be freed
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_OUT_OF_MEMORY Out of Memory
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  int dnssd_service_get_ip(
    int dnssd_service,
    ffi.Pointer<ffi.Pointer<ffi.Char>> ip_v4_address,
    ffi.Pointer<ffi.Pointer<ffi.Char>> ip_v6_address,
  ) {
    return _dnssd_service_get_ip(
      dnssd_service,
      ip_v4_address,
      ip_v6_address,
    );
  }

  late final _dnssd_service_get_ipPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(dnssd_service_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('dnssd_service_get_ip');
  late final _dnssd_service_get_ip = _dnssd_service_get_ipPtr.asFunction<
      int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the port number of DNSSD local/remote service.
  /// @since_tizen 3.0
  /// @param[in] dnssd_service The DNSSD service local/remote handle
  /// @param[out] port The port number of DNSSD service
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  int dnssd_service_get_port(
    int dnssd_service,
    ffi.Pointer<ffi.Int> port,
  ) {
    return _dnssd_service_get_port(
      dnssd_service,
      port,
    );
  }

  late final _dnssd_service_get_portPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(dnssd_service_h,
              ffi.Pointer<ffi.Int>)>>('dnssd_service_get_port');
  late final _dnssd_service_get_port = _dnssd_service_get_portPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the TXT record.
  /// @details TXT record gives additional information about the service. Some
  /// services discovered via dnssd_start_browsing_service() may need
  /// more than just IP address and port number to completely identify
  /// the service instance. For example, a web server typically has
  /// multiple pages, each identified by its own URL. So additional data
  /// is stored in a TXT record. Check Section 6 of
  /// http://files.dns-sd.org/draft-cheshire-dnsext-dns-sd.txt for
  /// details. TXT record of known service types can be found at
  /// http://www.dns-sd.org/ServiceTypes.html. TXT record is stored in a
  /// structured form using key/value pairs.
  /// @since_tizen 3.0
  /// @remarks You must release @a value using free().
  /// @param[in] dnssd_service The DNSSD local/remote service handle
  /// @param[out] length The length of the value of the TXT record in bytes
  /// @param[out] value The value of the TXT record
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #DNSSD_ERROR_NONE Successful
  /// @retval #DNSSD_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DNSSD_ERROR_NOT_SUPPORTED Not Supported
  /// @retval #DNSSD_ERROR_OUT_OF_MEMORY Out of Memory
  /// @retval #DNSSD_ERROR_SERVICE_NOT_RUNNING Service Not Running
  /// @retval #DNSSD_ERROR_NOT_INITIALIZED Not Initialized
  int dnssd_service_get_all_txt_record(
    int dnssd_service,
    ffi.Pointer<ffi.UnsignedShort> length,
    ffi.Pointer<ffi.Pointer<ffi.Void>> value,
  ) {
    return _dnssd_service_get_all_txt_record(
      dnssd_service,
      length,
      value,
    );
  }

  late final _dnssd_service_get_all_txt_recordPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(dnssd_service_h, ffi.Pointer<ffi.UnsignedShort>,
                  ffi.Pointer<ffi.Pointer<ffi.Void>>)>>(
      'dnssd_service_get_all_txt_record');
  late final _dnssd_service_get_all_txt_record =
      _dnssd_service_get_all_txt_recordPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.UnsignedShort>,
              ffi.Pointer<ffi.Pointer<ffi.Void>>)>();

  /// @brief Creates a new list handle.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a list by calling iotcon_list_destroy() if @a list is no longer needed.
  /// @param[in] type The type of list
  /// @param[out] list A newly allocated list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_list_create(
    int type,
    ffi.Pointer<iotcon_list_h> list,
  ) {
    return _iotcon_list_create(
      type,
      list,
    );
  }

  late final _iotcon_list_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<iotcon_list_h>)>>('iotcon_list_create');
  late final _iotcon_list_create = _iotcon_list_createPtr
      .asFunction<int Function(int, ffi.Pointer<iotcon_list_h>)>();

  /// @brief Destroys a list handle.
  /// @details Releases a @a list and its internal data.
  /// @since_tizen 3.0
  /// @param[in] list The handle to the list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_list_destroy(
    iotcon_list_h list,
  ) {
    return _iotcon_list_destroy(
      list,
    );
  }

  late final _iotcon_list_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_list_h)>>(
          'iotcon_list_destroy');
  late final _iotcon_list_destroy =
      _iotcon_list_destroyPtr.asFunction<int Function(iotcon_list_h)>();

  /// @brief Adds a new element integer value into the list at the given position.
  /// @details If @a pos is negative, or is larger than the number of elements in the list, the new value is added on to the end of the list.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] val The new integer value
  /// @param[in] pos The position to insert value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_list_add_int(
    iotcon_list_h list,
    int val,
    int pos,
  ) {
    return _iotcon_list_add_int(
      list,
      val,
      pos,
    );
  }

  late final _iotcon_list_add_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_list_h, ffi.Int, ffi.Int)>>('iotcon_list_add_int');
  late final _iotcon_list_add_int = _iotcon_list_add_intPtr
      .asFunction<int Function(iotcon_list_h, int, int)>();

  /// @brief Adds a new element boolean value into the list at the given position.
  /// @details If @a pos is negative, or is larger than the number of elements in the list, the new value is added on to the end of the list.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] val The new boolean value
  /// @param[in] pos The position to insert value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_list_add_bool(
    iotcon_list_h list,
    bool val,
    int pos,
  ) {
    return _iotcon_list_add_bool(
      list,
      val,
      pos,
    );
  }

  late final _iotcon_list_add_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_list_h, ffi.Bool, ffi.Int)>>('iotcon_list_add_bool');
  late final _iotcon_list_add_bool = _iotcon_list_add_boolPtr
      .asFunction<int Function(iotcon_list_h, bool, int)>();

  /// @brief Adds a new element double value into the list at the given position.
  /// @details If @a pos is negative, or is larger than the number of elements in the list, the new value is added on to the end of the list.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] val The new double value
  /// @param[in] pos The position to insert value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_list_add_double(
    iotcon_list_h list,
    double val,
    int pos,
  ) {
    return _iotcon_list_add_double(
      list,
      val,
      pos,
    );
  }

  late final _iotcon_list_add_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_list_h, ffi.Double, ffi.Int)>>('iotcon_list_add_double');
  late final _iotcon_list_add_double = _iotcon_list_add_doublePtr
      .asFunction<int Function(iotcon_list_h, double, int)>();

  /// @brief Adds a new element string value into the list at the given position.
  /// @details If @a pos is negative, or is larger than the number of elements in the list, the new value is added on to the end of the list.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] val The new char value
  /// @param[in] pos The position to insert value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_list_add_str(
    iotcon_list_h list,
    ffi.Pointer<ffi.Char> val,
    int pos,
  ) {
    return _iotcon_list_add_str(
      list,
      val,
      pos,
    );
  }

  late final _iotcon_list_add_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, ffi.Pointer<ffi.Char>,
              ffi.Int)>>('iotcon_list_add_str');
  late final _iotcon_list_add_str = _iotcon_list_add_strPtr
      .asFunction<int Function(iotcon_list_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Adds a new element byte string value into the list at the given position.
  /// @details If @a pos is negative, or is larger than the number of elements in the list, the new value is added on to the end of the list.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] val The new byte string value
  /// @param[in] len The length of @a val
  /// @param[in] pos The position to insert value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_list_add_byte_str(
    iotcon_list_h list,
    ffi.Pointer<ffi.UnsignedChar> val,
    int len,
    int pos,
  ) {
    return _iotcon_list_add_byte_str(
      list,
      val,
      len,
      pos,
    );
  }

  late final _iotcon_list_add_byte_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, ffi.Pointer<ffi.UnsignedChar>,
              ffi.Int, ffi.Int)>>('iotcon_list_add_byte_str');
  late final _iotcon_list_add_byte_str =
      _iotcon_list_add_byte_strPtr.asFunction<
          int Function(
              iotcon_list_h, ffi.Pointer<ffi.UnsignedChar>, int, int)>();

  /// @brief Adds a new element list into the list at the given position.
  /// @details If @a pos is negative, or is larger than the number of elements in the list, the new value is added on to the end of the list.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] val The new list value
  /// @param[in] pos The position to insert value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_list_add_list(
    iotcon_list_h list,
    iotcon_list_h val,
    int pos,
  ) {
    return _iotcon_list_add_list(
      list,
      val,
      pos,
    );
  }

  late final _iotcon_list_add_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_list_h, iotcon_list_h, ffi.Int)>>('iotcon_list_add_list');
  late final _iotcon_list_add_list = _iotcon_list_add_listPtr
      .asFunction<int Function(iotcon_list_h, iotcon_list_h, int)>();

  /// @brief Adds a new element attributes value into the list at the given position.
  /// @details If @a pos is negative, or is larger than the number of elements in the list, the new value is added on to the end of the list.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] val The new attributes value
  /// @param[in] pos The position to insert value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_list_add_attributes(
    iotcon_list_h list,
    iotcon_attributes_h val,
    int pos,
  ) {
    return _iotcon_list_add_attributes(
      list,
      val,
      pos,
    );
  }

  late final _iotcon_list_add_attributesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, iotcon_attributes_h,
              ffi.Int)>>('iotcon_list_add_attributes');
  late final _iotcon_list_add_attributes = _iotcon_list_add_attributesPtr
      .asFunction<int Function(iotcon_list_h, iotcon_attributes_h, int)>();

  /// @brief Gets the integer value at the given position.
  /// @details Iterates over the list until it reaches the @a pos-1 position.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] pos The position
  /// @param[out] val The integer value to get
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_REPRESENTATION Representation errors
  int iotcon_list_get_nth_int(
    iotcon_list_h list,
    int pos,
    ffi.Pointer<ffi.Int> val,
  ) {
    return _iotcon_list_get_nth_int(
      list,
      pos,
      val,
    );
  }

  late final _iotcon_list_get_nth_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('iotcon_list_get_nth_int');
  late final _iotcon_list_get_nth_int = _iotcon_list_get_nth_intPtr
      .asFunction<int Function(iotcon_list_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the boolean value at the given position.
  /// @details Iterates over the list until it reaches the @a pos-1 position.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] pos The position
  /// @param[out] val The boolean value to get
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_REPRESENTATION Representation errors
  int iotcon_list_get_nth_bool(
    iotcon_list_h list,
    int pos,
    ffi.Pointer<ffi.Bool> val,
  ) {
    return _iotcon_list_get_nth_bool(
      list,
      pos,
      val,
    );
  }

  late final _iotcon_list_get_nth_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, ffi.Int,
              ffi.Pointer<ffi.Bool>)>>('iotcon_list_get_nth_bool');
  late final _iotcon_list_get_nth_bool = _iotcon_list_get_nth_boolPtr
      .asFunction<int Function(iotcon_list_h, int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the double value at the given position.
  /// @details Iterates over the list until it reaches the @a pos-1 position.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] pos The position
  /// @param[out] val The double value to get
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_REPRESENTATION Representation errors
  int iotcon_list_get_nth_double(
    iotcon_list_h list,
    int pos,
    ffi.Pointer<ffi.Double> val,
  ) {
    return _iotcon_list_get_nth_double(
      list,
      pos,
      val,
    );
  }

  late final _iotcon_list_get_nth_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, ffi.Int,
              ffi.Pointer<ffi.Double>)>>('iotcon_list_get_nth_double');
  late final _iotcon_list_get_nth_double = _iotcon_list_get_nth_doublePtr
      .asFunction<int Function(iotcon_list_h, int, ffi.Pointer<ffi.Double>)>();

  /// @brief Gets the string value at the given position.
  /// @details Iterates over the list until it reaches the @a pos-1 position.
  /// @since_tizen 3.0
  /// @remarks @a val must not be released using free().
  /// @param[in] list The list handle
  /// @param[in] pos The position
  /// @param[out] val The string value to get
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_REPRESENTATION Representation errors
  int iotcon_list_get_nth_str(
    iotcon_list_h list,
    int pos,
    ffi.Pointer<ffi.Pointer<ffi.Char>> val,
  ) {
    return _iotcon_list_get_nth_str(
      list,
      pos,
      val,
    );
  }

  late final _iotcon_list_get_nth_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('iotcon_list_get_nth_str');
  late final _iotcon_list_get_nth_str = _iotcon_list_get_nth_strPtr.asFunction<
      int Function(iotcon_list_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the string value at the given position.
  /// @details Iterates over the list until it reaches the @a pos-1 position.
  /// @since_tizen 3.0
  /// @remarks @a val must not be released using free().
  /// @param[in] list The list handle
  /// @param[in] pos The position
  /// @param[out] val The byte string value to get
  /// @param[out] len The length of the @a val
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_REPRESENTATION Representation errors
  int iotcon_list_get_nth_byte_str(
    iotcon_list_h list,
    int pos,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> val,
    ffi.Pointer<ffi.Int> len,
  ) {
    return _iotcon_list_get_nth_byte_str(
      list,
      pos,
      val,
      len,
    );
  }

  late final _iotcon_list_get_nth_byte_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_list_h,
              ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>>('iotcon_list_get_nth_byte_str');
  late final _iotcon_list_get_nth_byte_str =
      _iotcon_list_get_nth_byte_strPtr.asFunction<
          int Function(
              iotcon_list_h,
              int,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the list value at the given position.
  /// @details Iterates over the list until it reaches the @a pos-1 position.
  /// @since_tizen 3.0
  /// @remarks @a dest must not be released using iotcon_list_destroy().
  /// @param[in] src The list handle
  /// @param[in] pos The position
  /// @param[out] dest The list value to get
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_REPRESENTATION Representation errors
  int iotcon_list_get_nth_list(
    iotcon_list_h src,
    int pos,
    ffi.Pointer<iotcon_list_h> dest,
  ) {
    return _iotcon_list_get_nth_list(
      src,
      pos,
      dest,
    );
  }

  late final _iotcon_list_get_nth_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, ffi.Int,
              ffi.Pointer<iotcon_list_h>)>>('iotcon_list_get_nth_list');
  late final _iotcon_list_get_nth_list =
      _iotcon_list_get_nth_listPtr.asFunction<
          int Function(iotcon_list_h, int, ffi.Pointer<iotcon_list_h>)>();

  /// @brief Gets the attributes value at the given position.
  /// @details Iterates over the list until it reaches the @a pos-1 position.
  /// @since_tizen 3.0
  /// @remarks @a attributes must not be released using iotcon_attributes_destroy().
  /// @param[in] list The list handle
  /// @param[in] pos The position
  /// @param[out] attributes The attributes value to get
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_REPRESENTATION Representation errors
  int iotcon_list_get_nth_attributes(
    iotcon_list_h list,
    int pos,
    ffi.Pointer<iotcon_attributes_h> attributes,
  ) {
    return _iotcon_list_get_nth_attributes(
      list,
      pos,
      attributes,
    );
  }

  late final _iotcon_list_get_nth_attributesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_list_h, ffi.Int, ffi.Pointer<iotcon_attributes_h>)>>(
      'iotcon_list_get_nth_attributes');
  late final _iotcon_list_get_nth_attributes =
      _iotcon_list_get_nth_attributesPtr.asFunction<
          int Function(iotcon_list_h, int, ffi.Pointer<iotcon_attributes_h>)>();

  /// @brief Removes the value at the given position.
  /// @details Iterates over the list until it reaches the @a pos-1 position.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[in] pos The position to delete
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  int iotcon_list_remove_nth(
    iotcon_list_h list,
    int pos,
  ) {
    return _iotcon_list_remove_nth(
      list,
      pos,
    );
  }

  late final _iotcon_list_remove_nthPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_list_h, ffi.Int)>>(
          'iotcon_list_remove_nth');
  late final _iotcon_list_remove_nth =
      _iotcon_list_remove_nthPtr.asFunction<int Function(iotcon_list_h, int)>();

  /// @brief Gets the type of the list.
  /// @details It gets the data type of value related to the @a key in @a attributes.
  /// The data type could be one of #iotcon_type_e.
  /// @since_tizen 3.0
  /// @param[in] list The list handle
  /// @param[out] type The data type of list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_list_get_type(
    iotcon_list_h list,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _iotcon_list_get_type(
      list,
      type,
    );
  }

  late final _iotcon_list_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_list_h, ffi.Pointer<ffi.Int32>)>>('iotcon_list_get_type');
  late final _iotcon_list_get_type = _iotcon_list_get_typePtr
      .asFunction<int Function(iotcon_list_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the number of elements in a list.
  /// @since_tizen 3.0
  /// @param[in] list The handle to the list
  /// @param[out] length The length of list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_list_get_length(
    iotcon_list_h list,
    ffi.Pointer<ffi.UnsignedInt> length,
  ) {
    return _iotcon_list_get_length(
      list,
      length,
    );
  }

  late final _iotcon_list_get_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h,
              ffi.Pointer<ffi.UnsignedInt>)>>('iotcon_list_get_length');
  late final _iotcon_list_get_length = _iotcon_list_get_lengthPtr
      .asFunction<int Function(iotcon_list_h, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets all integer values of the given list by invoking the callback function.
  /// @details iotcon_list_int_cb() will be called for each child.
  /// @since_tizen 3.0
  /// @param[in] list The handle to the list
  /// @param[in] cb The callback function to get each integer value
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_list_int_cb() will be called for each item.
  /// @see iotcon_list_int_cb()
  int iotcon_list_foreach_int(
    iotcon_list_h list,
    iotcon_list_int_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_list_foreach_int(
      list,
      cb,
      user_data,
    );
  }

  late final _iotcon_list_foreach_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, iotcon_list_int_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_list_foreach_int');
  late final _iotcon_list_foreach_int = _iotcon_list_foreach_intPtr.asFunction<
      int Function(iotcon_list_h, iotcon_list_int_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets all boolean values of the given list by invoking the callback function.
  /// @details iotcon_list_bool_cb() will be called for each child.
  /// @since_tizen 3.0
  /// @param[in] list The handle to the list
  /// @param[in] cb The callback function to get each boolean value
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_list_bool_cb() will be called for each item.
  /// @see iotcon_list_bool_cb()
  int iotcon_list_foreach_bool(
    iotcon_list_h list,
    iotcon_list_bool_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_list_foreach_bool(
      list,
      cb,
      user_data,
    );
  }

  late final _iotcon_list_foreach_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, iotcon_list_bool_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_list_foreach_bool');
  late final _iotcon_list_foreach_bool =
      _iotcon_list_foreach_boolPtr.asFunction<
          int Function(
              iotcon_list_h, iotcon_list_bool_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets all double values of the given list by invoking the callback function.
  /// @details iotcon_list_double_cb() will be called for each child.
  /// @since_tizen 3.0
  /// @param[in] list The handle to the list
  /// @param[in] cb The callback function to get each double value
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_list_double_cb() will be called for each item.
  /// @see iotcon_list_double_cb()
  int iotcon_list_foreach_double(
    iotcon_list_h list,
    iotcon_list_double_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_list_foreach_double(
      list,
      cb,
      user_data,
    );
  }

  late final _iotcon_list_foreach_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, iotcon_list_double_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_list_foreach_double');
  late final _iotcon_list_foreach_double =
      _iotcon_list_foreach_doublePtr.asFunction<
          int Function(
              iotcon_list_h, iotcon_list_double_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets all string values of the given list by invoking the callback function.
  /// @details iotcon_list_byte_str_cb() will be called for each child.
  /// @since_tizen 3.0
  /// @param[in] list The handle to the list
  /// @param[in] cb The callback function to get each string value
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_list_byte_str_cb() will be called for each item.
  /// @see iotcon_list_byte_str_cb()
  int iotcon_list_foreach_byte_str(
    iotcon_list_h list,
    iotcon_list_byte_str_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_list_foreach_byte_str(
      list,
      cb,
      user_data,
    );
  }

  late final _iotcon_list_foreach_byte_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, iotcon_list_byte_str_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_list_foreach_byte_str');
  late final _iotcon_list_foreach_byte_str =
      _iotcon_list_foreach_byte_strPtr.asFunction<
          int Function(
              iotcon_list_h, iotcon_list_byte_str_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets all string values of the given list by invoking the callback function.
  /// @details iotcon_list_str_cb() will be called for each child.
  /// @since_tizen 3.0
  /// @param[in] list The handle to the list
  /// @param[in] cb The callback function to get each string value
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_list_str_cb() will be called for each item.
  /// @see iotcon_list_str_cb()
  int iotcon_list_foreach_str(
    iotcon_list_h list,
    iotcon_list_str_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_list_foreach_str(
      list,
      cb,
      user_data,
    );
  }

  late final _iotcon_list_foreach_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, iotcon_list_str_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_list_foreach_str');
  late final _iotcon_list_foreach_str = _iotcon_list_foreach_strPtr.asFunction<
      int Function(iotcon_list_h, iotcon_list_str_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets all sub lists of the given list by invoking the callback function.
  /// @details iotcon_list_list_cb() will be called for each child.
  /// @since_tizen 3.0
  /// @param[in] list The handle to the origin list
  /// @param[in] cb The callback function to get each sub list
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_list_list_cb() will be called for each item.
  /// @see iotcon_list_list_cb()
  int iotcon_list_foreach_list(
    iotcon_list_h list,
    iotcon_list_list_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_list_foreach_list(
      list,
      cb,
      user_data,
    );
  }

  late final _iotcon_list_foreach_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, iotcon_list_list_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_list_foreach_list');
  late final _iotcon_list_foreach_list =
      _iotcon_list_foreach_listPtr.asFunction<
          int Function(
              iotcon_list_h, iotcon_list_list_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets all attributes of the given list by invoking the callback function.
  /// @details iotcon_list_attributes_cb() will be called for each child.
  /// @since_tizen 3.0
  /// @param[in] list The handle to the list
  /// @param[in] cb The callback function to get each attributes
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_list_attributes_cb() will be called for each item.
  /// @see iotcon_list_attributes_cb()
  int iotcon_list_foreach_attributes(
    iotcon_list_h list,
    iotcon_list_attributes_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_list_foreach_attributes(
      list,
      cb,
      user_data,
    );
  }

  late final _iotcon_list_foreach_attributesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_list_h, iotcon_list_attributes_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_list_foreach_attributes');
  late final _iotcon_list_foreach_attributes =
      _iotcon_list_foreach_attributesPtr.asFunction<
          int Function(iotcon_list_h, iotcon_list_attributes_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Creates a new query handle.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a query by calling iotcon_query_destroy() if @a query is no longer needed.
  /// @param[out] query A newly allocated query handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_query_destroy()
  /// @see iotcon_query_add()
  /// @see iotcon_query_remove()
  /// @see iotcon_query_lookup()
  int iotcon_query_create(
    ffi.Pointer<iotcon_query_h> query,
  ) {
    return _iotcon_query_create(
      query,
    );
  }

  late final _iotcon_query_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<iotcon_query_h>)>>(
      'iotcon_query_create');
  late final _iotcon_query_create = _iotcon_query_createPtr
      .asFunction<int Function(ffi.Pointer<iotcon_query_h>)>();

  /// @brief Destroys a query handle.
  /// @since_tizen 3.0
  /// @param[in] query The handle of the query
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_query_create()
  /// @see iotcon_query_add()
  /// @see iotcon_query_remove()
  /// @see iotcon_query_lookup()
  int iotcon_query_destroy(
    iotcon_query_h query,
  ) {
    return _iotcon_query_destroy(
      query,
    );
  }

  late final _iotcon_query_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_query_h)>>(
          'iotcon_query_destroy');
  late final _iotcon_query_destroy =
      _iotcon_query_destroyPtr.asFunction<int Function(iotcon_query_h)>();

  /// @brief Gets resource type from the query.
  /// @since_tizen 3.0
  /// @remarks @a resource_type must not be released using free().
  /// @a resource_type must start with a lowercase alphabetic character, followed by a sequence
  /// of lowercase alphabetic, numeric, ".", or "-" characters, and contains no white space.
  /// @param[in] query The handle of the query
  /// @param[out] resource_type Found resource type from query
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @see iotcon_query_create()
  /// @see iotcon_query_destroy()
  /// @see iotcon_query_add()
  /// @see iotcon_query_remove()
  /// @see iotcon_query_set_resource_type()
  int iotcon_query_get_resource_type(
    iotcon_query_h query,
    ffi.Pointer<ffi.Pointer<ffi.Char>> resource_type,
  ) {
    return _iotcon_query_get_resource_type(
      query,
      resource_type,
    );
  }

  late final _iotcon_query_get_resource_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_query_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_query_get_resource_type');
  late final _iotcon_query_get_resource_type =
      _iotcon_query_get_resource_typePtr.asFunction<
          int Function(iotcon_query_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets resource interface from the query.
  /// @since_tizen 3.0
  /// @remarks @a resource_iface could be a value such as #IOTCON_INTERFACE_DEFAULT.
  /// @remarks @a resource_iface must not be released using free().
  /// @param[in] query The handle of the query
  /// @param[out] resource_iface Found resource interface from query
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @see iotcon_query_create()
  /// @see iotcon_query_destroy()
  /// @see iotcon_query_add()
  /// @see iotcon_query_remove()
  /// @see iotcon_query_set_interface()
  int iotcon_query_get_interface(
    iotcon_query_h query,
    ffi.Pointer<ffi.Pointer<ffi.Char>> resource_iface,
  ) {
    return _iotcon_query_get_interface(
      query,
      resource_iface,
    );
  }

  late final _iotcon_query_get_interfacePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_query_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_query_get_interface');
  late final _iotcon_query_get_interface =
      _iotcon_query_get_interfacePtr.asFunction<
          int Function(iotcon_query_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the resource type into the query.
  /// @since_tizen 3.0
  /// @param[in] query The handle of the query
  /// @param[in] resource_type The resource type to set into the query
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_query_create()
  /// @see iotcon_query_destroy()
  /// @see iotcon_query_add()
  /// @see iotcon_query_remove()
  /// @see iotcon_query_lookup()
  /// @see iotcon_query_get_resource_type()
  int iotcon_query_set_resource_type(
    iotcon_query_h query,
    ffi.Pointer<ffi.Char> resource_type,
  ) {
    return _iotcon_query_set_resource_type(
      query,
      resource_type,
    );
  }

  late final _iotcon_query_set_resource_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_query_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_query_set_resource_type');
  late final _iotcon_query_set_resource_type =
      _iotcon_query_set_resource_typePtr
          .asFunction<int Function(iotcon_query_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the resource interface into the query.
  /// @since_tizen 3.0
  /// @remarks @a resource_iface could be a value such as #IOTCON_INTERFACE_DEFAULT.
  /// @param[in] query The handle of the query
  /// @param[in] resource_iface The resource interface to add into the query
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_query_create()
  /// @see iotcon_query_destroy()
  /// @see iotcon_query_add()
  /// @see iotcon_query_remove()
  /// @see iotcon_query_lookup()
  /// @see iotcon_query_get_interface()
  int iotcon_query_set_interface(
    iotcon_query_h query,
    ffi.Pointer<ffi.Char> resource_iface,
  ) {
    return _iotcon_query_set_interface(
      query,
      resource_iface,
    );
  }

  late final _iotcon_query_set_interfacePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_query_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_query_set_interface');
  late final _iotcon_query_set_interface = _iotcon_query_set_interfacePtr
      .asFunction<int Function(iotcon_query_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Adds a new key and corresponding value into the query.
  /// @since_tizen 3.0
  /// @remarks The full length of query should be less than or equal to 64.
  /// @param[in] query The handle of the query
  /// @param[in] key The key of the query to insert
  /// @param[in] value The string data to insert into the query
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_query_create()
  /// @see iotcon_query_destroy()
  /// @see iotcon_query_remove()
  /// @see iotcon_query_lookup()
  int iotcon_query_add(
    iotcon_query_h query,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _iotcon_query_add(
      query,
      key,
      value,
    );
  }

  late final _iotcon_query_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_query_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('iotcon_query_add');
  late final _iotcon_query_add = _iotcon_query_addPtr.asFunction<
      int Function(
          iotcon_query_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Removes the key and its associated value from the query.
  /// @since_tizen 3.0
  /// @param[in] query The handle of the query
  /// @param[in] key The key of the option to delete
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_query_create()
  /// @see iotcon_query_destroy()
  /// @see iotcon_query_add()
  /// @see iotcon_query_lookup()
  int iotcon_query_remove(
    iotcon_query_h query,
    ffi.Pointer<ffi.Char> key,
  ) {
    return _iotcon_query_remove(
      query,
      key,
    );
  }

  late final _iotcon_query_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_query_h, ffi.Pointer<ffi.Char>)>>('iotcon_query_remove');
  late final _iotcon_query_remove = _iotcon_query_removePtr
      .asFunction<int Function(iotcon_query_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Looks up data at the given key from the query.
  /// @since_tizen 3.0
  /// @remarks @a data must not be released using free().
  /// @param[in] query The handle of the query
  /// @param[in] key The key of the query to lookup
  /// @param[out] data Found data from query
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_query_create()
  /// @see iotcon_query_destroy()
  /// @see iotcon_query_add()
  /// @see iotcon_query_remove()
  int iotcon_query_lookup(
    iotcon_query_h query,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> data,
  ) {
    return _iotcon_query_lookup(
      query,
      key,
      data,
    );
  }

  late final _iotcon_query_lookupPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_query_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('iotcon_query_lookup');
  late final _iotcon_query_lookup = _iotcon_query_lookupPtr.asFunction<
      int Function(iotcon_query_h, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets all data of the query by invoking the callback function.
  /// @details iotcon_query_foreach_cb() will be called for each query. \n
  /// If iotcon_query_foreach_cb() returns false, iteration will be stopped.
  /// @since_tizen 3.0
  /// @param[in] query The handle of the query
  /// @param[in] cb The callback function to get data
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_query_foreach_cb() will be called for each query.
  /// @see iotcon_query_foreach_cb()
  int iotcon_query_foreach(
    iotcon_query_h query,
    iotcon_query_foreach_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_query_foreach(
      query,
      cb,
      user_data,
    );
  }

  late final _iotcon_query_foreachPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_query_h, iotcon_query_foreach_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_query_foreach');
  late final _iotcon_query_foreach = _iotcon_query_foreachPtr.asFunction<
      int Function(
          iotcon_query_h, iotcon_query_foreach_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Creates a new attributes handle.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a attributes by calling iotcon_attributes_destroy() if @a attributes is no longer needed.
  /// @param[out] attributes A newly allocated attributes handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_attributes_destroy()
  int iotcon_attributes_create(
    ffi.Pointer<iotcon_attributes_h> attributes,
  ) {
    return _iotcon_attributes_create(
      attributes,
    );
  }

  late final _iotcon_attributes_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<iotcon_attributes_h>)>>('iotcon_attributes_create');
  late final _iotcon_attributes_create = _iotcon_attributes_createPtr
      .asFunction<int Function(ffi.Pointer<iotcon_attributes_h>)>();

  /// @brief Destroys the attributes.
  /// @details Releases @a attributes and its internal data.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle to free
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_attributes_create()
  int iotcon_attributes_destroy(
    iotcon_attributes_h attributes,
  ) {
    return _iotcon_attributes_destroy(
      attributes,
    );
  }

  late final _iotcon_attributes_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_attributes_h)>>(
          'iotcon_attributes_destroy');
  late final _iotcon_attributes_destroy = _iotcon_attributes_destroyPtr
      .asFunction<int Function(iotcon_attributes_h)>();

  /// @brief Clones the attributes handle.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a attributes_clone by calling iotcon_attributes_destroy() if @a attributes_clone is no longer needed.
  /// @param[in] attributes The attributes handle
  /// @param[out] attributes_clone The cloned attributes handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_attributes_create()
  /// @see iotcon_attributes_destroy()
  int iotcon_attributes_clone(
    iotcon_attributes_h attributes,
    ffi.Pointer<iotcon_attributes_h> attributes_clone,
  ) {
    return _iotcon_attributes_clone(
      attributes,
      attributes_clone,
    );
  }

  late final _iotcon_attributes_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h,
              ffi.Pointer<iotcon_attributes_h>)>>('iotcon_attributes_clone');
  late final _iotcon_attributes_clone = _iotcon_attributes_clonePtr.asFunction<
      int Function(iotcon_attributes_h, ffi.Pointer<iotcon_attributes_h>)>();

  /// @brief Adds a new key and integer value into the attributes.
  /// @details If @a key is already exists, current value will be replaced with new @a val.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[in] val The value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_attributes_add_int(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    int val,
  ) {
    return _iotcon_attributes_add_int(
      attributes,
      key,
      val,
    );
  }

  late final _iotcon_attributes_add_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Int)>>('iotcon_attributes_add_int');
  late final _iotcon_attributes_add_int =
      _iotcon_attributes_add_intPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Adds a new key and boolean value into the attributes.
  /// @details If @a key is already exists, current value will be replaced with new @a val.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[in] val The value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_attributes_add_bool(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    bool val,
  ) {
    return _iotcon_attributes_add_bool(
      attributes,
      key,
      val,
    );
  }

  late final _iotcon_attributes_add_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Bool)>>('iotcon_attributes_add_bool');
  late final _iotcon_attributes_add_bool =
      _iotcon_attributes_add_boolPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>, bool)>();

  /// @brief Adds a new key and double value into the attributes.
  /// @details If @a key is already exists, current value will be replaced with new @a val.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[in] val The value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_attributes_add_double(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    double val,
  ) {
    return _iotcon_attributes_add_double(
      attributes,
      key,
      val,
    );
  }

  late final _iotcon_attributes_add_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Double)>>('iotcon_attributes_add_double');
  late final _iotcon_attributes_add_double =
      _iotcon_attributes_add_doublePtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>, double)>();

  /// @brief Adds a new key and string value into the attributes.
  /// @details If @a key is already exists, current value will be replaced with new @a val.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[in] val The value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_attributes_add_str(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> val,
  ) {
    return _iotcon_attributes_add_str(
      attributes,
      key,
      val,
    );
  }

  late final _iotcon_attributes_add_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('iotcon_attributes_add_str');
  late final _iotcon_attributes_add_str =
      _iotcon_attributes_add_strPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief Adds a new key and byte string value into the attributes.
  /// @details If @a key is already exists, current value will be replaced with new @a val.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[in] val The value
  /// @param[in] len The length of @a val
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_attributes_add_byte_str(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.UnsignedChar> val,
    int len,
  ) {
    return _iotcon_attributes_add_byte_str(
      attributes,
      key,
      val,
      len,
    );
  }

  late final _iotcon_attributes_add_byte_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_attributes_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Int)>>('iotcon_attributes_add_byte_str');
  late final _iotcon_attributes_add_byte_str =
      _iotcon_attributes_add_byte_strPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.UnsignedChar>, int)>();

  /// @brief Adds a new key and list value into the attributes.
  /// @details If @a key already exists, current list will be replaced with new @a list.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[in] list The value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_attributes_add_list(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    iotcon_list_h list,
  ) {
    return _iotcon_attributes_add_list(
      attributes,
      key,
      list,
    );
  }

  late final _iotcon_attributes_add_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              iotcon_list_h)>>('iotcon_attributes_add_list');
  late final _iotcon_attributes_add_list =
      _iotcon_attributes_add_listPtr.asFunction<
          int Function(
              iotcon_attributes_h, ffi.Pointer<ffi.Char>, iotcon_list_h)>();

  /// @brief Adds a new key and attributes value into the attributes.
  /// @details If @a key already exists, current attributes will be replaced with new @a src.
  /// @since_tizen 3.0
  /// @param[in] dest The attributes handle
  /// @param[in] key The key
  /// @param[in] src The attributes handle to set newly
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_attributes_add_attributes(
    iotcon_attributes_h dest,
    ffi.Pointer<ffi.Char> key,
    iotcon_attributes_h src,
  ) {
    return _iotcon_attributes_add_attributes(
      dest,
      key,
      src,
    );
  }

  late final _iotcon_attributes_add_attributesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              iotcon_attributes_h)>>('iotcon_attributes_add_attributes');
  late final _iotcon_attributes_add_attributes =
      _iotcon_attributes_add_attributesPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              iotcon_attributes_h)>();

  /// @brief Adds a new key with NULL value into the attributes.
  /// @details If @a key already exists, current value will be replaced with NULL.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key to be set NULL
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_attributes_add_null(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
  ) {
    return _iotcon_attributes_add_null(
      attributes,
      key,
    );
  }

  late final _iotcon_attributes_add_nullPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_attributes_add_null');
  late final _iotcon_attributes_add_null = _iotcon_attributes_add_nullPtr
      .asFunction<int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the integer value from the given key.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[out] val The integer value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_attributes_get_int(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Int> val,
  ) {
    return _iotcon_attributes_get_int(
      attributes,
      key,
      val,
    );
  }

  late final _iotcon_attributes_get_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('iotcon_attributes_get_int');
  late final _iotcon_attributes_get_int =
      _iotcon_attributes_get_intPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the boolean value from the given key.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[out] val The boolean value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_attributes_get_bool(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Bool> val,
  ) {
    return _iotcon_attributes_get_bool(
      attributes,
      key,
      val,
    );
  }

  late final _iotcon_attributes_get_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('iotcon_attributes_get_bool');
  late final _iotcon_attributes_get_bool =
      _iotcon_attributes_get_boolPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the double value from the given key.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[out] val The double value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_attributes_get_double(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Double> val,
  ) {
    return _iotcon_attributes_get_double(
      attributes,
      key,
      val,
    );
  }

  late final _iotcon_attributes_get_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Double>)>>('iotcon_attributes_get_double');
  late final _iotcon_attributes_get_double =
      _iotcon_attributes_get_doublePtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Double>)>();

  /// @brief Gets the string value from the given key.
  /// @since_tizen 3.0
  /// @remarks @a val must not be released using free().
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[out] val The string value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_attributes_get_str(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> val,
  ) {
    return _iotcon_attributes_get_str(
      attributes,
      key,
      val,
    );
  }

  late final _iotcon_attributes_get_strPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_attributes_get_str');
  late final _iotcon_attributes_get_str =
      _iotcon_attributes_get_strPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the byte string value from the given key.
  /// @since_tizen 3.0
  /// @remarks @a val must not be released using free().
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[out] val The byte string value
  /// @param[out] len The length of @a val
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_attributes_get_byte_str(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> val,
    ffi.Pointer<ffi.Int> len,
  ) {
    return _iotcon_attributes_get_byte_str(
      attributes,
      key,
      val,
      len,
    );
  }

  late final _iotcon_attributes_get_byte_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_attributes_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>>('iotcon_attributes_get_byte_str');
  late final _iotcon_attributes_get_byte_str =
      _iotcon_attributes_get_byte_strPtr.asFunction<
          int Function(
              iotcon_attributes_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the list value from the given key.
  /// @since_tizen 3.0
  /// @remarks @a list must not be released using iotcon_list_destroy().
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[out] list The list value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_attributes_get_list(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<iotcon_list_h> list,
  ) {
    return _iotcon_attributes_get_list(
      attributes,
      key,
      list,
    );
  }

  late final _iotcon_attributes_get_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<iotcon_list_h>)>>('iotcon_attributes_get_list');
  late final _iotcon_attributes_get_list =
      _iotcon_attributes_get_listPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<iotcon_list_h>)>();

  /// @brief Gets the attributes value from the given key.
  /// @since_tizen 3.0
  /// @remarks @a attributes must not be released using iotcon_attributes_destroy().
  /// @param[in] src The attributes handle
  /// @param[in] key The key
  /// @param[out] dest The attributes value at the key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @retval #IOTCON_ERROR_INVALID_TYPE Invalid type
  int iotcon_attributes_get_attributes(
    iotcon_attributes_h src,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<iotcon_attributes_h> dest,
  ) {
    return _iotcon_attributes_get_attributes(
      src,
      key,
      dest,
    );
  }

  late final _iotcon_attributes_get_attributesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<iotcon_attributes_h>)>>(
      'iotcon_attributes_get_attributes');
  late final _iotcon_attributes_get_attributes =
      _iotcon_attributes_get_attributesPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<iotcon_attributes_h>)>();

  /// @brief Checks whether the value of given key is NULL or not.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[out] is_null true if the type of the given key is null,
  /// otherwise false
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_attributes_is_null(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Bool> is_null,
  ) {
    return _iotcon_attributes_is_null(
      attributes,
      key,
      is_null,
    );
  }

  late final _iotcon_attributes_is_nullPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('iotcon_attributes_is_null');
  late final _iotcon_attributes_is_null =
      _iotcon_attributes_is_nullPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>();

  /// @brief Removes the key and its associated value from the attributes.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  int iotcon_attributes_remove(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
  ) {
    return _iotcon_attributes_remove(
      attributes,
      key,
    );
  }

  late final _iotcon_attributes_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_attributes_remove');
  late final _iotcon_attributes_remove = _iotcon_attributes_removePtr
      .asFunction<int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the type of a value at the given key.
  /// @details It gets the data type of value related to the @a key in @a attributes.
  /// The data type could be one of #iotcon_type_e.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] key The key
  /// @param[out] type The data type of value related to the key in attributes handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  int iotcon_attributes_get_type(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _iotcon_attributes_get_type(
      attributes,
      key,
      type,
    );
  }

  late final _iotcon_attributes_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>>('iotcon_attributes_get_type');
  late final _iotcon_attributes_get_type =
      _iotcon_attributes_get_typePtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>();

  /// @brief Calls a function for each element of attributes.
  /// @details iotcon_attributes_cb() will be called for each child.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[in] cb The callback function to invoke
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_attributes_cb() will be called for each child.
  /// @see iotcon_attributes_cb()
  int iotcon_attributes_foreach(
    iotcon_attributes_h attributes,
    iotcon_attributes_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_attributes_foreach(
      attributes,
      cb,
      user_data,
    );
  }

  late final _iotcon_attributes_foreachPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_attributes_h, iotcon_attributes_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_attributes_foreach');
  late final _iotcon_attributes_foreach =
      _iotcon_attributes_foreachPtr.asFunction<
          int Function(iotcon_attributes_h, iotcon_attributes_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the number of keys in the attributes.
  /// @since_tizen 3.0
  /// @param[in] attributes The attributes handle
  /// @param[out] count The number of keys
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_attributes_get_keys_count(
    iotcon_attributes_h attributes,
    ffi.Pointer<ffi.UnsignedInt> count,
  ) {
    return _iotcon_attributes_get_keys_count(
      attributes,
      count,
    );
  }

  late final _iotcon_attributes_get_keys_countPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_attributes_h, ffi.Pointer<ffi.UnsignedInt>)>>(
      'iotcon_attributes_get_keys_count');
  late final _iotcon_attributes_get_keys_count =
      _iotcon_attributes_get_keys_countPtr.asFunction<
          int Function(iotcon_attributes_h, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Creates a new option handle.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a options by calling iotcon_options_destroy() if @a options is no longer needed.
  /// @param[out] options A newly allocated option handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_options_destroy()
  /// @see iotcon_options_add()
  /// @see iotcon_options_remove()
  /// @see iotcon_options_lookup()
  int iotcon_options_create(
    ffi.Pointer<iotcon_options_h> options,
  ) {
    return _iotcon_options_create(
      options,
    );
  }

  late final _iotcon_options_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<iotcon_options_h>)>>(
      'iotcon_options_create');
  late final _iotcon_options_create = _iotcon_options_createPtr
      .asFunction<int Function(ffi.Pointer<iotcon_options_h>)>();

  /// @brief Destroys an option handle.
  /// @since_tizen 3.0
  /// @param[in] options The handle of the options
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_options_create()
  /// @see iotcon_options_add()
  /// @see iotcon_options_remove()
  /// @see iotcon_options_lookup()
  int iotcon_options_destroy(
    iotcon_options_h options,
  ) {
    return _iotcon_options_destroy(
      options,
    );
  }

  late final _iotcon_options_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_options_h)>>(
          'iotcon_options_destroy');
  late final _iotcon_options_destroy =
      _iotcon_options_destroyPtr.asFunction<int Function(iotcon_options_h)>();

  /// @brief Adds a new ID and a corresponding data into the options.
  /// @since_tizen 3.0
  /// @remarks iotcon_options_h can have up to 2 options. \n
  /// Option ID is always situated between 2048 and 3000. \n
  /// Length of option data is less than or equal to 15.
  /// @param[in] options The handle of the options
  /// @param[in] id The ID of the option to insert
  /// @param[in] data The string data to insert into the options
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_options_create()
  /// @see iotcon_options_destroy()
  /// @see iotcon_options_remove()
  /// @see iotcon_options_lookup()
  int iotcon_options_add(
    iotcon_options_h options,
    int id,
    ffi.Pointer<ffi.Char> data,
  ) {
    return _iotcon_options_add(
      options,
      id,
      data,
    );
  }

  late final _iotcon_options_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_options_h, ffi.UnsignedShort,
              ffi.Pointer<ffi.Char>)>>('iotcon_options_add');
  late final _iotcon_options_add = _iotcon_options_addPtr
      .asFunction<int Function(iotcon_options_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Removes the ID and its associated data from the options.
  /// @since_tizen 3.0
  /// @param[in] options The handle of the options
  /// @param[in] id The ID of the option to delete
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_options_create()
  /// @see iotcon_options_destroy()
  /// @see iotcon_options_add()
  /// @see iotcon_options_lookup()
  int iotcon_options_remove(
    iotcon_options_h options,
    int id,
  ) {
    return _iotcon_options_remove(
      options,
      id,
    );
  }

  late final _iotcon_options_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_options_h, ffi.UnsignedShort)>>('iotcon_options_remove');
  late final _iotcon_options_remove = _iotcon_options_removePtr
      .asFunction<int Function(iotcon_options_h, int)>();

  /// @brief Looks up data at the given ID from the options.
  /// @since_tizen 3.0
  /// @remarks @a data must not be released using free().
  /// @param[in] options The handle of the options
  /// @param[in] id The ID of the option to lookup
  /// @param[out] data Found data from options
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_options_create()
  /// @see iotcon_options_destroy()
  /// @see iotcon_options_add()
  /// @see iotcon_options_remove()
  int iotcon_options_lookup(
    iotcon_options_h options,
    int id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> data,
  ) {
    return _iotcon_options_lookup(
      options,
      id,
      data,
    );
  }

  late final _iotcon_options_lookupPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_options_h, ffi.UnsignedShort,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('iotcon_options_lookup');
  late final _iotcon_options_lookup = _iotcon_options_lookupPtr.asFunction<
      int Function(
          iotcon_options_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets all data of the options by invoking the callback function.
  /// @details iotcon_options_foreach_cb() will be called for each option. \n
  /// If iotcon_options_foreach_cb() returns false, iteration will be stopped.
  /// @since_tizen 3.0
  /// @param[in] options The handle of the options
  /// @param[in] cb The callback function to get data
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_options_foreach_cb() will be called for each option.
  /// @see iotcon_options_foreach_cb()
  int iotcon_options_foreach(
    iotcon_options_h options,
    iotcon_options_foreach_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_options_foreach(
      options,
      cb,
      user_data,
    );
  }

  late final _iotcon_options_foreachPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_options_h, iotcon_options_foreach_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_options_foreach');
  late final _iotcon_options_foreach = _iotcon_options_foreachPtr.asFunction<
      int Function(iotcon_options_h, iotcon_options_foreach_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Creates a new Representation handle.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a repr by calling iotcon_representation_destroy() if @a repr is no longer needed.
  /// @param[out] repr A newly allocated Representation handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_representation_destroy()
  int iotcon_representation_create(
    ffi.Pointer<iotcon_representation_h> repr,
  ) {
    return _iotcon_representation_create(
      repr,
    );
  }

  late final _iotcon_representation_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<iotcon_representation_h>)>>(
      'iotcon_representation_create');
  late final _iotcon_representation_create = _iotcon_representation_createPtr
      .asFunction<int Function(ffi.Pointer<iotcon_representation_h>)>();

  /// @brief Destroys a Representation.
  /// @details Releases @a Representation and its internal data.
  /// @since_tizen 3.0
  /// @param[in] repr The representation handle to free
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_representation_create()
  int iotcon_representation_destroy(
    iotcon_representation_h repr,
  ) {
    return _iotcon_representation_destroy(
      repr,
    );
  }

  late final _iotcon_representation_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_representation_h)>>(
          'iotcon_representation_destroy');
  late final _iotcon_representation_destroy = _iotcon_representation_destroyPtr
      .asFunction<int Function(iotcon_representation_h)>();

  /// @brief Clones from the source Representation.
  /// @details Makes a deep copy of a source Representation.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a dest by calling iotcon_representation_destroy() if @a dest is no longer needed.
  /// @param[in] src Source of Representation to be copied
  /// @param[out] dest Clone of a source Representation
  /// @return Clone of a source Representation,
  /// otherwise NULL on failure
  /// @retval iotcon_representation_h Success
  /// @retval NULL Failure
  int iotcon_representation_clone(
    iotcon_representation_h src,
    ffi.Pointer<iotcon_representation_h> dest,
  ) {
    return _iotcon_representation_clone(
      src,
      dest,
    );
  }

  late final _iotcon_representation_clonePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_representation_h,
                  ffi.Pointer<iotcon_representation_h>)>>(
      'iotcon_representation_clone');
  late final _iotcon_representation_clone =
      _iotcon_representation_clonePtr.asFunction<
          int Function(
              iotcon_representation_h, ffi.Pointer<iotcon_representation_h>)>();

  /// @brief Appends resource type name.
  /// @since_tizen 3.0
  /// @remarks Stored string is replaced with @a uri_path. If @a uri_path is NULL, stored string is set to NULL.
  /// @param[in] repr The handle to the Representation
  /// @param[in] uri_path The URI of resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_representation_set_uri_path(
    iotcon_representation_h repr,
    ffi.Pointer<ffi.Char> uri_path,
  ) {
    return _iotcon_representation_set_uri_path(
      repr,
      uri_path,
    );
  }

  late final _iotcon_representation_set_uri_pathPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_representation_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_representation_set_uri_path');
  late final _iotcon_representation_set_uri_path =
      _iotcon_representation_set_uri_pathPtr.asFunction<
          int Function(iotcon_representation_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets a URI path from the Representation.
  /// @since_tizen 3.0
  /// @remarks @a uri_path must not be released using free().
  /// @param[in] repr The Representation handle
  /// @param[out] uri_path The URI path to get
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  int iotcon_representation_get_uri_path(
    iotcon_representation_h repr,
    ffi.Pointer<ffi.Pointer<ffi.Char>> uri_path,
  ) {
    return _iotcon_representation_get_uri_path(
      repr,
      uri_path,
    );
  }

  late final _iotcon_representation_get_uri_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_representation_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_representation_get_uri_path');
  late final _iotcon_representation_get_uri_path =
      _iotcon_representation_get_uri_pathPtr.asFunction<
          int Function(
              iotcon_representation_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets resource type list to the Representation.
  /// @since_tizen 3.0
  /// @remarks Stored list is replaced with @a types. If @a types is NULL, stored list is set to NULL.
  /// @param[in] repr The handle to the Representation
  /// @param[in] types The resource type list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_representation_set_resource_types(
    iotcon_representation_h repr,
    iotcon_resource_types_h types,
  ) {
    return _iotcon_representation_set_resource_types(
      repr,
      types,
    );
  }

  late final _iotcon_representation_set_resource_typesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_representation_h, iotcon_resource_types_h)>>(
      'iotcon_representation_set_resource_types');
  late final _iotcon_representation_set_resource_types =
      _iotcon_representation_set_resource_typesPtr.asFunction<
          int Function(iotcon_representation_h, iotcon_resource_types_h)>();

  /// @brief Gets list of resource type from the Representation.
  /// @since_tizen 3.0
  /// @remarks @a types must not be released using iotcon_resource_types_destroy().
  /// @param[in] repr The Representation handle
  /// @param[out] types The list of resource types to get
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_representation_get_resource_types(
    iotcon_representation_h repr,
    ffi.Pointer<iotcon_resource_types_h> types,
  ) {
    return _iotcon_representation_get_resource_types(
      repr,
      types,
    );
  }

  late final _iotcon_representation_get_resource_typesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_representation_h,
                  ffi.Pointer<iotcon_resource_types_h>)>>(
      'iotcon_representation_get_resource_types');
  late final _iotcon_representation_get_resource_types =
      _iotcon_representation_get_resource_typesPtr.asFunction<
          int Function(
              iotcon_representation_h, ffi.Pointer<iotcon_resource_types_h>)>();

  /// @brief Sets list of resource interfaces to the Representation.
  /// @since_tizen 3.0
  /// @remarks Stored list is replaced with @a ifaces. If @a ifaces is NULL, stored list is set to NULL.
  /// @param[in] repr The Representation handle
  /// @param[in] ifaces The list of resource interfaces
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_representation_set_resource_interfaces(
    iotcon_representation_h repr,
    iotcon_resource_interfaces_h ifaces,
  ) {
    return _iotcon_representation_set_resource_interfaces(
      repr,
      ifaces,
    );
  }

  late final _iotcon_representation_set_resource_interfacesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_representation_h, iotcon_resource_interfaces_h)>>(
      'iotcon_representation_set_resource_interfaces');
  late final _iotcon_representation_set_resource_interfaces =
      _iotcon_representation_set_resource_interfacesPtr.asFunction<
          int Function(
              iotcon_representation_h, iotcon_resource_interfaces_h)>();

  /// @brief Gets list of resource interfaces from the Representation.
  /// @since_tizen 3.0
  /// @remarks @a ifaces must not be released using iotcon_resource_interfaces_destroy().
  /// @param[in] repr The Representation handle
  /// @param[out] ifaces The list of resource interfaces to get
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_representation_get_resource_interfaces(
    iotcon_representation_h repr,
    ffi.Pointer<iotcon_resource_interfaces_h> ifaces,
  ) {
    return _iotcon_representation_get_resource_interfaces(
      repr,
      ifaces,
    );
  }

  late final _iotcon_representation_get_resource_interfacesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_representation_h,
                  ffi.Pointer<iotcon_resource_interfaces_h>)>>(
      'iotcon_representation_get_resource_interfaces');
  late final _iotcon_representation_get_resource_interfaces =
      _iotcon_representation_get_resource_interfacesPtr.asFunction<
          int Function(iotcon_representation_h,
              ffi.Pointer<iotcon_resource_interfaces_h>)>();

  /// @brief Sets a new attributes handle into the Representation.
  /// @since_tizen 3.0
  /// @param[in] repr The Representation handle
  /// @param[in] attributes The attributes handle to be set newly
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_representation_set_attributes(
    iotcon_representation_h repr,
    iotcon_attributes_h attributes,
  ) {
    return _iotcon_representation_set_attributes(
      repr,
      attributes,
    );
  }

  late final _iotcon_representation_set_attributesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_representation_h,
              iotcon_attributes_h)>>('iotcon_representation_set_attributes');
  late final _iotcon_representation_set_attributes =
      _iotcon_representation_set_attributesPtr.asFunction<
          int Function(iotcon_representation_h, iotcon_attributes_h)>();

  /// @brief Gets the attributes handle in the Representation.
  /// @since_tizen 3.0
  /// @remarks @a attributes must not be released using iotcon_attributes_destroy().
  /// @param[in] repr The Representation handle
  /// @param[in] attributes The attributes handle to get
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_representation_get_attributes(
    iotcon_representation_h repr,
    ffi.Pointer<iotcon_attributes_h> attributes,
  ) {
    return _iotcon_representation_get_attributes(
      repr,
      attributes,
    );
  }

  late final _iotcon_representation_get_attributesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_representation_h, ffi.Pointer<iotcon_attributes_h>)>>(
      'iotcon_representation_get_attributes');
  late final _iotcon_representation_get_attributes =
      _iotcon_representation_get_attributesPtr.asFunction<
          int Function(
              iotcon_representation_h, ffi.Pointer<iotcon_attributes_h>)>();

  /// @brief Adds a new child Representation on to the end of the parent Representation.
  /// @details Duplicated child Representation is allowed to append.
  /// @since_tizen 3.0
  /// @param[in] parent The parent Representation handle
  /// @param[in] child The child Representation handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_representation_add_child(
    iotcon_representation_h parent,
    iotcon_representation_h child,
  ) {
    return _iotcon_representation_add_child(
      parent,
      child,
    );
  }

  late final _iotcon_representation_add_childPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_representation_h,
              iotcon_representation_h)>>('iotcon_representation_add_child');
  late final _iotcon_representation_add_child =
      _iotcon_representation_add_childPtr.asFunction<
          int Function(iotcon_representation_h, iotcon_representation_h)>();

  /// @brief Removes a child Representation from parent Representation without freeing.
  /// @since_tizen 3.0
  /// @param[in] parent The parent Representation handle
  /// @param[in] child The child Representation handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_representation_remove_child(
    iotcon_representation_h parent,
    iotcon_representation_h child,
  ) {
    return _iotcon_representation_remove_child(
      parent,
      child,
    );
  }

  late final _iotcon_representation_remove_childPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_representation_h,
              iotcon_representation_h)>>('iotcon_representation_remove_child');
  late final _iotcon_representation_remove_child =
      _iotcon_representation_remove_childPtr.asFunction<
          int Function(iotcon_representation_h, iotcon_representation_h)>();

  /// @brief Calls a function for each child Representation of parent.
  /// @details iotcon_children_cb() will be called for each child.
  /// @since_tizen 3.0
  /// @param[in] parent The parent Representation handle
  /// @param[in] cb The callback function to invoke
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_children_cb() will be called for each child.
  /// @see iotcon_children_cb()
  int iotcon_representation_foreach_children(
    iotcon_representation_h parent,
    iotcon_children_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_representation_foreach_children(
      parent,
      cb,
      user_data,
    );
  }

  late final _iotcon_representation_foreach_childrenPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_representation_h, iotcon_children_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'iotcon_representation_foreach_children');
  late final _iotcon_representation_foreach_children =
      _iotcon_representation_foreach_childrenPtr.asFunction<
          int Function(iotcon_representation_h, iotcon_children_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the number of child Representations in the parent Representation.
  /// @since_tizen 3.0
  /// @param[in] parent The parent Representation handle
  /// @param[out] count The number of child Representations
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_representation_get_child_count(
    iotcon_representation_h parent,
    ffi.Pointer<ffi.UnsignedInt> count,
  ) {
    return _iotcon_representation_get_child_count(
      parent,
      count,
    );
  }

  late final _iotcon_representation_get_child_countPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_representation_h, ffi.Pointer<ffi.UnsignedInt>)>>(
      'iotcon_representation_get_child_count');
  late final _iotcon_representation_get_child_count =
      _iotcon_representation_get_child_countPtr.asFunction<
          int Function(
              iotcon_representation_h, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets the child Representation at the given position.
  /// @details Iterates over the parent until it reaches the @a pos-1 position.
  /// @since_tizen 3.0
  /// @remarks @a child must not be released using iotcon_representation_destroy().
  /// @param[in] parent The parent Representation handle
  /// @param[in] pos The position of the child Representation
  /// @param[out] child The handle to the child Representation
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA  No data available
  int iotcon_representation_get_nth_child(
    iotcon_representation_h parent,
    int pos,
    ffi.Pointer<iotcon_representation_h> child,
  ) {
    return _iotcon_representation_get_nth_child(
      parent,
      pos,
      child,
    );
  }

  late final _iotcon_representation_get_nth_childPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_representation_h, ffi.Int,
                  ffi.Pointer<iotcon_representation_h>)>>(
      'iotcon_representation_get_nth_child');
  late final _iotcon_representation_get_nth_child =
      _iotcon_representation_get_nth_childPtr.asFunction<
          int Function(iotcon_representation_h, int,
              ffi.Pointer<iotcon_representation_h>)>();

  /// @brief Creates a new resource types handle.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a types by calling iotcon_resource_types_destroy() if @a types is no longer needed.
  /// @param[out] types A newly allocated list of resource types handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_types_destroy()
  /// @see iotcon_resource_types_add()
  /// @see iotcon_resource_types_remove()
  /// @see iotcon_resource_types_clone()
  int iotcon_resource_types_create(
    ffi.Pointer<iotcon_resource_types_h> types,
  ) {
    return _iotcon_resource_types_create(
      types,
    );
  }

  late final _iotcon_resource_types_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<iotcon_resource_types_h>)>>(
      'iotcon_resource_types_create');
  late final _iotcon_resource_types_create = _iotcon_resource_types_createPtr
      .asFunction<int Function(ffi.Pointer<iotcon_resource_types_h>)>();

  /// @brief Destroys a resource types handle.
  /// @since_tizen 3.0
  /// @param[in] types The handle of the resource types
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_types_create()
  /// @see iotcon_resource_types_add()
  /// @see iotcon_resource_types_remove()
  /// @see iotcon_resource_types_clone()
  int iotcon_resource_types_destroy(
    iotcon_resource_types_h types,
  ) {
    return _iotcon_resource_types_destroy(
      types,
    );
  }

  late final _iotcon_resource_types_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_resource_types_h)>>(
          'iotcon_resource_types_destroy');
  late final _iotcon_resource_types_destroy = _iotcon_resource_types_destroyPtr
      .asFunction<int Function(iotcon_resource_types_h)>();

  /// @brief Inserts a resource types into the list.
  /// @since_tizen 3.0
  /// @remarks The length of @a type should be less than or equal to 61.\n
  /// The @a type must start with a lowercase alphabetic character, followed by a sequence
  /// of lowercase alphabetic, numeric, ".", or "-" characters, and contains no white space.\n
  /// Duplicate strings are not allowed.
  /// @param[in] types The handle of the resource types
  /// @param[in] type The string data to insert into the resource types (e.g. "org.tizen.light")
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_ALREADY Already done
  /// @see iotcon_resource_types_create()
  /// @see iotcon_resource_types_destroy()
  /// @see iotcon_resource_types_remove()
  /// @see iotcon_resource_types_clone()
  int iotcon_resource_types_add(
    iotcon_resource_types_h types,
    ffi.Pointer<ffi.Char> type,
  ) {
    return _iotcon_resource_types_add(
      types,
      type,
    );
  }

  late final _iotcon_resource_types_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_types_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_resource_types_add');
  late final _iotcon_resource_types_add =
      _iotcon_resource_types_addPtr.asFunction<
          int Function(iotcon_resource_types_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Deletes a resource types from the list.
  /// @since_tizen 3.0
  /// @param[in] types The handle of the resource types
  /// @param[in] type The string data to delete from the resource types
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @see iotcon_resource_types_create()
  /// @see iotcon_resource_types_destroy()
  /// @see iotcon_resource_types_add()
  /// @see iotcon_resource_types_clone()
  int iotcon_resource_types_remove(
    iotcon_resource_types_h types,
    ffi.Pointer<ffi.Char> type,
  ) {
    return _iotcon_resource_types_remove(
      types,
      type,
    );
  }

  late final _iotcon_resource_types_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_types_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_resource_types_remove');
  late final _iotcon_resource_types_remove =
      _iotcon_resource_types_removePtr.asFunction<
          int Function(iotcon_resource_types_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets all of the resource types of the list by invoking the callback function.
  /// @details iotcon_resource_types_foreach_cb() will be called for each type. \n
  /// If iotcon_resource_types_foreach_cb() returns false, iteration will be stopped.
  /// @since_tizen 3.0
  /// @param[in] types The handle of resource types
  /// @param[in] cb The callback function to get data
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_resource_types_foreach() will be called for each type.
  /// @see iotcon_resource_types_foreach_cb()
  int iotcon_resource_types_foreach(
    iotcon_resource_types_h types,
    iotcon_resource_types_foreach_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_resource_types_foreach(
      types,
      cb,
      user_data,
    );
  }

  late final _iotcon_resource_types_foreachPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_resource_types_h,
              iotcon_resource_types_foreach_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_resource_types_foreach');
  late final _iotcon_resource_types_foreach =
      _iotcon_resource_types_foreachPtr.asFunction<
          int Function(iotcon_resource_types_h,
              iotcon_resource_types_foreach_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Clones the resource types handle.
  /// @details Makes a deep copy of a source list of resource types.
  /// @since_tizen 3.0
  /// @remarks You must @a destroy dest by calling iotcon_resource_types_destroy() if @a dest is no longer needed.
  /// @param[in] src The origin handle of the resource types
  /// @param[out] dest Clone of a source list of resource types
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_types_create()
  /// @see iotcon_resource_types_destroy()
  /// @see iotcon_resource_types_add()
  /// @see iotcon_resource_types_remove()
  int iotcon_resource_types_clone(
    iotcon_resource_types_h src,
    ffi.Pointer<iotcon_resource_types_h> dest,
  ) {
    return _iotcon_resource_types_clone(
      src,
      dest,
    );
  }

  late final _iotcon_resource_types_clonePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_resource_types_h,
                  ffi.Pointer<iotcon_resource_types_h>)>>(
      'iotcon_resource_types_clone');
  late final _iotcon_resource_types_clone =
      _iotcon_resource_types_clonePtr.asFunction<
          int Function(
              iotcon_resource_types_h, ffi.Pointer<iotcon_resource_types_h>)>();

  /// @brief Creates a new resource interfaces handle.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a ifaces by calling iotcon_resource_interfaces_destroy() if @a ifaces is no longer needed.
  /// @param[out] ifaces A newly allocated list of resource ifaces handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_interfaces_destroy()
  /// @see iotcon_resource_interfaces_add()
  /// @see iotcon_resource_interfaces_remove()
  /// @see iotcon_resource_interfaces_clone()
  int iotcon_resource_interfaces_create(
    ffi.Pointer<iotcon_resource_interfaces_h> ifaces,
  ) {
    return _iotcon_resource_interfaces_create(
      ifaces,
    );
  }

  late final _iotcon_resource_interfaces_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<iotcon_resource_interfaces_h>)>>(
      'iotcon_resource_interfaces_create');
  late final _iotcon_resource_interfaces_create =
      _iotcon_resource_interfaces_createPtr.asFunction<
          int Function(ffi.Pointer<iotcon_resource_interfaces_h>)>();

  /// @brief Destroys a resource ifaces handle.
  /// @since_tizen 3.0
  /// @param[in] ifaces The handle of the resource ifaces
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_interfaces_create()
  /// @see iotcon_resource_interfaces_add()
  /// @see iotcon_resource_interfaces_remove()
  /// @see iotcon_resource_interfaces_clone()
  int iotcon_resource_interfaces_destroy(
    iotcon_resource_interfaces_h ifaces,
  ) {
    return _iotcon_resource_interfaces_destroy(
      ifaces,
    );
  }

  late final _iotcon_resource_interfaces_destroyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(iotcon_resource_interfaces_h)>>(
      'iotcon_resource_interfaces_destroy');
  late final _iotcon_resource_interfaces_destroy =
      _iotcon_resource_interfaces_destroyPtr
          .asFunction<int Function(iotcon_resource_interfaces_h)>();

  /// @brief Inserts a resource iface into the list.
  /// @since_tizen 3.0
  /// @remarks @a iface could be a value such as #IOTCON_INTERFACE_DEFAULT.
  /// @param[in] ifaces The handle of the resource ifaces
  /// @param[in] iface The string data to insert into the resource ifaces
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_ALREADY Already done
  /// @see iotcon_resource_interfaces_create()
  /// @see iotcon_resource_interfaces_destroy()
  /// @see iotcon_resource_interfaces_remove()
  /// @see iotcon_resource_interfaces_clone()
  int iotcon_resource_interfaces_add(
    iotcon_resource_interfaces_h ifaces,
    ffi.Pointer<ffi.Char> iface,
  ) {
    return _iotcon_resource_interfaces_add(
      ifaces,
      iface,
    );
  }

  late final _iotcon_resource_interfaces_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_interfaces_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_resource_interfaces_add');
  late final _iotcon_resource_interfaces_add =
      _iotcon_resource_interfaces_addPtr.asFunction<
          int Function(iotcon_resource_interfaces_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Deletes a resource iface from the list.
  /// @since_tizen 3.0
  /// @remarks @a iface could be a value such as #IOTCON_INTERFACE_DEFAULT.
  /// @param[in] ifaces The handle of the resource ifaces
  /// @param[in] iface The string data to delete from the resource ifaces
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @see iotcon_resource_interfaces_create()
  /// @see iotcon_resource_interfaces_destroy()
  /// @see iotcon_resource_interfaces_add()
  /// @see iotcon_resource_interfaces_clone()
  int iotcon_resource_interfaces_remove(
    iotcon_resource_interfaces_h ifaces,
    ffi.Pointer<ffi.Char> iface,
  ) {
    return _iotcon_resource_interfaces_remove(
      ifaces,
      iface,
    );
  }

  late final _iotcon_resource_interfaces_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_interfaces_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_resource_interfaces_remove');
  late final _iotcon_resource_interfaces_remove =
      _iotcon_resource_interfaces_removePtr.asFunction<
          int Function(iotcon_resource_interfaces_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets all of the resource ifaces of the list by invoking the callback function.
  /// @details iotcon_resource_interfaces_foreach_cb() will be called for each iface. \n
  /// If iotcon_resource_interfaces_foreach_cb() returns false, iteration will be stopped.
  /// @since_tizen 3.0
  /// @param[in] ifaces The handle of resource ifaces
  /// @param[in] cb The callback function to get data
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post iotcon_resource_interfaces_foreach() will be called for each iface.
  /// @see iotcon_resource_interfaces_foreach_cb()
  int iotcon_resource_interfaces_foreach(
    iotcon_resource_interfaces_h ifaces,
    iotcon_resource_interfaces_foreach_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_resource_interfaces_foreach(
      ifaces,
      cb,
      user_data,
    );
  }

  late final _iotcon_resource_interfaces_foreachPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_resource_interfaces_h,
              iotcon_resource_interfaces_foreach_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_resource_interfaces_foreach');
  late final _iotcon_resource_interfaces_foreach =
      _iotcon_resource_interfaces_foreachPtr.asFunction<
          int Function(iotcon_resource_interfaces_h,
              iotcon_resource_interfaces_foreach_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Clones the resource ifaces handle.
  /// @details Makes a deep copy of a source list of resource ifaces.
  /// @since_tizen 3.0
  /// @remarks You must @a destroy dest by calling iotcon_resource_interfaces_destroy() if @a dest is no longer needed.
  /// @param[in] src The origin handle of the resource ifaces
  /// @param[out] dest Clone of a source list of resource ifaces
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_interfaces_create()
  /// @see iotcon_resource_interfaces_destroy()
  /// @see iotcon_resource_interfaces_add()
  /// @see iotcon_resource_interfaces_remove()
  int iotcon_resource_interfaces_clone(
    iotcon_resource_interfaces_h src,
    ffi.Pointer<iotcon_resource_interfaces_h> dest,
  ) {
    return _iotcon_resource_interfaces_clone(
      src,
      dest,
    );
  }

  late final _iotcon_resource_interfaces_clonePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_resource_interfaces_h,
                  ffi.Pointer<iotcon_resource_interfaces_h>)>>(
      'iotcon_resource_interfaces_clone');
  late final _iotcon_resource_interfaces_clone =
      _iotcon_resource_interfaces_clonePtr.asFunction<
          int Function(iotcon_resource_interfaces_h,
              ffi.Pointer<iotcon_resource_interfaces_h>)>();

  /// @brief Creates a resource handle and registers the resource in server.
  /// @details Registers a resource specified by @a uri_path, @a res_types, @a ifaces which has @a properties in IoTCon server. \n
  /// When client finds the registered resource, iotcon_request_handler_cb() will be called automatically. \n
  /// @a uri_path format would be relative URI path like '/a/light' \n
  /// @a res_types is a list of resource types. Create a iotcon_resource_types_h handle and add types string to it. \n
  /// @a ifaces is a list of resource interfaces. Create a iotcon_resource_interfaces_h handle and add interfaces string to it. \n
  /// @a policies also can contain multiple policies like IOTCON_RESOURCE_DISCOVERABLE | IOTCON_RESOURCE_OBSERVABLE. \n
  /// iotcon_request_handler_cb() will be called when receive CRUD request to the registered resource.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks @a uri_path length must be less than 128. \n
  /// You must destroy @a resource by calling iotcon_resource_destroy() if @a resource is no longer needed.
  /// @param[in] uri_path The URI path of the resource
  /// @param[in] res_types The list of type of the resource
  /// @param[in] ifaces The list of interface of the resource
  /// @param[in] policies The policies of the resource \n
  /// Set of #iotcon_resource_policy_e
  /// @param[in] cb The request handler callback function
  /// @param[in] user_data The user data to pass to the callback function
  /// @param[out] resource_handle The handle of the resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_IOTIVITY IoTivity errors
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post When the resource receive CRUD request, iotcon_request_handler_cb() will be called.
  /// @see iotcon_resource_destroy()
  /// @see iotcon_resource_bind_interface()
  /// @see iotcon_resource_bind_type()
  /// @see iotcon_resource_set_request_handler()
  /// @see iotcon_resource_bind_child_resource()
  /// @see iotcon_resource_unbind_child_resource()
  /// @see iotcon_request_handler_cb()
  int iotcon_resource_create(
    ffi.Pointer<ffi.Char> uri_path,
    iotcon_resource_types_h res_types,
    iotcon_resource_interfaces_h ifaces,
    int policies,
    iotcon_request_handler_cb cb,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<iotcon_resource_h> resource_handle,
  ) {
    return _iotcon_resource_create(
      uri_path,
      res_types,
      ifaces,
      policies,
      cb,
      user_data,
      resource_handle,
    );
  }

  late final _iotcon_resource_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              iotcon_resource_types_h,
              iotcon_resource_interfaces_h,
              ffi.Uint8,
              iotcon_request_handler_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<iotcon_resource_h>)>>('iotcon_resource_create');
  late final _iotcon_resource_create = _iotcon_resource_createPtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>,
          iotcon_resource_types_h,
          iotcon_resource_interfaces_h,
          int,
          iotcon_request_handler_cb,
          ffi.Pointer<ffi.Void>,
          ffi.Pointer<iotcon_resource_h>)>();

  /// @brief Destroys the resource and releases its data.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks When a normal variable is used, there is only permission denied error.
  /// If the errors of this API are not handled, then you must check an application has the privileges for the API.
  /// @param[in] resource_handle The handle of the resource to be unregistered
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_resource_create()
  /// @see iotcon_resource_bind_interface()
  /// @see iotcon_resource_bind_type()
  /// @see iotcon_resource_set_request_handler()
  /// @see iotcon_resource_bind_child_resource()
  /// @see iotcon_resource_unbind_child_resource()
  /// @see iotcon_request_handler_cb()
  int iotcon_resource_destroy(
    iotcon_resource_h resource_handle,
  ) {
    return _iotcon_resource_destroy(
      resource_handle,
    );
  }

  late final _iotcon_resource_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_resource_h)>>(
          'iotcon_resource_destroy');
  late final _iotcon_resource_destroy =
      _iotcon_resource_destroyPtr.asFunction<int Function(iotcon_resource_h)>();

  /// @brief Binds an interface to the resource.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks @a iface could be a value such as #IOTCON_INTERFACE_DEFAULT.
  /// @param[in] resource The handle of the resource
  /// @param[in] iface The interface to be bound to the resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #IOTCON_ERROR_ALREADY Already done
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_resource_create()
  /// @see iotcon_resource_destroy()
  /// @see iotcon_resource_bind_type()
  /// @see iotcon_resource_set_request_handler()
  /// @see iotcon_resource_bind_child_resource()
  /// @see iotcon_resource_unbind_child_resource()
  /// @see iotcon_request_handler_cb()
  int iotcon_resource_bind_interface(
    iotcon_resource_h resource,
    ffi.Pointer<ffi.Char> iface,
  ) {
    return _iotcon_resource_bind_interface(
      resource,
      iface,
    );
  }

  late final _iotcon_resource_bind_interfacePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_resource_bind_interface');
  late final _iotcon_resource_bind_interface =
      _iotcon_resource_bind_interfacePtr
          .asFunction<int Function(iotcon_resource_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Binds a type to the resource.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks The length of @a resource_type should be less than or equal to 61.\n
  /// The @a resource_type must start with a lowercase alphabetic character, followed by a sequence
  /// of lowercase alphabetic, numeric, ".", or "-" characters, and contains no white space.
  /// @param[in] resource_handle The handle of the resource
  /// @param[in] resource_type The type to be bound to the resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #IOTCON_ERROR_ALREADY Already done
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_resource_create()
  /// @see iotcon_resource_destroy()
  /// @see iotcon_resource_bind_interface()
  /// @see iotcon_resource_set_request_handler()
  /// @see iotcon_resource_bind_child_resource()
  /// @see iotcon_resource_unbind_child_resource()
  /// @see iotcon_request_handler_cb()
  int iotcon_resource_bind_type(
    iotcon_resource_h resource_handle,
    ffi.Pointer<ffi.Char> resource_type,
  ) {
    return _iotcon_resource_bind_type(
      resource_handle,
      resource_type,
    );
  }

  late final _iotcon_resource_bind_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_h,
              ffi.Pointer<ffi.Char>)>>('iotcon_resource_bind_type');
  late final _iotcon_resource_bind_type = _iotcon_resource_bind_typePtr
      .asFunction<int Function(iotcon_resource_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets a request handler to the resource.
  /// @details When the resource receive CRUD request, iotcon_request_handler_cb() will be called.
  /// @since_tizen 3.0
  /// @remarks Registered callback function will be replaced with the new @a cb.
  /// @param[in] resource The handle of the resource
  /// @param[in] cb The request handler to be bound to the resource
  /// @param[in] user_data The user data to pass to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_create()
  /// @see iotcon_resource_destroy()
  /// @see iotcon_resource_bind_interface()
  /// @see iotcon_resource_bind_type()
  /// @see iotcon_resource_bind_child_resource()
  /// @see iotcon_resource_unbind_child_resource()
  /// @see iotcon_request_handler_cb()
  int iotcon_resource_set_request_handler(
    iotcon_resource_h resource,
    iotcon_request_handler_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_resource_set_request_handler(
      resource,
      cb,
      user_data,
    );
  }

  late final _iotcon_resource_set_request_handlerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_h, iotcon_request_handler_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_resource_set_request_handler');
  late final _iotcon_resource_set_request_handler =
      _iotcon_resource_set_request_handlerPtr.asFunction<
          int Function(iotcon_resource_h, iotcon_request_handler_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Binds a child resource into the parent resource.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] parent The handle of the parent resource
  /// @param[in] child The handle of the child resource to be added to the parent resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_ALREADY Already done
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_resource_create()
  /// @see iotcon_resource_destroy()
  /// @see iotcon_resource_bind_interface()
  /// @see iotcon_resource_bind_type()
  /// @see iotcon_resource_set_request_handler()
  /// @see iotcon_resource_unbind_child_resource()
  /// @see iotcon_request_handler_cb()
  int iotcon_resource_bind_child_resource(
    iotcon_resource_h parent,
    iotcon_resource_h child,
  ) {
    return _iotcon_resource_bind_child_resource(
      parent,
      child,
    );
  }

  late final _iotcon_resource_bind_child_resourcePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_h,
              iotcon_resource_h)>>('iotcon_resource_bind_child_resource');
  late final _iotcon_resource_bind_child_resource =
      _iotcon_resource_bind_child_resourcePtr
          .asFunction<int Function(iotcon_resource_h, iotcon_resource_h)>();

  /// @brief Unbinds a child resource from the parent resource.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] parent The handle of the parent resource
  /// @param[in] child The handle of the child resource to be unbound from the parent resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_resource_create()
  /// @see iotcon_resource_destroy()
  /// @see iotcon_resource_bind_interface()
  /// @see iotcon_resource_bind_type()
  /// @see iotcon_resource_set_request_handler()
  /// @see iotcon_resource_bind_child_resource()
  /// @see iotcon_request_handler_cb()
  int iotcon_resource_unbind_child_resource(
    iotcon_resource_h parent,
    iotcon_resource_h child,
  ) {
    return _iotcon_resource_unbind_child_resource(
      parent,
      child,
    );
  }

  late final _iotcon_resource_unbind_child_resourcePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_h,
              iotcon_resource_h)>>('iotcon_resource_unbind_child_resource');
  late final _iotcon_resource_unbind_child_resource =
      _iotcon_resource_unbind_child_resourcePtr
          .asFunction<int Function(iotcon_resource_h, iotcon_resource_h)>();

  /// @brief Notifies specific clients that resource's attributes have changed.
  /// @details If @a observers is @c NULL, the @a msg will notify to all observers.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the resource
  /// @param[in] repr The handle of the representation
  /// @param[in] observers The handle of the observers
  /// @param[in] qos The quality of service for message transfer
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_REPRESENTATION Representation error
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_remote_resource_observe_cb()
  /// @see iotcon_remote_resource_observe_register()
  /// @see iotcon_remote_resource_observe_deregister()
  /// @see iotcon_observers_create()
  /// @see iotcon_observers_destroy()
  /// @see iotcon_observers_add()
  /// @see iotcon_observers_remove()
  int iotcon_resource_notify(
    iotcon_resource_h resource,
    iotcon_representation_h repr,
    iotcon_observers_h observers,
    int qos,
  ) {
    return _iotcon_resource_notify(
      resource,
      repr,
      observers,
      qos,
    );
  }

  late final _iotcon_resource_notifyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_h, iotcon_representation_h,
              iotcon_observers_h, ffi.Int32)>>('iotcon_resource_notify');
  late final _iotcon_resource_notify = _iotcon_resource_notifyPtr.asFunction<
      int Function(iotcon_resource_h, iotcon_representation_h,
          iotcon_observers_h, int)>();

  /// @brief Gets the number of child resources of the resource.
  /// @since_tizen 3.0
  /// @param[in] resource The handle of the resource
  /// @param[out] count The number of child resources
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_get_nth_child()
  /// @see iotcon_resource_get_uri_path()
  /// @see iotcon_resource_get_types()
  /// @see iotcon_resource_get_interfaces()
  /// @see iotcon_resource_get_policies()
  int iotcon_resource_get_child_count(
    iotcon_resource_h resource,
    ffi.Pointer<ffi.UnsignedInt> count,
  ) {
    return _iotcon_resource_get_child_count(
      resource,
      count,
    );
  }

  late final _iotcon_resource_get_child_countPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_resource_h, ffi.Pointer<ffi.UnsignedInt>)>>(
      'iotcon_resource_get_child_count');
  late final _iotcon_resource_get_child_count =
      _iotcon_resource_get_child_countPtr.asFunction<
          int Function(iotcon_resource_h, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets the child resource at the given index in the parent resource.
  /// @since_tizen 3.0
  /// @remarks @a child must not be released using iotcon_resource_destroy().
  /// @param[in] parent The handle of the parent resource
  /// @param[in] index The index of the child resource
  /// @param[out] child The child resource at the index
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @see iotcon_resource_get_child_count()
  /// @see iotcon_resource_get_uri_path()
  /// @see iotcon_resource_get_types()
  /// @see iotcon_resource_get_interfaces()
  /// @see iotcon_resource_get_policies()
  int iotcon_resource_get_nth_child(
    iotcon_resource_h parent,
    int index,
    ffi.Pointer<iotcon_resource_h> child,
  ) {
    return _iotcon_resource_get_nth_child(
      parent,
      index,
      child,
    );
  }

  late final _iotcon_resource_get_nth_childPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_resource_h, ffi.Int, ffi.Pointer<iotcon_resource_h>)>>(
      'iotcon_resource_get_nth_child');
  late final _iotcon_resource_get_nth_child =
      _iotcon_resource_get_nth_childPtr.asFunction<
          int Function(
              iotcon_resource_h, int, ffi.Pointer<iotcon_resource_h>)>();

  /// @brief Gets an URI path of the resource.
  /// @since_tizen 3.0
  /// @remarks @a uri_path must not be released using free().
  /// @param[in] resource The handle of the resource
  /// @param[out] uri_path The URI path of the resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_get_child_count()
  /// @see iotcon_resource_get_nth_child()
  /// @see iotcon_resource_get_types()
  /// @see iotcon_resource_get_interfaces()
  /// @see iotcon_resource_get_policies()
  int iotcon_resource_get_uri_path(
    iotcon_resource_h resource,
    ffi.Pointer<ffi.Pointer<ffi.Char>> uri_path,
  ) {
    return _iotcon_resource_get_uri_path(
      resource,
      uri_path,
    );
  }

  late final _iotcon_resource_get_uri_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_resource_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_resource_get_uri_path');
  late final _iotcon_resource_get_uri_path =
      _iotcon_resource_get_uri_pathPtr.asFunction<
          int Function(
              iotcon_resource_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the list of types in the resource.
  /// @since_tizen 3.0
  /// @remarks @a types must not be released using iotcon_resource_types_destroy().
  /// @param[in] resource The handle of the resource
  /// @param[out] types The types of the resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_get_child_count()
  /// @see iotcon_resource_get_nth_child()
  /// @see iotcon_resource_get_uri_path()
  /// @see iotcon_resource_get_interfaces()
  /// @see iotcon_resource_get_policies()
  int iotcon_resource_get_types(
    iotcon_resource_h resource,
    ffi.Pointer<iotcon_resource_types_h> types,
  ) {
    return _iotcon_resource_get_types(
      resource,
      types,
    );
  }

  late final _iotcon_resource_get_typesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_resource_h, ffi.Pointer<iotcon_resource_types_h>)>>(
      'iotcon_resource_get_types');
  late final _iotcon_resource_get_types =
      _iotcon_resource_get_typesPtr.asFunction<
          int Function(
              iotcon_resource_h, ffi.Pointer<iotcon_resource_types_h>)>();

  /// @brief Gets the interfaces of the resource.
  /// @since_tizen 3.0
  /// @remarks @a ifaces must not be released using iotcon_resource_interfaces_destroy().
  /// @param[in] resource The handle of the resource
  /// @param[out] ifaces The interfaces of the resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_get_child_count()
  /// @see iotcon_resource_get_nth_child()
  /// @see iotcon_resource_get_uri_path()
  /// @see iotcon_resource_get_types()
  /// @see iotcon_resource_get_policies()
  int iotcon_resource_get_interfaces(
    iotcon_resource_h resource,
    ffi.Pointer<iotcon_resource_interfaces_h> ifaces,
  ) {
    return _iotcon_resource_get_interfaces(
      resource,
      ifaces,
    );
  }

  late final _iotcon_resource_get_interfacesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_resource_h,
                  ffi.Pointer<iotcon_resource_interfaces_h>)>>(
      'iotcon_resource_get_interfaces');
  late final _iotcon_resource_get_interfaces =
      _iotcon_resource_get_interfacesPtr.asFunction<
          int Function(
              iotcon_resource_h, ffi.Pointer<iotcon_resource_interfaces_h>)>();

  /// @brief Gets the policies in the resource.
  /// @details @a policies can contain multiple policies like IOTCON_RESOURCE_DISCOVERABLE | IOTCON_RESOURCE_OBSERVABLE.
  /// @since_tizen 3.0
  /// @param[in] resource The handle of the resource
  /// @param[out] policies The policies of resource \n
  /// Set of #iotcon_resource_policy_e
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_resource_get_child_count()
  /// @see iotcon_resource_get_nth_child()
  /// @see iotcon_resource_get_uri_path()
  /// @see iotcon_resource_get_types()
  /// @see iotcon_resource_get_interfaces()
  int iotcon_resource_get_policies(
    iotcon_resource_h resource,
    ffi.Pointer<ffi.Uint8> policies,
  ) {
    return _iotcon_resource_get_policies(
      resource,
      policies,
    );
  }

  late final _iotcon_resource_get_policiesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_resource_h,
              ffi.Pointer<ffi.Uint8>)>>('iotcon_resource_get_policies');
  late final _iotcon_resource_get_policies = _iotcon_resource_get_policiesPtr
      .asFunction<int Function(iotcon_resource_h, ffi.Pointer<ffi.Uint8>)>();

  /// @brief Creates a lite resource handle and registers the resource in server.
  /// @details Registers a resource specified by @a uri_path, @a res_types, @a attributes which have @a properties in IoTCon server. \n
  /// When client requests some operations, it send a response to client, automatically.\n
  /// The @a policies can contain multiple policies like IOTCON_RESOURCE_DISCOVERABLE | IOTCON_RESOURCE_OBSERVABLE.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks @a uri_path length must be less than 128. \n
  /// You must destroy @a resource_handle by calling iotcon_lite_resource_destroy() if @a remote_handle is no longer needed.
  /// @param[in] uri_path The URI path of the resource
  /// @param[in] res_types The list of type of the resource
  /// @param[in] policies The policies of the resource \n
  /// Set of #iotcon_resource_policy_e
  /// @param[in] attributes The attributes handle to set
  /// @param[in] cb The callback function to add into callback list
  /// @param[in] user_data The user data to pass to the callback function
  /// @param[out] resource_handle The handle of the resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_IOTIVITY IoTivity errors
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_lite_resource_destroy()
  int iotcon_lite_resource_create(
    ffi.Pointer<ffi.Char> uri_path,
    iotcon_resource_types_h res_types,
    int policies,
    iotcon_attributes_h attributes,
    iotcon_lite_resource_post_request_cb cb,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<iotcon_lite_resource_h> resource_handle,
  ) {
    return _iotcon_lite_resource_create(
      uri_path,
      res_types,
      policies,
      attributes,
      cb,
      user_data,
      resource_handle,
    );
  }

  late final _iotcon_lite_resource_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>,
                  iotcon_resource_types_h,
                  ffi.Uint8,
                  iotcon_attributes_h,
                  iotcon_lite_resource_post_request_cb,
                  ffi.Pointer<ffi.Void>,
                  ffi.Pointer<iotcon_lite_resource_h>)>>(
      'iotcon_lite_resource_create');
  late final _iotcon_lite_resource_create =
      _iotcon_lite_resource_createPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              iotcon_resource_types_h,
              int,
              iotcon_attributes_h,
              iotcon_lite_resource_post_request_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<iotcon_lite_resource_h>)>();

  /// @brief Destroys the resource and releases its data.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks When a normal variable is used, there is only permission denied error.
  /// If the errors of this API are not handled, then you must check an application having the privileges for the API.
  /// @param[in] resource The handle of the lite resource to be unregistered
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_lite_resource_create()
  int iotcon_lite_resource_destroy(
    iotcon_lite_resource_h resource,
  ) {
    return _iotcon_lite_resource_destroy(
      resource,
    );
  }

  late final _iotcon_lite_resource_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_lite_resource_h)>>(
          'iotcon_lite_resource_destroy');
  late final _iotcon_lite_resource_destroy = _iotcon_lite_resource_destroyPtr
      .asFunction<int Function(iotcon_lite_resource_h)>();

  /// @brief Updates attributes into the lite resource handle.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the lite resource
  /// @param[in] attributes The attributes handle to update
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_lite_resource_get_attributes()
  int iotcon_lite_resource_update_attributes(
    iotcon_lite_resource_h resource,
    iotcon_attributes_h attributes,
  ) {
    return _iotcon_lite_resource_update_attributes(
      resource,
      attributes,
    );
  }

  late final _iotcon_lite_resource_update_attributesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_lite_resource_h,
              iotcon_attributes_h)>>('iotcon_lite_resource_update_attributes');
  late final _iotcon_lite_resource_update_attributes =
      _iotcon_lite_resource_update_attributesPtr.asFunction<
          int Function(iotcon_lite_resource_h, iotcon_attributes_h)>();

  /// @brief Gets attributes from the lite resource handle.
  /// @since_tizen 3.0
  /// @remarks @a attributes must not be released using iotcon_attributes_destroy().
  /// @param[in] resource The handle of the lite resource
  /// @param[out] attributes The attributes handle of the lite resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_lite_resource_update_attributes()
  int iotcon_lite_resource_get_attributes(
    iotcon_lite_resource_h resource,
    ffi.Pointer<iotcon_attributes_h> attributes,
  ) {
    return _iotcon_lite_resource_get_attributes(
      resource,
      attributes,
    );
  }

  late final _iotcon_lite_resource_get_attributesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_lite_resource_h, ffi.Pointer<iotcon_attributes_h>)>>(
      'iotcon_lite_resource_get_attributes');
  late final _iotcon_lite_resource_get_attributes =
      _iotcon_lite_resource_get_attributesPtr.asFunction<
          int Function(
              iotcon_lite_resource_h, ffi.Pointer<iotcon_attributes_h>)>();

  /// @brief Creates a response handle.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a response by calling iotcon_response_destroy() if @a response is no longer needed.
  /// @param[in] request The handle of received request handle
  /// @param[out] response Generated response handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @see iotcon_response_destroy()
  int iotcon_response_create(
    iotcon_request_h request,
    ffi.Pointer<iotcon_response_h> response,
  ) {
    return _iotcon_response_create(
      request,
      response,
    );
  }

  late final _iotcon_response_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_request_h,
              ffi.Pointer<iotcon_response_h>)>>('iotcon_response_create');
  late final _iotcon_response_create = _iotcon_response_createPtr.asFunction<
      int Function(iotcon_request_h, ffi.Pointer<iotcon_response_h>)>();

  /// @brief Destroys a response handle.
  /// @since_tizen 3.0
  /// @param[in] resp The handle of the response
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_response_create()
  int iotcon_response_destroy(
    iotcon_response_h resp,
  ) {
    return _iotcon_response_destroy(
      resp,
    );
  }

  late final _iotcon_response_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_response_h)>>(
          'iotcon_response_destroy');
  late final _iotcon_response_destroy =
      _iotcon_response_destroyPtr.asFunction<int Function(iotcon_response_h)>();

  /// @brief Gets header options of the response.
  /// @since_tizen 3.0
  /// @remarks @a options must not be released using iotcon_options_destroy().
  /// @param[in] resp The handle of the response
  /// @param[out] options The handle of the header options
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_response_get_representation()
  /// @see iotcon_response_get_result()
  int iotcon_response_get_options(
    iotcon_response_h resp,
    ffi.Pointer<iotcon_options_h> options,
  ) {
    return _iotcon_response_get_options(
      resp,
      options,
    );
  }

  late final _iotcon_response_get_optionsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_response_h,
              ffi.Pointer<iotcon_options_h>)>>('iotcon_response_get_options');
  late final _iotcon_response_get_options =
      _iotcon_response_get_optionsPtr.asFunction<
          int Function(iotcon_response_h, ffi.Pointer<iotcon_options_h>)>();

  /// @brief Gets representation of the response.
  /// @since_tizen 3.0
  /// @remarks @a repr must not be released using iotcon_representation_destroy().
  /// @param[in] resp The handle of the response
  /// @param[out] repr The handle of the representation
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data
  /// @see iotcon_response_get_options()
  /// @see iotcon_response_get_result()
  int iotcon_response_get_representation(
    iotcon_response_h resp,
    ffi.Pointer<iotcon_representation_h> repr,
  ) {
    return _iotcon_response_get_representation(
      resp,
      repr,
    );
  }

  late final _iotcon_response_get_representationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_response_h, ffi.Pointer<iotcon_representation_h>)>>(
      'iotcon_response_get_representation');
  late final _iotcon_response_get_representation =
      _iotcon_response_get_representationPtr.asFunction<
          int Function(
              iotcon_response_h, ffi.Pointer<iotcon_representation_h>)>();

  /// @brief Gets result of the response.
  /// @since_tizen 3.0
  /// @param[in] resp The handle of the response
  /// @param[out] result The result of the response
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_response_get_options()
  /// @see iotcon_response_get_representation()
  int iotcon_response_get_result(
    iotcon_response_h resp,
    ffi.Pointer<ffi.Int32> result,
  ) {
    return _iotcon_response_get_result(
      resp,
      result,
    );
  }

  late final _iotcon_response_get_resultPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_response_h,
              ffi.Pointer<ffi.Int32>)>>('iotcon_response_get_result');
  late final _iotcon_response_get_result = _iotcon_response_get_resultPtr
      .asFunction<int Function(iotcon_response_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets result into the response.
  /// @details The @a result could be one of #iotcon_response_result_e.
  /// @since_tizen 3.0
  /// @param[in] resp The handle of the response
  /// @param[in] result The result to set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @see iotcon_response_create()
  /// @see iotcon_response_destroy()
  int iotcon_response_set_result(
    iotcon_response_h resp,
    int result,
  ) {
    return _iotcon_response_set_result(
      resp,
      result,
    );
  }

  late final _iotcon_response_set_resultPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(iotcon_response_h, ffi.Int32)>>(
      'iotcon_response_set_result');
  late final _iotcon_response_set_result = _iotcon_response_set_resultPtr
      .asFunction<int Function(iotcon_response_h, int)>();

  /// @brief Sets representation into the response.
  /// @since_tizen 3.0
  /// @param[in] resp The handle of the response
  /// @param[in] repr The representation of the response
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @see iotcon_response_create()
  /// @see iotcon_response_destroy()
  int iotcon_response_set_representation(
    iotcon_response_h resp,
    iotcon_representation_h repr,
  ) {
    return _iotcon_response_set_representation(
      resp,
      repr,
    );
  }

  late final _iotcon_response_set_representationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_response_h,
              iotcon_representation_h)>>('iotcon_response_set_representation');
  late final _iotcon_response_set_representation =
      _iotcon_response_set_representationPtr.asFunction<
          int Function(iotcon_response_h, iotcon_representation_h)>();

  /// @brief Sets header options into the response.
  /// @since_tizen 3.0
  /// @param[in] resp The handle of the response
  /// @param[in] options The header options of the response
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @see iotcon_response_create()
  /// @see iotcon_response_destroy()
  int iotcon_response_set_options(
    iotcon_response_h resp,
    iotcon_options_h options,
  ) {
    return _iotcon_response_set_options(
      resp,
      options,
    );
  }

  late final _iotcon_response_set_optionsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_response_h,
              iotcon_options_h)>>('iotcon_response_set_options');
  late final _iotcon_response_set_options = _iotcon_response_set_optionsPtr
      .asFunction<int Function(iotcon_response_h, iotcon_options_h)>();

  /// @brief Sends response for incoming request.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resp The handle of the response to send
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  int iotcon_response_send(
    iotcon_response_h resp,
  ) {
    return _iotcon_response_send(
      resp,
    );
  }

  late final _iotcon_response_sendPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_response_h)>>(
          'iotcon_response_send');
  late final _iotcon_response_send =
      _iotcon_response_sendPtr.asFunction<int Function(iotcon_response_h)>();

  /// @brief Creates a new observers handle.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a observers by calling iotcon_observers_destroy() if @a observers is no longer needed.
  /// @param[out] observers A newly allocated list of observers handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @see iotcon_observers_destroy()
  /// @see iotcon_observers_add()
  /// @see iotcon_observers_remove()
  int iotcon_observers_create(
    ffi.Pointer<iotcon_observers_h> observers,
  ) {
    return _iotcon_observers_create(
      observers,
    );
  }

  late final _iotcon_observers_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<iotcon_observers_h>)>>('iotcon_observers_create');
  late final _iotcon_observers_create = _iotcon_observers_createPtr
      .asFunction<int Function(ffi.Pointer<iotcon_observers_h>)>();

  /// @brief Destroys a observers handle.
  /// @since_tizen 3.0
  /// @param[in] observers The handle of the observers
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_observers_create()
  /// @see iotcon_observers_add()
  /// @see iotcon_observers_remove()
  int iotcon_observers_destroy(
    iotcon_observers_h observers,
  ) {
    return _iotcon_observers_destroy(
      observers,
    );
  }

  late final _iotcon_observers_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_observers_h)>>(
          'iotcon_observers_destroy');
  late final _iotcon_observers_destroy = _iotcon_observers_destroyPtr
      .asFunction<int Function(iotcon_observers_h)>();

  /// @brief Adds an observers ID into the observers handle.
  /// @since_tizen 3.0
  /// @param[in] observers The handle of the observers
  /// @param[in] obs_id The ID to be appended to observers
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_observers_create()
  /// @see iotcon_observers_destroy()
  /// @see iotcon_observers_remove()
  int iotcon_observers_add(
    iotcon_observers_h observers,
    int obs_id,
  ) {
    return _iotcon_observers_add(
      observers,
      obs_id,
    );
  }

  late final _iotcon_observers_addPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(iotcon_observers_h, ffi.Int)>>(
      'iotcon_observers_add');
  late final _iotcon_observers_add = _iotcon_observers_addPtr
      .asFunction<int Function(iotcon_observers_h, int)>();

  /// @brief Removes ID from the observers.
  /// @since_tizen 3.0
  /// @param[in] observers observers The handle of the observers
  /// @param[in] obs_id The ID to be removed from observers
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_observers_create()
  /// @see iotcon_observers_destroy()
  /// @see iotcon_observers_add()
  int iotcon_observers_remove(
    iotcon_observers_h observers,
    int obs_id,
  ) {
    return _iotcon_observers_remove(
      observers,
      obs_id,
    );
  }

  late final _iotcon_observers_removePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(iotcon_observers_h, ffi.Int)>>(
      'iotcon_observers_remove');
  late final _iotcon_observers_remove = _iotcon_observers_removePtr
      .asFunction<int Function(iotcon_observers_h, int)>();

  /// @brief Gets host address of the request.
  /// @since_tizen 3.0
  /// @remarks @a host_address must not be released using free().
  /// @param[in] request The handle of the request
  /// @param[out] host_address The host address of the request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_request_get_connectivity_type()
  /// @see iotcon_request_get_representation()
  /// @see iotcon_request_get_request_type()
  /// @see iotcon_request_get_options()
  /// @see iotcon_request_get_query()
  /// @see iotcon_request_get_observe_type()
  /// @see iotcon_request_get_observe_id()
  int iotcon_request_get_host_address(
    iotcon_request_h request,
    ffi.Pointer<ffi.Pointer<ffi.Char>> host_address,
  ) {
    return _iotcon_request_get_host_address(
      request,
      host_address,
    );
  }

  late final _iotcon_request_get_host_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_request_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_request_get_host_address');
  late final _iotcon_request_get_host_address =
      _iotcon_request_get_host_addressPtr.asFunction<
          int Function(iotcon_request_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets connectivity type of the request.
  /// @since_tizen 3.0
  /// @param[in] request The handle of the request
  /// @param[out] connectivity_type The connectivity type of the request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_request_get_host_address()
  /// @see iotcon_request_get_representation()
  /// @see iotcon_request_get_request_type()
  /// @see iotcon_request_get_options()
  /// @see iotcon_request_get_query()
  /// @see iotcon_request_get_observe_type()
  /// @see iotcon_request_get_observe_id()
  int iotcon_request_get_connectivity_type(
    iotcon_request_h request,
    ffi.Pointer<ffi.Int32> connectivity_type,
  ) {
    return _iotcon_request_get_connectivity_type(
      request,
      connectivity_type,
    );
  }

  late final _iotcon_request_get_connectivity_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_request_h,
              ffi.Pointer<ffi.Int32>)>>('iotcon_request_get_connectivity_type');
  late final _iotcon_request_get_connectivity_type =
      _iotcon_request_get_connectivity_typePtr
          .asFunction<int Function(iotcon_request_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets a representation of the request.
  /// @since_tizen 3.0
  /// @remarks @a repr must not be released using iotcon_representation_destroy().
  /// @param[in] request The handle of the request
  /// @param[out] repr The representation of the request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_request_get_host_address()
  /// @see iotcon_request_get_connectivity_type()
  /// @see iotcon_request_get_request_type()
  /// @see iotcon_request_get_options()
  /// @see iotcon_request_get_query()
  /// @see iotcon_request_get_observe_type()
  /// @see iotcon_request_get_observe_id()
  int iotcon_request_get_representation(
    iotcon_request_h request,
    ffi.Pointer<iotcon_representation_h> repr,
  ) {
    return _iotcon_request_get_representation(
      request,
      repr,
    );
  }

  late final _iotcon_request_get_representationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_request_h, ffi.Pointer<iotcon_representation_h>)>>(
      'iotcon_request_get_representation');
  late final _iotcon_request_get_representation =
      _iotcon_request_get_representationPtr.asFunction<
          int Function(
              iotcon_request_h, ffi.Pointer<iotcon_representation_h>)>();

  /// @brief Gets type of the request.
  /// @details @a type could be one of the #iotcon_request_type_e.
  /// @since_tizen 3.0
  /// @param[in] request The handle of the request
  /// @param[out] type The types of the request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_request_get_host_address()
  /// @see iotcon_request_get_connectivity_type()
  /// @see iotcon_request_get_representation()
  /// @see iotcon_request_get_options()
  /// @see iotcon_request_get_query()
  /// @see iotcon_request_get_observe_type()
  /// @see iotcon_request_get_observe_id()
  int iotcon_request_get_request_type(
    iotcon_request_h request,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _iotcon_request_get_request_type(
      request,
      type,
    );
  }

  late final _iotcon_request_get_request_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_request_h,
              ffi.Pointer<ffi.Int32>)>>('iotcon_request_get_request_type');
  late final _iotcon_request_get_request_type =
      _iotcon_request_get_request_typePtr
          .asFunction<int Function(iotcon_request_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets options of the request.
  /// @since_tizen 3.0
  /// @remarks @a options must not be released using iotcon_options_destroy().
  /// @param[in] request The handle of the request
  /// @param[out] options The options of the request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_request_get_host_address()
  /// @see iotcon_request_get_connectivity_type()
  /// @see iotcon_request_get_representation()
  /// @see iotcon_request_get_request_type()
  /// @see iotcon_request_get_query()
  /// @see iotcon_request_get_observe_type()
  /// @see iotcon_request_get_observe_id()
  int iotcon_request_get_options(
    iotcon_request_h request,
    ffi.Pointer<iotcon_options_h> options,
  ) {
    return _iotcon_request_get_options(
      request,
      options,
    );
  }

  late final _iotcon_request_get_optionsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_request_h,
              ffi.Pointer<iotcon_options_h>)>>('iotcon_request_get_options');
  late final _iotcon_request_get_options =
      _iotcon_request_get_optionsPtr.asFunction<
          int Function(iotcon_request_h, ffi.Pointer<iotcon_options_h>)>();

  /// @brief Gets query of the request.
  /// @since_tizen 3.0
  /// @remarks @a query must not be released using iotcon_query_destroy().
  /// @param[in] request The handle of the request
  /// @param[out] query The query of the request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_request_get_host_address()
  /// @see iotcon_request_get_connectivity_type()
  /// @see iotcon_request_get_representation()
  /// @see iotcon_request_get_request_type()
  /// @see iotcon_request_get_options()
  /// @see iotcon_request_get_observe_type()
  /// @see iotcon_request_get_observe_id()
  int iotcon_request_get_query(
    iotcon_request_h request,
    ffi.Pointer<iotcon_query_h> query,
  ) {
    return _iotcon_request_get_query(
      request,
      query,
    );
  }

  late final _iotcon_request_get_queryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_request_h,
              ffi.Pointer<iotcon_query_h>)>>('iotcon_request_get_query');
  late final _iotcon_request_get_query =
      _iotcon_request_get_queryPtr.asFunction<
          int Function(iotcon_request_h, ffi.Pointer<iotcon_query_h>)>();

  /// @brief Gets observation action of the request.
  /// @details The @a observe_type could be one of #iotcon_observe_type_e.
  /// @since_tizen 3.0
  /// @param[in] request The handle of the request
  /// @param[out] observe_type The observation type of the request
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_request_get_host_address()
  /// @see iotcon_request_get_connectivity_type()
  /// @see iotcon_request_get_representation()
  /// @see iotcon_request_get_request_type()
  /// @see iotcon_request_get_options()
  /// @see iotcon_request_get_query()
  /// @see iotcon_request_get_observe_id()
  int iotcon_request_get_observe_type(
    iotcon_request_h request,
    ffi.Pointer<ffi.Int32> observe_type,
  ) {
    return _iotcon_request_get_observe_type(
      request,
      observe_type,
    );
  }

  late final _iotcon_request_get_observe_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_request_h,
              ffi.Pointer<ffi.Int32>)>>('iotcon_request_get_observe_type');
  late final _iotcon_request_get_observe_type =
      _iotcon_request_get_observe_typePtr
          .asFunction<int Function(iotcon_request_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets observation ID of the request.
  /// @since_tizen 3.0
  /// @param[in] request The handle of the request
  /// @param[out] observe_id The ID of the observer
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_request_get_host_address()
  /// @see iotcon_request_get_connectivity_type()
  /// @see iotcon_request_get_representation()
  /// @see iotcon_request_get_request_type()
  /// @see iotcon_request_get_options()
  /// @see iotcon_request_get_query()
  /// @see iotcon_request_get_observe_type()
  int iotcon_request_get_observe_id(
    iotcon_request_h request,
    ffi.Pointer<ffi.Int> observe_id,
  ) {
    return _iotcon_request_get_observe_id(
      request,
      observe_id,
    );
  }

  late final _iotcon_request_get_observe_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_request_h,
              ffi.Pointer<ffi.Int>)>>('iotcon_request_get_observe_id');
  late final _iotcon_request_get_observe_id = _iotcon_request_get_observe_idPtr
      .asFunction<int Function(iotcon_request_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Starts presence of a server.
  /// @details Use this function to send server's announcements to clients. \n
  /// Server can call this function when online for the first time or come back from offline to online.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks If @a time_to_live is 0, server will set default value as 60 seconds. \n
  /// If @a time_to_live is very big, server will set maximum value as (60 * 60 * 24) seconds (24 hours).
  /// @param[in] time_to_live The interval of announcing presence in seconds
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_stop_presence()
  /// @see iotcon_add_presence_cb()
  /// @see iotcon_remove_presence_cb()
  int iotcon_start_presence(
    int time_to_live,
  ) {
    return _iotcon_start_presence(
      time_to_live,
    );
  }

  late final _iotcon_start_presencePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.UnsignedInt)>>(
          'iotcon_start_presence');
  late final _iotcon_start_presence =
      _iotcon_start_presencePtr.asFunction<int Function(int)>();

  /// @brief Stops presence of a server.
  /// @details Use this function to stop sending server's announcements to clients.
  /// Server can call this function when terminating, entering to offline or out of network.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_start_presence()
  /// @see iotcon_add_presence_cb()
  /// @see iotcon_remove_presence_cb()
  int iotcon_stop_presence() {
    return _iotcon_stop_presence();
  }

  late final _iotcon_stop_presencePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('iotcon_stop_presence');
  late final _iotcon_stop_presence =
      _iotcon_stop_presencePtr.asFunction<int Function()>();

  /// @brief Sets the device name.
  /// @details The function sets the name of the local device (the device calling the function).
  /// If the device name is set, clients can get the name using iotcon_device_info_get_property() or iotcon_remote_resource_get_device_name().
  /// @since_tizen 3.0
  /// @remarks @a device_name may not be an empty string.
  /// @param[in] device_name The device name
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_IOTIVITY Iotivity errors
  /// @see iotcon_get_device_info()
  /// @see iotcon_device_info_get_property()
  /// @see iotcon_remote_resource_get_device_name()
  int iotcon_set_device_name(
    ffi.Pointer<ffi.Char> device_name,
  ) {
    return _iotcon_set_device_name(
      device_name,
    );
  }

  late final _iotcon_set_device_namePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'iotcon_set_device_name');
  late final _iotcon_set_device_name = _iotcon_set_device_namePtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Creates a new resource handle.
  /// @details Creates a resource proxy object so that iotcon_remote_resource_get(),
  /// iotcon_remote_resource_put(), iotcon_remote_resource_post(),
  /// iotcon_remote_resource_delete(), iotcon_remote_resource_observe_register(),
  /// iotcon_remote_resource_start_caching() and iotcon_remote_resource_start_monitoring()
  /// API can be used without discovering the object in advance.\n
  /// To use this API, you should provide all of the details required to correctly contact and observe the object.\n
  /// If not, you should discover the resource object manually.\n
  /// The @a policies can contain multiple policies like IOTCON_RESOURCE_DISCOVERABLE | IOTCON_RESOURCE_OBSERVABLE.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a remote_resource by calling iotcon_remote_resource_destroy() if @a remote_resource is no longer needed.
  /// @param[in] host_address The host address of the resource
  /// @param[in] connectivity_type The connectivity type. Can not use @a IOTCON_CONNECTIVITY_ALL. \n
  /// Connectivity type of specific remote resource(It has specific host address, not @a IOTCON_MULTICAST_ADDRESS) is already decided. \n
  /// Use specific connectivity type of the remote resource. \n
  /// You can refer to the @a iotcon_remote_resource_get_connectivity_type().
  /// @param[in] uri_path The URI path of the resource
  /// @param[in] policies The policies of the resource \n
  /// Set of #iotcon_resource_policy_e
  /// @param[in] resource_types The resource types of the resource. For example, "core.light"
  /// @param[in] resource_ifaces The resource interfaces of the resource
  /// @param[out] remote_resource Generated resource handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_IOTIVITY IoTivity errors
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @see iotcon_remote_resource_destroy()
  /// @see iotcon_remote_resource_clone()
  int iotcon_remote_resource_create(
    ffi.Pointer<ffi.Char> host_address,
    int connectivity_type,
    ffi.Pointer<ffi.Char> uri_path,
    int policies,
    iotcon_resource_types_h resource_types,
    iotcon_resource_interfaces_h resource_ifaces,
    ffi.Pointer<iotcon_remote_resource_h> remote_resource,
  ) {
    return _iotcon_remote_resource_create(
      host_address,
      connectivity_type,
      uri_path,
      policies,
      resource_types,
      resource_ifaces,
      remote_resource,
    );
  }

  late final _iotcon_remote_resource_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>,
                  ffi.Int32,
                  ffi.Pointer<ffi.Char>,
                  ffi.Uint8,
                  iotcon_resource_types_h,
                  iotcon_resource_interfaces_h,
                  ffi.Pointer<iotcon_remote_resource_h>)>>(
      'iotcon_remote_resource_create');
  late final _iotcon_remote_resource_create =
      _iotcon_remote_resource_createPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              int,
              ffi.Pointer<ffi.Char>,
              int,
              iotcon_resource_types_h,
              iotcon_resource_interfaces_h,
              ffi.Pointer<iotcon_remote_resource_h>)>();

  /// @brief Destroys a resource handle.
  /// @since_tizen 3.0
  /// @param[in] resource The handle of the resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_create()
  /// @see iotcon_remote_resource_clone()
  int iotcon_remote_resource_destroy(
    iotcon_remote_resource_h resource,
  ) {
    return _iotcon_remote_resource_destroy(
      resource,
    );
  }

  late final _iotcon_remote_resource_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_remote_resource_h)>>(
          'iotcon_remote_resource_destroy');
  late final _iotcon_remote_resource_destroy =
      _iotcon_remote_resource_destroyPtr
          .asFunction<int Function(iotcon_remote_resource_h)>();

  /// @brief Clones a clone of a remote resource.
  /// @since_tizen 3.0
  /// @remarks You must destroy @a dest by calling iotcon_remote_resource_destroy() if @a dest is no longer needed.
  /// @param[in] src The Source of resource
  /// @param[out] dest The cloned resource handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_create()
  /// @see iotcon_remote_resource_destroy()
  int iotcon_remote_resource_clone(
    iotcon_remote_resource_h src,
    ffi.Pointer<iotcon_remote_resource_h> dest,
  ) {
    return _iotcon_remote_resource_clone(
      src,
      dest,
    );
  }

  late final _iotcon_remote_resource_clonePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_remote_resource_h,
                  ffi.Pointer<iotcon_remote_resource_h>)>>(
      'iotcon_remote_resource_clone');
  late final _iotcon_remote_resource_clone =
      _iotcon_remote_resource_clonePtr.asFunction<
          int Function(iotcon_remote_resource_h,
              ffi.Pointer<iotcon_remote_resource_h>)>();

  /// @brief Registers observe callback on the resource.
  /// @details When server sends notification message, iotcon_remote_resource_observe_cb() will be called.
  /// The @a observe_policy could be one of #iotcon_observe_policy_e.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the resource
  /// @param[in] observe_policy The type to specify how client wants to observe
  /// @param[in] query The query to send to server
  /// @param[in] cb The callback function to get notifications from server
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_IOTIVITY IoTivity errors
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post When the @a resource receive notification message, iotcon_remote_resource_observe_cb() will be called.
  /// @see iotcon_remote_resource_observe_cb()
  /// @see iotcon_remote_resource_observe_deregister()
  /// @see iotcon_resource_notify()
  int iotcon_remote_resource_observe_register(
    iotcon_remote_resource_h resource,
    int observe_policy,
    iotcon_query_h query,
    iotcon_remote_resource_observe_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_remote_resource_observe_register(
      resource,
      observe_policy,
      query,
      cb,
      user_data,
    );
  }

  late final _iotcon_remote_resource_observe_registerPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_remote_resource_h,
                  ffi.Int32,
                  iotcon_query_h,
                  iotcon_remote_resource_observe_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'iotcon_remote_resource_observe_register');
  late final _iotcon_remote_resource_observe_register =
      _iotcon_remote_resource_observe_registerPtr.asFunction<
          int Function(iotcon_remote_resource_h, int, iotcon_query_h,
              iotcon_remote_resource_observe_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Deregisters observe callback on the resource.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_remote_resource_observe_cb()
  /// @see iotcon_remote_resource_observe_register()
  /// @see iotcon_resource_notify()
  int iotcon_remote_resource_observe_deregister(
    iotcon_remote_resource_h resource,
  ) {
    return _iotcon_remote_resource_observe_deregister(
      resource,
    );
  }

  late final _iotcon_remote_resource_observe_deregisterPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_remote_resource_h)>>(
          'iotcon_remote_resource_observe_deregister');
  late final _iotcon_remote_resource_observe_deregister =
      _iotcon_remote_resource_observe_deregisterPtr
          .asFunction<int Function(iotcon_remote_resource_h)>();

  /// @brief Gets the attributes of a resource asynchronously.
  /// @details When server sends response on get request, iotcon_remote_resource_response_cb() will be called.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the resource
  /// @param[in] query The query to send to server
  /// @param[in] cb The callback function
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post When the client receive get response, iotcon_remote_resource_response_cb() will be called.
  /// @see iotcon_remote_resource_response_cb()
  /// @see iotcon_set_timeout()
  int iotcon_remote_resource_get(
    iotcon_remote_resource_h resource,
    iotcon_query_h query,
    iotcon_remote_resource_response_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_remote_resource_get(
      resource,
      query,
      cb,
      user_data,
    );
  }

  late final _iotcon_remote_resource_getPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_remote_resource_h,
              iotcon_query_h,
              iotcon_remote_resource_response_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_remote_resource_get');
  late final _iotcon_remote_resource_get =
      _iotcon_remote_resource_getPtr.asFunction<
          int Function(iotcon_remote_resource_h, iotcon_query_h,
              iotcon_remote_resource_response_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Puts the representation of a resource asynchronously.
  /// @details When server sends response on put request, iotcon_remote_resource_response_cb() will be called.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the resource
  /// @param[in] repr The handle of the representation
  /// @param[in] query The query to send to server
  /// @param[in] cb The callback function
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post When the client receive put response, iotcon_remote_resource_response_cb() will be called.
  /// @see iotcon_remote_resource_response_cb()
  /// @see iotcon_set_timeout()
  int iotcon_remote_resource_put(
    iotcon_remote_resource_h resource,
    iotcon_representation_h repr,
    iotcon_query_h query,
    iotcon_remote_resource_response_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_remote_resource_put(
      resource,
      repr,
      query,
      cb,
      user_data,
    );
  }

  late final _iotcon_remote_resource_putPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_remote_resource_h,
              iotcon_representation_h,
              iotcon_query_h,
              iotcon_remote_resource_response_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_remote_resource_put');
  late final _iotcon_remote_resource_put =
      _iotcon_remote_resource_putPtr.asFunction<
          int Function(
              iotcon_remote_resource_h,
              iotcon_representation_h,
              iotcon_query_h,
              iotcon_remote_resource_response_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Posts on a resource asynchronously.
  /// @details When server sends response on post request, iotcon_remote_resource_response_cb() will be called.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the resource
  /// @param[in] repr The handle of the representation
  /// @param[in] query The query to send to server
  /// @param[in] cb The callback function
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post When the client receive post response, iotcon_remote_resource_response_cb() will be called.
  /// @see iotcon_remote_resource_response_cb()
  /// @see iotcon_set_timeout()
  int iotcon_remote_resource_post(
    iotcon_remote_resource_h resource,
    iotcon_representation_h repr,
    iotcon_query_h query,
    iotcon_remote_resource_response_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_remote_resource_post(
      resource,
      repr,
      query,
      cb,
      user_data,
    );
  }

  late final _iotcon_remote_resource_postPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_remote_resource_h,
              iotcon_representation_h,
              iotcon_query_h,
              iotcon_remote_resource_response_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_remote_resource_post');
  late final _iotcon_remote_resource_post =
      _iotcon_remote_resource_postPtr.asFunction<
          int Function(
              iotcon_remote_resource_h,
              iotcon_representation_h,
              iotcon_query_h,
              iotcon_remote_resource_response_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Deletes a resource asynchronously.
  /// @details When server sends response on delete request, iotcon_remote_resource_response_cb() will be called.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the resource
  /// @param[in] cb The callback function
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post When the client receive delete response, iotcon_remote_resource_response_cb() will be called.
  /// @see iotcon_remote_resource_response_cb()
  /// @see iotcon_set_timeout()
  int iotcon_remote_resource_delete(
    iotcon_remote_resource_h resource,
    iotcon_remote_resource_response_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_remote_resource_delete(
      resource,
      cb,
      user_data,
    );
  }

  late final _iotcon_remote_resource_deletePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_remote_resource_h,
              iotcon_remote_resource_response_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_remote_resource_delete');
  late final _iotcon_remote_resource_delete =
      _iotcon_remote_resource_deletePtr.asFunction<
          int Function(iotcon_remote_resource_h,
              iotcon_remote_resource_response_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Starts caching of a remote resource.
  /// @details Use this function to start caching the resource's attribute. \n
  /// Although, remote resource is not observable, it keeps the representation up-to-date.
  /// Because it checks whether representation is changed periodically. \n
  /// Therefore, you can get the cached representation even when the remote resource is off-line.
  /// The default checking interval is 10 seconds.
  /// It can be changed by iotcon_remote_resource_set_checking_interval().
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the remote resource to be cached
  /// @param[in] cb The callback function to add into callback list
  /// @param[in] user_data The user data to pass to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_ALREADY Already done
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_remote_resource_stop_caching()
  /// @see iotcon_remote_resource_cached_representation_changed_cb()
  int iotcon_remote_resource_start_caching(
    iotcon_remote_resource_h resource,
    iotcon_remote_resource_cached_representation_changed_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_remote_resource_start_caching(
      resource,
      cb,
      user_data,
    );
  }

  late final _iotcon_remote_resource_start_cachingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              iotcon_remote_resource_h,
              iotcon_remote_resource_cached_representation_changed_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_remote_resource_start_caching');
  late final _iotcon_remote_resource_start_caching =
      _iotcon_remote_resource_start_cachingPtr.asFunction<
          int Function(
              iotcon_remote_resource_h,
              iotcon_remote_resource_cached_representation_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Stops caching of a remote resource.
  /// @details Use this function to stop caching the resource's attribute.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the remote resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_remote_resource_start_caching()
  /// @see iotcon_remote_resource_cached_representation_changed_cb()
  int iotcon_remote_resource_stop_caching(
    iotcon_remote_resource_h resource,
  ) {
    return _iotcon_remote_resource_stop_caching(
      resource,
    );
  }

  late final _iotcon_remote_resource_stop_cachingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_remote_resource_h)>>(
          'iotcon_remote_resource_stop_caching');
  late final _iotcon_remote_resource_stop_caching =
      _iotcon_remote_resource_stop_cachingPtr
          .asFunction<int Function(iotcon_remote_resource_h)>();

  /// @brief Starts monitoring of a remote resource.
  /// @details When remote resource's state is changed, registered callbacks will be called in turn.
  /// Although, remote resource does not call iotcon_start_presence(), it knows the state of resource.
  /// Because it checks the state of resource, periodically. \n
  /// The default checking interval is 10 seconds.
  /// It can be changed by iotcon_remote_resource_set_checking_interval().
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the remote resource
  /// @param[in] cb The callback function to add into callback list
  /// @param[in] user_data The user data to pass to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_ALREADY Already done
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_remote_resource_stop_monitoring()
  /// @see iotcon_remote_resource_state_changed_cb()
  int iotcon_remote_resource_start_monitoring(
    iotcon_remote_resource_h resource,
    iotcon_remote_resource_state_changed_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_remote_resource_start_monitoring(
      resource,
      cb,
      user_data,
    );
  }

  late final _iotcon_remote_resource_start_monitoringPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_remote_resource_h,
                  iotcon_remote_resource_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'iotcon_remote_resource_start_monitoring');
  late final _iotcon_remote_resource_start_monitoring =
      _iotcon_remote_resource_start_monitoringPtr.asFunction<
          int Function(
              iotcon_remote_resource_h,
              iotcon_remote_resource_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Stops monitoring of a remote resource.
  /// @details Use this function to stop monitoring the remote resource.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] resource The handle of the remote resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_remote_resource_start_monitoring()
  /// @see iotcon_remote_resource_state_changed_cb()
  int iotcon_remote_resource_stop_monitoring(
    iotcon_remote_resource_h resource,
  ) {
    return _iotcon_remote_resource_stop_monitoring(
      resource,
    );
  }

  late final _iotcon_remote_resource_stop_monitoringPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_remote_resource_h)>>(
          'iotcon_remote_resource_stop_monitoring');
  late final _iotcon_remote_resource_stop_monitoring =
      _iotcon_remote_resource_stop_monitoringPtr
          .asFunction<int Function(iotcon_remote_resource_h)>();

  /// @brief Gets an URI path of the remote resource.
  /// @since_tizen 3.0
  /// @remarks @a uri_path must not be released using free().
  /// @param[in] resource The handle of the remote resource
  /// @param[out] uri_path The URI path of the remote resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_get_host_address()
  /// @see iotcon_remote_resource_get_connectivity_type()
  /// @see iotcon_remote_resource_get_device_id()
  /// @see iotcon_remote_resource_get_device_name()
  /// @see iotcon_remote_resource_get_types()
  /// @see iotcon_remote_resource_get_interfaces()
  /// @see iotcon_remote_resource_get_policies()
  /// @see iotcon_remote_resource_set_options()
  int iotcon_remote_resource_get_uri_path(
    iotcon_remote_resource_h resource,
    ffi.Pointer<ffi.Pointer<ffi.Char>> uri_path,
  ) {
    return _iotcon_remote_resource_get_uri_path(
      resource,
      uri_path,
    );
  }

  late final _iotcon_remote_resource_get_uri_pathPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_remote_resource_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_remote_resource_get_uri_path');
  late final _iotcon_remote_resource_get_uri_path =
      _iotcon_remote_resource_get_uri_pathPtr.asFunction<
          int Function(
              iotcon_remote_resource_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets a connectivity type of the remote resource.
  /// @since_tizen 3.0
  /// @param[in] resource The handle of the remote resource
  /// @param[out] connectivity_type The connectivity type of the remote resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_get_uri_path()
  /// @see iotcon_remote_resource_get_host_address()
  /// @see iotcon_remote_resource_get_connectivity_type()
  /// @see iotcon_remote_resource_get_device_id()
  /// @see iotcon_remote_resource_get_device_name()
  /// @see iotcon_remote_resource_get_types()
  /// @see iotcon_remote_resource_get_interfaces()
  /// @see iotcon_remote_resource_get_policies()
  /// @see iotcon_remote_resource_set_options()
  int iotcon_remote_resource_get_connectivity_type(
    iotcon_remote_resource_h resource,
    ffi.Pointer<ffi.Int32> connectivity_type,
  ) {
    return _iotcon_remote_resource_get_connectivity_type(
      resource,
      connectivity_type,
    );
  }

  late final _iotcon_remote_resource_get_connectivity_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_remote_resource_h, ffi.Pointer<ffi.Int32>)>>(
      'iotcon_remote_resource_get_connectivity_type');
  late final _iotcon_remote_resource_get_connectivity_type =
      _iotcon_remote_resource_get_connectivity_typePtr.asFunction<
          int Function(iotcon_remote_resource_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets a host address of the remote resource.
  /// @since_tizen 3.0
  /// @remarks @a host_address must not be released using free().
  /// @param[in] resource The handle of the remote resource
  /// @param[out] host_address The host address of the remote resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_get_connectivity_type()
  /// @see iotcon_remote_resource_get_uri_path()
  /// @see iotcon_remote_resource_get_device_id()
  /// @see iotcon_remote_resource_get_device_name()
  /// @see iotcon_remote_resource_get_types()
  /// @see iotcon_remote_resource_get_interfaces()
  /// @see iotcon_remote_resource_get_policies()
  /// @see iotcon_remote_resource_set_options()
  int iotcon_remote_resource_get_host_address(
    iotcon_remote_resource_h resource,
    ffi.Pointer<ffi.Pointer<ffi.Char>> host_address,
  ) {
    return _iotcon_remote_resource_get_host_address(
      resource,
      host_address,
    );
  }

  late final _iotcon_remote_resource_get_host_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_remote_resource_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_remote_resource_get_host_address');
  late final _iotcon_remote_resource_get_host_address =
      _iotcon_remote_resource_get_host_addressPtr.asFunction<
          int Function(
              iotcon_remote_resource_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets a device ID of the remote resource.
  /// @since_tizen 3.0
  /// @remarks @a device_id must not be released using free().\n
  /// If @a resource is created by calling iotcon_remote_resource_create(), you cannot get @a device_id.
  /// In this case, the return value of this function is #IOTCON_ERROR_NO_DATA.
  /// @param[in] resource The handle of the remote resource
  /// @param[out] device_id The device ID of the remote resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @see iotcon_remote_resource_get_uri_path()
  /// @see iotcon_remote_resource_get_device_name()
  /// @see iotcon_remote_resource_get_host_address()
  /// @see iotcon_remote_resource_get_connectivity_type()
  /// @see iotcon_remote_resource_get_types()
  /// @see iotcon_remote_resource_get_interfaces()
  /// @see iotcon_remote_resource_get_policies()
  /// @see iotcon_remote_resource_set_options()
  int iotcon_remote_resource_get_device_id(
    iotcon_remote_resource_h resource,
    ffi.Pointer<ffi.Pointer<ffi.Char>> device_id,
  ) {
    return _iotcon_remote_resource_get_device_id(
      resource,
      device_id,
    );
  }

  late final _iotcon_remote_resource_get_device_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_remote_resource_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_remote_resource_get_device_id');
  late final _iotcon_remote_resource_get_device_id =
      _iotcon_remote_resource_get_device_idPtr.asFunction<
          int Function(
              iotcon_remote_resource_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the device name of the remote resource.
  /// @since_tizen 3.0
  /// @remarks @a device_name must not be released using free().\n
  /// If @a resource is created by calling iotcon_remote_resource_create(), you cannot get @a device_name.
  /// In this case, the return value of this function is #IOTCON_ERROR_NO_DATA.
  /// @param[in] resource The handle of the remote resource
  /// @param[out] device_name The device name of the remote resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @see iotcon_set_device_name()
  /// @see iotcon_remote_resource_get_uri_path()
  /// @see iotcon_remote_resource_get_device_id()
  /// @see iotcon_remote_resource_get_device_name()
  /// @see iotcon_remote_resource_get_host_address()
  /// @see iotcon_remote_resource_get_connectivity_type()
  /// @see iotcon_remote_resource_get_types()
  /// @see iotcon_remote_resource_get_interfaces()
  /// @see iotcon_remote_resource_get_properties()
  /// @see iotcon_remote_resource_set_options()
  int iotcon_remote_resource_get_device_name(
    iotcon_remote_resource_h resource,
    ffi.Pointer<ffi.Pointer<ffi.Char>> device_name,
  ) {
    return _iotcon_remote_resource_get_device_name(
      resource,
      device_name,
    );
  }

  late final _iotcon_remote_resource_get_device_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_remote_resource_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_remote_resource_get_device_name');
  late final _iotcon_remote_resource_get_device_name =
      _iotcon_remote_resource_get_device_namePtr.asFunction<
          int Function(
              iotcon_remote_resource_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets resource types of the remote resource.
  /// @since_tizen 3.0
  /// @remarks @a types must not be released using iotcon_resource_types_destroy().
  /// @param[in] resource The handle of the remote resource
  /// @param[out] types The resource types of the remote resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_get_uri_path()
  /// @see iotcon_remote_resource_get_host_address()
  /// @see iotcon_remote_resource_get_connectivity_type()
  /// @see iotcon_remote_resource_get_device_id()
  /// @see iotcon_remote_resource_get_device_name()
  /// @see iotcon_remote_resource_get_interfaces()
  /// @see iotcon_remote_resource_get_policies()
  /// @see iotcon_remote_resource_set_options()
  int iotcon_remote_resource_get_types(
    iotcon_remote_resource_h resource,
    ffi.Pointer<iotcon_resource_types_h> types,
  ) {
    return _iotcon_remote_resource_get_types(
      resource,
      types,
    );
  }

  late final _iotcon_remote_resource_get_typesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_remote_resource_h,
                  ffi.Pointer<iotcon_resource_types_h>)>>(
      'iotcon_remote_resource_get_types');
  late final _iotcon_remote_resource_get_types =
      _iotcon_remote_resource_get_typesPtr.asFunction<
          int Function(iotcon_remote_resource_h,
              ffi.Pointer<iotcon_resource_types_h>)>();

  /// @brief Gets resource interfaces of the remote resource.
  /// @since_tizen 3.0
  /// @remarks @a ifaces must not be released using iotcon_resource_interfaces_destroy().
  /// @param[in] resource The handle of the remote resource
  /// @param[out] ifaces The resource interfaces of the remote resource
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_get_uri_path()
  /// @see iotcon_remote_resource_get_host_address()
  /// @see iotcon_remote_resource_get_connectivity_type()
  /// @see iotcon_remote_resource_get_device_id()
  /// @see iotcon_remote_resource_get_device_name()
  /// @see iotcon_remote_resource_get_types()
  /// @see iotcon_remote_resource_get_policies()
  /// @see iotcon_remote_resource_set_options()
  int iotcon_remote_resource_get_interfaces(
    iotcon_remote_resource_h resource,
    ffi.Pointer<iotcon_resource_interfaces_h> ifaces,
  ) {
    return _iotcon_remote_resource_get_interfaces(
      resource,
      ifaces,
    );
  }

  late final _iotcon_remote_resource_get_interfacesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_remote_resource_h,
                  ffi.Pointer<iotcon_resource_interfaces_h>)>>(
      'iotcon_remote_resource_get_interfaces');
  late final _iotcon_remote_resource_get_interfaces =
      _iotcon_remote_resource_get_interfacesPtr.asFunction<
          int Function(iotcon_remote_resource_h,
              ffi.Pointer<iotcon_resource_interfaces_h>)>();

  /// @brief Checks whether the remote resource is observable or not.
  /// @details The @a policies can contain multiple policies like IOTCON_RESOURCE_DISCOVERABLE | IOTCON_RESOURCE_OBSERVABLE.
  /// @since_tizen 3.0
  /// @param[in] resource The handle of the resource
  /// @param[out] policies The policies of the resource \n
  /// Set of #iotcon_resource_policy_e
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_get_uri_path()
  /// @see iotcon_remote_resource_get_host_address()
  /// @see iotcon_remote_resource_get_connectivity_type()
  /// @see iotcon_remote_resource_get_device_id()
  /// @see iotcon_remote_resource_get_device_name()
  /// @see iotcon_remote_resource_get_types()
  /// @see iotcon_remote_resource_get_interfaces()
  /// @see iotcon_remote_resource_set_options()
  int iotcon_remote_resource_get_policies(
    iotcon_remote_resource_h resource,
    ffi.Pointer<ffi.Uint8> policies,
  ) {
    return _iotcon_remote_resource_get_policies(
      resource,
      policies,
    );
  }

  late final _iotcon_remote_resource_get_policiesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_remote_resource_h,
              ffi.Pointer<ffi.Uint8>)>>('iotcon_remote_resource_get_policies');
  late final _iotcon_remote_resource_get_policies =
      _iotcon_remote_resource_get_policiesPtr.asFunction<
          int Function(iotcon_remote_resource_h, ffi.Pointer<ffi.Uint8>)>();

  /// @brief Gets options of the remote resource.
  /// @since_tizen 3.0
  /// @remarks @a options must not be released using iotcon_options_destroy().
  /// @param[in] resource The handle of the remote resource
  /// @param[out] options The handle of the header options
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_get_uri_path()
  /// @see iotcon_remote_resource_get_host_address()
  /// @see iotcon_remote_resource_get_connectivity_type()
  /// @see iotcon_remote_resource_get_device_id()
  /// @see iotcon_remote_resource_get_device_name()
  /// @see iotcon_remote_resource_get_types()
  /// @see iotcon_remote_resource_get_interfaces()
  /// @see iotcon_remote_resource_set_options()
  /// @see iotcon_remote_resource_get_policies()
  int iotcon_remote_resource_get_options(
    iotcon_remote_resource_h resource,
    ffi.Pointer<iotcon_options_h> options,
  ) {
    return _iotcon_remote_resource_get_options(
      resource,
      options,
    );
  }

  late final _iotcon_remote_resource_get_optionsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_remote_resource_h, ffi.Pointer<iotcon_options_h>)>>(
      'iotcon_remote_resource_get_options');
  late final _iotcon_remote_resource_get_options =
      _iotcon_remote_resource_get_optionsPtr.asFunction<
          int Function(
              iotcon_remote_resource_h, ffi.Pointer<iotcon_options_h>)>();

  /// @brief Sets options into the remote resource.
  /// @since_tizen 3.0
  /// @param[in] resource The handle of the remote resource
  /// @param[in] options The handle of the header options
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_get_uri_path()
  /// @see iotcon_remote_resource_get_host_address()
  /// @see iotcon_remote_resource_get_connectivity_type()
  /// @see iotcon_remote_resource_get_device_id()
  /// @see iotcon_remote_resource_get_device_name()
  /// @see iotcon_remote_resource_get_types()
  /// @see iotcon_remote_resource_get_interfaces()
  /// @see iotcon_remote_resource_get_options()
  /// @see iotcon_remote_resource_get_policies()
  int iotcon_remote_resource_set_options(
    iotcon_remote_resource_h resource,
    iotcon_options_h options,
  ) {
    return _iotcon_remote_resource_set_options(
      resource,
      options,
    );
  }

  late final _iotcon_remote_resource_set_optionsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_remote_resource_h,
              iotcon_options_h)>>('iotcon_remote_resource_set_options');
  late final _iotcon_remote_resource_set_options =
      _iotcon_remote_resource_set_optionsPtr.asFunction<
          int Function(iotcon_remote_resource_h, iotcon_options_h)>();

  /// @brief Gets cached representation from the remote resource.
  /// @since_tizen 3.0
  /// @remarks @a representation must not be released using iotcon_representation_destroy().
  /// @param[in] resource The handle of the remote resource
  /// @param[out] representation The handle of the representation
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  int iotcon_remote_resource_get_cached_representation(
    iotcon_remote_resource_h resource,
    ffi.Pointer<iotcon_representation_h> representation,
  ) {
    return _iotcon_remote_resource_get_cached_representation(
      resource,
      representation,
    );
  }

  late final _iotcon_remote_resource_get_cached_representationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_remote_resource_h,
                  ffi.Pointer<iotcon_representation_h>)>>(
      'iotcon_remote_resource_get_cached_representation');
  late final _iotcon_remote_resource_get_cached_representation =
      _iotcon_remote_resource_get_cached_representationPtr.asFunction<
          int Function(iotcon_remote_resource_h,
              ffi.Pointer<iotcon_representation_h>)>();

  /// @brief Gets the checking interval which is using on the monitoring & caching of remote resource.
  /// @details This API get the checking interval which is using in the process of monitoring and caching() of remote resource. \n
  /// The monitoring and caching will operate "GET method" with the checking interval.
  /// Default checking interval is 10 seconds.
  /// @since_tizen 3.0
  /// @param[in] resource The handle of the remote resource
  /// @param[out] interval Seconds for time interval
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_set_checking_interval()
  /// @see iotcon_remote_resource_start_monitoring()
  /// @see iotcon_remote_resource_start_caching()
  int iotcon_remote_resource_get_checking_interval(
    iotcon_remote_resource_h resource,
    ffi.Pointer<ffi.Int> interval,
  ) {
    return _iotcon_remote_resource_get_checking_interval(
      resource,
      interval,
    );
  }

  late final _iotcon_remote_resource_get_checking_intervalPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_remote_resource_h, ffi.Pointer<ffi.Int>)>>(
      'iotcon_remote_resource_get_checking_interval');
  late final _iotcon_remote_resource_get_checking_interval =
      _iotcon_remote_resource_get_checking_intervalPtr.asFunction<
          int Function(iotcon_remote_resource_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the checking interval which is using on the monitoring & caching of remote resource.
  /// @details This API set the checking interval which is using in the process of monitoring and caching() of remote resource. \n
  /// The monitoring and caching will operate "GET method" with the checking interval changed by this function.
  /// Default checking interval is 10 seconds.
  /// @since_tizen 3.0
  /// @param[in] resource The handle of the remote resource
  /// @param[in] interval Seconds for time interval (must be in range from 1 to 3600)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_remote_resource_get_checking_interval()
  /// @see iotcon_remote_resource_start_monitoring()
  /// @see iotcon_remote_resource_start_caching()
  int iotcon_remote_resource_set_checking_interval(
    iotcon_remote_resource_h resource,
    int interval,
  ) {
    return _iotcon_remote_resource_set_checking_interval(
      resource,
      interval,
    );
  }

  late final _iotcon_remote_resource_set_checking_intervalPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_remote_resource_h,
              ffi.Int)>>('iotcon_remote_resource_set_checking_interval');
  late final _iotcon_remote_resource_set_checking_interval =
      _iotcon_remote_resource_set_checking_intervalPtr
          .asFunction<int Function(iotcon_remote_resource_h, int)>();

  /// @brief Adds callback to a server to receive presence events.
  /// @details Request to receive presence to an interested server's resource with @a resource_type. \n
  /// If succeeded to subscribe, iotcon_presence_cb() will be invoked when the server sends presence. \n
  /// A server sends presence events when adds/removes/alters a resource or start/stop presence. \n
  /// @a host_address could be #IOTCON_MULTICAST_ADDRESS for IPv4 multicast.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks The length of @a resource_type should be less than or equal to 61.\n
  /// The @a resource_type must start with a lowercase alphabetic character, followed by a sequence
  /// of lowercase alphabetic, numeric, ".", or "-" characters, and contains no white space.\n
  /// You must destroy @a presence by calling iotcon_unsubscribe_presence()
  /// if @a presence is no longer needed.
  /// @param[in] host_address The address or addressable name of the server
  /// @param[in] connectivity_type The connectivity type
  /// @param[in] resource_type A resource type that a client is interested in
  /// @param[in] cb The callback function to invoke
  /// @param[in] user_data The user data to pass to the function
  /// @param[out] presence_handle The generated presence handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_IOTIVITY IoTivity errors
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post When the resource receive presence, iotcon_presence_cb() will be called.
  /// @see iotcon_start_presence()
  /// @see iotcon_stop_presence()
  /// @see iotcon_remove_presence_cb()
  /// @see iotcon_presence_cb()
  int iotcon_add_presence_cb(
    ffi.Pointer<ffi.Char> host_address,
    int connectivity_type,
    ffi.Pointer<ffi.Char> resource_type,
    iotcon_presence_cb cb,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<iotcon_presence_h> presence_handle,
  ) {
    return _iotcon_add_presence_cb(
      host_address,
      connectivity_type,
      resource_type,
      cb,
      user_data,
      presence_handle,
    );
  }

  late final _iotcon_add_presence_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              iotcon_presence_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<iotcon_presence_h>)>>('iotcon_add_presence_cb');
  late final _iotcon_add_presence_cb = _iotcon_add_presence_cbPtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>,
          int,
          ffi.Pointer<ffi.Char>,
          iotcon_presence_cb,
          ffi.Pointer<ffi.Void>,
          ffi.Pointer<iotcon_presence_h>)>();

  /// @brief Removes callback to a server's presence events.
  /// @details Request not to receive server's presence any more.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] presence_handle The presence handle to be unsubscribed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_start_presence()
  /// @see iotcon_stop_presence()
  /// @see iotcon_add_presence_cb()
  /// @see iotcon_presence_cb()
  int iotcon_remove_presence_cb(
    iotcon_presence_h presence_handle,
  ) {
    return _iotcon_remove_presence_cb(
      presence_handle,
    );
  }

  late final _iotcon_remove_presence_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_presence_h)>>(
          'iotcon_remove_presence_cb');
  late final _iotcon_remove_presence_cb = _iotcon_remove_presence_cbPtr
      .asFunction<int Function(iotcon_presence_h)>();

  /// @brief Gets host address from the presence handle.
  /// @since_tizen 3.0
  /// @remarks @a host_address must not be released using free().
  /// @param[in] presence The handle of the presence
  /// @param[out] host_address The host address of the presence
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_presence_get_connectivity_type()
  /// @see iotcon_presence_get_resource_type()
  int iotcon_presence_get_host_address(
    iotcon_presence_h presence,
    ffi.Pointer<ffi.Pointer<ffi.Char>> host_address,
  ) {
    return _iotcon_presence_get_host_address(
      presence,
      host_address,
    );
  }

  late final _iotcon_presence_get_host_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_presence_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_presence_get_host_address');
  late final _iotcon_presence_get_host_address =
      _iotcon_presence_get_host_addressPtr.asFunction<
          int Function(
              iotcon_presence_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets connectivity type from the presence handle.
  /// @details The @a connectivity_type could be one of #iotcon_connectivity_type_e.
  /// @since_tizen 3.0
  /// @param[in] presence The handle of the presence
  /// @param[out] connectivity_type The connectivity type of the presence
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_presence_get_host_address()
  /// @see iotcon_presence_get_resource_type()
  int iotcon_presence_get_connectivity_type(
    iotcon_presence_h presence,
    ffi.Pointer<ffi.Int32> connectivity_type,
  ) {
    return _iotcon_presence_get_connectivity_type(
      presence,
      connectivity_type,
    );
  }

  late final _iotcon_presence_get_connectivity_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_presence_h, ffi.Pointer<ffi.Int32>)>>(
      'iotcon_presence_get_connectivity_type');
  late final _iotcon_presence_get_connectivity_type =
      _iotcon_presence_get_connectivity_typePtr.asFunction<
          int Function(iotcon_presence_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets resource type from the presence handle.
  /// @since_tizen 3.0
  /// @remarks @a resource_type must not be released using free().
  /// @param[in] presence The handle of the presence
  /// @param[out] resource_type The resource type of the presence
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_presence_get_host_address()
  /// @see iotcon_presence_get_connectivity_type()
  int iotcon_presence_get_resource_type(
    iotcon_presence_h presence,
    ffi.Pointer<ffi.Pointer<ffi.Char>> resource_type,
  ) {
    return _iotcon_presence_get_resource_type(
      presence,
      resource_type,
    );
  }

  late final _iotcon_presence_get_resource_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_presence_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_presence_get_resource_type');
  late final _iotcon_presence_get_resource_type =
      _iotcon_presence_get_resource_typePtr.asFunction<
          int Function(
              iotcon_presence_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets result from the presence response handle.
  /// @details The @a result could be one of #iotcon_presence_result_e.
  /// @since_tizen 3.0
  /// @param[in] response The handle of the presence response
  /// @param[out] result The result code
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_presence_response_get_trigger()
  /// @see iotcon_presence_response_get_host_address()
  /// @see iotcon_presence_response_get_connectivity_type()
  /// @see iotcon_presence_response_get_resource_type()
  int iotcon_presence_response_get_result(
    iotcon_presence_response_h response,
    ffi.Pointer<ffi.Int32> result,
  ) {
    return _iotcon_presence_response_get_result(
      response,
      result,
    );
  }

  late final _iotcon_presence_response_get_resultPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_presence_response_h,
              ffi.Pointer<ffi.Int32>)>>('iotcon_presence_response_get_result');
  late final _iotcon_presence_response_get_result =
      _iotcon_presence_response_get_resultPtr.asFunction<
          int Function(iotcon_presence_response_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets trigger from the presence response handle.
  /// @details The @a trigger could be one of #iotcon_presence_trigger_e.
  /// It is set only if a response result is IOTCON_PRESENCE_OK.
  /// @since_tizen 3.0
  /// @param[in] response The handle of the presence response
  /// @param[out] trigger The presence trigger value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_presence_response_get_result()
  /// @see iotcon_presence_response_get_host_address()
  /// @see iotcon_presence_response_get_connectivity_type()
  /// @see iotcon_presence_response_get_resource_type()
  int iotcon_presence_response_get_trigger(
    iotcon_presence_response_h response,
    ffi.Pointer<ffi.Int32> trigger,
  ) {
    return _iotcon_presence_response_get_trigger(
      response,
      trigger,
    );
  }

  late final _iotcon_presence_response_get_triggerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_presence_response_h,
              ffi.Pointer<ffi.Int32>)>>('iotcon_presence_response_get_trigger');
  late final _iotcon_presence_response_get_trigger =
      _iotcon_presence_response_get_triggerPtr.asFunction<
          int Function(iotcon_presence_response_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets host address from the presence response handle.
  /// @since_tizen 3.0
  /// @remarks @a host_address must not be released using free().
  /// @param[in] response The handle of the presence response
  /// @param[out] host_address The host address of the presence response
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see iotcon_presence_response_get_result()
  /// @see iotcon_presence_response_get_trigger()
  /// @see iotcon_presence_response_get_connectivity_type()
  /// @see iotcon_presence_response_get_resource_type()
  int iotcon_presence_response_get_host_address(
    iotcon_presence_response_h response,
    ffi.Pointer<ffi.Pointer<ffi.Char>> host_address,
  ) {
    return _iotcon_presence_response_get_host_address(
      response,
      host_address,
    );
  }

  late final _iotcon_presence_response_get_host_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_presence_response_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_presence_response_get_host_address');
  late final _iotcon_presence_response_get_host_address =
      _iotcon_presence_response_get_host_addressPtr.asFunction<
          int Function(iotcon_presence_response_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets connectivity type from the presence response handle.
  /// @details The @a connectivity_type could be one of #iotcon_connectivity_type_e.
  /// @since_tizen 3.0
  /// @param[in] response The handle of the presence response
  /// @param[out] connectivity_type The connectivity type of the presence response
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_presence_response_get_result()
  /// @see iotcon_presence_response_get_trigger()
  /// @see iotcon_presence_response_get_host_address()
  /// @see iotcon_presence_response_get_resource_type()
  int iotcon_presence_response_get_connectivity_type(
    iotcon_presence_response_h response,
    ffi.Pointer<ffi.Int32> connectivity_type,
  ) {
    return _iotcon_presence_response_get_connectivity_type(
      response,
      connectivity_type,
    );
  }

  late final _iotcon_presence_response_get_connectivity_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  iotcon_presence_response_h, ffi.Pointer<ffi.Int32>)>>(
      'iotcon_presence_response_get_connectivity_type');
  late final _iotcon_presence_response_get_connectivity_type =
      _iotcon_presence_response_get_connectivity_typePtr.asFunction<
          int Function(iotcon_presence_response_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets resource type from the presence response handle.
  /// @since_tizen 3.0
  /// @remarks @a resource_type must not be released using free().
  /// @param[in] response The handle of the presence response
  /// @param[out] resource_type The resource type of the presence response
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_presence_response_get_result()
  /// @see iotcon_presence_response_get_trigger()
  /// @see iotcon_presence_response_get_host_address()
  /// @see iotcon_presence_response_get_connectivity_type()
  int iotcon_presence_response_get_resource_type(
    iotcon_presence_response_h response,
    ffi.Pointer<ffi.Pointer<ffi.Char>> resource_type,
  ) {
    return _iotcon_presence_response_get_resource_type(
      response,
      resource_type,
    );
  }

  late final _iotcon_presence_response_get_resource_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_presence_response_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_presence_response_get_resource_type');
  late final _iotcon_presence_response_get_resource_type =
      _iotcon_presence_response_get_resource_typePtr.asFunction<
          int Function(iotcon_presence_response_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Finds resources asynchronously.
  /// @details Request to find a resource of @a host_address server with @a query.\n
  /// @a host_address could be #IOTCON_MULTICAST_ADDRESS for multicast.\n
  /// If succeeded to find the resource, iotcon_found_resource_cb() will be invoked with information of the resource.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks @a host_address should be in the format coap://address:port. \n
  /// (ex. coaps://[fe80::ae5a:14ff:fe24:b8fe]:12345, or coaps://192.168.1.10:12345)\n
  /// @a connectivity_type can be set with extra options.
  /// If @a connectivity_type is set without IOTCON_CONNECTIVITY_IPV4_ONLY
  /// and IOTCON_CONNECTIVITY_IPV6_ONLY, the resources are discovered by default setting
  /// of IoTivity(IPv6 is preferred over IPv4). \n
  /// If there are no preference options(PREFER_XXX), resources will reply using each of
  /// opened protocol(TCP/UDP).
  /// Therefore, you can get remote resource handles which include different host address,
  /// but indicates same resource. \n
  /// (coaps://192.168.0.2:1234/res/light, coaps+tcp://192.168.0.2/1235/res/light)
  /// @a query can be set using specific resource types, or resource interfaces.
  /// If @a query is NULL, every resource discovered is listed.
  /// @param[in] host_address The address or addressable name of server
  /// @param[in] connectivity_type The connectivity type
  /// @param[in] query The query specified as a filter for the resource
  /// @param[in] cb The callback function to invoke
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post iotcon_found_resource_cb() will be invoked.
  /// @see iotcon_found_resource_cb()
  /// @see iotcon_set_timeout()
  int iotcon_find_resource(
    ffi.Pointer<ffi.Char> host_address,
    int connectivity_type,
    iotcon_query_h query,
    iotcon_found_resource_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_find_resource(
      host_address,
      connectivity_type,
      query,
      cb,
      user_data,
    );
  }

  late final _iotcon_find_resourcePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              iotcon_query_h,
              iotcon_found_resource_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_find_resource');
  late final _iotcon_find_resource = _iotcon_find_resourcePtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, int, iotcon_query_h,
          iotcon_found_resource_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Finds the device information of remote server asynchronously.
  /// @details Request device information to server and pass the information by calling iotcon_device_info_cb(). \n
  /// @a host_address could be #IOTCON_MULTICAST_ADDRESS for multicast. \n
  /// If succeeded in getting device information, iotcon_device_info_cb() will be invoked with information.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks @a host_address should be in the format coap://address:port. \n
  /// (ex. coap://[fe80::ae5a:14ff:fe24:b8fe]:12345, or coap://192.168.1.10:12345) \n
  /// @a connectivity_type can be set with extra options.
  /// If @a connectivity_type is set without IOTCON_CONNECTIVITY_IPV4_ONLY
  /// and IOTCON_CONNECTIVITY_IPV6_ONLY, device informations are discovered by default setting
  /// of IoTivity(IPv6 is preferred over IPv4). \n
  /// If there are no preference options(PREFER_XXX), it will reply using UDP.
  /// @param[in] host_address The host address of remote server
  /// @param[in] connectivity_type The connectivity type
  /// @param[in] query The query specified as a filter for the device information
  /// @param[in] cb The callback function to invoke
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post iotcon_device_info_cb() will be invoked.
  /// @see iotcon_set_device_name()
  /// @see iotcon_device_info_cb()
  /// @see iotcon_device_info_get_property()
  /// @see iotcon_set_timeout()
  int iotcon_find_device_info(
    ffi.Pointer<ffi.Char> host_address,
    int connectivity_type,
    iotcon_query_h query,
    iotcon_device_info_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_find_device_info(
      host_address,
      connectivity_type,
      query,
      cb,
      user_data,
    );
  }

  late final _iotcon_find_device_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              iotcon_query_h,
              iotcon_device_info_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_find_device_info');
  late final _iotcon_find_device_info = _iotcon_find_device_infoPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, int, iotcon_query_h,
          iotcon_device_info_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets device properties from the device information handle.
  /// @since_tizen 3.0
  /// @remarks @a value must not be released using free().
  /// @param[in] device_info The handle of the device information
  /// @param[in] property The properties of the device information
  /// @param[out] value The value of the property
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_set_device_name()
  /// @see iotcon_device_info_cb()
  /// @see iotcon_find_device_info()
  int iotcon_device_info_get_property(
    iotcon_device_info_h device_info,
    int property,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _iotcon_device_info_get_property(
      device_info,
      property,
      value,
    );
  }

  late final _iotcon_device_info_get_propertyPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_device_info_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_device_info_get_property');
  late final _iotcon_device_info_get_property =
      _iotcon_device_info_get_propertyPtr.asFunction<
          int Function(
              iotcon_device_info_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Finds the platform information of remote server asynchronously.
  /// @details Request platform information to server and pass the information by calling iotcon_platform_info_cb(). \n
  /// @a host_address could be #IOTCON_MULTICAST_ADDRESS for multicast. \n
  /// If succeeded in getting platform information, iotcon_platform_info_cb() will be invoked with information.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks @a host_address should be in the format coap://address:port. \n
  /// (ex. coap://[fe80::ae5a:14ff:fe24:b8fe]:12345, or coap://192.168.1.10:12345) \n
  /// @a connectivity_type can be set with extra options.
  /// If @a connectivity_type is set without IOTCON_CONNECTIVITY_IPV4_ONLY
  /// and IOTCON_CONNECTIVITY_IPV6_ONLY, platform informations are discovered by default setting
  /// of IoTivity(IPv6 is preferred over IPv4). \n
  /// If there are no preference options(PREFER_XXX), it will reply using UDP.
  /// @param[in] host_address The host address of remote server
  /// @param[in] connectivity_type The connectivity type
  /// @param[in] query The query specified as a filter for the platform information
  /// @param[in] cb The callback function to invoke
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_SYSTEM System error
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post iotcon_platform_info_cb() will be invoked.
  /// @see iotcon_platform_info_cb()
  /// @see iotcon_platform_info_get_property()
  /// @see iotcon_set_timeout()
  int iotcon_find_platform_info(
    ffi.Pointer<ffi.Char> host_address,
    int connectivity_type,
    iotcon_query_h query,
    iotcon_platform_info_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_find_platform_info(
      host_address,
      connectivity_type,
      query,
      cb,
      user_data,
    );
  }

  late final _iotcon_find_platform_infoPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              iotcon_query_h,
              iotcon_platform_info_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_find_platform_info');
  late final _iotcon_find_platform_info =
      _iotcon_find_platform_infoPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, iotcon_query_h,
              iotcon_platform_info_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets platform properties from the platform information handle.
  /// @since_tizen 3.0
  /// @remarks @a value must not be released using free().
  /// @param[in] platform_info The handle of the platform information
  /// @param[in] property The properties of the platform information
  /// @param[out] value The value of the property
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @see iotcon_platform_info_cb()
  /// @see iotcon_find_platform_info()
  int iotcon_platform_info_get_property(
    iotcon_platform_info_h platform_info,
    int property,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _iotcon_platform_info_get_property(
      platform_info,
      property,
      value,
    );
  }

  late final _iotcon_platform_info_get_propertyPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(iotcon_platform_info_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'iotcon_platform_info_get_property');
  late final _iotcon_platform_info_get_property =
      _iotcon_platform_info_get_propertyPtr.asFunction<
          int Function(iotcon_platform_info_h, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Initializes IoTCon.
  /// @details Calls this function to start IoTCon.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks The @a file_path point to a file for handling secure virtual resources.
  /// The file that is CBOR(Concise Binary Object Representation)-format must already exist in @a file_path.
  /// We recommend to use application-local file for @a file_path. \n
  /// You must call iotcon_deinitialize() if IoTCon API is no longer needed.
  /// @param[in] file_path The path of SVR(Secure Virtual Resources) DB
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_PERMISSION_DENIED Permission denied
  /// @see iotcon_deinitialize()
  int iotcon_initialize(
    ffi.Pointer<ffi.Char> file_path,
  ) {
    return _iotcon_initialize(
      file_path,
    );
  }

  late final _iotcon_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'iotcon_initialize');
  late final _iotcon_initialize =
      _iotcon_initializePtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Deinitializes IoTCon.
  /// @details Frees the resources allocated to IoTCon.
  /// @since_tizen 3.0
  /// @remarks This function must be called if IoTCon API is no longer needed.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_initialize()
  int iotcon_deinitialize() {
    return _iotcon_deinitialize();
  }

  late final _iotcon_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('iotcon_deinitialize');
  late final _iotcon_deinitialize =
      _iotcon_deinitializePtr.asFunction<int Function()>();

  /// @brief Gets the timeout seconds of asynchronous API.
  /// @details This API get the timeout of iotcon_find_device_info(),
  /// iotcon_find_platform_info(), iotcon_find_resource(),
  /// iotcon_remote_resource_get(), iotcon_remote_resource_put(),
  /// iotcon_remote_resource_post() and iotcon_remote_resource_delete().
  /// @since_tizen 3.0
  /// @param[out] timeout_seconds Seconds for timeout
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_set_timeout()
  int iotcon_get_timeout(
    ffi.Pointer<ffi.Int> timeout_seconds,
  ) {
    return _iotcon_get_timeout(
      timeout_seconds,
    );
  }

  late final _iotcon_get_timeoutPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'iotcon_get_timeout');
  late final _iotcon_get_timeout =
      _iotcon_get_timeoutPtr.asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the timeout seconds of asynchronous APIs.
  /// @details This API set the timeout of iotcon_find_device_info(),
  /// iotcon_find_platform_info(), iotcon_find_resource(),
  /// iotcon_remote_resource_get(), iotcon_remote_resource_put(),
  /// iotcon_remote_resource_post() and iotcon_remote_resource_delete().\n
  /// Default timeout interval value is 30.
  /// @since_tizen 3.0
  /// @param[in] timeout_seconds Seconds for timeout (must be in range from 1 to 3600)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_get_timeout()
  int iotcon_set_timeout(
    int timeout_seconds,
  ) {
    return _iotcon_set_timeout(
      timeout_seconds,
    );
  }

  late final _iotcon_set_timeoutPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'iotcon_set_timeout');
  late final _iotcon_set_timeout =
      _iotcon_set_timeoutPtr.asFunction<int Function(int)>();

  /// @brief Gets the polling interval(milliseconds) of IoTCon.
  /// @details This API gets the polling interval of IoTCon.
  /// Default polling interval is 100 milliseconds.
  /// @since_tizen 3.0
  /// @param[out] interval Milliseconds for polling interval
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_set_timeout()
  int iotcon_polling_get_interval(
    ffi.Pointer<ffi.Int> interval,
  ) {
    return _iotcon_polling_get_interval(
      interval,
    );
  }

  late final _iotcon_polling_get_intervalPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'iotcon_polling_get_interval');
  late final _iotcon_polling_get_interval = _iotcon_polling_get_intervalPtr
      .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the polling interval(milliseconds) of IoTCon.
  /// @details This API sets the polling interval of IoTCon.
  /// The closer to 0, the faster it operates. It is invoked immediately for changing the interval.
  /// Default polling interval is 100 milliseconds. If you want the faster operation,
  /// we recommend you set 10 milliseconds for polling interval.
  /// @since_tizen 3.0
  /// @param[in] interval Milliseconds for polling interval (must be in range from 1 to 999)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_polling_get_interval()
  int iotcon_polling_set_interval(
    int interval,
  ) {
    return _iotcon_polling_set_interval(
      interval,
    );
  }

  late final _iotcon_polling_set_intervalPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'iotcon_polling_set_interval');
  late final _iotcon_polling_set_interval =
      _iotcon_polling_set_intervalPtr.asFunction<int Function(int)>();

  /// @brief Invokes a next message from a queue for receiving messages from others immediately.
  /// @details This API invokes a next message from a queue for receiving messages from others immediately. \n
  /// After calling the API, it continues the polling with existing interval.
  /// @since_tizen 3.0
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED Not supported
  /// @pre iotcon_initialize() should be called to initialize.
  int iotcon_polling_invoke() {
    return _iotcon_polling_invoke();
  }

  late final _iotcon_polling_invokePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('iotcon_polling_invoke');
  late final _iotcon_polling_invoke =
      _iotcon_polling_invokePtr.asFunction<int Function()>();

  /// @brief Adds callback to show pin number which is generated automatically.
  /// @details When a provisioning tool tries to register this device using random pin based \n
  /// ownership transfer method, it makes pin number which is generated automatically be shown.
  /// @since_tizen 3.0
  /// @param[in] cb The callback function to invoke
  /// @param[in] user_data The user data to pass to the function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED  Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_ALREADY Already done
  /// @retval #IOTCON_ERROR_OUT_OF_MEMORY Out of memory
  /// @pre iotcon_initialize() should be called to initialize.
  /// @post When the device is registered by provisioning tool, iotcon_generated_pin_cb() will be called.
  /// @see iotcon_remove_generated_pin_cb()
  int iotcon_add_generated_pin_cb(
    iotcon_generated_pin_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _iotcon_add_generated_pin_cb(
      cb,
      user_data,
    );
  }

  late final _iotcon_add_generated_pin_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(iotcon_generated_pin_cb,
              ffi.Pointer<ffi.Void>)>>('iotcon_add_generated_pin_cb');
  late final _iotcon_add_generated_pin_cb =
      _iotcon_add_generated_pin_cbPtr.asFunction<
          int Function(iotcon_generated_pin_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Removes callback to show pin number which is generated automatically.
  /// @details If this function is called, @a cb will be not called anymore. \n
  /// For removing @a cb that is used at iotcon_add_generated_pin_cb() should be used.
  /// @since_tizen 3.0
  /// @param[in] cb The callback function to invoke
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IOTCON_ERROR_NONE Successful
  /// @retval #IOTCON_ERROR_NOT_SUPPORTED  Not supported
  /// @retval #IOTCON_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IOTCON_ERROR_NO_DATA No data available
  /// @pre iotcon_initialize() should be called to initialize.
  /// @see iotcon_add_generated_pin_cb()
  int iotcon_remove_generated_pin_cb(
    iotcon_generated_pin_cb cb,
  ) {
    return _iotcon_remove_generated_pin_cb(
      cb,
    );
  }

  late final _iotcon_remove_generated_pin_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(iotcon_generated_pin_cb)>>(
          'iotcon_remove_generated_pin_cb');
  late final _iotcon_remove_generated_pin_cb =
      _iotcon_remove_generated_pin_cbPtr
          .asFunction<int Function(iotcon_generated_pin_cb)>();

  /// @brief Initializes for using MTP.
  /// @since_tizen 3.0
  /// @remarks This function must be called before proceeding any other mtp functions.
  /// @remarks http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage. \n
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_PERMISSION_DENIED Permission Denied
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  ///
  /// @see mtp_deinitialize()
  int mtp_initialize() {
    return _mtp_initialize();
  }

  late final _mtp_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('mtp_initialize');
  late final _mtp_initialize = _mtp_initializePtr.asFunction<int Function()>();

  /// @brief Gets the mtp devices.
  /// @since_tizen 3.0
  /// @param [out] mtp_devices The MTP device list
  /// @param [out] device_count Length of device list
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  ///
  /// @see mtp_initialize()
  int mtp_get_devices(
    ffi.Pointer<ffi.Pointer<mtp_device_h>> mtp_devices,
    ffi.Pointer<ffi.Int> device_count,
  ) {
    return _mtp_get_devices(
      mtp_devices,
      device_count,
    );
  }

  late final _mtp_get_devicesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Pointer<mtp_device_h>>,
              ffi.Pointer<ffi.Int>)>>('mtp_get_devices');
  late final _mtp_get_devices = _mtp_get_devicesPtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Pointer<mtp_device_h>>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets mtp storages from the given device.
  /// @since_tizen 3.0
  /// @remarks The @a mtp_storages should be freed using free().
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [out] mtp_storages Current mtp storage list
  /// @param [out] storage_count Length of storage list
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  ///
  /// @see mtp_get_devices()
  int mtp_get_storages(
    int mtp_device,
    ffi.Pointer<ffi.Pointer<mtp_storage_h>> mtp_storages,
    ffi.Pointer<ffi.Int> storage_count,
  ) {
    return _mtp_get_storages(
      mtp_device,
      mtp_storages,
      storage_count,
    );
  }

  late final _mtp_get_storagesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mtp_device_h,
              ffi.Pointer<ffi.Pointer<mtp_storage_h>>,
              ffi.Pointer<ffi.Int>)>>('mtp_get_storages');
  late final _mtp_get_storages = _mtp_get_storagesPtr.asFunction<
      int Function(int, ffi.Pointer<ffi.Pointer<mtp_storage_h>>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Gets object handles from the given device and storage.
  /// @since_tizen 3.0
  /// @remarks The @a object_handles should be freed using free().
  /// @remarks If the @a parent is 0, it means "root folder" of mtp storage.
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] mtp_storage The MTP storage
  /// @param [in] file_type The file type what you want
  /// @param [in] parent The parent object handle
  /// @param [out] object_handles The object handle list
  /// @param [out] object_count Length of object handle list
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  ///
  /// @see mtp_get_devices()
  /// @see mtp_get_storages()
  int mtp_get_object_handles(
    int mtp_device,
    int mtp_storage,
    int file_type,
    int parent,
    ffi.Pointer<ffi.Pointer<mtp_object_h>> object_handles,
    ffi.Pointer<ffi.Int> object_count,
  ) {
    return _mtp_get_object_handles(
      mtp_device,
      mtp_storage,
      file_type,
      parent,
      object_handles,
      object_count,
    );
  }

  late final _mtp_get_object_handlesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mtp_device_h,
              mtp_storage_h,
              ffi.Int32,
              mtp_object_h,
              ffi.Pointer<ffi.Pointer<mtp_object_h>>,
              ffi.Pointer<ffi.Int>)>>('mtp_get_object_handles');
  late final _mtp_get_object_handles = _mtp_get_object_handlesPtr.asFunction<
      int Function(int, int, int, int, ffi.Pointer<ffi.Pointer<mtp_object_h>>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Gets object for a given path from object handle.
  /// @since_tizen 3.0
  /// @remarks The @a dest_path is host storage path.
  /// @remarks http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage. \n
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [in] dest_path The dest path
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_IO_ERROR I/O error
  /// @retval #MTP_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see mtp_get_devices()
  /// @see mtp_get_object_handles()
  int mtp_get_object(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Char> dest_path,
  ) {
    return _mtp_get_object(
      mtp_device,
      object_handle,
      dest_path,
    );
  }

  late final _mtp_get_objectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Char>)>>('mtp_get_object');
  late final _mtp_get_object = _mtp_get_objectPtr
      .asFunction<int Function(int, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets thumbnail from the given object handle.
  /// @since_tizen 3.0
  /// @remarks The @a dest_path is host storage path.
  /// @remarks http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage.
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [in] dest_path The dest path
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_IO_ERROR I/O error
  /// @retval #MTP_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see mtp_get_devices()
  /// @see mtp_get_object_handles()
  int mtp_get_thumbnail(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Char> dest_path,
  ) {
    return _mtp_get_thumbnail(
      mtp_device,
      object_handle,
      dest_path,
    );
  }

  late final _mtp_get_thumbnailPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Char>)>>('mtp_get_thumbnail');
  late final _mtp_get_thumbnail = _mtp_get_thumbnailPtr
      .asFunction<int Function(int, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Adds a callback function for receiving MTP event.
  /// @since_tizen 3.0
  /// @remarks You can register multiple callback. \n
  /// If you don't want to receive the event, then using the mtp_remove_mtp_event_cb() function to unregister a callback.
  /// @remarks If device state is changed, #MTP_EVENT_DEVICE_ADDED or #MTP_EVENT_DEVICE_REMOVED event is occur. \n
  /// If storage state is changed, #MTP_EVENT_STORAGE_ADDED or #MTP_EVENT_STORAGE_REMOVED event is occur. \n
  /// If object state is changed, #MTP_EVENT_OBJECT_ADDED or #MTP_EVENT_OBJECT_REMOVED event is occur. \n
  /// If mtp service is turned off, #MTP_EVENT_TURNED_OFF event is occur. \n
  ///
  /// @param [in] event_cb The callback
  /// @param [in] user_data The user data
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see mtp_remove_mtp_event_cb()
  int mtp_add_mtp_event_cb(
    mtp_event_cb event_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _mtp_add_mtp_event_cb(
      event_cb,
      user_data,
    );
  }

  late final _mtp_add_mtp_event_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              mtp_event_cb, ffi.Pointer<ffi.Void>)>>('mtp_add_mtp_event_cb');
  late final _mtp_add_mtp_event_cb = _mtp_add_mtp_event_cbPtr
      .asFunction<int Function(mtp_event_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Removes the callback function.
  /// @since_tizen 3.0
  ///
  /// @param [in] event_cb The callback
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  ///
  /// @see mtp_add_mtp_event_cb()
  int mtp_remove_mtp_event_cb(
    mtp_event_cb event_cb,
  ) {
    return _mtp_remove_mtp_event_cb(
      event_cb,
    );
  }

  late final _mtp_remove_mtp_event_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(mtp_event_cb)>>(
          'mtp_remove_mtp_event_cb');
  late final _mtp_remove_mtp_event_cb =
      _mtp_remove_mtp_event_cbPtr.asFunction<int Function(mtp_event_cb)>();

  /// @brief Deinitializes MTP operation.
  /// @since_tizen 3.0
  /// @remarks http://tizen.org/privilege/mediastorage is needed if input or output path are relevant to media storage.\n
  /// http://tizen.org/privilege/externalstorage is needed if input or output path are relevant to external storage. \n
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_PERMISSION_DENIED Permission Denied
  ///
  /// @see mtp_initialize()
  int mtp_deinitialize() {
    return _mtp_deinitialize();
  }

  late final _mtp_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('mtp_deinitialize');
  late final _mtp_deinitialize =
      _mtp_deinitializePtr.asFunction<int Function()>();

  /// @brief Gets the manufacturer name of the device information.
  /// @since_tizen 3.0
  /// @remarks The @a manufacturer_name should be freed using free().
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [out] manufacturer_name The manufacturer name of Device information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Memory Allocation failed
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  ///
  /// @see mtp_get_devices()
  int mtp_deviceinfo_get_manufacturer_name(
    int mtp_device,
    ffi.Pointer<ffi.Pointer<ffi.Char>> manufacturer_name,
  ) {
    return _mtp_deviceinfo_get_manufacturer_name(
      mtp_device,
      manufacturer_name,
    );
  }

  late final _mtp_deviceinfo_get_manufacturer_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mtp_device_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mtp_deviceinfo_get_manufacturer_name');
  late final _mtp_deviceinfo_get_manufacturer_name =
      _mtp_deviceinfo_get_manufacturer_namePtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the model name of the device information.
  /// @since_tizen 3.0
  /// @remarks The @a model_name should be freed using free().
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [out] model_name The model name of Device information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  ///
  /// @see mtp_get_devices()
  int mtp_deviceinfo_get_model_name(
    int mtp_device,
    ffi.Pointer<ffi.Pointer<ffi.Char>> model_name,
  ) {
    return _mtp_deviceinfo_get_model_name(
      mtp_device,
      model_name,
    );
  }

  late final _mtp_deviceinfo_get_model_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mtp_device_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mtp_deviceinfo_get_model_name');
  late final _mtp_deviceinfo_get_model_name = _mtp_deviceinfo_get_model_namePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the serial number of the device information.
  /// @since_tizen 3.0
  /// @remarks The @a serial_number should be freed using free().
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [out] serial_number The serial number of Device information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  ///
  /// @see mtp_get_devices()
  int mtp_deviceinfo_get_serial_number(
    int mtp_device,
    ffi.Pointer<ffi.Pointer<ffi.Char>> serial_number,
  ) {
    return _mtp_deviceinfo_get_serial_number(
      mtp_device,
      serial_number,
    );
  }

  late final _mtp_deviceinfo_get_serial_numberPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mtp_device_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mtp_deviceinfo_get_serial_number');
  late final _mtp_deviceinfo_get_serial_number =
      _mtp_deviceinfo_get_serial_numberPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the device version of the device information.
  /// @since_tizen 3.0
  /// @remarks The @a device_version should be freed using free().
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [out] device_version The device version of Device information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  ///
  /// @see mtp_get_devices()
  int mtp_deviceinfo_get_device_version(
    int mtp_device,
    ffi.Pointer<ffi.Pointer<ffi.Char>> device_version,
  ) {
    return _mtp_deviceinfo_get_device_version(
      mtp_device,
      device_version,
    );
  }

  late final _mtp_deviceinfo_get_device_versionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mtp_device_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mtp_deviceinfo_get_device_version');
  late final _mtp_deviceinfo_get_device_version =
      _mtp_deviceinfo_get_device_versionPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the description of the storage information.
  /// @since_tizen 3.0
  /// @remarks The @a description should be freed using free().
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] mtp_storage The MTP storage
  /// @param [out] description The description of Storage information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  ///
  /// @see mtp_get_storages()
  int mtp_storageinfo_get_description(
    int mtp_device,
    int mtp_storage,
    ffi.Pointer<ffi.Pointer<ffi.Char>> description,
  ) {
    return _mtp_storageinfo_get_description(
      mtp_device,
      mtp_storage,
      description,
    );
  }

  late final _mtp_storageinfo_get_descriptionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mtp_device_h, mtp_storage_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mtp_storageinfo_get_description');
  late final _mtp_storageinfo_get_description =
      _mtp_storageinfo_get_descriptionPtr.asFunction<
          int Function(int, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the free space of the storage information in bytes.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] mtp_storage The MTP storage
  /// @param [out] free_space The free space of Storage information (bytes)
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  ///
  /// @see mtp_get_storages()
  int mtp_storageinfo_get_free_space(
    int mtp_device,
    int mtp_storage,
    ffi.Pointer<ffi.UnsignedLongLong> free_space,
  ) {
    return _mtp_storageinfo_get_free_space(
      mtp_device,
      mtp_storage,
      free_space,
    );
  }

  late final _mtp_storageinfo_get_free_spacePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mtp_device_h, mtp_storage_h,
                  ffi.Pointer<ffi.UnsignedLongLong>)>>(
      'mtp_storageinfo_get_free_space');
  late final _mtp_storageinfo_get_free_space =
      _mtp_storageinfo_get_free_spacePtr.asFunction<
          int Function(int, int, ffi.Pointer<ffi.UnsignedLongLong>)>();

  /// @brief Gets the max capacity of the storage information in bytes.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] mtp_storage The MTP storage
  /// @param [out] max_capacity The max capacity of Storage information (bytes)
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  ///
  /// @see mtp_get_storages()
  int mtp_storageinfo_get_max_capacity(
    int mtp_device,
    int mtp_storage,
    ffi.Pointer<ffi.UnsignedLongLong> max_capacity,
  ) {
    return _mtp_storageinfo_get_max_capacity(
      mtp_device,
      mtp_storage,
      max_capacity,
    );
  }

  late final _mtp_storageinfo_get_max_capacityPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mtp_device_h, mtp_storage_h,
                  ffi.Pointer<ffi.UnsignedLongLong>)>>(
      'mtp_storageinfo_get_max_capacity');
  late final _mtp_storageinfo_get_max_capacity =
      _mtp_storageinfo_get_max_capacityPtr.asFunction<
          int Function(int, int, ffi.Pointer<ffi.UnsignedLongLong>)>();

  /// @brief Gets the storage type of the storage information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] mtp_storage The MTP storage
  /// @param [out] storage_type The storage type of Storage information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  ///
  /// @see mtp_get_storages()
  int mtp_storageinfo_get_storage_type(
    int mtp_device,
    int mtp_storage,
    ffi.Pointer<ffi.Int32> storage_type,
  ) {
    return _mtp_storageinfo_get_storage_type(
      mtp_device,
      mtp_storage,
      storage_type,
    );
  }

  late final _mtp_storageinfo_get_storage_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_storage_h,
              ffi.Pointer<ffi.Int32>)>>('mtp_storageinfo_get_storage_type');
  late final _mtp_storageinfo_get_storage_type =
      _mtp_storageinfo_get_storage_typePtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the volume identifier of the storage information.
  /// @since_tizen 3.0
  /// @remarks The @a volume_identifier should be freed using free().
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] mtp_storage The MTP storage
  /// @param [out] volume_identifier The volume identifier of Storage information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  ///
  /// @see mtp_get_object_handles()
  int mtp_storageinfo_get_volume_identifier(
    int mtp_device,
    int mtp_storage,
    ffi.Pointer<ffi.Pointer<ffi.Char>> volume_identifier,
  ) {
    return _mtp_storageinfo_get_volume_identifier(
      mtp_device,
      mtp_storage,
      volume_identifier,
    );
  }

  late final _mtp_storageinfo_get_volume_identifierPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mtp_device_h, mtp_storage_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mtp_storageinfo_get_volume_identifier');
  late final _mtp_storageinfo_get_volume_identifier =
      _mtp_storageinfo_get_volume_identifierPtr.asFunction<
          int Function(int, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the filename of the object information.
  /// @since_tizen 3.0
  /// @remarks The @a file_name should be freed using free().
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] file_name The file name of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_file_name(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> file_name,
  ) {
    return _mtp_objectinfo_get_file_name(
      mtp_device,
      object_handle,
      file_name,
    );
  }

  late final _mtp_objectinfo_get_file_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mtp_device_h, mtp_object_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mtp_objectinfo_get_file_name');
  late final _mtp_objectinfo_get_file_name = _mtp_objectinfo_get_file_namePtr
      .asFunction<int Function(int, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the keywords of the object information.
  /// @since_tizen 3.0
  /// @remarks The @a keywords should be freed using free().
  /// @remarks The keywords are separated by comma.
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] keywords The keywords of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_keywords(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> keywords,
  ) {
    return _mtp_objectinfo_get_keywords(
      mtp_device,
      object_handle,
      keywords,
    );
  }

  late final _mtp_objectinfo_get_keywordsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(mtp_device_h, mtp_object_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'mtp_objectinfo_get_keywords');
  late final _mtp_objectinfo_get_keywords = _mtp_objectinfo_get_keywordsPtr
      .asFunction<int Function(int, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the association desc of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] asso_desc The association description of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_association_desc(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> asso_desc,
  ) {
    return _mtp_objectinfo_get_association_desc(
      mtp_device,
      object_handle,
      asso_desc,
    );
  }

  late final _mtp_objectinfo_get_association_descPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int>)>>('mtp_objectinfo_get_association_desc');
  late final _mtp_objectinfo_get_association_desc =
      _mtp_objectinfo_get_association_descPtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the association type of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] asso_type The association type of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_association_type(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> asso_type,
  ) {
    return _mtp_objectinfo_get_association_type(
      mtp_device,
      object_handle,
      asso_type,
    );
  }

  late final _mtp_objectinfo_get_association_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int>)>>('mtp_objectinfo_get_association_type');
  late final _mtp_objectinfo_get_association_type =
      _mtp_objectinfo_get_association_typePtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the size of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] size The size of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_size(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> size,
  ) {
    return _mtp_objectinfo_get_size(
      mtp_device,
      object_handle,
      size,
    );
  }

  late final _mtp_objectinfo_get_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int>)>>('mtp_objectinfo_get_size');
  late final _mtp_objectinfo_get_size = _mtp_objectinfo_get_sizePtr
      .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the parent object handle of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] parent_object_handle The parent of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_parent_object_handle(
    int mtp_device,
    int object_handle,
    ffi.Pointer<mtp_object_h> parent_object_handle,
  ) {
    return _mtp_objectinfo_get_parent_object_handle(
      mtp_device,
      object_handle,
      parent_object_handle,
    );
  }

  late final _mtp_objectinfo_get_parent_object_handlePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mtp_device_h, mtp_object_h, ffi.Pointer<mtp_object_h>)>>(
      'mtp_objectinfo_get_parent_object_handle');
  late final _mtp_objectinfo_get_parent_object_handle =
      _mtp_objectinfo_get_parent_object_handlePtr
          .asFunction<int Function(int, int, ffi.Pointer<mtp_object_h>)>();

  /// @brief Gets the mtp storage of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] mtp_storage The MTP storage of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_storage(
    int mtp_device,
    int object_handle,
    ffi.Pointer<mtp_storage_h> mtp_storage,
  ) {
    return _mtp_objectinfo_get_storage(
      mtp_device,
      object_handle,
      mtp_storage,
    );
  }

  late final _mtp_objectinfo_get_storagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<mtp_storage_h>)>>('mtp_objectinfo_get_storage');
  late final _mtp_objectinfo_get_storage = _mtp_objectinfo_get_storagePtr
      .asFunction<int Function(int, int, ffi.Pointer<mtp_storage_h>)>();

  /// @brief Gets the object created time of the object information.
  /// @since_tizen 3.0
  /// @remarks When interpreted as an absolute time value, \n
  /// @a data_created represents the number of seconds elapsed since the Epoch, 1970-01-01 00:00:00 +0000 (UTC).
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] date_created The object created time of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_date_created(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> date_created,
  ) {
    return _mtp_objectinfo_get_date_created(
      mtp_device,
      object_handle,
      date_created,
    );
  }

  late final _mtp_objectinfo_get_date_createdPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int>)>>('mtp_objectinfo_get_date_created');
  late final _mtp_objectinfo_get_date_created =
      _mtp_objectinfo_get_date_createdPtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the object modified time of the object information.
  /// @since_tizen 3.0
  /// @remarks When interpreted as an absolute time value, \n
  /// @a data_modified represents the number of seconds elapsed since the Epoch, 1970-01-01 00:00:00 +0000 (UTC).
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] date_modified The object modified time of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_date_modified(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> date_modified,
  ) {
    return _mtp_objectinfo_get_date_modified(
      mtp_device,
      object_handle,
      date_modified,
    );
  }

  late final _mtp_objectinfo_get_date_modifiedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int>)>>('mtp_objectinfo_get_date_modified');
  late final _mtp_objectinfo_get_date_modified =
      _mtp_objectinfo_get_date_modifiedPtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the file type of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] file_type The file type of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_file_type(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int32> file_type,
  ) {
    return _mtp_objectinfo_get_file_type(
      mtp_device,
      object_handle,
      file_type,
    );
  }

  late final _mtp_objectinfo_get_file_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int32>)>>('mtp_objectinfo_get_file_type');
  late final _mtp_objectinfo_get_file_type = _mtp_objectinfo_get_file_typePtr
      .asFunction<int Function(int, int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the image bit depth of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] depth The image bit depth of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_image_bit_depth(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> depth,
  ) {
    return _mtp_objectinfo_get_image_bit_depth(
      mtp_device,
      object_handle,
      depth,
    );
  }

  late final _mtp_objectinfo_get_image_bit_depthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int>)>>('mtp_objectinfo_get_image_bit_depth');
  late final _mtp_objectinfo_get_image_bit_depth =
      _mtp_objectinfo_get_image_bit_depthPtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the image pixel width of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] width The image pixel width of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_image_pix_width(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> width,
  ) {
    return _mtp_objectinfo_get_image_pix_width(
      mtp_device,
      object_handle,
      width,
    );
  }

  late final _mtp_objectinfo_get_image_pix_widthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int>)>>('mtp_objectinfo_get_image_pix_width');
  late final _mtp_objectinfo_get_image_pix_width =
      _mtp_objectinfo_get_image_pix_widthPtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the image pixel height of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] height The image pixel height of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_image_pix_height(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _mtp_objectinfo_get_image_pix_height(
      mtp_device,
      object_handle,
      height,
    );
  }

  late final _mtp_objectinfo_get_image_pix_heightPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int>)>>('mtp_objectinfo_get_image_pix_height');
  late final _mtp_objectinfo_get_image_pix_height =
      _mtp_objectinfo_get_image_pix_heightPtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the thumbnail size of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] size The thumbnail size of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_thumbnail_size(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> size,
  ) {
    return _mtp_objectinfo_get_thumbnail_size(
      mtp_device,
      object_handle,
      size,
    );
  }

  late final _mtp_objectinfo_get_thumbnail_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int>)>>('mtp_objectinfo_get_thumbnail_size');
  late final _mtp_objectinfo_get_thumbnail_size =
      _mtp_objectinfo_get_thumbnail_sizePtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the thumbnail file type of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] file_type The file type of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_thumbnail_file_type(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int32> file_type,
  ) {
    return _mtp_objectinfo_get_thumbnail_file_type(
      mtp_device,
      object_handle,
      file_type,
    );
  }

  late final _mtp_objectinfo_get_thumbnail_file_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mtp_device_h, mtp_object_h, ffi.Pointer<ffi.Int32>)>>(
      'mtp_objectinfo_get_thumbnail_file_type');
  late final _mtp_objectinfo_get_thumbnail_file_type =
      _mtp_objectinfo_get_thumbnail_file_typePtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the thumbnail pixel height of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] height The thumbnail pixel height of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_thumbnail_pix_height(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _mtp_objectinfo_get_thumbnail_pix_height(
      mtp_device,
      object_handle,
      height,
    );
  }

  late final _mtp_objectinfo_get_thumbnail_pix_heightPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  mtp_device_h, mtp_object_h, ffi.Pointer<ffi.Int>)>>(
      'mtp_objectinfo_get_thumbnail_pix_height');
  late final _mtp_objectinfo_get_thumbnail_pix_height =
      _mtp_objectinfo_get_thumbnail_pix_heightPtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the thumbnail pixel width of the object information.
  /// @since_tizen 3.0
  ///
  /// @param [in] mtp_device The MTP device
  /// @param [in] object_handle The object handle
  /// @param [out] width The thumbnail pixel width of Object information
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #MTP_ERROR_NONE Successful
  /// @retval #MTP_ERROR_NOT_SUPPORTED MTP is not supported
  /// @retval #MTP_ERROR_NOT_INITIALIZED MTP is not initialized
  /// @retval #MTP_ERROR_NOT_ACTIVATED MTP is not activated
  /// @retval #MTP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #MTP_ERROR_NOT_COMM_INITIALIZED MTP communication is not initialized
  /// @retval #MTP_ERROR_COMM_ERROR MTP communication error
  /// @retval #MTP_ERROR_CONTROLLER MTP controller error
  /// @retval #MTP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #MTP_ERROR_NO_DEVICE MTP have not any device
  /// @retval #MTP_ERROR_PLUGIN_FAIL Plugin failed
  ///
  /// @see mtp_get_object_handles()
  int mtp_objectinfo_get_thumbnail_pix_width(
    int mtp_device,
    int object_handle,
    ffi.Pointer<ffi.Int> width,
  ) {
    return _mtp_objectinfo_get_thumbnail_pix_width(
      mtp_device,
      object_handle,
      width,
    );
  }

  late final _mtp_objectinfo_get_thumbnail_pix_widthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(mtp_device_h, mtp_object_h,
              ffi.Pointer<ffi.Int>)>>('mtp_objectinfo_get_thumbnail_pix_width');
  late final _mtp_objectinfo_get_thumbnail_pix_width =
      _mtp_objectinfo_get_thumbnail_pix_widthPtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Initializes SSDP.
  /// @since_tizen 3.0
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_OPERATION_FAILED Operation failed
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  int ssdp_initialize() {
    return _ssdp_initialize();
  }

  late final _ssdp_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('ssdp_initialize');
  late final _ssdp_initialize =
      _ssdp_initializePtr.asFunction<int Function()>();

  /// @brief Deinitializes SSDP.
  /// @since_tizen 3.0
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  int ssdp_deinitialize() {
    return _ssdp_deinitialize();
  }

  late final _ssdp_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('ssdp_deinitialize');
  late final _ssdp_deinitialize =
      _ssdp_deinitializePtr.asFunction<int Function()>();

  /// @brief Creates a SSDP local service handle.
  /// @since_tizen 3.0
  /// @remarks You must release @a local_service using ssdp_destroy_local_service().
  /// @param[in] target The SSDP local service's target. It may be a device type or a service type specified in UPnP forum (http://upnp.org)
  /// @param[out] local_service The SSDP local service handle
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  /// @see ssdp_destroy_local_service()
  /// @pre This API needs ssdp_initialize() before use.
  int ssdp_create_local_service(
    ffi.Pointer<ffi.Char> target,
    ffi.Pointer<ssdp_service_h> local_service,
  ) {
    return _ssdp_create_local_service(
      target,
      local_service,
    );
  }

  late final _ssdp_create_local_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ssdp_service_h>)>>('ssdp_create_local_service');
  late final _ssdp_create_local_service =
      _ssdp_create_local_servicePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ssdp_service_h>)>();

  /// @brief Destroys the SSDP local service handle.
  /// @details You must call ssdp_deregister_local_service() before destroying the local service.
  /// @since_tizen 3.0
  /// @param[in] local_service The SSDP local service handle
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_SERVICE_NOT_FOUND Service not found
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  /// @see ssdp_create_local_service()
  int ssdp_destroy_local_service(
    int local_service,
  ) {
    return _ssdp_destroy_local_service(
      local_service,
    );
  }

  late final _ssdp_destroy_local_servicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ssdp_service_h)>>(
          'ssdp_destroy_local_service');
  late final _ssdp_destroy_local_service =
      _ssdp_destroy_local_servicePtr.asFunction<int Function(int)>();

  /// @brief Sets the USN (Unique Service Name) of SSDP local service. The USN format is specified in UPnP forum (http://upnp.org).
  /// @since_tizen 3.0
  /// @remarks You must pass only @a unregistered local_service created using ssdp_create_local_service().
  /// If @a local_service is already registered, you cannot set @a usn.
  /// @param[in] local_service The SSDP local service handle
  /// @param[in] usn The USN of SSDP local service
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_SERVICE_NOT_FOUND Service not found
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  int ssdp_service_set_usn(
    int local_service,
    ffi.Pointer<ffi.Char> usn,
  ) {
    return _ssdp_service_set_usn(
      local_service,
      usn,
    );
  }

  late final _ssdp_service_set_usnPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ssdp_service_h, ffi.Pointer<ffi.Char>)>>('ssdp_service_set_usn');
  late final _ssdp_service_set_usn = _ssdp_service_set_usnPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the URL (Uniform Resource Locator) for description of SSDP local service. See RFC 3986.
  /// @since_tizen 3.0
  /// @remarks You must pass only unregistered @a local_service created using ssdp_create_local_service().
  /// If @a local_service is already registered, you cannot set @a url.
  /// @param[in] local_service The SSDP local service handle
  /// @param[in] url The URL of SSDP local service
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_SERVICE_NOT_FOUND Service not found
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  int ssdp_service_set_url(
    int local_service,
    ffi.Pointer<ffi.Char> url,
  ) {
    return _ssdp_service_set_url(
      local_service,
      url,
    );
  }

  late final _ssdp_service_set_urlPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ssdp_service_h, ffi.Pointer<ffi.Char>)>>('ssdp_service_set_url');
  late final _ssdp_service_set_url = _ssdp_service_set_urlPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the target of SSDP service.
  /// @since_tizen 3.0
  /// @remarks You must release @a target using free().
  /// @param[in] service The SSDP service handle
  /// @param[out] target The target of SSDP service
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_SERVICE_NOT_FOUND Service not found
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  int ssdp_service_get_target(
    int service,
    ffi.Pointer<ffi.Pointer<ffi.Char>> target,
  ) {
    return _ssdp_service_get_target(
      service,
      target,
    );
  }

  late final _ssdp_service_get_targetPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ssdp_service_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('ssdp_service_get_target');
  late final _ssdp_service_get_target = _ssdp_service_get_targetPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the USN of SSDP service.
  /// @since_tizen 3.0
  /// @remarks You must release @a usn using free().
  /// @param[in] service The SSDP service handle
  /// @param[out] usn The USN of SSDP service
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_SERVICE_NOT_FOUND Service not found
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  int ssdp_service_get_usn(
    int service,
    ffi.Pointer<ffi.Pointer<ffi.Char>> usn,
  ) {
    return _ssdp_service_get_usn(
      service,
      usn,
    );
  }

  late final _ssdp_service_get_usnPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ssdp_service_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('ssdp_service_get_usn');
  late final _ssdp_service_get_usn = _ssdp_service_get_usnPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the URL of SSDP service.
  /// @since_tizen 3.0
  /// @remarks You must release @a url using free().
  /// @param[in] service The SSDP service handle
  /// @param[out] url The URL of SSDP service
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_SERVICE_NOT_FOUND Service not found
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  int ssdp_service_get_url(
    int service,
    ffi.Pointer<ffi.Pointer<ffi.Char>> url,
  ) {
    return _ssdp_service_get_url(
      service,
      url,
    );
  }

  late final _ssdp_service_get_urlPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ssdp_service_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('ssdp_service_get_url');
  late final _ssdp_service_get_url = _ssdp_service_get_urlPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Registers the SSDP local service for publishing.
  /// @details You must set a USN and a URL of the local service before ssdp_register_local_service() is called.
  /// @since_tizen 3.0
  /// @remarks You must pass only local_service created using ssdp_create_local_service().
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] local_service The SSDP local service handle
  /// @param[in] registered_cb The callback function to be called
  /// @param[in] user_data The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_SERVICE_NOT_FOUND Service not found
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_OPERATION_FAILED Operation failed
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SSDP_ERROR_SERVICE_ALREADY_REGISTERED Service already registered
  /// @retval #SSDP_ERROR_PERMISSION_DENIED Permission Denied
  /// @pre This API needs ssdp_service_set_usn() and ssdp_service_set_url() before use.
  int ssdp_register_local_service(
    int local_service,
    ssdp_registered_cb registered_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ssdp_register_local_service(
      local_service,
      registered_cb,
      user_data,
    );
  }

  late final _ssdp_register_local_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ssdp_service_h, ssdp_registered_cb,
              ffi.Pointer<ffi.Void>)>>('ssdp_register_local_service');
  late final _ssdp_register_local_service =
      _ssdp_register_local_servicePtr.asFunction<
          int Function(int, ssdp_registered_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Deregisters the SSDP local service.
  /// @since_tizen 3.0
  /// @remarks You must pass only local_service created using ssdp_create_local_service().
  /// @param[in] local_service The SSDP local service handle
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_SERVICE_NOT_FOUND Service not found
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  int ssdp_deregister_local_service(
    int local_service,
  ) {
    return _ssdp_deregister_local_service(
      local_service,
    );
  }

  late final _ssdp_deregister_local_servicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ssdp_service_h)>>(
          'ssdp_deregister_local_service');
  late final _ssdp_deregister_local_service =
      _ssdp_deregister_local_servicePtr.asFunction<int Function(int)>();

  /// @brief Starts browsing the SSDP remote service.
  /// @details ssdp_start_browsing_service() keeps browsing services until calling ssdp_stop_browsing_service().
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @param[in] target The target to browse
  /// @param[out] ssdp_browser The SSDP browser handle
  /// @param[in] found_cb The callback function to be called
  /// @param[in] user_data The user data passed to the callback function
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_SERVICE_NOT_FOUND Service not found
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_OPERATION_FAILED Operation failed
  /// @retval #SSDP_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SSDP_ERROR_PERMISSION_DENIED Permission Denied
  int ssdp_start_browsing_service(
    ffi.Pointer<ffi.Char> target,
    ffi.Pointer<ssdp_browser_h> ssdp_browser,
    ssdp_found_cb found_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ssdp_start_browsing_service(
      target,
      ssdp_browser,
      found_cb,
      user_data,
    );
  }

  late final _ssdp_start_browsing_servicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ssdp_browser_h>,
              ssdp_found_cb,
              ffi.Pointer<ffi.Void>)>>('ssdp_start_browsing_service');
  late final _ssdp_start_browsing_service =
      _ssdp_start_browsing_servicePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ssdp_browser_h>,
              ssdp_found_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Stops browsing the SSDP remote service.
  /// @since_tizen 3.0
  /// @param[in] ssdp_browser The SSDP browser handle
  /// @return @c 0 on success,
  /// otherwise negative error value
  /// @retval #SSDP_ERROR_NONE Successful
  /// @retval #SSDP_ERROR_NOT_INITIALIZED Not initialized
  /// @retval #SSDP_ERROR_SERVICE_NOT_FOUND Service not found
  /// @retval #SSDP_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #SSDP_ERROR_NOT_SUPPORTED Not supported
  int ssdp_stop_browsing_service(
    int ssdp_browser,
  ) {
    return _ssdp_stop_browsing_service(
      ssdp_browser,
    );
  }

  late final _ssdp_stop_browsing_servicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ssdp_browser_h)>>(
          'ssdp_stop_browsing_service');
  late final _ssdp_stop_browsing_service =
      _ssdp_stop_browsing_servicePtr.asFunction<int Function(int)>();

  /// @brief Initializes smartcard service
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_SE_SERVICE_MODULE
  ///
  /// @remarks This function must be called before proceeding any other smartcard function
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_deinitialize()
  int smartcard_initialize() {
    return _smartcard_initialize();
  }

  late final _smartcard_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('smartcard_initialize');
  late final _smartcard_initialize =
      _smartcard_initializePtr.asFunction<int Function()>();

  /// @brief Deinitializes smartcard service
  /// @details Releases all the resource of the smartcard service
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_SE_SERVICE_MODULE
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_initialize()
  int smartcard_deinitialize() {
    return _smartcard_deinitialize();
  }

  late final _smartcard_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('smartcard_deinitialize');
  late final _smartcard_deinitialize =
      _smartcard_deinitializePtr.asFunction<int Function()>();

  /// @brief Gets the version of SIMAlliance OpenMobileAPI specification
  /// @since_tizen 3.0
  /// @ingroup CAPI_NETWORK_SMARTCARD_SE_SERVICE_MODULE
  ///
  /// @remarks The @a version must be released using free().
  ///
  /// @param [out] version The version of SIMAlliance OpenMobileAPI specification
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_OUT_OF_MEMORY Out of memory
  int smartcard_get_version(
    ffi.Pointer<ffi.Pointer<ffi.Char>> version,
  ) {
    return _smartcard_get_version(
      version,
    );
  }

  late final _smartcard_get_versionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('smartcard_get_version');
  late final _smartcard_get_version = _smartcard_get_versionPtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the list of available Secure Element readers.
  /// @since_tizen 2.3.1
  /// @ingroup CAPI_NETWORK_SMARTCARD_SE_SERVICE_MODULE
  ///
  /// @remarks readers must be released using free().
  ///
  /// @param [out] readers List of readers
  /// @param [out] length The number of readers
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  int smartcard_get_readers(
    ffi.Pointer<ffi.Pointer<ffi.Int>> readers,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _smartcard_get_readers(
      readers,
      length,
    );
  }

  late final _smartcard_get_readersPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Pointer<ffi.Int>>,
              ffi.Pointer<ffi.Int>)>>('smartcard_get_readers');
  late final _smartcard_get_readers = _smartcard_get_readersPtr.asFunction<
      int Function(ffi.Pointer<ffi.Pointer<ffi.Int>>, ffi.Pointer<ffi.Int>)>();

  /// @brief Returns the name of the given reader.
  /// @since_tizen 2.3.1
  /// @ingroup CAPI_NETWORK_SMARTCARD_READER_MODULE
  ///
  /// @remarks reader_name must be released using free().
  /// @remarks If the reader is a SIM reader, then its name must be "SIM[Slot]"
  /// @remarks If the reader is a SD or micro SD reader, then its name must be "SD[slot]"
  /// @remarks If the reader is a embedded SE reader, then its name must be "eSE[slot]"
  ///
  /// @param [in] reader Handle to the reader
  /// @param [out] reader_name The name of reader
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_get_readers()
  int smartcard_reader_get_name(
    int reader,
    ffi.Pointer<ffi.Pointer<ffi.Char>> reader_name,
  ) {
    return _smartcard_reader_get_name(
      reader,
      reader_name,
    );
  }

  late final _smartcard_reader_get_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'smartcard_reader_get_name');
  late final _smartcard_reader_get_name = _smartcard_reader_get_namePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Checks if a Secure Element is present in the given reader.
  /// @since_tizen 2.3.1
  /// @ingroup CAPI_NETWORK_SMARTCARD_READER_MODULE
  ///
  /// @param [in] reader Handle to the reader
  /// @param [out] is_present True or false depending whether a secure element is present in the
  /// reader - undefined when an error is returned
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_get_readers()
  int smartcard_reader_is_secure_element_present(
    int reader,
    ffi.Pointer<ffi.Bool> is_present,
  ) {
    return _smartcard_reader_is_secure_element_present(
      reader,
      is_present,
    );
  }

  late final _smartcard_reader_is_secure_element_presentPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Bool>)>>(
      'smartcard_reader_is_secure_element_present');
  late final _smartcard_reader_is_secure_element_present =
      _smartcard_reader_is_secure_element_presentPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Connects to a Secure Element in the given reader.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_READER_MODULE
  ///
  /// @param [in] reader Handle to the reader
  /// @param [out] session Handle to the session created for the given reader
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_IO_ERROR I/O error
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_get_readers()
  int smartcard_reader_open_session(
    int reader,
    ffi.Pointer<ffi.Int> session,
  ) {
    return _smartcard_reader_open_session(
      reader,
      session,
    );
  }

  late final _smartcard_reader_open_sessionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'smartcard_reader_open_session');
  late final _smartcard_reader_open_session = _smartcard_reader_open_sessionPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Closes all the sessions opened on the given reader.
  /// @details All the channels opened by all these sessions will be closed.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_READER_MODULE
  ///
  /// @param [in] reader Handle to the reader
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_IO_ERROR I/O error
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_get_readers()
  int smartcard_reader_close_sessions(
    int reader,
  ) {
    return _smartcard_reader_close_sessions(
      reader,
    );
  }

  late final _smartcard_reader_close_sessionsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'smartcard_reader_close_sessions');
  late final _smartcard_reader_close_sessions =
      _smartcard_reader_close_sessionsPtr.asFunction<int Function(int)>();

  /// @brief Sets a callback function for receiving reader event.
  /// @since_tizen 3.0
  /// @ingroup CAPI_NETWORK_SMARTCARD_READER_MODULE
  ///
  /// @param [in] cb The reader event callback
  /// @param [in] user_data The user data
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_reader_unset_event_cb()
  int smartcard_reader_set_event_cb(
    smartcard_reader_event_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _smartcard_reader_set_event_cb(
      cb,
      user_data,
    );
  }

  late final _smartcard_reader_set_event_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(smartcard_reader_event_cb,
              ffi.Pointer<ffi.Void>)>>('smartcard_reader_set_event_cb');
  late final _smartcard_reader_set_event_cb =
      _smartcard_reader_set_event_cbPtr.asFunction<
          int Function(smartcard_reader_event_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets the reader event callback function.
  /// @since_tizen 3.0
  /// @ingroup CAPI_NETWORK_SMARTCARD_READER_MODULE
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_reader_set_event_cb()
  int smartcard_reader_unset_event_cb() {
    return _smartcard_reader_unset_event_cb();
  }

  late final _smartcard_reader_unset_event_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'smartcard_reader_unset_event_cb');
  late final _smartcard_reader_unset_event_cb =
      _smartcard_reader_unset_event_cbPtr.asFunction<int Function()>();

  /// @brief Gets the reader that provides the given session.
  /// @since_tizen 2.3.1
  /// @ingroup CAPI_NETWORK_SMARTCARD_SESSION_MODULE
  ///
  /// @param [in] session Handle to the session
  /// @param [out] reader Reader handle that provides the given session
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_reader_open_session()
  int smartcard_session_get_reader(
    int session,
    ffi.Pointer<ffi.Int> reader,
  ) {
    return _smartcard_session_get_reader(
      session,
      reader,
    );
  }

  late final _smartcard_session_get_readerPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'smartcard_session_get_reader');
  late final _smartcard_session_get_reader = _smartcard_session_get_readerPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the Answer to Reset(ATR) of this Secure Element.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_SESSION_MODULE
  ///
  /// @remarks atr must be released using free().
  /// @remarks If the Answer to Reset(ATR) for this Secure Element is not available the returned length is set to zero and return value is Success.
  ///
  /// @param [in] session Handle to the session
  /// @param [out] atr Byte array to retrieve the Answer to Reset(ATR)
  /// @param [out] length The length of atr
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_reader_open_session()
  int smartcard_session_get_atr(
    int session,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> atr,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _smartcard_session_get_atr(
      session,
      atr,
      length,
    );
  }

  late final _smartcard_session_get_atrPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>>('smartcard_session_get_atr');
  late final _smartcard_session_get_atr =
      _smartcard_session_get_atrPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Closes the connection with the Secure Element.
  /// @details This will close any channels opened by this application with this Secure Element.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_SESSION_MODULE
  ///
  /// @param [in] session handle to the session
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_IO_ERROR I/O error
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_reader_open_session()
  int smartcard_session_close(
    int session,
  ) {
    return _smartcard_session_close(
      session,
    );
  }

  late final _smartcard_session_closePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'smartcard_session_close');
  late final _smartcard_session_close =
      _smartcard_session_closePtr.asFunction<int Function(int)>();

  /// @brief Checks if the given session is closed.
  /// @since_tizen 2.3.1
  /// @ingroup CAPI_NETWORK_SMARTCARD_SESSION_MODULE
  ///
  /// @param [in] session Handle to the session
  /// @param [out] is_closed True or false depending on the session state
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_reader_open_session()
  int smartcard_session_is_closed(
    int session,
    ffi.Pointer<ffi.Bool> is_closed,
  ) {
    return _smartcard_session_is_closed(
      session,
      is_closed,
    );
  }

  late final _smartcard_session_is_closedPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Bool>)>>(
      'smartcard_session_is_closed');
  late final _smartcard_session_is_closed = _smartcard_session_is_closedPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Closes any channel opened on the given session.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_SESSION_MODULE
  ///
  /// @param [in] session Handle to the session
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_IO_ERROR I/O error
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_reader_open_session()
  int smartcard_session_close_channels(
    int session,
  ) {
    return _smartcard_session_close_channels(
      session,
    );
  }

  late final _smartcard_session_close_channelsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'smartcard_session_close_channels');
  late final _smartcard_session_close_channels =
      _smartcard_session_close_channelsPtr.asFunction<int Function(int)>();

  /// @brief Gets an access to the basic channel, as defined in the ISO/IEC 7816-4 specification (the one that has number 0).
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_SESSION_MODULE
  ///
  /// @remarks ex) unsigned char aid[] = {0xA0, 0x00, 0x00, 0x00, 0x63, 0x50, 0x4B, 0x43, 0x53, 0x2D, 0x31, 0x35};
  /// @remarks If the Application ID(AID) is null, it means no Applet is to be selected on this channel and the default Applet is used.
  /// @remarks Opening of the basic channel to a specific applet is NOT allowed for UICC.
  ///
  /// @param [in] session Handle to the session
  /// @param [in] aid Byte array containing the Application ID(AID) to be selected on the given channel
  /// @param [in] aid_len Size of byte array or 0 when no SELECT should be executed
  /// @param [in] P2 P2 byte of the SELECT command if executed
  /// @param [out] channel Handle of the basic channel
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_CHANNEL_NOT_AVAILABLE No channel available
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NO_SUCH_ELEMENT No such element error
  /// @retval #SMARTCARD_ERROR_IO_ERROR I/O error
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_reader_open_session()
  int smartcard_session_open_basic_channel(
    int session,
    ffi.Pointer<ffi.UnsignedChar> aid,
    int aid_len,
    int P2,
    ffi.Pointer<ffi.Int> channel,
  ) {
    return _smartcard_session_open_basic_channel(
      session,
      aid,
      aid_len,
      P2,
      channel,
    );
  }

  late final _smartcard_session_open_basic_channelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Int,
              ffi.UnsignedChar,
              ffi.Pointer<ffi.Int>)>>('smartcard_session_open_basic_channel');
  late final _smartcard_session_open_basic_channel =
      _smartcard_session_open_basic_channelPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.UnsignedChar>, int, int,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Open a logical channel with the Secure Element, selecting the Applet represented by the given Application ID(AID).
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_SESSION_MODULE
  ///
  /// @remarks ex) unsigned char aid[] = {0xA0, 0x00, 0x00, 0x00, 0x63, 0x50, 0x4B, 0x43, 0x53, 0x2D, 0x31, 0x35};
  /// @remarks If the Application ID(AID) is null, it means no Applet is to be selected on this channel and the default Applet is used.
  ///
  /// @param [in] session Handle to the session
  /// @param [in] aid Byte array containing the Application ID(AID) to be selected on the given channel
  /// @param [in] aid_len Size of byte array or 0 when no SELECT should be executed
  /// @param [in] P2 P2 byte of the SELECT command if executed
  /// @param [out] channel Handle of the new logical channel
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_CHANNEL_NOT_AVAILABLE No channel available
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NO_SUCH_ELEMENT No such element error
  /// @retval #SMARTCARD_ERROR_IO_ERROR I/O error
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_reader_open_session()
  int smartcard_session_open_logical_channel(
    int session,
    ffi.Pointer<ffi.UnsignedChar> aid,
    int aid_len,
    int P2,
    ffi.Pointer<ffi.Int> channel,
  ) {
    return _smartcard_session_open_logical_channel(
      session,
      aid,
      aid_len,
      P2,
      channel,
    );
  }

  late final _smartcard_session_open_logical_channelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Int,
              ffi.UnsignedChar,
              ffi.Pointer<ffi.Int>)>>('smartcard_session_open_logical_channel');
  late final _smartcard_session_open_logical_channel =
      _smartcard_session_open_logical_channelPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.UnsignedChar>, int, int,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Closes the given channel to the Secure Element.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_CHANNEL_MODULE
  ///
  /// @param [in] channel Handle to the channel
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_IO_ERROR I/O error
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_session_open_basic_channel()
  /// @see smartcard_session_open_logical_channel()
  int smartcard_channel_close(
    int channel,
  ) {
    return _smartcard_channel_close(
      channel,
    );
  }

  late final _smartcard_channel_closePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'smartcard_channel_close');
  late final _smartcard_channel_close =
      _smartcard_channel_closePtr.asFunction<int Function(int)>();

  /// @brief Checks if the given channel is the basic channel.
  /// @since_tizen 2.3.1
  /// @ingroup CAPI_NETWORK_SMARTCARD_CHANNEL_MODULE
  ///
  /// @param [in] channel Handle to the channel
  /// @param [out] is_basic_channel True or false depending on the channel type
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_session_open_basic_channel()
  /// @see smartcard_session_open_logical_channel()
  int smartcard_channel_is_basic_channel(
    int channel,
    ffi.Pointer<ffi.Bool> is_basic_channel,
  ) {
    return _smartcard_channel_is_basic_channel(
      channel,
      is_basic_channel,
    );
  }

  late final _smartcard_channel_is_basic_channelPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Bool>)>>(
      'smartcard_channel_is_basic_channel');
  late final _smartcard_channel_is_basic_channel =
      _smartcard_channel_is_basic_channelPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks if the given channel is closed.
  /// @since_tizen 2.3.1
  /// @ingroup CAPI_NETWORK_SMARTCARD_CHANNEL_MODULE
  ///
  /// @param [in] channel Handle to the channel
  /// @param [out] is_closed True or false depending on the channel state
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_session_open_basic_channel()
  /// @see smartcard_session_open_logical_channel()
  int smartcard_channel_is_closed(
    int channel,
    ffi.Pointer<ffi.Bool> is_closed,
  ) {
    return _smartcard_channel_is_closed(
      channel,
      is_closed,
    );
  }

  late final _smartcard_channel_is_closedPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Bool>)>>(
      'smartcard_channel_is_closed');
  late final _smartcard_channel_is_closed = _smartcard_channel_is_closedPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the response to the select command.
  /// @since_tizen 2.3.1
  /// @ingroup CAPI_NETWORK_SMARTCARD_CHANNEL_MODULE
  ///
  /// @remarks select_resp must be released using free().
  ///
  /// @param [in] channel Handle to the channel
  /// @param [out] select_resp Byte array to retrieve the SELECT response
  /// @param [out] length The length of select_resp
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_session_open_basic_channel()
  /// @see smartcard_session_open_logical_channel()
  int smartcard_channel_get_select_response(
    int channel,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> select_resp,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _smartcard_channel_get_select_response(
      channel,
      select_resp,
      length,
    );
  }

  late final _smartcard_channel_get_select_responsePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>>('smartcard_channel_get_select_response');
  late final _smartcard_channel_get_select_response =
      _smartcard_channel_get_select_responsePtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the session that has opened the given channel.
  /// @since_tizen 2.3.1
  /// @ingroup CAPI_NETWORK_SMARTCARD_CHANNEL_MODULE
  ///
  /// @param [in] channel Handle to the channel
  /// @param [out] session Session handle of the given channel
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_session_open_basic_channel()
  /// @see smartcard_session_open_logical_channel()
  int smartcard_channel_get_session(
    int channel,
    ffi.Pointer<ffi.Int> session,
  ) {
    return _smartcard_channel_get_session(
      channel,
      session,
    );
  }

  late final _smartcard_channel_get_sessionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'smartcard_channel_get_session');
  late final _smartcard_channel_get_session = _smartcard_channel_get_sessionPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Transmits an APDU command (as per ISO/IEC 7816-4) to the Secure Element.
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_CHANNEL_MODULE
  ///
  /// @remarks resp must be released using free().
  /// @remarks MANAGE_CHANNEL commands are not allowed.
  /// @remarks SELECT by DF Name (P1=04) are not allowed.
  /// @remarks bytes with channel numbers are de-masked.
  ///
  /// @param [in] channel Handle to the channel
  /// @param [in] cmd Command APDU to be send to the secure element
  /// @param [in] cmd_len Size of command APDU
  /// @param [out] resp Byte array for the response APDU plus status words
  /// @param [out] length The length of resp
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_ILLEGAL_STATE Illegal state of execution error
  /// @retval #SMARTCARD_ERROR_IO_ERROR I/O error
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_session_open_basic_channel()
  /// @see smartcard_session_open_logical_channel()
  int smartcard_channel_transmit(
    int channel,
    ffi.Pointer<ffi.UnsignedChar> cmd,
    int cmd_len,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> resp,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _smartcard_channel_transmit(
      channel,
      cmd,
      cmd_len,
      resp,
      length,
    );
  }

  late final _smartcard_channel_transmitPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Int,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>>('smartcard_channel_transmit');
  late final _smartcard_channel_transmit =
      _smartcard_channel_transmitPtr.asFunction<
          int Function(
              int,
              ffi.Pointer<ffi.UnsignedChar>,
              int,
              ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Helper function to retrieves the response APDU of the previous transmit() call
  /// @since_tizen 2.3.1
  /// @ingroup CAPI_NETWORK_SMARTCARD_CHANNEL_MODULE
  ///
  /// @remarks resp must be released using free().
  ///
  /// @param [in] channel Handle to the channel
  /// @param [out] resp Byte array for the response APDU plus status words
  /// @param [out] length The length of resp
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_ILLEGAL_STATE Illegal state of execution error
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @see smartcard_session_open_basic_channel()
  /// @see smartcard_session_open_logical_channel()
  int smartcard_channel_transmit_retrieve_response(
    int channel,
    ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>> resp,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _smartcard_channel_transmit_retrieve_response(
      channel,
      resp,
      length,
    );
  }

  late final _smartcard_channel_transmit_retrieve_responsePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Int,
                  ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
                  ffi.Pointer<ffi.Int>)>>(
      'smartcard_channel_transmit_retrieve_response');
  late final _smartcard_channel_transmit_retrieve_response =
      _smartcard_channel_transmit_retrieve_responsePtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Pointer<ffi.UnsignedChar>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Performs a selection of the next Applet on the given channel that matches to the partial Application ID(AID)
  /// @since_tizen 2.3.1
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/secureelement
  /// @ingroup CAPI_NETWORK_SMARTCARD_CHANNEL_MODULE
  ///
  /// @param [in] channel Handle to the channel
  /// @param [out] is_success True or false depending whether another applet with the partial Application ID(AID)
  /// could be selected on the given channel
  ///
  /// @return 0 on success, otherwise a negative error value.
  /// @retval #SMARTCARD_ERROR_NONE Successful
  /// @retval #SMARTCARD_ERROR_GENERAL	A general error occurred
  /// @retval #SMARTCARD_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #SMARTCARD_ERROR_ILLEGAL_STATE Illegal state of execution error
  /// @retval #SMARTCARD_ERROR_OPERATION_NOT_SUPPORTED Operation not supported from SE
  /// @retval #SMARTCARD_ERROR_IO_ERROR I/O error
  /// @retval #SMARTCARD_ERROR_NOT_INITIALIZED Smartcard service not initialized
  /// @retval #SMARTCARD_ERROR_NOT_SUPPORTED Not supported
  /// @retval #SMARTCARD_ERROR_PERMISSION_DENIED Permission denied
  ///
  /// @see smartcard_session_open_basic_channel()
  /// @see smartcard_session_open_logical_channel()
  int smartcard_channel_select_next(
    int channel,
    ffi.Pointer<ffi.Bool> is_success,
  ) {
    return _smartcard_channel_select_next(
      channel,
      is_success,
    );
  }

  late final _smartcard_channel_select_nextPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Bool>)>>(
      'smartcard_channel_select_next');
  late final _smartcard_channel_select_next = _smartcard_channel_select_nextPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Initializes Wi-Fi.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @remarks You must release @a wifi using wifi_manager_deinitialize().
  /// @param[out] wifi        The Wi-Fi handle
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_ALREADY_INITIALIZED  Already initialized
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_initialize(
    ffi.Pointer<wifi_manager_h> wifi,
  ) {
    return _wifi_manager_initialize(
      wifi,
    );
  }

  late final _wifi_manager_initializePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<wifi_manager_h>)>>(
      'wifi_manager_initialize');
  late final _wifi_manager_initialize = _wifi_manager_initializePtr
      .asFunction<int Function(ffi.Pointer<wifi_manager_h>)>();

  /// @brief Deinitializes Wi-Fi.
  /// @since_tizen 3.0
  /// @param[in] wifi        The Wi-Fi handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE               Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION  Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED      Not supported
  int wifi_manager_deinitialize(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_deinitialize(
      wifi,
    );
  }

  late final _wifi_manager_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_deinitialize');
  late final _wifi_manager_deinitialize =
      _wifi_manager_deinitializePtr.asFunction<int Function(wifi_manager_h)>();

  /// @brief Activates Wi-Fi asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi          The Wi-Fi handle
  /// @param[in] callback      The callback function to be called \n
  /// This can be @c NULL if you don't want to get the notification.
  /// @param[in] user_data     The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_SECURITY_RESTRICTED  Restricted by security system policy
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post wifi_manager_activated_cb() will be invoked.
  /// @see wifi_manager_activated_cb()
  /// @see wifi_manager_deactivate()
  int wifi_manager_activate(
    wifi_manager_h wifi,
    wifi_manager_activated_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_activate(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_activatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, wifi_manager_activated_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_activate');
  late final _wifi_manager_activate = _wifi_manager_activatePtr.asFunction<
      int Function(
          wifi_manager_h, wifi_manager_activated_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Activates Wi-Fi asynchronously and displays Wi-Fi picker (popup) when Wi-Fi is not automatically connected.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi          The Wi-Fi handle
  /// @param[in] callback      The callback function to be called \n
  /// This can be @c NULL if you don't want to get the notification.
  /// @param[in] user_data     The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_SECURITY_RESTRICTED  Restricted by security system policy
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post wifi_manager_activated_cb() will be invoked.
  /// @see wifi_manager_activated_cb()
  /// @see wifi_manager_deactivate()
  int wifi_manager_activate_with_wifi_picker_tested(
    wifi_manager_h wifi,
    wifi_manager_activated_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_activate_with_wifi_picker_tested(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_activate_with_wifi_picker_testedPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h, wifi_manager_activated_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_activate_with_wifi_picker_tested');
  late final _wifi_manager_activate_with_wifi_picker_tested =
      _wifi_manager_activate_with_wifi_picker_testedPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_activated_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Deactivates Wi-Fi asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi          The Wi-Fi handle
  /// @param[in] callback      The callback function to be called \n
  /// This can be @c NULL if you don't want to get the notification.
  /// @param[in] user_data     The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post wifi_manager_deactivated_cb() will be invoked.
  /// @see wifi_manager_deactivated_cb()
  /// @see wifi_manager_activate()
  int wifi_manager_deactivate(
    wifi_manager_h wifi,
    wifi_manager_deactivated_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_deactivate(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_deactivatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, wifi_manager_deactivated_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_deactivate');
  late final _wifi_manager_deactivate = _wifi_manager_deactivatePtr.asFunction<
      int Function(wifi_manager_h, wifi_manager_deactivated_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Checks whether Wi-Fi is activated.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] wifi        The Wi-Fi handle
  /// @param[out] activated  @c true if Wi-Fi is activated,
  /// otherwise @c false if Wi-Fi is not activated.
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_is_activated(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Bool> activated,
  ) {
    return _wifi_manager_is_activated(
      wifi,
      activated,
    );
  }

  late final _wifi_manager_is_activatedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h,
              ffi.Pointer<ffi.Bool>)>>('wifi_manager_is_activated');
  late final _wifi_manager_is_activated = _wifi_manager_is_activatedPtr
      .asFunction<int Function(wifi_manager_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the local MAC address.
  /// @since_tizen 3.0
  /// @remarks You must release @a mac_address using free().
  /// @param[in] wifi          The Wi-Fi handle
  /// @param[out] mac_address  The MAC address
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_get_mac_address(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mac_address,
  ) {
    return _wifi_manager_get_mac_address(
      wifi,
      mac_address,
    );
  }

  late final _wifi_manager_get_mac_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_get_mac_address');
  late final _wifi_manager_get_mac_address =
      _wifi_manager_get_mac_addressPtr.asFunction<
          int Function(wifi_manager_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the name of the network interface.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @remarks You must release @a name using free().
  /// @param[in] wifi        The Wi-Fi handle
  /// @param[out] name       The name of network interface
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_get_network_interface_name(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _wifi_manager_get_network_interface_name(
      wifi,
      name,
    );
  }

  late final _wifi_manager_get_network_interface_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_get_network_interface_name');
  late final _wifi_manager_get_network_interface_name =
      _wifi_manager_get_network_interface_namePtr.asFunction<
          int Function(wifi_manager_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Starts scan asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_scan_finished_cb().
  int wifi_manager_scan(
    wifi_manager_h wifi,
    wifi_manager_scan_finished_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_scan(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_scanPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, wifi_manager_scan_finished_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_scan');
  late final _wifi_manager_scan = _wifi_manager_scanPtr.asFunction<
      int Function(wifi_manager_h, wifi_manager_scan_finished_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the Wi-Fi scan state.
  /// @since_tizen 4.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] scan_state      The Wi-Fi scan state
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_get_scan_state(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Int32> scan_state,
  ) {
    return _wifi_manager_get_scan_state(
      wifi,
      scan_state,
    );
  }

  late final _wifi_manager_get_scan_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_get_scan_state');
  late final _wifi_manager_get_scan_state = _wifi_manager_get_scan_statePtr
      .asFunction<int Function(wifi_manager_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Starts specific AP scan, asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] essid           The essid of specific AP
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value.
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_scan_finished_cb().
  int wifi_manager_scan_specific_ap(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> essid,
    wifi_manager_scan_finished_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_scan_specific_ap(
      wifi,
      essid,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_scan_specific_apPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_h,
              ffi.Pointer<ffi.Char>,
              wifi_manager_scan_finished_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_scan_specific_ap');
  late final _wifi_manager_scan_specific_ap =
      _wifi_manager_scan_specific_apPtr.asFunction<
          int Function(wifi_manager_h, ffi.Pointer<ffi.Char>,
              wifi_manager_scan_finished_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Creates a Wi-Fi specific AP scan handle.
  /// @since_tizen 4.0
  /// @remarks You must release @a specific_scan using wifi_manager_specific_scan_destroy().
  /// @param[in] wifi		The Wi-Fi handle
  /// @param[out] specific_scan	The Wi-Fi specific AP scan handle
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @pre This function needs a wifi_manager_initialize() call before use.
  /// @see wifi_manager_specific_scan_create()
  int wifi_manager_specific_scan_create(
    wifi_manager_h wifi,
    ffi.Pointer<wifi_manager_specific_scan_h> specific_scan,
  ) {
    return _wifi_manager_specific_scan_create(
      wifi,
      specific_scan,
    );
  }

  late final _wifi_manager_specific_scan_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_h, ffi.Pointer<wifi_manager_specific_scan_h>)>>(
      'wifi_manager_specific_scan_create');
  late final _wifi_manager_specific_scan_create =
      _wifi_manager_specific_scan_createPtr.asFunction<
          int Function(
              wifi_manager_h, ffi.Pointer<wifi_manager_specific_scan_h>)>();

  /// @brief Destroys a Wi-Fi specific AP scan handle.
  /// @since_tizen 4.0
  /// @param[in] wifi		The Wi-Fi handle
  /// @param[in] specific_scan	The Wi-Fi specific AP scan handle
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @pre This function needs a wifi_manager_initialize() call before use.
  /// @see wifi_manager_specific_scan_destroy()
  int wifi_manager_specific_scan_destroy(
    wifi_manager_h wifi,
    wifi_manager_specific_scan_h specific_scan,
  ) {
    return _wifi_manager_specific_scan_destroy(
      wifi,
      specific_scan,
    );
  }

  late final _wifi_manager_specific_scan_destroyPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h, wifi_manager_specific_scan_h)>>(
      'wifi_manager_specific_scan_destroy');
  late final _wifi_manager_specific_scan_destroy =
      _wifi_manager_specific_scan_destroyPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_specific_scan_h)>();

  /// @brief Sets the SSID of a specific AP scan.
  /// @since_tizen 4.0
  /// @param[in] specific_scan     The Wi-Fi specific AP scan handle
  /// @param[in] essid		The SSID of specific AP scan
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_specific_scan_set_ssid()
  int wifi_manager_specific_scan_set_ssid(
    wifi_manager_specific_scan_h specific_scan,
    ffi.Pointer<ffi.Char> essid,
  ) {
    return _wifi_manager_specific_scan_set_ssid(
      specific_scan,
      essid,
    );
  }

  late final _wifi_manager_specific_scan_set_ssidPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_specific_scan_h,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_specific_scan_set_ssid');
  late final _wifi_manager_specific_scan_set_ssid =
      _wifi_manager_specific_scan_set_ssidPtr.asFunction<
          int Function(wifi_manager_specific_scan_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the channel frequency of a specific AP scan.
  /// @since_tizen 4.0
  /// @param[in] specific_scan     The Wi-Fi specific AP scan handle
  /// @param[in] freq		The channel frequency of specific AP scan
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_specific_scan_set_freq()
  int wifi_manager_specific_scan_set_freq(
    wifi_manager_specific_scan_h specific_scan,
    int freq,
  ) {
    return _wifi_manager_specific_scan_set_freq(
      specific_scan,
      freq,
    );
  }

  late final _wifi_manager_specific_scan_set_freqPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_specific_scan_h,
              ffi.Int)>>('wifi_manager_specific_scan_set_freq');
  late final _wifi_manager_specific_scan_set_freq =
      _wifi_manager_specific_scan_set_freqPtr
          .asFunction<int Function(wifi_manager_specific_scan_h, int)>();

  /// @brief Starts multi SSID and multi channel specific scan, asynchronously.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] specific_scan   The Wi-Fi specific AP scan handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value.
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_scan_finished_cb().
  int wifi_manager_specific_ap_start_multi_scan(
    wifi_manager_h wifi,
    wifi_manager_specific_scan_h specific_scan,
    wifi_manager_scan_finished_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_specific_ap_start_multi_scan(
      wifi,
      specific_scan,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_specific_ap_start_multi_scanPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h, wifi_manager_specific_scan_h,
                  wifi_manager_scan_finished_cb, ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_specific_ap_start_multi_scan');
  late final _wifi_manager_specific_ap_start_multi_scan =
      _wifi_manager_specific_ap_start_multi_scanPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_specific_scan_h,
              wifi_manager_scan_finished_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Connects to the hidden AP, asynchronously.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get \n
  /// %http://tizen.org/privilege/network.profile
  /// @remarks This function needs all listed privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] essid           The ESSID of the hidden AP
  /// @param[in] sec_type        The security type of the hidden AP
  /// @param[in] passphrase      The passphrase of the hidden AP
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value.
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @pre This function needs wifi_manager_scan() before use.
  /// @post This function invokes wifi_manager_connected_cb().
  int wifi_manager_connect_hidden_ap(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> essid,
    int sec_type,
    ffi.Pointer<ffi.Char> passphrase,
    wifi_manager_connected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_connect_hidden_ap(
      wifi,
      essid,
      sec_type,
      passphrase,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_connect_hidden_apPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_h,
              ffi.Pointer<ffi.Char>,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              wifi_manager_connected_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_connect_hidden_ap');
  late final _wifi_manager_connect_hidden_ap =
      _wifi_manager_connect_hidden_apPtr.asFunction<
          int Function(
              wifi_manager_h,
              ffi.Pointer<ffi.Char>,
              int,
              ffi.Pointer<ffi.Char>,
              wifi_manager_connected_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the handle of the connected access point.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @remarks You must release @a ap using wifi_manager_ap_destroy().
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[out] ap             The access point handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NO_CONNECTION        There is no connected AP
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_get_connected_ap(
    wifi_manager_h wifi,
    ffi.Pointer<wifi_manager_ap_h> ap,
  ) {
    return _wifi_manager_get_connected_ap(
      wifi,
      ap,
    );
  }

  late final _wifi_manager_get_connected_apPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_h, ffi.Pointer<wifi_manager_ap_h>)>>(
      'wifi_manager_get_connected_ap');
  late final _wifi_manager_get_connected_ap =
      _wifi_manager_get_connected_apPtr.asFunction<
          int Function(wifi_manager_h, ffi.Pointer<wifi_manager_ap_h>)>();

  /// @brief Gets the result of the scan.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_found_ap_cb().
  int wifi_manager_foreach_found_ap(
    wifi_manager_h wifi,
    wifi_manager_found_ap_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_foreach_found_ap(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_foreach_found_apPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, wifi_manager_found_ap_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_foreach_found_ap');
  late final _wifi_manager_foreach_found_ap =
      _wifi_manager_foreach_found_apPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_found_ap_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the result of specific AP scan.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value.
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_found_ap_cb().
  /// @see wifi_manager_scan_specific_ap()
  int wifi_manager_foreach_found_specific_ap(
    wifi_manager_h wifi,
    wifi_manager_found_ap_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_foreach_found_specific_ap(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_foreach_found_specific_apPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h, wifi_manager_found_ap_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_foreach_found_specific_ap');
  late final _wifi_manager_foreach_found_specific_ap =
      _wifi_manager_foreach_found_specific_apPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_found_ap_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the result of the BSSID scan (i.e. BSSID, ESSID & RSSI).
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_found_ap_cb().
  /// @see wifi_manager_scan_ap()
  /// @see wifi_manager_scan_specific_ap()
  int wifi_manager_foreach_found_bssid_ap(
    wifi_manager_h wifi,
    wifi_manager_found_ap_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_foreach_found_bssid_ap(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_foreach_found_bssid_apPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, wifi_manager_found_ap_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_foreach_found_bssid_ap');
  late final _wifi_manager_foreach_found_bssid_ap =
      _wifi_manager_foreach_found_bssid_apPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_found_ap_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Connects to the access point asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] ap              The access point handle
  /// @param[in] callback        The callback function to be called \n
  /// This can be @c NULL if you don't want to get the notification.
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_connected_cb().
  /// @see wifi_manager_connected_cb()
  /// @see wifi_manager_connect_by_wps_pbc()
  /// @see wifi_manager_connect_by_wps_pin()
  /// @see wifi_manager_disconnect()
  int wifi_manager_connect(
    wifi_manager_h wifi,
    wifi_manager_ap_h ap,
    wifi_manager_connected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_connect(
      wifi,
      ap,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_connectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_h,
              wifi_manager_ap_h,
              wifi_manager_connected_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_connect');
  late final _wifi_manager_connect = _wifi_manager_connectPtr.asFunction<
      int Function(wifi_manager_h, wifi_manager_ap_h, wifi_manager_connected_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Disconnects to the access point asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] ap              The access point handle
  /// @param[in] callback        The callback function to be called \n
  /// This can be @c NULL if you don't want to get the notification.
  /// @param[in] user_data        The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_disconnected_cb().
  /// @see wifi_manager_disconnected_cb()
  /// @see wifi_manager_connect_by_wps_pbc()
  /// @see wifi_manager_connect_by_wps_pin()
  /// @see wifi_manager_connect()
  int wifi_manager_disconnect(
    wifi_manager_h wifi,
    wifi_manager_ap_h ap,
    wifi_manager_disconnected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_disconnect(
      wifi,
      ap,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_disconnectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_h,
              wifi_manager_ap_h,
              wifi_manager_disconnected_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_disconnect');
  late final _wifi_manager_disconnect = _wifi_manager_disconnectPtr.asFunction<
      int Function(wifi_manager_h, wifi_manager_ap_h,
          wifi_manager_disconnected_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Connects to the access point with WPS PBC asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] ap              The access point handle
  /// @param[in] callback        The callback function to be called \n
  /// This can be NULL if you don't want to get the notification.
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE               Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_connected_cb().
  /// @see wifi_manager_connected_cb()
  /// @see wifi_manager_connect()
  /// @see wifi_manager_disconnect()
  /// @see wifi_manager_ap_is_wps_supported()
  int wifi_manager_connect_by_wps_pbc(
    wifi_manager_h wifi,
    wifi_manager_ap_h ap,
    wifi_manager_connected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_connect_by_wps_pbc(
      wifi,
      ap,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_connect_by_wps_pbcPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_h,
              wifi_manager_ap_h,
              wifi_manager_connected_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_connect_by_wps_pbc');
  late final _wifi_manager_connect_by_wps_pbc =
      _wifi_manager_connect_by_wps_pbcPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_ap_h,
              wifi_manager_connected_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Connects to the access point with WPS PIN asynchronously.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] ap              The access point handle
  /// @param[in] pin             The WPS PIN is a non-NULL string with length greater than 0 and less than or equal to 8
  /// @param[in] callback        The callback function to be called (this can be NULL if you don't want to get the notification)
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_connected_cb().
  /// @see wifi_manager_connected_cb()
  /// @see wifi_manager_connect()
  /// @see wifi_manager_disconnect()
  /// @see wifi_manager_ap_is_wps_supported()
  int wifi_manager_connect_by_wps_pin(
    wifi_manager_h wifi,
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Char> pin,
    wifi_manager_connected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_connect_by_wps_pin(
      wifi,
      ap,
      pin,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_connect_by_wps_pinPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_h,
              wifi_manager_ap_h,
              ffi.Pointer<ffi.Char>,
              wifi_manager_connected_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_connect_by_wps_pin');
  late final _wifi_manager_connect_by_wps_pin =
      _wifi_manager_connect_by_wps_pinPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_ap_h, ffi.Pointer<ffi.Char>,
              wifi_manager_connected_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Connects to the access point with WPS PBC without entering SSID.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get \n
  /// %http://tizen.org/privilege/network.profile
  /// @remarks This function needs all listed privileges.
  /// @param[in] wifi      The Wi-Fi handle
  /// @param[in] callback  The callback function to be called \n
  /// This can be NULL if you don't want to get the notification.
  /// @param[in] user_data The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_connected_cb().
  /// @see wifi_manager_connected_cb()
  /// @see wifi_manager_connect()
  /// @see wifi_manager_disconnect()
  /// @see wifi_manager_ap_is_wps_supported()
  int wifi_manager_connect_by_wps_pbc_without_ssid(
    wifi_manager_h wifi,
    wifi_manager_connected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_connect_by_wps_pbc_without_ssid(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_connect_by_wps_pbc_without_ssidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h, wifi_manager_connected_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_connect_by_wps_pbc_without_ssid');
  late final _wifi_manager_connect_by_wps_pbc_without_ssid =
      _wifi_manager_connect_by_wps_pbc_without_ssidPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_connected_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Connects to the access point with WPS PIN without entering SSID.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get \n
  /// %http://tizen.org/privilege/network.profile
  /// @remarks This function needs all listed privileges.
  /// @param[in] wifi      The Wi-Fi handle
  /// @param[in] pin       The WPS PIN, a non-NULL string with length greater \n
  /// than 0 and less than or equal to 8
  /// @param[in] callback  The callback function to be called \n
  /// This can be NULL if you don't want to get the notification.
  /// @param[in] user_data The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_connected_cb().
  /// @see wifi_manager_connected_cb()
  /// @see wifi_manager_connect()
  /// @see wifi_manager_disconnect()
  /// @see wifi_manager_ap_is_wps_supported()
  int wifi_manager_connect_by_wps_pin_without_ssid(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> pin,
    wifi_manager_connected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_connect_by_wps_pin_without_ssid(
      wifi,
      pin,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_connect_by_wps_pin_without_ssidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h, ffi.Pointer<ffi.Char>,
                  wifi_manager_connected_cb, ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_connect_by_wps_pin_without_ssid');
  late final _wifi_manager_connect_by_wps_pin_without_ssid =
      _wifi_manager_connect_by_wps_pin_without_ssidPtr.asFunction<
          int Function(wifi_manager_h, ffi.Pointer<ffi.Char>,
              wifi_manager_connected_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Stops ongoing WPS provisioning / disconnects from the connected access point.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi      The Wi-Fi handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_cancel_wps(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_cancel_wps(
      wifi,
    );
  }

  late final _wifi_manager_cancel_wpsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_cancel_wps');
  late final _wifi_manager_cancel_wps =
      _wifi_manager_cancel_wpsPtr.asFunction<int Function(wifi_manager_h)>();

  /// @brief Deletes the information of a stored access point and disconnects from it if it was connected to.
  /// @details If an AP is connected to, then connection information will be stored.
  /// This information is used when a connection to that AP is established automatically.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] ap              The access point handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_forget_ap(
    wifi_manager_h wifi,
    wifi_manager_ap_h ap,
  ) {
    return _wifi_manager_forget_ap(
      wifi,
      ap,
    );
  }

  late final _wifi_manager_forget_apPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_h, wifi_manager_ap_h)>>('wifi_manager_forget_ap');
  late final _wifi_manager_forget_ap = _wifi_manager_forget_apPtr
      .asFunction<int Function(wifi_manager_h, wifi_manager_ap_h)>();

  /// @brief Updates an existing AP.
  /// @details When a AP is changed, these changes will be not applied to the Connection Manager immediately.
  /// When you call this function, your changes affect the Connection Manager and the existing AP is updated.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] ap              The access point handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_update_ap(
    wifi_manager_h wifi,
    wifi_manager_ap_h ap,
  ) {
    return _wifi_manager_update_ap(
      wifi,
      ap,
    );
  }

  late final _wifi_manager_update_apPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_h, wifi_manager_ap_h)>>('wifi_manager_update_ap');
  late final _wifi_manager_update_ap = _wifi_manager_update_apPtr
      .asFunction<int Function(wifi_manager_h, wifi_manager_ap_h)>();

  /// @brief Adds the Wi-Fi Vendor Specific Information Element (VSIE) to a specific frame type.
  /// @since_tizen 5.0
  /// @privlevel public
  /// @privilege http://tizen.org/privilege/network.set
  /// @remarks @a vsie_str for @a frame_id will be in effect until Wi-Fi is deactivated.
  ///
  /// @param[in] wifi           The Wi-Fi handle
  /// @param[in] frame_id       The frame ID for setting VSIE
  /// @param[in] vsie_str       The VSIE data
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @pre Wi-Fi service must be activated by wifi_manager_activate().
  /// @see wifi_manager_activate()
  /// @see wifi_manager_remove_vsie()
  /// @see wifi_manager_get_vsie()
  int wifi_manager_add_vsie(
    wifi_manager_h wifi,
    int frame_id,
    ffi.Pointer<ffi.Char> vsie_str,
  ) {
    return _wifi_manager_add_vsie(
      wifi,
      frame_id,
      vsie_str,
    );
  }

  late final _wifi_manager_add_vsiePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_add_vsie');
  late final _wifi_manager_add_vsie = _wifi_manager_add_vsiePtr
      .asFunction<int Function(wifi_manager_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the Wi-Fi Vendor Specific Information Elements (VSIE) from a specific frame.
  /// @since_tizen 5.0
  /// @privlevel public
  /// @privilege http://tizen.org/privilege/network.get
  /// @remarks @a vsie_str must be released with free().
  ///
  /// @param[in] wifi           The Wi-Fi handle
  /// @param[in] frame_id       The frame ID for getting VSIE
  /// @param[out] vsie_str      The VSIE data
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @pre Wi-Fi service must be activated by wifi_manager_activate()
  /// and VSIE for a specific frame must be set with wifi_manager_add_vsie().
  /// @see wifi_manager_activate()
  /// @see wifi_manager_remove_vsie()
  /// @see wifi_manager_add_vsie()
  int wifi_manager_get_vsie(
    wifi_manager_h wifi,
    int frame_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> vsie_str,
  ) {
    return _wifi_manager_get_vsie(
      wifi,
      frame_id,
      vsie_str,
    );
  }

  late final _wifi_manager_get_vsiePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, ffi.Int32,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('wifi_manager_get_vsie');
  late final _wifi_manager_get_vsie = _wifi_manager_get_vsiePtr.asFunction<
      int Function(wifi_manager_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Removes the Wi-Fi Vendor Specific Information Element (VSIE) from specific frame.
  /// @since_tizen 5.0
  /// @privlevel public
  /// @privilege http://tizen.org/privilege/network.set
  /// @remarks @a vsie_str for @a frame_id will be in effect until Wi-Fi is deactivated.
  ///
  /// @param[in] wifi           The wifi handle
  /// @param[in] frame_id       The frame ID for removing VSIE
  /// @param[in] vsie_str       The VSIE data
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @pre Wi-Fi service must be activated by wifi_manager_activate()
  /// and VSIE for a specific frame must be set with wifi_manager_add_vsie().
  /// @see wifi_manager_activate()
  /// @see wifi_manager_get_vsie()
  /// @see wifi_manager_add_vsie()
  int wifi_manager_remove_vsie(
    wifi_manager_h wifi,
    int frame_id,
    ffi.Pointer<ffi.Char> vsie_str,
  ) {
    return _wifi_manager_remove_vsie(
      wifi,
      frame_id,
      vsie_str,
    );
  }

  late final _wifi_manager_remove_vsiePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_remove_vsie');
  late final _wifi_manager_remove_vsie = _wifi_manager_remove_vsiePtr
      .asFunction<int Function(wifi_manager_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the connection state.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] wifi                The Wi-Fi handle
  /// @param[out] connection_state   The connection state
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_get_connection_state(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Int32> connection_state,
  ) {
    return _wifi_manager_get_connection_state(
      wifi,
      connection_state,
    );
  }

  late final _wifi_manager_get_connection_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_get_connection_state');
  late final _wifi_manager_get_connection_state =
      _wifi_manager_get_connection_statePtr
          .asFunction<int Function(wifi_manager_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Registers the callback called when the device state is changed.
  /// @since_tizen 3.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_set_device_state_changed_cb(
    wifi_manager_h wifi,
    wifi_manager_device_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_set_device_state_changed_cb(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_set_device_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_h,
                  wifi_manager_device_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_set_device_state_changed_cb');
  late final _wifi_manager_set_device_state_changed_cb =
      _wifi_manager_set_device_state_changed_cbPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_device_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback called when the device state is changed.
  /// @since_tizen 3.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_unset_device_state_changed_cb(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_unset_device_state_changed_cb(
      wifi,
    );
  }

  late final _wifi_manager_unset_device_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_unset_device_state_changed_cb');
  late final _wifi_manager_unset_device_state_changed_cb =
      _wifi_manager_unset_device_state_changed_cbPtr
          .asFunction<int Function(wifi_manager_h)>();

  /// @brief Registers the callback called when the background scan is finished.
  /// @since_tizen 3.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_set_background_scan_cb(
    wifi_manager_h wifi,
    wifi_manager_scan_finished_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_set_background_scan_cb(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_set_background_scan_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, wifi_manager_scan_finished_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_set_background_scan_cb');
  late final _wifi_manager_set_background_scan_cb =
      _wifi_manager_set_background_scan_cbPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_scan_finished_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback called when the scan is finished.
  /// @since_tizen 3.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_unset_background_scan_cb(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_unset_background_scan_cb(
      wifi,
    );
  }

  late final _wifi_manager_unset_background_scan_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_unset_background_scan_cb');
  late final _wifi_manager_unset_background_scan_cb =
      _wifi_manager_unset_background_scan_cbPtr
          .asFunction<int Function(wifi_manager_h)>();

  /// @brief Registers the callback called when the scanning state is changed.
  /// @since_tizen 4.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_set_scan_state_changed_cb(
    wifi_manager_h wifi,
    wifi_manager_scan_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_set_scan_state_changed_cb(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_set_scan_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h,
                  wifi_manager_scan_state_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_set_scan_state_changed_cb');
  late final _wifi_manager_set_scan_state_changed_cb =
      _wifi_manager_set_scan_state_changed_cbPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_scan_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback called when the scanning state is changed.
  /// @since_tizen 4.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_unset_scan_state_changed_cb(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_unset_scan_state_changed_cb(
      wifi,
    );
  }

  late final _wifi_manager_unset_scan_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_unset_scan_state_changed_cb');
  late final _wifi_manager_unset_scan_state_changed_cb =
      _wifi_manager_unset_scan_state_changed_cbPtr
          .asFunction<int Function(wifi_manager_h)>();

  /// @brief Registers the callback called when the connection state is changed.
  /// @since_tizen 3.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_set_connection_state_changed_cb(
    wifi_manager_h wifi,
    wifi_manager_connection_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_set_connection_state_changed_cb(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_set_connection_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_h,
                  wifi_manager_connection_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_set_connection_state_changed_cb');
  late final _wifi_manager_set_connection_state_changed_cb =
      _wifi_manager_set_connection_state_changed_cbPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_connection_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback called when the connection state is changed.
  /// @since_tizen 3.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_unset_connection_state_changed_cb(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_unset_connection_state_changed_cb(
      wifi,
    );
  }

  late final _wifi_manager_unset_connection_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_unset_connection_state_changed_cb');
  late final _wifi_manager_unset_connection_state_changed_cb =
      _wifi_manager_unset_connection_state_changed_cbPtr
          .asFunction<int Function(wifi_manager_h)>();

  /// @brief Registers callback called when the RSSI of connected Wi-Fi is changed.
  /// @since_tizen 3.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_set_rssi_level_changed_cb(
    wifi_manager_h wifi,
    wifi_manager_rssi_level_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_set_rssi_level_changed_cb(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_set_rssi_level_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h,
                  wifi_manager_rssi_level_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_set_rssi_level_changed_cb');
  late final _wifi_manager_set_rssi_level_changed_cb =
      _wifi_manager_set_rssi_level_changed_cbPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_rssi_level_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters callback called when the RSSI of connected Wi-Fi is changed.
  /// @since_tizen 3.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_unset_rssi_level_changed_cb(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_unset_rssi_level_changed_cb(
      wifi,
    );
  }

  late final _wifi_manager_unset_rssi_level_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_unset_rssi_level_changed_cb');
  late final _wifi_manager_unset_rssi_level_changed_cb =
      _wifi_manager_unset_rssi_level_changed_cbPtr
          .asFunction<int Function(wifi_manager_h)>();

  /// @brief Registers a callback called when the Wi-Fi Module state is changed.
  /// @since_tizen 4.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_module_state_changed_cb()
  /// @see wifi_manager_unset_module_state_changed_cb()
  int wifi_manager_set_module_state_changed_cb(
    wifi_manager_h wifi,
    wifi_manager_module_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_set_module_state_changed_cb(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_set_module_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_h,
                  wifi_manager_module_state_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_set_module_state_changed_cb');
  late final _wifi_manager_set_module_state_changed_cb =
      _wifi_manager_set_module_state_changed_cbPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_module_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback called when the Wi-Fi Module state is changed.
  /// @since_tizen 4.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_module_state_changed_cb()
  /// @see wifi_manager_set_module_state_changed_cb()
  int wifi_manager_unset_module_state_changed_cb(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_unset_module_state_changed_cb(
      wifi,
    );
  }

  late final _wifi_manager_unset_module_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_unset_module_state_changed_cb');
  late final _wifi_manager_unset_module_state_changed_cb =
      _wifi_manager_unset_module_state_changed_cbPtr
          .asFunction<int Function(wifi_manager_h)>();

  /// @brief Gets the Wi-Fi Module state.
  /// @since_tizen 4.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[out] state          The Wi-Fi Module state
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_get_module_state(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _wifi_manager_get_module_state(
      wifi,
      state,
    );
  }

  late final _wifi_manager_get_module_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_get_module_state');
  late final _wifi_manager_get_module_state = _wifi_manager_get_module_statePtr
      .asFunction<int Function(wifi_manager_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Starts BSSID scan asynchronously.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set \n
  /// %http://tizen.org/privilege/network.get
  /// @remarks This function needs both privileges.
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @post This function invokes wifi_manager_bssid_scan_finished_cb().
  int wifi_manager_bssid_scan(
    wifi_manager_h wifi,
    wifi_manager_bssid_scan_finished_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_bssid_scan(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_bssid_scanPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, wifi_manager_bssid_scan_finished_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_bssid_scan');
  late final _wifi_manager_bssid_scan = _wifi_manager_bssid_scanPtr.asFunction<
      int Function(wifi_manager_h, wifi_manager_bssid_scan_finished_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Creates the access point handle.
  /// @since_tizen 3.0
  /// @remarks You must release @a ap using wifi_manager_ap_destroy().
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] essid           The ESSID (Extended Service Set Identifier) should be null-terminated and can be UTF-8 encoded
  /// @param[out] ap             The access point handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_ap_destroy()
  int wifi_manager_ap_create(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> essid,
    ffi.Pointer<wifi_manager_ap_h> ap,
  ) {
    return _wifi_manager_ap_create(
      wifi,
      essid,
      ap,
    );
  }

  late final _wifi_manager_ap_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<wifi_manager_ap_h>)>>('wifi_manager_ap_create');
  late final _wifi_manager_ap_create = _wifi_manager_ap_createPtr.asFunction<
      int Function(wifi_manager_h, ffi.Pointer<ffi.Char>,
          ffi.Pointer<wifi_manager_ap_h>)>();

  /// @brief Creates the hidden access point handle.
  /// @since_tizen 3.0
  /// @remarks You must release @a ap using wifi_manager_ap_destroy().
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] essid           The ESSID (Extended Service Set Identifier) should be null-terminated and can be UTF-8 encoded
  /// @param[out] ap             The access point handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_ap_destroy()
  int wifi_manager_ap_hidden_create(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> essid,
    ffi.Pointer<wifi_manager_ap_h> ap,
  ) {
    return _wifi_manager_ap_hidden_create(
      wifi,
      essid,
      ap,
    );
  }

  late final _wifi_manager_ap_hidden_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<wifi_manager_ap_h>)>>(
      'wifi_manager_ap_hidden_create');
  late final _wifi_manager_ap_hidden_create =
      _wifi_manager_ap_hidden_createPtr.asFunction<
          int Function(wifi_manager_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<wifi_manager_ap_h>)>();

  /// @brief Destroys the access point handle.
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_ap_create()
  int wifi_manager_ap_destroy(
    wifi_manager_ap_h ap,
  ) {
    return _wifi_manager_ap_destroy(
      ap,
    );
  }

  late final _wifi_manager_ap_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_ap_h)>>(
          'wifi_manager_ap_destroy');
  late final _wifi_manager_ap_destroy =
      _wifi_manager_ap_destroyPtr.asFunction<int Function(wifi_manager_ap_h)>();

  /// @brief Clones the access point handle.
  /// @since_tizen 3.0
  /// @remarks You must release @a cloned_ap using wifi_manager_ap_destroy().
  /// @param[out] cloned_ap      The cloned access point handle
  /// @param[in] origin          The origin access point handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_ap_destroy()
  int wifi_manager_ap_clone(
    ffi.Pointer<wifi_manager_ap_h> cloned_ap,
    wifi_manager_ap_h origin,
  ) {
    return _wifi_manager_ap_clone(
      cloned_ap,
      origin,
    );
  }

  late final _wifi_manager_ap_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<wifi_manager_ap_h>,
              wifi_manager_ap_h)>>('wifi_manager_ap_clone');
  late final _wifi_manager_ap_clone = _wifi_manager_ap_clonePtr.asFunction<
      int Function(ffi.Pointer<wifi_manager_ap_h>, wifi_manager_ap_h)>();

  /// @brief Refreshes the access point information.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @remarks You should call this function in order to get the current access point information, because the information can be changed.
  /// @param[in] ap              The access point handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_refresh(
    wifi_manager_ap_h ap,
  ) {
    return _wifi_manager_ap_refresh(
      ap,
    );
  }

  late final _wifi_manager_ap_refreshPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_ap_h)>>(
          'wifi_manager_ap_refresh');
  late final _wifi_manager_ap_refresh =
      _wifi_manager_ap_refreshPtr.asFunction<int Function(wifi_manager_ap_h)>();

  /// @brief Gets ESSID (Extended Service Set Identifier).
  /// @since_tizen 3.0
  /// @remarks You must release @a essid using free().
  /// @param[in] ap              The access point handle
  /// @param[out] essid          The ESSID
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_essid(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Pointer<ffi.Char>> essid,
  ) {
    return _wifi_manager_ap_get_essid(
      ap,
      essid,
    );
  }

  late final _wifi_manager_ap_get_essidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_essid');
  late final _wifi_manager_ap_get_essid =
      _wifi_manager_ap_get_essidPtr.asFunction<
          int Function(
              wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets raw SSID (Service Set Identifier).
  /// @since_tizen 4.0
  /// @remarks You must release @a ssid using free().
  /// @param[in] ap              The access point handle
  /// @param[out] ssid           The raw SSID bytes
  /// @param[out] ssid_len       The raw SSID length
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_raw_ssid(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Pointer<ffi.Char>> ssid,
    ffi.Pointer<ffi.Int> ssid_len,
  ) {
    return _wifi_manager_ap_get_raw_ssid(
      ap,
      ssid,
      ssid_len,
    );
  }

  late final _wifi_manager_ap_get_raw_ssidPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_ap_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int>)>>('wifi_manager_ap_get_raw_ssid');
  late final _wifi_manager_ap_get_raw_ssid =
      _wifi_manager_ap_get_raw_ssidPtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets BSSID (Basic Service Set Identifier).
  /// @since_tizen 3.0
  /// @remarks You must release @a bssid using free().
  /// @param[in] ap              The access point handle
  /// @param[out] bssid          The BSSID
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_bssid(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Pointer<ffi.Char>> bssid,
  ) {
    return _wifi_manager_ap_get_bssid(
      ap,
      bssid,
    );
  }

  late final _wifi_manager_ap_get_bssidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_bssid');
  late final _wifi_manager_ap_get_bssid =
      _wifi_manager_ap_get_bssidPtr.asFunction<
          int Function(
              wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the RSSI.
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @param[out] rssi           The RSSI value (in dBm)
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_rssi(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int> rssi,
  ) {
    return _wifi_manager_ap_get_rssi(
      ap,
      rssi,
    );
  }

  late final _wifi_manager_ap_get_rssiPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int>)>>('wifi_manager_ap_get_rssi');
  late final _wifi_manager_ap_get_rssi = _wifi_manager_ap_get_rssiPtr
      .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the RSSI level.
  /// @since_tizen 4.0
  /// @param[in] ap              The access point handle
  /// @param[out] rssi_level     The RSSI level
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_rssi_level(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int32> rssi_level,
  ) {
    return _wifi_manager_ap_get_rssi_level(
      ap,
      rssi_level,
    );
  }

  late final _wifi_manager_ap_get_rssi_levelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_ap_get_rssi_level');
  late final _wifi_manager_ap_get_rssi_level =
      _wifi_manager_ap_get_rssi_levelPtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the frequency band (MHz).
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @param[out] frequency      The frequency
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_frequency(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int> frequency,
  ) {
    return _wifi_manager_ap_get_frequency(
      ap,
      frequency,
    );
  }

  late final _wifi_manager_ap_get_frequencyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int>)>>('wifi_manager_ap_get_frequency');
  late final _wifi_manager_ap_get_frequency = _wifi_manager_ap_get_frequencyPtr
      .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the max speed (Mbps).
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @param[out] max_speed      The max speed
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_max_speed(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int> max_speed,
  ) {
    return _wifi_manager_ap_get_max_speed(
      ap,
      max_speed,
    );
  }

  late final _wifi_manager_ap_get_max_speedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int>)>>('wifi_manager_ap_get_max_speed');
  late final _wifi_manager_ap_get_max_speed = _wifi_manager_ap_get_max_speedPtr
      .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Checks whether the access point is favorite or not.
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @param[out] favorite  @c true if access point is favorite,
  /// otherwise @c false if access point is not favorite
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_is_favorite(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Bool> favorite,
  ) {
    return _wifi_manager_ap_is_favorite(
      ap,
      favorite,
    );
  }

  late final _wifi_manager_ap_is_favoritePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Bool>)>>('wifi_manager_ap_is_favorite');
  late final _wifi_manager_ap_is_favorite = _wifi_manager_ap_is_favoritePtr
      .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks whether the access point is passpoint or not.
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @param[out] passpoint  @c true if access point is passpoint,
  /// otherwise @c false if access point is not passpoint.
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_is_passpoint(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Bool> passpoint,
  ) {
    return _wifi_manager_ap_is_passpoint(
      ap,
      passpoint,
    );
  }

  late final _wifi_manager_ap_is_passpointPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Bool>)>>('wifi_manager_ap_is_passpoint');
  late final _wifi_manager_ap_is_passpoint = _wifi_manager_ap_is_passpointPtr
      .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the connection state.
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @param[out] state          The connection state
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_connection_state(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _wifi_manager_ap_get_connection_state(
      ap,
      state,
    );
  }

  late final _wifi_manager_ap_get_connection_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_ap_get_connection_state');
  late final _wifi_manager_ap_get_connection_state =
      _wifi_manager_ap_get_connection_statePtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the config type of IP.
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @param[in] address_family  The address family
  /// @param[out] type           The type of IP config
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED           Not supported
  int wifi_manager_ap_get_ip_config_type(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _wifi_manager_ap_get_ip_config_type(
      ap,
      address_family,
      type,
    );
  }

  late final _wifi_manager_ap_get_ip_config_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_ap_get_ip_config_type');
  late final _wifi_manager_ap_get_ip_config_type =
      _wifi_manager_ap_get_ip_config_typePtr.asFunction<
          int Function(wifi_manager_ap_h, int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the config type of IP.
  /// @details If you set IP config type to #WIFI_MANAGER_IP_CONFIG_TYPE_STATIC,
  /// then IP address, Gateway and Subnet mask will be set to the initial value "0.0.0.0".
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @param[in] address_family  The address family
  /// @param[in] type            The type of IP config
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_update_ap()
  int wifi_manager_ap_set_ip_config_type(
    wifi_manager_ap_h ap,
    int address_family,
    int type,
  ) {
    return _wifi_manager_ap_set_ip_config_type(
      ap,
      address_family,
      type,
    );
  }

  late final _wifi_manager_ap_set_ip_config_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
              ffi.Int32)>>('wifi_manager_ap_set_ip_config_type');
  late final _wifi_manager_ap_set_ip_config_type =
      _wifi_manager_ap_set_ip_config_typePtr
          .asFunction<int Function(wifi_manager_ap_h, int, int)>();

  /// @brief Gets the IP address.
  /// @since_tizen 3.0
  /// @remarks You must release @a ip_address using free().
  /// @param[in] ap              The access point handle
  /// @param[in] address_family  The address family
  /// @param[out] ip_address     The IP address; this value is for default address \n
  /// e.g, IPv6 can have multiple addresses. but you can only obtain a representative address \n
  /// if you want to get all IPv6 address, you can use the wifi_manager_ap_foreach_ipv6_address().
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see  wifi_manager_ap_foreach_ipv6_address()
  int wifi_manager_ap_get_ip_address(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> ip_address,
  ) {
    return _wifi_manager_ap_get_ip_address(
      ap,
      address_family,
      ip_address,
    );
  }

  late final _wifi_manager_ap_get_ip_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_ip_address');
  late final _wifi_manager_ap_get_ip_address =
      _wifi_manager_ap_get_ip_addressPtr.asFunction<
          int Function(
              wifi_manager_ap_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the IP address.
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @param[in] address_family  The address family
  /// @param[in] ip_address      The IP address; if you set this value to NULL, then the existing value will be deleted
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_update_ap()
  int wifi_manager_ap_set_ip_address(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Char> ip_address,
  ) {
    return _wifi_manager_ap_set_ip_address(
      ap,
      address_family,
      ip_address,
    );
  }

  late final _wifi_manager_ap_set_ip_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_ap_set_ip_address');
  late final _wifi_manager_ap_set_ip_address =
      _wifi_manager_ap_set_ip_addressPtr.asFunction<
          int Function(wifi_manager_ap_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets all IPv6 addresses assigned to the Wi-Fi interface.
  /// @since_tizen 4.0
  /// @param[in] ap        The access point handle
  /// @param[in] callback  The callback to be called for each IPv6 address
  /// @param[in] user_data The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value.
  /// @retval #WIFI_MANAGER_ERROR_NONE               Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED      Not supported
  int wifi_manager_ap_foreach_ipv6_address(
    wifi_manager_ap_h ap,
    wifi_manager_ap_ipv6_address_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_ap_foreach_ipv6_address(
      ap,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_ap_foreach_ipv6_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, wifi_manager_ap_ipv6_address_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_ap_foreach_ipv6_address');
  late final _wifi_manager_ap_foreach_ipv6_address =
      _wifi_manager_ap_foreach_ipv6_addressPtr.asFunction<
          int Function(wifi_manager_ap_h, wifi_manager_ap_ipv6_address_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the subnet mask.
  /// @since_tizen 3.0
  /// @remarks You must release @a subnet_mask using free().
  /// @param[in] ap              The access point handle
  /// @param[in] address_family  The address family
  /// @param[out] subnet_mask    The subnet mask
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_subnet_mask(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> subnet_mask,
  ) {
    return _wifi_manager_ap_get_subnet_mask(
      ap,
      address_family,
      subnet_mask,
    );
  }

  late final _wifi_manager_ap_get_subnet_maskPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_subnet_mask');
  late final _wifi_manager_ap_get_subnet_mask =
      _wifi_manager_ap_get_subnet_maskPtr.asFunction<
          int Function(
              wifi_manager_ap_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the subnet mask.
  /// @since_tizen 3.0
  /// @param[in] ap              The access point handle
  /// @param[in] address_family  The address family
  /// @param[in] subnet_mask     The subnet mask; if you set this value to NULL, then the existing value will be deleted
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_update_ap()
  int wifi_manager_ap_set_subnet_mask(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Char> subnet_mask,
  ) {
    return _wifi_manager_ap_set_subnet_mask(
      ap,
      address_family,
      subnet_mask,
    );
  }

  late final _wifi_manager_ap_set_subnet_maskPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_ap_set_subnet_mask');
  late final _wifi_manager_ap_set_subnet_mask =
      _wifi_manager_ap_set_subnet_maskPtr.asFunction<
          int Function(wifi_manager_ap_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the gateway address.
  /// @since_tizen 3.0
  /// @remarks You must release @a gateway_address using free().
  /// @param[in] ap                The access point handle
  /// @param[in] address_family    The address family
  /// @param[out] gateway_address  The gateway address
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_gateway_address(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> gateway_address,
  ) {
    return _wifi_manager_ap_get_gateway_address(
      ap,
      address_family,
      gateway_address,
    );
  }

  late final _wifi_manager_ap_get_gateway_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_gateway_address');
  late final _wifi_manager_ap_get_gateway_address =
      _wifi_manager_ap_get_gateway_addressPtr.asFunction<
          int Function(
              wifi_manager_ap_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the gateway address.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[in] address_family    The address family
  /// @param[in] gateway_address   The gateway address \n
  /// If you set this value to @c NULL, then the existing value will be deleted.
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_update_ap()
  int wifi_manager_ap_set_gateway_address(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Char> gateway_address,
  ) {
    return _wifi_manager_ap_set_gateway_address(
      ap,
      address_family,
      gateway_address,
    );
  }

  late final _wifi_manager_ap_set_gateway_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_ap_set_gateway_address');
  late final _wifi_manager_ap_set_gateway_address =
      _wifi_manager_ap_set_gateway_addressPtr.asFunction<
          int Function(wifi_manager_ap_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the DHCP Server address.
  /// @since_tizen 4.0
  /// @remarks You must release @a dhcp_server using g_free().
  /// This function is supported only for IPv4 address family.
  /// @param[in] ap                The access point handle
  /// @param[in] address_family    The address family
  /// @param[out] dhcp_server      The DHCP server address
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_dhcp_server_address(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> dhcp_server,
  ) {
    return _wifi_manager_ap_get_dhcp_server_address(
      ap,
      address_family,
      dhcp_server,
    );
  }

  late final _wifi_manager_ap_get_dhcp_server_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_dhcp_server_address');
  late final _wifi_manager_ap_get_dhcp_server_address =
      _wifi_manager_ap_get_dhcp_server_addressPtr.asFunction<
          int Function(
              wifi_manager_ap_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the DHCP lease duration.
  /// @since_tizen 4.0
  /// @param[in] ap                        The access point handle
  /// @param[in] address_family            The address family
  /// @param[out] dhcp_lease_duration      The DHCP lease duration in seconds
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_dhcp_lease_duration(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Int> dhcp_lease_duration,
  ) {
    return _wifi_manager_ap_get_dhcp_lease_duration(
      ap,
      address_family,
      dhcp_lease_duration,
    );
  }

  late final _wifi_manager_ap_get_dhcp_lease_durationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_ap_h, ffi.Int32, ffi.Pointer<ffi.Int>)>>(
      'wifi_manager_ap_get_dhcp_lease_duration');
  late final _wifi_manager_ap_get_dhcp_lease_duration =
      _wifi_manager_ap_get_dhcp_lease_durationPtr.asFunction<
          int Function(wifi_manager_ap_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the proxy address.
  /// @since_tizen 3.0
  /// @remarks You must release @a proxy_address using free().
  /// @param[in] ap                The access point handle
  /// @param[in] address_family    The address family
  /// @param[out] proxy_address    The proxy address
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_proxy_address(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> proxy_address,
  ) {
    return _wifi_manager_ap_get_proxy_address(
      ap,
      address_family,
      proxy_address,
    );
  }

  late final _wifi_manager_ap_get_proxy_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_proxy_address');
  late final _wifi_manager_ap_get_proxy_address =
      _wifi_manager_ap_get_proxy_addressPtr.asFunction<
          int Function(
              wifi_manager_ap_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the proxy address.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[in] address_family    The address family
  /// @param[in] proxy_address        The proxy address \n
  /// If you set this value to @c NULL, then the existing value will be deleted.
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_update_ap()
  int wifi_manager_ap_set_proxy_address(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Char> proxy_address,
  ) {
    return _wifi_manager_ap_set_proxy_address(
      ap,
      address_family,
      proxy_address,
    );
  }

  late final _wifi_manager_ap_set_proxy_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_ap_set_proxy_address');
  late final _wifi_manager_ap_set_proxy_address =
      _wifi_manager_ap_set_proxy_addressPtr.asFunction<
          int Function(wifi_manager_ap_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the Proxy type.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[out] proxy_type       The type of proxy
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_proxy_type(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int32> proxy_type,
  ) {
    return _wifi_manager_ap_get_proxy_type(
      ap,
      proxy_type,
    );
  }

  late final _wifi_manager_ap_get_proxy_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_ap_get_proxy_type');
  late final _wifi_manager_ap_get_proxy_type =
      _wifi_manager_ap_get_proxy_typePtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the Proxy address.
  /// @details If you set Proxy type to #WIFI_MANAGER_PROXY_TYPE_AUTO or #WIFI_MANAGER_PROXY_TYPE_MANUAL, then Proxy will be restored.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[in] proxy_type        The type of proxy
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_update_ap()
  int wifi_manager_ap_set_proxy_type(
    wifi_manager_ap_h ap,
    int proxy_type,
  ) {
    return _wifi_manager_ap_set_proxy_type(
      ap,
      proxy_type,
    );
  }

  late final _wifi_manager_ap_set_proxy_typePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(wifi_manager_ap_h, ffi.Int32)>>(
      'wifi_manager_ap_set_proxy_type');
  late final _wifi_manager_ap_set_proxy_type =
      _wifi_manager_ap_set_proxy_typePtr
          .asFunction<int Function(wifi_manager_ap_h, int)>();

  /// @brief Gets the DNS address.
  /// @since_tizen 3.0
  /// @remarks The allowance of DNS address is @c 2.You must release @a dns_address using free().
  /// @param[in] ap                The access point handle
  /// @param[in] order             The order of DNS address; it starts from 1, which means first DNS address
  /// @param[in] address_family    The address family
  /// @param[out] dns_address      The DNS address
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_dns_address(
    wifi_manager_ap_h ap,
    int order,
    int address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> dns_address,
  ) {
    return _wifi_manager_ap_get_dns_address(
      ap,
      order,
      address_family,
      dns_address,
    );
  }

  late final _wifi_manager_ap_get_dns_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Int, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_dns_address');
  late final _wifi_manager_ap_get_dns_address =
      _wifi_manager_ap_get_dns_addressPtr.asFunction<
          int Function(wifi_manager_ap_h, int, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the DNS address.
  /// @since_tizen 3.0
  /// @remarks The allowance of DNS address is @c 2 \n
  /// @param[in] ap                The access point handle
  /// @param[in] order             The order of DNS address \n
  /// It starts from @c 1, which means first DNS address.
  /// @param[in] address_family    The address family
  /// @param[in] dns_address       The DNS address \n
  /// If you set this value to @c NULL, then the existing value will be deleted.
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED  Address family not supported
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_update_ap()
  int wifi_manager_ap_set_dns_address(
    wifi_manager_ap_h ap,
    int order,
    int address_family,
    ffi.Pointer<ffi.Char> dns_address,
  ) {
    return _wifi_manager_ap_set_dns_address(
      ap,
      order,
      address_family,
      dns_address,
    );
  }

  late final _wifi_manager_ap_set_dns_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_ap_set_dns_address');
  late final _wifi_manager_ap_set_dns_address =
      _wifi_manager_ap_set_dns_addressPtr.asFunction<
          int Function(wifi_manager_ap_h, int, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the Wi-Fi security mode.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[out] type             The type of Wi-Fi security
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_security_type(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _wifi_manager_ap_get_security_type(
      ap,
      type,
    );
  }

  late final _wifi_manager_ap_get_security_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_ap_get_security_type');
  late final _wifi_manager_ap_get_security_type =
      _wifi_manager_ap_get_security_typePtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the Wi-Fi security mode.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[in] type              The type of Wi-Fi security
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_set_security_type(
    wifi_manager_ap_h ap,
    int type,
  ) {
    return _wifi_manager_ap_set_security_type(
      ap,
      type,
    );
  }

  late final _wifi_manager_ap_set_security_typePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(wifi_manager_ap_h, ffi.Int32)>>(
      'wifi_manager_ap_set_security_type');
  late final _wifi_manager_ap_set_security_type =
      _wifi_manager_ap_set_security_typePtr
          .asFunction<int Function(wifi_manager_ap_h, int)>();

  /// @brief Gets the Wi-Fi encryption type.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[out] type             The type of Wi-Fi encryption
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_encryption_type(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _wifi_manager_ap_get_encryption_type(
      ap,
      type,
    );
  }

  late final _wifi_manager_ap_get_encryption_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_ap_get_encryption_type');
  late final _wifi_manager_ap_get_encryption_type =
      _wifi_manager_ap_get_encryption_typePtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the Wi-Fi encryption type.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[in] type              The type of Wi-Fi encryption
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_set_encryption_type(
    wifi_manager_ap_h ap,
    int type,
  ) {
    return _wifi_manager_ap_set_encryption_type(
      ap,
      type,
    );
  }

  late final _wifi_manager_ap_set_encryption_typePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(wifi_manager_ap_h, ffi.Int32)>>(
      'wifi_manager_ap_set_encryption_type');
  late final _wifi_manager_ap_set_encryption_type =
      _wifi_manager_ap_set_encryption_typePtr
          .asFunction<int Function(wifi_manager_ap_h, int)>();

  /// @brief Checks whether the passphrase is required or not.
  /// @since_tizen 3.0
  /// @remarks This function is not valid if security type is #WIFI_MANAGER_SECURITY_TYPE_EAP.
  /// @param[in] ap                The access point handle
  /// @param[out] required  @c true if passphrase is required,
  /// @c false if passphrase is not required.
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_is_passphrase_required(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Bool> required1,
  ) {
    return _wifi_manager_ap_is_passphrase_required(
      ap,
      required1,
    );
  }

  late final _wifi_manager_ap_is_passphrase_requiredPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Bool>)>>(
      'wifi_manager_ap_is_passphrase_required');
  late final _wifi_manager_ap_is_passphrase_required =
      _wifi_manager_ap_is_passphrase_requiredPtr
          .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the passphrase.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[in] passphrase        The passphrase of access point
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_set_passphrase(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Char> passphrase,
  ) {
    return _wifi_manager_ap_set_passphrase(
      ap,
      passphrase,
    );
  }

  late final _wifi_manager_ap_set_passphrasePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_ap_set_passphrase');
  late final _wifi_manager_ap_set_passphrase =
      _wifi_manager_ap_set_passphrasePtr
          .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Checks whether the WPS(Wi-Fi Protected Setup) is supported or not.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[out] supported  @c true if WPS is supported,
  /// otherwise @c false is WPS is not supported.
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_connect_by_wps_pbc()
  /// @see wifi_manager_connect_by_wps_pin()
  int wifi_manager_ap_is_wps_supported(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Bool> supported,
  ) {
    return _wifi_manager_ap_is_wps_supported(
      ap,
      supported,
    );
  }

  late final _wifi_manager_ap_is_wps_supportedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Bool>)>>('wifi_manager_ap_is_wps_supported');
  late final _wifi_manager_ap_is_wps_supported =
      _wifi_manager_ap_is_wps_supportedPtr
          .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the passphrase of EAP.
  /// @details You can set one of @a user_name and @a password as @c NULL.
  /// In this case, the value of a parameter which is set as @c NULL will be the previous value.
  /// But it is not allowed that both @a user_name and @a password are set as @c NULL.
  /// @since_tizen 3.0
  /// @remarks This function is valid only if the EAP type is #WIFI_MANAGER_EAP_TYPE_PEAP or #WIFI_MANAGER_EAP_TYPE_TTLS.
  /// @param[in] ap                The access point handle
  /// @param[in] user_name         The user name \n
  /// This value can be @c NULL.
  /// @param[in] password          The password \n
  /// This value can be @c NULL.
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_set_eap_passphrase(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Char> user_name,
    ffi.Pointer<ffi.Char> password,
  ) {
    return _wifi_manager_ap_set_eap_passphrase(
      ap,
      user_name,
      password,
    );
  }

  late final _wifi_manager_ap_set_eap_passphrasePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_ap_set_eap_passphrase');
  late final _wifi_manager_ap_set_eap_passphrase =
      _wifi_manager_ap_set_eap_passphrasePtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the passphrase of EAP.
  /// @since_tizen 3.0
  /// @remarks This function is valid only if the EAP type is #WIFI_MANAGER_EAP_TYPE_PEAP or #WIFI_MANAGER_EAP_TYPE_TTLS.
  /// You must release @a user_name using free().
  /// @param[in] ap                The access point handle
  /// @param[out] user_name        The user name
  /// @param[out] is_password_set  @c true if password is set,
  /// otherwise @c false if password is not set.
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_eap_passphrase(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Pointer<ffi.Char>> user_name,
    ffi.Pointer<ffi.Bool> is_password_set,
  ) {
    return _wifi_manager_ap_get_eap_passphrase(
      ap,
      user_name,
      is_password_set,
    );
  }

  late final _wifi_manager_ap_get_eap_passphrasePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_ap_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Bool>)>>('wifi_manager_ap_get_eap_passphrase');
  late final _wifi_manager_ap_get_eap_passphrase =
      _wifi_manager_ap_get_eap_passphrasePtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the CA Certificate of EAP.
  /// @since_tizen 3.0
  /// @remarks This function is valid only if the EAP type is #WIFI_MANAGER_EAP_TYPE_TLS.
  /// You must release @a file using free().
  /// @param[in] ap                The access point handle
  /// @param[out] file             The file path of CA Certificate
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_eap_ca_cert_file(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Pointer<ffi.Char>> file,
  ) {
    return _wifi_manager_ap_get_eap_ca_cert_file(
      ap,
      file,
    );
  }

  late final _wifi_manager_ap_get_eap_ca_cert_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_eap_ca_cert_file');
  late final _wifi_manager_ap_get_eap_ca_cert_file =
      _wifi_manager_ap_get_eap_ca_cert_filePtr.asFunction<
          int Function(
              wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the CA Certificate of EAP.
  /// @since_tizen 3.0
  /// @remarks This function is valid only if the EAP type is #WIFI_MANAGER_EAP_TYPE_TLS.
  /// @param[in] ap                The access point handle
  /// @param[in] file              The file path of CA Certificate
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_set_eap_ca_cert_file(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Char> file,
  ) {
    return _wifi_manager_ap_set_eap_ca_cert_file(
      ap,
      file,
    );
  }

  late final _wifi_manager_ap_set_eap_ca_cert_filePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_ap_set_eap_ca_cert_file');
  late final _wifi_manager_ap_set_eap_ca_cert_file =
      _wifi_manager_ap_set_eap_ca_cert_filePtr
          .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the Client Certificate of EAP.
  /// @since_tizen 3.0
  /// @remarks This function is valid only if the EAP type is #WIFI_MANAGER_EAP_TYPE_TLS.
  /// You must release @a file using free().
  /// @param[in] ap                The access point handle
  /// @param[out] file             The file path of Client Certificate
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_eap_client_cert_file(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Pointer<ffi.Char>> file,
  ) {
    return _wifi_manager_ap_get_eap_client_cert_file(
      ap,
      file,
    );
  }

  late final _wifi_manager_ap_get_eap_client_cert_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_eap_client_cert_file');
  late final _wifi_manager_ap_get_eap_client_cert_file =
      _wifi_manager_ap_get_eap_client_cert_filePtr.asFunction<
          int Function(
              wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the CA Certificate of EAP.
  /// @since_tizen 3.0
  /// @remarks This function is valid only if the EAP type is #WIFI_MANAGER_EAP_TYPE_TLS.
  /// @param[in] ap                The access point handle
  /// @param[in] file              The file path of Client Certificate
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_set_eap_client_cert_file(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Char> file,
  ) {
    return _wifi_manager_ap_set_eap_client_cert_file(
      ap,
      file,
    );
  }

  late final _wifi_manager_ap_set_eap_client_cert_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Char>)>>(
      'wifi_manager_ap_set_eap_client_cert_file');
  late final _wifi_manager_ap_set_eap_client_cert_file =
      _wifi_manager_ap_set_eap_client_cert_filePtr
          .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the private key file of EAP.
  /// @since_tizen 3.0
  /// @remarks This function is valid only if the EAP type is #WIFI_MANAGER_EAP_TYPE_TLS.
  /// You must release @a file using free().
  /// @param[in] ap                The access point handle
  /// @param[out] file             The file path of private key
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_eap_private_key_file(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Pointer<ffi.Char>> file,
  ) {
    return _wifi_manager_ap_get_eap_private_key_file(
      ap,
      file,
    );
  }

  late final _wifi_manager_ap_get_eap_private_key_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_ap_get_eap_private_key_file');
  late final _wifi_manager_ap_get_eap_private_key_file =
      _wifi_manager_ap_get_eap_private_key_filePtr.asFunction<
          int Function(
              wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the private key information of EAP.
  /// @since_tizen 3.0
  /// @remarks This function is valid only if the EAP type is #WIFI_MANAGER_EAP_TYPE_TLS.
  /// @param[in] ap                The access point handle
  /// @param[in] file              The file path of private key
  /// @param[in] password          The password
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_set_eap_private_key_info(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Char> file,
    ffi.Pointer<ffi.Char> password,
  ) {
    return _wifi_manager_ap_set_eap_private_key_info(
      ap,
      file,
      password,
    );
  }

  late final _wifi_manager_ap_set_eap_private_key_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>)>>(
      'wifi_manager_ap_set_eap_private_key_info');
  late final _wifi_manager_ap_set_eap_private_key_info =
      _wifi_manager_ap_set_eap_private_key_infoPtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the EAP type of Wi-Fi.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[out] type             The type of EAP
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_eap_type(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _wifi_manager_ap_get_eap_type(
      ap,
      type,
    );
  }

  late final _wifi_manager_ap_get_eap_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_ap_get_eap_type');
  late final _wifi_manager_ap_get_eap_type = _wifi_manager_ap_get_eap_typePtr
      .asFunction<int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the EAP type of Wi-Fi.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[in] type              The type of EAP
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_set_eap_type(
    wifi_manager_ap_h ap,
    int type,
  ) {
    return _wifi_manager_ap_set_eap_type(
      ap,
      type,
    );
  }

  late final _wifi_manager_ap_set_eap_typePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(wifi_manager_ap_h, ffi.Int32)>>(
      'wifi_manager_ap_set_eap_type');
  late final _wifi_manager_ap_set_eap_type = _wifi_manager_ap_set_eap_typePtr
      .asFunction<int Function(wifi_manager_ap_h, int)>();

  /// @brief Gets the type of EAP phase2 authentication of Wi-Fi.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[out] type             The type of EAP phase2 authentication
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_eap_auth_type(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _wifi_manager_ap_get_eap_auth_type(
      ap,
      type,
    );
  }

  late final _wifi_manager_ap_get_eap_auth_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_ap_get_eap_auth_type');
  late final _wifi_manager_ap_get_eap_auth_type =
      _wifi_manager_ap_get_eap_auth_typePtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the type of EAP phase2 authentication of Wi-Fi.
  /// @since_tizen 3.0
  /// @param[in] ap                The access point handle
  /// @param[in] type              The type of EAP phase2 authentication
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_set_eap_auth_type(
    wifi_manager_ap_h ap,
    int type,
  ) {
    return _wifi_manager_ap_set_eap_auth_type(
      ap,
      type,
    );
  }

  late final _wifi_manager_ap_set_eap_auth_typePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(wifi_manager_ap_h, ffi.Int32)>>(
      'wifi_manager_ap_set_eap_auth_type');
  late final _wifi_manager_ap_set_eap_auth_type =
      _wifi_manager_ap_set_eap_auth_typePtr
          .asFunction<int Function(wifi_manager_ap_h, int)>();

  /// @brief Gets the Wi-Fi disconnect reason from the supplicant.
  /// @since_tizen 3.0
  /// @param[in] ap                    The access point handle
  /// @param[out] disconnect_reason    The supplicant disconnect reason
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_disconnect_reason(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int32> disconnect_reason,
  ) {
    return _wifi_manager_ap_get_disconnect_reason(
      ap,
      disconnect_reason,
    );
  }

  late final _wifi_manager_ap_get_disconnect_reasonPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>>(
      'wifi_manager_ap_get_disconnect_reason');
  late final _wifi_manager_ap_get_disconnect_reason =
      _wifi_manager_ap_get_disconnect_reasonPtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the DNS config type.
  /// @since_tizen 4.0
  /// @param[in] ap              The access point handle
  /// @param[in] address_family  The address family
  /// @param[out] type           The DNS config type
  /// @return 0 on success, otherwise negative error value.
  /// @retval #WIFI_MANAGER_ERROR_NONE               Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED      Not supported
  int wifi_manager_ap_get_dns_config_type(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _wifi_manager_ap_get_dns_config_type(
      ap,
      address_family,
      type,
    );
  }

  late final _wifi_manager_ap_get_dns_config_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_ap_get_dns_config_type');
  late final _wifi_manager_ap_get_dns_config_type =
      _wifi_manager_ap_get_dns_config_typePtr.asFunction<
          int Function(wifi_manager_ap_h, int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the DNS config type.
  /// @since_tizen 4.0
  /// @param[in] ap              The access point handle
  /// @param[in] address_family  The address family
  /// @param[in] type            The DNS config type
  /// @return 0 on success, otherwise negative error value.
  /// @retval #WIFI_MANAGER_ERROR_NONE               Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED   Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED      Not supported
  /// @see wifi_manager_update_ap()
  int wifi_manager_ap_set_dns_config_type(
    wifi_manager_ap_h ap,
    int address_family,
    int type,
  ) {
    return _wifi_manager_ap_set_dns_config_type(
      ap,
      address_family,
      type,
    );
  }

  late final _wifi_manager_ap_set_dns_config_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
              ffi.Int32)>>('wifi_manager_ap_set_dns_config_type');
  late final _wifi_manager_ap_set_dns_config_type =
      _wifi_manager_ap_set_dns_config_typePtr
          .asFunction<int Function(wifi_manager_ap_h, int, int)>();

  /// @brief Gets the network prefix length.
  /// @since_tizen 4.0
  /// @param[in] ap              The access point handle
  /// @param[in] address_family  The address family
  /// @param[out] prefix_len     The network prefix length. \n
  /// In case of IPv4, it means netmask length \n
  /// (also called a prefix, e.g. 8, 16, 24, 32)
  /// @return 0 on success, otherwise negative error value.
  /// @retval #WIFI_MANAGER_ERROR_NONE                   Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER      Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED  Not supported
  int wifi_manager_ap_get_prefix_length(
    wifi_manager_ap_h ap,
    int address_family,
    ffi.Pointer<ffi.Int> prefix_len,
  ) {
    return _wifi_manager_ap_get_prefix_length(
      ap,
      address_family,
      prefix_len,
    );
  }

  late final _wifi_manager_ap_get_prefix_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
              ffi.Pointer<ffi.Int>)>>('wifi_manager_ap_get_prefix_length');
  late final _wifi_manager_ap_get_prefix_length =
      _wifi_manager_ap_get_prefix_lengthPtr.asFunction<
          int Function(wifi_manager_ap_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the network prefix length.
  /// @since_tizen 4.0
  /// @param[in] ap              The access point handle
  /// @param[in] address_family  The address family
  /// @param[in] prefix_len      The network prefix length. \n
  /// In case of IPv4, it means netmask length \n
  /// (also called a prefix, e.g. 8, 16, 24, 32)
  /// @return 0 on success, otherwise negative error value.
  /// @retval #WIFI_MANAGER_ERROR_NONE                   Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER      Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED  Not supported
  /// @see wifi_manager_update_ap()
  int wifi_manager_ap_set_prefix_length(
    wifi_manager_ap_h ap,
    int address_family,
    int prefix_len,
  ) {
    return _wifi_manager_ap_set_prefix_length(
      ap,
      address_family,
      prefix_len,
    );
  }

  late final _wifi_manager_ap_set_prefix_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h, ffi.Int32,
              ffi.Int)>>('wifi_manager_ap_set_prefix_length');
  late final _wifi_manager_ap_set_prefix_length =
      _wifi_manager_ap_set_prefix_lengthPtr
          .asFunction<int Function(wifi_manager_ap_h, int, int)>();

  /// @brief Gets the error state.
  /// @since_tizen 4.0
  /// @param[in] ap              The access point handle
  /// @param[out] error_state    The Wi-Fi connection error state
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_error_state(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int32> error_state,
  ) {
    return _wifi_manager_ap_get_error_state(
      ap,
      error_state,
    );
  }

  late final _wifi_manager_ap_get_error_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_ap_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_ap_get_error_state');
  late final _wifi_manager_ap_get_error_state =
      _wifi_manager_ap_get_error_statePtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the Wi-Fi Association Status Code from the supplicant.
  /// @since_tizen 5.0
  /// @param[in] ap              The access point handle
  /// @param[out] status_code    The supplicant Wi-Fi association status code
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_assoc_status_code(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Int32> status_code,
  ) {
    return _wifi_manager_ap_get_assoc_status_code(
      ap,
      status_code,
    );
  }

  late final _wifi_manager_ap_get_assoc_status_codePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>>(
      'wifi_manager_ap_get_assoc_status_code');
  late final _wifi_manager_ap_get_assoc_status_code =
      _wifi_manager_ap_get_assoc_status_codePtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the VSIE result of the AP.
  /// @since_tizen 5.0
  /// @remarks You must release @a vsie using free().
  ///
  /// @param[in] ap               The access point handle
  /// @param[out] vsie            The vendor specific information element
  /// @param[out] length          The VSIE length
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ap_get_vsie(
    wifi_manager_ap_h ap,
    ffi.Pointer<ffi.Pointer<ffi.Char>> vsie,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _wifi_manager_ap_get_vsie(
      ap,
      vsie,
      length,
    );
  }

  late final _wifi_manager_ap_get_vsiePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              wifi_manager_ap_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int>)>>('wifi_manager_ap_get_vsie');
  late final _wifi_manager_ap_get_vsie =
      _wifi_manager_ap_get_vsiePtr.asFunction<
          int Function(wifi_manager_ap_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Gets access point configuration handle.
  /// @since_tizen 3.0
  /// @remarks You must release @a config using wifi_manager_config_destroy().
  ///
  /// @param[in] wifi              The Wi-Fi handle
  /// @param[in] name              The access point name
  /// @param[in] passphrase        The access point passphrase
  /// @param[in] security_type     The access point security type
  /// @param[out] config           The access point configuration handle
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @pre This function needs a wifi_manager_initialize() call before use
  /// @see wifi_manager_config_destroy()
  int wifi_manager_config_create(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Char> passphrase,
    int security_type,
    ffi.Pointer<wifi_manager_config_h> config,
  ) {
    return _wifi_manager_config_create(
      wifi,
      name,
      passphrase,
      security_type,
      config,
    );
  }

  late final _wifi_manager_config_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_h,
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ffi.Int32,
                  ffi.Pointer<wifi_manager_config_h>)>>(
      'wifi_manager_config_create');
  late final _wifi_manager_config_create =
      _wifi_manager_config_createPtr.asFunction<
          int Function(
              wifi_manager_h,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              int,
              ffi.Pointer<wifi_manager_config_h>)>();

  /// @brief Clones the access point configuration handle.
  /// @since_tizen 3.0
  /// @remarks You must release @a cloned_config using wifi_manager_config_destroy().
  ///
  /// @param[in] origin            The origin access point configuration handle
  /// @param[out] cloned_config    The cloned access point configuration handle
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_config_destroy()
  int wifi_manager_config_clone(
    wifi_manager_config_h origin,
    ffi.Pointer<wifi_manager_config_h> cloned_config,
  ) {
    return _wifi_manager_config_clone(
      origin,
      cloned_config,
    );
  }

  late final _wifi_manager_config_clonePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_config_h, ffi.Pointer<wifi_manager_config_h>)>>(
      'wifi_manager_config_clone');
  late final _wifi_manager_config_clone =
      _wifi_manager_config_clonePtr.asFunction<
          int Function(
              wifi_manager_config_h, ffi.Pointer<wifi_manager_config_h>)>();

  /// @brief Destroys the access point configuration handle.
  /// @since_tizen 3.0
  ///
  /// @param[in] config            The access point configuration handle
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_config_create()
  /// @see wifi_manager_config_clone()
  int wifi_manager_config_destroy(
    wifi_manager_config_h config,
  ) {
    return _wifi_manager_config_destroy(
      config,
    );
  }

  late final _wifi_manager_config_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_config_h)>>(
          'wifi_manager_config_destroy');
  late final _wifi_manager_config_destroy = _wifi_manager_config_destroyPtr
      .asFunction<int Function(wifi_manager_config_h)>();

  /// @brief Saves Wi-Fi configuration of access point.
  /// @details When a configuration is changed, these changes will be not applied to the Connection Manager immediately.\n
  /// When you call this function, your changes affect the Connection Manager and the existing configuration is updated.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile
  ///
  /// @param[in] wifi              The Wi-Fi handle
  /// @param[in] config            The access point configuration handle
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_config_create()
  int wifi_manager_config_save(
    wifi_manager_h wifi,
    wifi_manager_config_h config,
  ) {
    return _wifi_manager_config_save(
      wifi,
      config,
    );
  }

  late final _wifi_manager_config_savePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h,
              wifi_manager_config_h)>>('wifi_manager_config_save');
  late final _wifi_manager_config_save = _wifi_manager_config_savePtr
      .asFunction<int Function(wifi_manager_h, wifi_manager_config_h)>();

  /// @brief Removes Wi-Fi configuration of access point.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile
  ///
  /// @param[in] wifi              The Wi-Fi handle
  /// @param[in] config            The access point configuration handle
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_config_create()
  /// @see wifi_manager_config_foreach_configuration()
  int wifi_manager_config_remove(
    wifi_manager_h wifi,
    wifi_manager_config_h config,
  ) {
    return _wifi_manager_config_remove(
      wifi,
      config,
    );
  }

  late final _wifi_manager_config_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h,
              wifi_manager_config_h)>>('wifi_manager_config_remove');
  late final _wifi_manager_config_remove = _wifi_manager_config_removePtr
      .asFunction<int Function(wifi_manager_h, wifi_manager_config_h)>();

  /// @brief Gets configurations of an access point.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.profile
  ///
  /// @param[in] wifi              The Wi-Fi handle
  /// @param[in] callback          The callback to be called
  /// @param[in] user_data         The user data passed to the callback function
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @pre This function needs wifi_manager_initialize() before use.
  /// @post This function invokes wifi_manager_config_list_cb().
  int wifi_manager_config_foreach_configuration(
    wifi_manager_h wifi,
    wifi_manager_config_list_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_config_foreach_configuration(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_config_foreach_configurationPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h, wifi_manager_config_list_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_config_foreach_configuration');
  late final _wifi_manager_config_foreach_configuration =
      _wifi_manager_config_foreach_configurationPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_config_list_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the name of access point from configuration.
  /// @since_tizen 3.0
  /// @remarks You must release @a name using free().
  ///
  /// @param[in] config            The access point configuration handle
  /// @param[out] name             The name of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_config_get_name(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _wifi_manager_config_get_name(
      config,
      name,
    );
  }

  late final _wifi_manager_config_get_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_config_get_name');
  late final _wifi_manager_config_get_name =
      _wifi_manager_config_get_namePtr.asFunction<
          int Function(
              wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the security type of access point from configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config            The access point configuration handle
  /// @param[out] security_type    The security type of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_config_get_security_type(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Int32> security_type,
  ) {
    return _wifi_manager_config_get_security_type(
      config,
      security_type,
    );
  }

  late final _wifi_manager_config_get_security_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_config_h, ffi.Pointer<ffi.Int32>)>>(
      'wifi_manager_config_get_security_type');
  late final _wifi_manager_config_get_security_type =
      _wifi_manager_config_get_security_typePtr.asFunction<
          int Function(wifi_manager_config_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets access point proxy address configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config            The access point configuration handle
  /// @param[in] address_family    The address family
  /// @param[in] proxy_address     The proxy address
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED Not supported address family
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_config_save()
  int wifi_manager_config_set_proxy_address(
    wifi_manager_config_h config,
    int address_family,
    ffi.Pointer<ffi.Char> proxy_address,
  ) {
    return _wifi_manager_config_set_proxy_address(
      config,
      address_family,
      proxy_address,
    );
  }

  late final _wifi_manager_config_set_proxy_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_config_h, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_config_set_proxy_address');
  late final _wifi_manager_config_set_proxy_address =
      _wifi_manager_config_set_proxy_addressPtr.asFunction<
          int Function(wifi_manager_config_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the proxy address of access point from configuration.
  /// @since_tizen 3.0
  /// @remarks You must release @a proxy_address using free().
  ///
  /// @param[in] config            The access point configuration handle
  /// @param[out] address_family   The address family
  /// @param[out] proxy_address    The proxy address
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_config_get_proxy_address(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Int32> address_family,
    ffi.Pointer<ffi.Pointer<ffi.Char>> proxy_address,
  ) {
    return _wifi_manager_config_get_proxy_address(
      config,
      address_family,
      proxy_address,
    );
  }

  late final _wifi_manager_config_get_proxy_addressPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_config_h, ffi.Pointer<ffi.Int32>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_config_get_proxy_address');
  late final _wifi_manager_config_get_proxy_address =
      _wifi_manager_config_get_proxy_addressPtr.asFunction<
          int Function(wifi_manager_config_h, ffi.Pointer<ffi.Int32>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the hidden property of access point from the configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config            The access point configuration handle
  /// @param[in] is_hidden         The new value of the hidden property
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  /// @see wifi_manager_config_save()
  int wifi_manager_config_set_hidden_ap_property(
    wifi_manager_config_h config,
    bool is_hidden,
  ) {
    return _wifi_manager_config_set_hidden_ap_property(
      config,
      is_hidden,
    );
  }

  late final _wifi_manager_config_set_hidden_ap_propertyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_config_h,
              ffi.Bool)>>('wifi_manager_config_set_hidden_ap_property');
  late final _wifi_manager_config_set_hidden_ap_property =
      _wifi_manager_config_set_hidden_ap_propertyPtr
          .asFunction<int Function(wifi_manager_config_h, bool)>();

  /// @brief Gets the hidden property of access point from the configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config            The access point configuration handle
  /// @param[out] is_hidden        The hidden property of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_config_get_hidden_ap_property(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Bool> is_hidden,
  ) {
    return _wifi_manager_config_get_hidden_ap_property(
      config,
      is_hidden,
    );
  }

  late final _wifi_manager_config_get_hidden_ap_propertyPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_config_h, ffi.Pointer<ffi.Bool>)>>(
      'wifi_manager_config_get_hidden_ap_property');
  late final _wifi_manager_config_get_hidden_ap_property =
      _wifi_manager_config_get_hidden_ap_propertyPtr.asFunction<
          int Function(wifi_manager_config_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets access point anonymous identity from configuration.
  /// @since_tizen 3.0
  /// @remarks You must release @a anonymous_identity using free().
  ///
  /// @param[in] config                The access point configuration handle
  /// @param[out] anonymous_identity   The anonymous identity of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  int wifi_manager_config_get_eap_anonymous_identity(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Pointer<ffi.Char>> anonymous_identity,
  ) {
    return _wifi_manager_config_get_eap_anonymous_identity(
      config,
      anonymous_identity,
    );
  }

  late final _wifi_manager_config_get_eap_anonymous_identityPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_config_get_eap_anonymous_identity');
  late final _wifi_manager_config_get_eap_anonymous_identity =
      _wifi_manager_config_get_eap_anonymous_identityPtr.asFunction<
          int Function(
              wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets access point anonymous identity to configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config                The access point configuration handle
  /// @param[in] anonymous_identity    The anonymous identity
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @see wifi_manager_config_save()
  int wifi_manager_config_set_eap_anonymous_identity(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Char> anonymous_identity,
  ) {
    return _wifi_manager_config_set_eap_anonymous_identity(
      config,
      anonymous_identity,
    );
  }

  late final _wifi_manager_config_set_eap_anonymous_identityPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_config_h, ffi.Pointer<ffi.Char>)>>(
      'wifi_manager_config_set_eap_anonymous_identity');
  late final _wifi_manager_config_set_eap_anonymous_identity =
      _wifi_manager_config_set_eap_anonymous_identityPtr.asFunction<
          int Function(wifi_manager_config_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets access point cacert file from configuration.
  /// @since_tizen 3.0
  /// @remarks You must release @a ca_cert using free().
  /// @remarks The mediastorage privilege http://tizen.org/privilege/mediastorage is needed \n
  /// if @a image_path is relevant to media storage.\n
  /// The externalstorage privilege http://tizen.org/privilege/externalstorage is needed \n
  /// if @a image_path is relevant to external storage.
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[out] ca_cert         The certification authority(CA) certificates file of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  int wifi_manager_config_get_eap_ca_cert_file(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Pointer<ffi.Char>> ca_cert,
  ) {
    return _wifi_manager_config_get_eap_ca_cert_file(
      config,
      ca_cert,
    );
  }

  late final _wifi_manager_config_get_eap_ca_cert_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_config_get_eap_ca_cert_file');
  late final _wifi_manager_config_get_eap_ca_cert_file =
      _wifi_manager_config_get_eap_ca_cert_filePtr.asFunction<
          int Function(
              wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets access point cacert file to configuration.
  /// @since_tizen 3.0
  /// @remarks The mediastorage privilege http://tizen.org/privilege/mediastorage is needed \n
  /// if @a image_path is relevant to media storage.\n
  /// The externalstorage privilege http://tizen.org/privilege/externalstorage is needed \n
  /// if @a image_path is relevant to external storage.
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[in] ca_cert          The certification authority(CA) certificates file of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @see wifi_manager_config_save()
  int wifi_manager_config_set_eap_ca_cert_file(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Char> ca_cert,
  ) {
    return _wifi_manager_config_set_eap_ca_cert_file(
      config,
      ca_cert,
    );
  }

  late final _wifi_manager_config_set_eap_ca_cert_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_config_h, ffi.Pointer<ffi.Char>)>>(
      'wifi_manager_config_set_eap_ca_cert_file');
  late final _wifi_manager_config_set_eap_ca_cert_file =
      _wifi_manager_config_set_eap_ca_cert_filePtr.asFunction<
          int Function(wifi_manager_config_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets access point client cert file from configuration.
  /// @since_tizen 3.0
  /// @remarks You must release @a client_cert using free().
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[out] client_cert     The certification authority(CA) certificates file of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  int wifi_manager_config_get_eap_client_cert_file(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Pointer<ffi.Char>> client_cert,
  ) {
    return _wifi_manager_config_get_eap_client_cert_file(
      config,
      client_cert,
    );
  }

  late final _wifi_manager_config_get_eap_client_cert_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_config_get_eap_client_cert_file');
  late final _wifi_manager_config_get_eap_client_cert_file =
      _wifi_manager_config_get_eap_client_cert_filePtr.asFunction<
          int Function(
              wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets access point client cert file to configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[in] private_key      The private key file
  /// @param[in] client_cert      The certification authority(CA) certificates file of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @see wifi_manager_config_save()
  int wifi_manager_config_set_eap_client_cert_file(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Char> private_key,
    ffi.Pointer<ffi.Char> client_cert,
  ) {
    return _wifi_manager_config_set_eap_client_cert_file(
      config,
      private_key,
      client_cert,
    );
  }

  late final _wifi_manager_config_set_eap_client_cert_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_config_h, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>)>>(
      'wifi_manager_config_set_eap_client_cert_file');
  late final _wifi_manager_config_set_eap_client_cert_file =
      _wifi_manager_config_set_eap_client_cert_filePtr.asFunction<
          int Function(wifi_manager_config_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>();

  /// @brief Gets access point identity from configuration.
  /// @since_tizen 3.0
  /// @remarks You must release @a identity using free().
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[out] identity        The identity of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  int wifi_manager_config_get_eap_identity(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Pointer<ffi.Char>> identity,
  ) {
    return _wifi_manager_config_get_eap_identity(
      config,
      identity,
    );
  }

  late final _wifi_manager_config_get_eap_identityPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_config_get_eap_identity');
  late final _wifi_manager_config_get_eap_identity =
      _wifi_manager_config_get_eap_identityPtr.asFunction<
          int Function(
              wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets access point identity to configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[in] identity         The identity
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @see wifi_manager_config_save()
  int wifi_manager_config_set_eap_identity(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Char> identity,
  ) {
    return _wifi_manager_config_set_eap_identity(
      config,
      identity,
    );
  }

  late final _wifi_manager_config_set_eap_identityPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_config_h,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_config_set_eap_identity');
  late final _wifi_manager_config_set_eap_identity =
      _wifi_manager_config_set_eap_identityPtr.asFunction<
          int Function(wifi_manager_config_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets access point EAP type from configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[out] eap_type        The EAP type of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  int wifi_manager_config_get_eap_type(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Int32> eap_type,
  ) {
    return _wifi_manager_config_get_eap_type(
      config,
      eap_type,
    );
  }

  late final _wifi_manager_config_get_eap_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_config_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_config_get_eap_type');
  late final _wifi_manager_config_get_eap_type =
      _wifi_manager_config_get_eap_typePtr.asFunction<
          int Function(wifi_manager_config_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets access point EAP type to configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[in] eap_type         The EAP type
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @see wifi_manager_config_save()
  int wifi_manager_config_set_eap_type(
    wifi_manager_config_h config,
    int eap_type,
  ) {
    return _wifi_manager_config_set_eap_type(
      config,
      eap_type,
    );
  }

  late final _wifi_manager_config_set_eap_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_config_h,
              ffi.Int32)>>('wifi_manager_config_set_eap_type');
  late final _wifi_manager_config_set_eap_type =
      _wifi_manager_config_set_eap_typePtr
          .asFunction<int Function(wifi_manager_config_h, int)>();

  /// @brief Gets access point EAP auth type from configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[out] eap_auth_type   The EAP auth type of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  int wifi_manager_config_get_eap_auth_type(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Int32> eap_auth_type,
  ) {
    return _wifi_manager_config_get_eap_auth_type(
      config,
      eap_auth_type,
    );
  }

  late final _wifi_manager_config_get_eap_auth_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_config_h, ffi.Pointer<ffi.Int32>)>>(
      'wifi_manager_config_get_eap_auth_type');
  late final _wifi_manager_config_get_eap_auth_type =
      _wifi_manager_config_get_eap_auth_typePtr.asFunction<
          int Function(wifi_manager_config_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets access point EAP auth type to configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[in] eap_auth_type    The EAP auth type
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @see wifi_manager_config_save()
  int wifi_manager_config_set_eap_auth_type(
    wifi_manager_config_h config,
    int eap_auth_type,
  ) {
    return _wifi_manager_config_set_eap_auth_type(
      config,
      eap_auth_type,
    );
  }

  late final _wifi_manager_config_set_eap_auth_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_config_h,
              ffi.Int32)>>('wifi_manager_config_set_eap_auth_type');
  late final _wifi_manager_config_set_eap_auth_type =
      _wifi_manager_config_set_eap_auth_typePtr
          .asFunction<int Function(wifi_manager_config_h, int)>();

  /// @brief Gets access point subject match from configuration.
  /// @since_tizen 3.0
  /// @remarks You must release @a subject_match using free().
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[out] subject_match   The subject match of access point
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  int wifi_manager_config_get_eap_subject_match(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Pointer<ffi.Char>> subject_match,
  ) {
    return _wifi_manager_config_get_eap_subject_match(
      config,
      subject_match,
    );
  }

  late final _wifi_manager_config_get_eap_subject_matchPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_config_get_eap_subject_match');
  late final _wifi_manager_config_get_eap_subject_match =
      _wifi_manager_config_get_eap_subject_matchPtr.asFunction<
          int Function(
              wifi_manager_config_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets access point subject match to configuration.
  /// @since_tizen 3.0
  ///
  /// @param[in] config           The access point configuration handle
  /// @param[in] subject_match    The subject match
  ///
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @see wifi_manager_config_save()
  int wifi_manager_config_set_eap_subject_match(
    wifi_manager_config_h config,
    ffi.Pointer<ffi.Char> subject_match,
  ) {
    return _wifi_manager_config_set_eap_subject_match(
      config,
      subject_match,
    );
  }

  late final _wifi_manager_config_set_eap_subject_matchPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_config_h, ffi.Pointer<ffi.Char>)>>(
      'wifi_manager_config_set_eap_subject_match');
  late final _wifi_manager_config_set_eap_subject_match =
      _wifi_manager_config_set_eap_subject_matchPtr.asFunction<
          int Function(wifi_manager_config_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Registers the callback called when a TDLS device is found.
  /// @since_tizen 4.0
  ///
  /// @param[in] wifi             The Wi-Fi handle
  /// @param[in] callback         The callback function to be called
  /// @param[in] user_data The user data passed to the callback function
  ///
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_tdls_set_discovered_cb(
    wifi_manager_h wifi,
    wifi_manager_tdls_discovered_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_tdls_set_discovered_cb(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_tdls_set_discovered_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, wifi_manager_tdls_discovered_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_tdls_set_discovered_cb');
  late final _wifi_manager_tdls_set_discovered_cb =
      _wifi_manager_tdls_set_discovered_cbPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_tdls_discovered_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback called when TDLS device is found.
  /// @since_tizen 4.0
  ///
  /// @param[in] wifi             The Wi-Fi handle
  ///
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_tdls_unset_discovered_cb(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_tdls_unset_discovered_cb(
      wifi,
    );
  }

  late final _wifi_manager_tdls_unset_discovered_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_tdls_unset_discovered_cb');
  late final _wifi_manager_tdls_unset_discovered_cb =
      _wifi_manager_tdls_unset_discovered_cbPtr
          .asFunction<int Function(wifi_manager_h)>();

  /// @brief Discovers devices that support TDLS.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  ///
  /// @param[in] wifi             The Wi-Fi handle
  /// @param[in] peer_mac_addr    The MAC address (e.g., ff:ff:ff:ff:ff:ff,
  /// AA:BB:CC:DD:EE:FF) of the peer to be discovered
  ///
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_tdls_start_discovery(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> peer_mac_addr,
  ) {
    return _wifi_manager_tdls_start_discovery(
      wifi,
      peer_mac_addr,
    );
  }

  late final _wifi_manager_tdls_start_discoveryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_tdls_start_discovery');
  late final _wifi_manager_tdls_start_discovery =
      _wifi_manager_tdls_start_discoveryPtr
          .asFunction<int Function(wifi_manager_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Connects to a peer device.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  ///
  /// @param[in] wifi             The Wi-Fi handle
  /// @param[in] peer_mac_addr    The MAC address of the peer device to be connected
  ///
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_tdls_connect(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> peer_mac_addr,
  ) {
    return _wifi_manager_tdls_connect(
      wifi,
      peer_mac_addr,
    );
  }

  late final _wifi_manager_tdls_connectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_tdls_connect');
  late final _wifi_manager_tdls_connect = _wifi_manager_tdls_connectPtr
      .asFunction<int Function(wifi_manager_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Disconnects the connected peer.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  ///
  /// @param[in] wifi                The Wi-Fi handle
  /// @param[in] peer_mac_addr       The MAC address of the connected peer
  ///
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_tdls_disconnect(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> peer_mac_addr,
  ) {
    return _wifi_manager_tdls_disconnect(
      wifi,
      peer_mac_addr,
    );
  }

  late final _wifi_manager_tdls_disconnectPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h,
              ffi.Pointer<ffi.Char>)>>('wifi_manager_tdls_disconnect');
  late final _wifi_manager_tdls_disconnect = _wifi_manager_tdls_disconnectPtr
      .asFunction<int Function(wifi_manager_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets Peer Mac address of Connected peer.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  ///
  /// @remarks The @a peer_mac_addr should be freed using free().
  /// @param[in] wifi                The Wi-Fi handle
  /// @param[out] peer_mac_addr      The MAC address of the connected peer
  ///
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_NO_CONNECTION        No active TDLS Connection
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_tdls_get_connected_peer(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Pointer<ffi.Char>> peer_mac_addr,
  ) {
    return _wifi_manager_tdls_get_connected_peer(
      wifi,
      peer_mac_addr,
    );
  }

  late final _wifi_manager_tdls_get_connected_peerPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  wifi_manager_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'wifi_manager_tdls_get_connected_peer');
  late final _wifi_manager_tdls_get_connected_peer =
      _wifi_manager_tdls_get_connected_peerPtr.asFunction<
          int Function(wifi_manager_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Registers the callback called when TDLS state is changed.
  /// @since_tizen 3.0
  ///
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  ///
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_tdls_set_state_changed_cb(
    wifi_manager_h wifi,
    wifi_manager_tdls_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_tdls_set_state_changed_cb(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_tdls_set_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h,
                  wifi_manager_tdls_state_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'wifi_manager_tdls_set_state_changed_cb');
  late final _wifi_manager_tdls_set_state_changed_cb =
      _wifi_manager_tdls_set_state_changed_cbPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_tdls_state_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback called when TDLS state is changed.
  /// @since_tizen 3.0
  ///
  /// @param[in] wifi            The Wi-Fi handle
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_tdls_unset_state_changed_cb(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_tdls_unset_state_changed_cb(
      wifi,
    );
  }

  late final _wifi_manager_tdls_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_tdls_unset_state_changed_cb');
  late final _wifi_manager_tdls_unset_state_changed_cb =
      _wifi_manager_tdls_unset_state_changed_cbPtr
          .asFunction<int Function(wifi_manager_h)>();

  /// @brief Enables a TDLS channel switching request.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  ///
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] peer_mac_addr   The MAC address of the connected TDLS peer
  /// @param[in] freq            The new frequency [MHz]
  ///
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_tdls_enable_channel_switching(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> peer_mac_addr,
    int freq,
  ) {
    return _wifi_manager_tdls_enable_channel_switching(
      wifi,
      peer_mac_addr,
      freq,
    );
  }

  late final _wifi_manager_tdls_enable_channel_switchingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, ffi.Pointer<ffi.Char>,
              ffi.Int)>>('wifi_manager_tdls_enable_channel_switching');
  late final _wifi_manager_tdls_enable_channel_switching =
      _wifi_manager_tdls_enable_channel_switchingPtr.asFunction<
          int Function(wifi_manager_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Disables a TDLS channel switching request.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  ///
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] peer_mac_addr   The MAC address of the connected TDLS peer
  ///
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_tdls_disable_channel_switching(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Char> peer_mac_addr,
  ) {
    return _wifi_manager_tdls_disable_channel_switching(
      wifi,
      peer_mac_addr,
    );
  }

  late final _wifi_manager_tdls_disable_channel_switchingPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h, ffi.Pointer<ffi.Char>)>>(
      'wifi_manager_tdls_disable_channel_switching');
  late final _wifi_manager_tdls_disable_channel_switching =
      _wifi_manager_tdls_disable_channel_switchingPtr
          .asFunction<int Function(wifi_manager_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Registers the callback called when IP conflict state is changed.
  /// @since_tizen 5.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] callback        The callback function to be called
  /// @param[in] user_data       The user data passed to the callback function
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_set_ip_conflict_cb(
    wifi_manager_h wifi,
    wifi_manager_ip_conflict_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _wifi_manager_set_ip_conflict_cb(
      wifi,
      callback,
      user_data,
    );
  }

  late final _wifi_manager_set_ip_conflict_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h, wifi_manager_ip_conflict_cb,
              ffi.Pointer<ffi.Void>)>>('wifi_manager_set_ip_conflict_cb');
  late final _wifi_manager_set_ip_conflict_cb =
      _wifi_manager_set_ip_conflict_cbPtr.asFunction<
          int Function(wifi_manager_h, wifi_manager_ip_conflict_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback called when IP conflict state is changed.
  /// @since_tizen 5.0
  /// @param[in] wifi            The Wi-Fi handle
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_unset_ip_conflict_cb(
    wifi_manager_h wifi,
  ) {
    return _wifi_manager_unset_ip_conflict_cb(
      wifi,
    );
  }

  late final _wifi_manager_unset_ip_conflict_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h)>>(
          'wifi_manager_unset_ip_conflict_cb');
  late final _wifi_manager_unset_ip_conflict_cb =
      _wifi_manager_unset_ip_conflict_cbPtr
          .asFunction<int Function(wifi_manager_h)>();

  /// @brief Enables or disables IP conflict detection.
  /// @since_tizen 5.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.set
  ///
  /// @param[in] wifi            The Wi-Fi handle
  /// @param[in] detect          True or false boolean to enable or disable
  ///
  /// @return @c 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_INVALID_OPERATION    Invalid operation
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_set_ip_conflict_detect_enable(
    wifi_manager_h wifi,
    bool detect,
  ) {
    return _wifi_manager_set_ip_conflict_detect_enable(
      wifi,
      detect,
    );
  }

  late final _wifi_manager_set_ip_conflict_detect_enablePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(wifi_manager_h, ffi.Bool)>>(
          'wifi_manager_set_ip_conflict_detect_enable');
  late final _wifi_manager_set_ip_conflict_detect_enable =
      _wifi_manager_set_ip_conflict_detect_enablePtr
          .asFunction<int Function(wifi_manager_h, bool)>();

  /// @brief Checks whether IP conflict detection is enabled.
  /// @since_tizen 5.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] wifi        The Wi-Fi handle
  /// @param[out] state     @c true if IP conflict detection is enabled,
  /// otherwise @c false if IP conflict detection is disabled.
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_ip_conflict_detect_is_enabled(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Bool> state,
  ) {
    return _wifi_manager_ip_conflict_detect_is_enabled(
      wifi,
      state,
    );
  }

  late final _wifi_manager_ip_conflict_detect_is_enabledPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(wifi_manager_h, ffi.Pointer<ffi.Bool>)>>(
      'wifi_manager_ip_conflict_detect_is_enabled');
  late final _wifi_manager_ip_conflict_detect_is_enabled =
      _wifi_manager_ip_conflict_detect_is_enabledPtr
          .asFunction<int Function(wifi_manager_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the state of the IP conflict.
  /// @since_tizen 5.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/network.get
  /// @param[in] wifi          The Wi-Fi handle
  /// @param[out] state        The current state of IP conflict
  /// @return 0 on success, otherwise negative error value
  /// @retval #WIFI_MANAGER_ERROR_NONE                 Successful
  /// @retval #WIFI_MANAGER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #WIFI_MANAGER_ERROR_OPERATION_FAILED     Operation failed
  /// @retval #WIFI_MANAGER_ERROR_PERMISSION_DENIED    Permission Denied
  /// @retval #WIFI_MANAGER_ERROR_NOT_SUPPORTED        Not supported
  int wifi_manager_get_ip_conflict_state(
    wifi_manager_h wifi,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _wifi_manager_get_ip_conflict_state(
      wifi,
      state,
    );
  }

  late final _wifi_manager_get_ip_conflict_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(wifi_manager_h,
              ffi.Pointer<ffi.Int32>)>>('wifi_manager_get_ip_conflict_state');
  late final _wifi_manager_get_ip_conflict_state =
      _wifi_manager_get_ip_conflict_statePtr
          .asFunction<int Function(wifi_manager_h, ffi.Pointer<ffi.Int32>)>();

  /// @platform
  /// @brief Gets the handle of a current engine information.
  /// @since_tizen 3.0
  /// @remarks @a engine should be released using csr_engine_destroy().
  /// @param[in] id Engine identifier to get handle
  /// @param[out] engine A pointer of the engine information handle
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a engine is invalid
  /// @retval #CSR_ERROR_ENGINE_NOT_EXIST No engine exists
  /// @retval #CSR_ERROR_ENGINE_NOT_ACTIVATED Engine is not activated
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_engine_destroy()
  int csr_get_current_engine(
    int id,
    ffi.Pointer<csr_engine_h> engine,
  ) {
    return _csr_get_current_engine(
      id,
      engine,
    );
  }

  late final _csr_get_current_enginePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<csr_engine_h>)>>('csr_get_current_engine');
  late final _csr_get_current_engine = _csr_get_current_enginePtr
      .asFunction<int Function(int, ffi.Pointer<csr_engine_h>)>();

  /// @platform
  /// @brief Extracts a vendor name from the engine information handle.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/antivirus.admin
  /// @remarks @a vendor must be released using free().
  /// @param[in] engine The engine information handle
  /// @param[out] vendor A pointer of the engine's vendor name
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid engine information handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a vendor is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_get_current_engine()
  int csr_engine_get_vendor(
    csr_engine_h engine,
    ffi.Pointer<ffi.Pointer<ffi.Char>> vendor,
  ) {
    return _csr_engine_get_vendor(
      engine,
      vendor,
    );
  }

  late final _csr_engine_get_vendorPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_engine_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('csr_engine_get_vendor');
  late final _csr_engine_get_vendor = _csr_engine_get_vendorPtr.asFunction<
      int Function(csr_engine_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @platform
  /// @brief Extracts an engine name from the engine information handle.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/antivirus.admin
  /// @remarks @a name must be released using free().
  /// @param[in] engine The engine information handle
  /// @param[out] name A pointer of the engine's name
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid engine information handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a name is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_get_current_engine()
  int csr_engine_get_name(
    csr_engine_h engine,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _csr_engine_get_name(
      engine,
      name,
    );
  }

  late final _csr_engine_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_engine_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('csr_engine_get_name');
  late final _csr_engine_get_name = _csr_engine_get_namePtr.asFunction<
      int Function(csr_engine_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @platform
  /// @brief Extracts an engine version from the engine information handle.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/antivirus.admin
  /// @remarks @a version must be released using free().
  /// @param[in] engine An engine information handle
  /// @param[out] version A pointer of the engine's version
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid engine information handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a version is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_get_current_engine()
  int csr_engine_get_version(
    csr_engine_h engine,
    ffi.Pointer<ffi.Pointer<ffi.Char>> version,
  ) {
    return _csr_engine_get_version(
      engine,
      version,
    );
  }

  late final _csr_engine_get_versionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_engine_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('csr_engine_get_version');
  late final _csr_engine_get_version = _csr_engine_get_versionPtr.asFunction<
      int Function(csr_engine_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @platform
  /// @brief Extracts an engine's data version from the engine information handle.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/antivirus.admin
  /// @remarks @a version must be released using free().
  /// @param[in] engine The engine information handle
  /// @param[out] version A pointer of the data version. It can be null
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid engine information handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a version is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_get_current_engine()
  int csr_engine_get_data_version(
    csr_engine_h engine,
    ffi.Pointer<ffi.Pointer<ffi.Char>> version,
  ) {
    return _csr_engine_get_data_version(
      engine,
      version,
    );
  }

  late final _csr_engine_get_data_versionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  csr_engine_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'csr_engine_get_data_version');
  late final _csr_engine_get_data_version =
      _csr_engine_get_data_versionPtr.asFunction<
          int Function(csr_engine_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @platform
  /// @brief Extracts the latest update time of an engine from the engine information handle.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/antivirus.admin
  /// @param[in] engine The engine information handle
  /// @param[out] time A pointer of lasted update time
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid engine information handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a time is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_get_current_engine()
  int csr_engine_get_latest_update_time(
    csr_engine_h engine,
    ffi.Pointer<time_t> time,
  ) {
    return _csr_engine_get_latest_update_time(
      engine,
      time,
    );
  }

  late final _csr_engine_get_latest_update_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_engine_h,
              ffi.Pointer<time_t>)>>('csr_engine_get_latest_update_time');
  late final _csr_engine_get_latest_update_time =
      _csr_engine_get_latest_update_timePtr
          .asFunction<int Function(csr_engine_h, ffi.Pointer<time_t>)>();

  /// @platform
  /// @brief Extracts the state of engine activation from the engine information handle.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/antivirus.admin
  /// @param[in] engine The engine information handle
  /// @param[out] activated A pointer of the engine activation state
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid engine information handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a activated is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_get_current_engine()
  int csr_engine_get_activated(
    csr_engine_h engine,
    ffi.Pointer<ffi.Int32> activated,
  ) {
    return _csr_engine_get_activated(
      engine,
      activated,
    );
  }

  late final _csr_engine_get_activatedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_engine_h,
              ffi.Pointer<ffi.Int32>)>>('csr_engine_get_activated');
  late final _csr_engine_get_activated = _csr_engine_get_activatedPtr
      .asFunction<int Function(csr_engine_h, ffi.Pointer<ffi.Int32>)>();

  /// @platform
  /// @brief Enable or disable an engine.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/antivirus.admin
  /// @remarks If an engine is disabled, all major operations would be failed with #CSR_ERROR_ENGINE_DISABLED error code.
  /// @param[in] engine The engine information handle
  /// @param[in] state The engine state
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid engine information handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a state is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_get_current_engine()
  int csr_engine_set_state(
    csr_engine_h engine,
    int state,
  ) {
    return _csr_engine_set_state(
      engine,
      state,
    );
  }

  late final _csr_engine_set_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(csr_engine_h, ffi.Int32)>>(
          'csr_engine_set_state');
  late final _csr_engine_set_state =
      _csr_engine_set_statePtr.asFunction<int Function(csr_engine_h, int)>();

  /// @platform
  /// @brief Gets the engine state.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/antivirus.admin
  /// @param[in] engine The engine information handle
  /// @param[out] state A pointer of the engine state
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid engine information handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a state is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_get_current_engine()
  int csr_engine_get_state(
    csr_engine_h engine,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _csr_engine_get_state(
      engine,
      state,
    );
  }

  late final _csr_engine_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              csr_engine_h, ffi.Pointer<ffi.Int32>)>>('csr_engine_get_state');
  late final _csr_engine_get_state = _csr_engine_get_statePtr
      .asFunction<int Function(csr_engine_h, ffi.Pointer<ffi.Int32>)>();

  /// @platform
  /// @brief Releases all system resources associated with a engine information handle.
  /// @since_tizen 3.0
  /// @param[in] engine The engine information handle
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid engine information handle
  int csr_engine_destroy(
    csr_engine_h engine,
  ) {
    return _csr_engine_destroy(
      engine,
    );
  }

  late final _csr_engine_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(csr_engine_h)>>(
          'csr_engine_destroy');
  late final _csr_engine_destroy =
      _csr_engine_destroyPtr.asFunction<int Function(csr_engine_h)>();

  /// @partner
  /// @brief Initializes and returns a Content Screening API handle.
  /// @details A Content Screening API handle (or CSR CS handle) is obtained by this method.
  /// The handle is required for subsequent CSR CS API calls.
  /// @since_tizen 3.0
  /// @remarks @a handle should be released using csr_cs_context_destroy().
  /// @remarks Multiple handles can be obtained.
  /// @param[out] handle A pointer of CSR CS context handle
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE @a handle may be null
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_context_destroy()
  int csr_cs_context_create(
    ffi.Pointer<csr_cs_context_h> handle,
  ) {
    return _csr_cs_context_create(
      handle,
    );
  }

  late final _csr_cs_context_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<csr_cs_context_h>)>>(
      'csr_cs_context_create');
  late final _csr_cs_context_create = _csr_cs_context_createPtr
      .asFunction<int Function(ffi.Pointer<csr_cs_context_h>)>();

  /// @partner
  /// @brief Releases all system resources associated with a Content Screening API handle.
  /// @since_tizen 3.0
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_context_create()
  int csr_cs_context_destroy(
    csr_cs_context_h handle,
  ) {
    return _csr_cs_context_destroy(
      handle,
    );
  }

  late final _csr_cs_context_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(csr_cs_context_h)>>(
          'csr_cs_context_destroy');
  late final _csr_cs_context_destroy =
      _csr_cs_context_destroyPtr.asFunction<int Function(csr_cs_context_h)>();

  /// @partner
  /// @brief Sets a popup option for malware detected.
  /// @details If #CSR_CS_ASK_USER_YES is set, a popup will be prompted to a user when a malware is detected.
  /// If #CSR_CS_ASK_USER_NO is set which is default value, no popup will be prompted even if a malware is detected.
  /// User can allow, disallow, and remove detected malware by popup.
  /// Selection can be different between malware's severity.
  /// @since_tizen 3.0
  /// @remarks This option is disabled(#CSR_CS_ASK_USER_NO) as a default.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] ask_user Popup option to set or unset
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a ask_user is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_context_create()
  /// @see csr_cs_context_destroy()
  int csr_cs_set_ask_user(
    csr_cs_context_h handle,
    int ask_user,
  ) {
    return _csr_cs_set_ask_user(
      handle,
      ask_user,
    );
  }

  late final _csr_cs_set_ask_userPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(csr_cs_context_h, ffi.Int32)>>(
      'csr_cs_set_ask_user');
  late final _csr_cs_set_ask_user =
      _csr_cs_set_ask_userPtr.asFunction<int Function(csr_cs_context_h, int)>();

  /// @partner
  /// @brief Sets a popup message of a client in case that a malware is detected.
  /// @details Default message is "Malware which may harm your device is detected."
  /// @since_tizen 3.0
  /// @remarks Meaningful only when ask user option is set by csr_cs_set_ask_user().
  /// @remarks The message will be printed on popup for user.
  /// @remarks Default popup message will be used if it isn't set.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] message A message to print on a popup
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a message is too long or empty. Max size is 64 bytes
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_context_create()
  /// @see csr_cs_context_destroy()
  int csr_cs_set_popup_message(
    csr_cs_context_h handle,
    ffi.Pointer<ffi.Char> message,
  ) {
    return _csr_cs_set_popup_message(
      handle,
      message,
    );
  }

  late final _csr_cs_set_popup_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h,
              ffi.Pointer<ffi.Char>)>>('csr_cs_set_popup_message');
  late final _csr_cs_set_popup_message = _csr_cs_set_popup_messagePtr
      .asFunction<int Function(csr_cs_context_h, ffi.Pointer<ffi.Char>)>();

  /// @partner
  /// @brief Sets a maximum core usage during scanning.
  /// @since_tizen 3.0
  /// @remarks If a core usage is not set, #CSR_CS_CORE_USAGE_DEFAULT will be used.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] usage A maximum core usage during scanning
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a usage is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_context_create()
  /// @see csr_cs_context_destroy()
  int csr_cs_set_core_usage(
    csr_cs_context_h handle,
    int usage,
  ) {
    return _csr_cs_set_core_usage(
      handle,
      usage,
    );
  }

  late final _csr_cs_set_core_usagePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(csr_cs_context_h, ffi.Int32)>>(
      'csr_cs_set_core_usage');
  late final _csr_cs_set_core_usage = _csr_cs_set_core_usagePtr
      .asFunction<int Function(csr_cs_context_h, int)>();

  /// @partner
  /// @brief Sets a scan on cloud option.
  /// @since_tizen 3.0
  /// @remarks Scan on cloud option is turned off as a default.
  /// @remarks If an engine does not support "scanning on cloud", this option is silently ignored.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] scan_on_cloud Flag of scanning on cloud option
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_context_create()
  /// @see csr_cs_context_destroy()
  int csr_cs_set_scan_on_cloud(
    csr_cs_context_h handle,
    bool scan_on_cloud,
  ) {
    return _csr_cs_set_scan_on_cloud(
      handle,
      scan_on_cloud,
    );
  }

  late final _csr_cs_set_scan_on_cloudPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(csr_cs_context_h, ffi.Bool)>>(
          'csr_cs_set_scan_on_cloud');
  late final _csr_cs_set_scan_on_cloud = _csr_cs_set_scan_on_cloudPtr
      .asFunction<int Function(csr_cs_context_h, bool)>();

  /// @partner
  /// @brief Scans a data buffer for malware.
  /// @details @a malware result of this method is not available for being judged by
  /// csr_cs_judge_detected_malware() because it's data and not a file, so it cannot be removed or ignored.
  /// @since_tizen 3.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/antivirus.scan
  /// @remarks Scan data synchronously.
  /// @remarks @a malware will be released when @a handle is released using csr_cs_context_destroy().
  /// @remarks If multiple malwares exists in @a data, the malware with the highest severity will be returned.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] data A scan target data
  /// @param[in] length A size of a scan target data
  /// @param[out] malware A pointer of the detected malware handle. It can be null when no malware detected
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a data or @a malware is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED No privilege to call
  /// @retval #CSR_ERROR_NOT_SUPPORTED Device needed to run API is not supported
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_USER_RESPONSE_FAILED Getting user response is failed.
  /// @a malware will be allocated on this error
  /// @retval #CSR_ERROR_ENGINE_NOT_EXIST No engine exists
  /// @retval #CSR_ERROR_ENGINE_DISABLED Engine is in disabled state
  /// @retval #CSR_ERROR_ENGINE_NOT_ACTIVATED Engine is not activated
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_context_create()
  /// @see csr_cs_context_destroy()
  int csr_cs_scan_data(
    csr_cs_context_h handle,
    ffi.Pointer<ffi.UnsignedChar> data,
    int length,
    ffi.Pointer<csr_cs_malware_h> malware,
  ) {
    return _csr_cs_scan_data(
      handle,
      data,
      length,
      malware,
    );
  }

  late final _csr_cs_scan_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h, ffi.Pointer<ffi.UnsignedChar>,
              ffi.Size, ffi.Pointer<csr_cs_malware_h>)>>('csr_cs_scan_data');
  late final _csr_cs_scan_data = _csr_cs_scan_dataPtr.asFunction<
      int Function(csr_cs_context_h, ffi.Pointer<ffi.UnsignedChar>, int,
          ffi.Pointer<csr_cs_malware_h>)>();

  /// @partner
  /// @brief Scans a file specified by file path for malware.
  /// @since_tizen 3.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/antivirus.scan
  /// @remarks Scan file synchronously.
  /// @remarks @a malware will be released when @a handle is released using csr_cs_context_destroy().
  /// @remarks If multiple malwares exists in a file, the malware with the highest severity will be returned.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] file_path A path of scan target file
  /// @param[out] malware A pointer of the detected malware handle. It can be null when no malware detected
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a file_path or @a malware is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Access denied
  /// @retval #CSR_ERROR_NOT_SUPPORTED Device needed to run API is not supported
  /// @retval #CSR_ERROR_DB DB transaction error
  /// @retval #CSR_ERROR_REMOVE_FAILED Removing file or application is failed when malware exist and user select to remove by popup.
  /// @a malware will be allocated on this error
  /// @retval #CSR_ERROR_USER_RESPONSE_FAILED Getting user response is failed
  /// @a malware will be allocated on this error
  /// @retval #CSR_ERROR_FILE_DO_NOT_EXIST File not found
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_ENGINE_NOT_EXIST No engine exists
  /// @retval #CSR_ERROR_ENGINE_DISABLED Engine is in disabled state
  /// @retval #CSR_ERROR_ENGINE_NOT_ACTIVATED Engine is not activated
  /// @retval #CSR_ERROR_ENGINE_PERMISSION Insufficient permission of engine
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_context_create()
  /// @see csr_cs_context_destroy()
  int csr_cs_scan_file(
    csr_cs_context_h handle,
    ffi.Pointer<ffi.Char> file_path,
    ffi.Pointer<csr_cs_malware_h> malware,
  ) {
    return _csr_cs_scan_file(
      handle,
      file_path,
      malware,
    );
  }

  late final _csr_cs_scan_filePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<csr_cs_malware_h>)>>('csr_cs_scan_file');
  late final _csr_cs_scan_file = _csr_cs_scan_filePtr.asFunction<
      int Function(csr_cs_context_h, ffi.Pointer<ffi.Char>,
          ffi.Pointer<csr_cs_malware_h>)>();

  /// @partner
  /// @brief Sets a callback function for the case that a file scan is completed.
  /// @since_tizen 3.0
  /// @remarks Callback for asynchronous scan functions.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] callback A callback function for each file or application scanning done without any malware.
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a callback is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_scan_files_async()
  /// @see csr_cs_scan_dir_async()
  /// @see csr_cs_scan_dirs_async()
  int csr_cs_set_file_scanned_cb(
    csr_cs_context_h handle,
    csr_cs_file_scanned_cb callback,
  ) {
    return _csr_cs_set_file_scanned_cb(
      handle,
      callback,
    );
  }

  late final _csr_cs_set_file_scanned_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h,
              csr_cs_file_scanned_cb)>>('csr_cs_set_file_scanned_cb');
  late final _csr_cs_set_file_scanned_cb = _csr_cs_set_file_scanned_cbPtr
      .asFunction<int Function(csr_cs_context_h, csr_cs_file_scanned_cb)>();

  /// @partner
  /// @brief Sets a callback function for detection of a malware.
  /// @since_tizen 3.0
  /// @remarks Callback for asynchronous scan functions.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] callback A callback function for each file or application scanning done with malware detected
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a callback is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_scan_files_async()
  /// @see csr_cs_scan_dir_async()
  /// @see csr_cs_scan_dirs_async()
  int csr_cs_set_detected_cb(
    csr_cs_context_h handle,
    csr_cs_detected_cb callback,
  ) {
    return _csr_cs_set_detected_cb(
      handle,
      callback,
    );
  }

  late final _csr_cs_set_detected_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              csr_cs_context_h, csr_cs_detected_cb)>>('csr_cs_set_detected_cb');
  late final _csr_cs_set_detected_cb = _csr_cs_set_detected_cbPtr
      .asFunction<int Function(csr_cs_context_h, csr_cs_detected_cb)>();

  /// @partner
  /// @brief Sets a callback function for scanning completed without an error.
  /// @since_tizen 3.0
  /// @remarks Callback for asynchronous scan functions.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] callback A callback function for scanning completed successfully
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a callback is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_scan_files_async()
  /// @see csr_cs_scan_dir_async()
  /// @see csr_cs_scan_dirs_async()
  int csr_cs_set_completed_cb(
    csr_cs_context_h handle,
    csr_cs_completed_cb callback,
  ) {
    return _csr_cs_set_completed_cb(
      handle,
      callback,
    );
  }

  late final _csr_cs_set_completed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h,
              csr_cs_completed_cb)>>('csr_cs_set_completed_cb');
  late final _csr_cs_set_completed_cb = _csr_cs_set_completed_cbPtr
      .asFunction<int Function(csr_cs_context_h, csr_cs_completed_cb)>();

  /// @partner
  /// @brief Sets a callback function for scanning cancelled.
  /// @since_tizen 3.0
  /// @remarks Callback for asynchronous scan functions.
  /// @remarks Client can cancel asynchronous scanning by csr_cs_cancel_scanning().
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] callback A callback function for scanning cancelled
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a callback is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_scan_files_async()
  /// @see csr_cs_scan_dir_async()
  /// @see csr_cs_scan_dirs_async()
  /// @see csr_cs_cancel_scanning()
  int csr_cs_set_cancelled_cb(
    csr_cs_context_h handle,
    csr_cs_cancelled_cb callback,
  ) {
    return _csr_cs_set_cancelled_cb(
      handle,
      callback,
    );
  }

  late final _csr_cs_set_cancelled_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h,
              csr_cs_cancelled_cb)>>('csr_cs_set_cancelled_cb');
  late final _csr_cs_set_cancelled_cb = _csr_cs_set_cancelled_cbPtr
      .asFunction<int Function(csr_cs_context_h, csr_cs_cancelled_cb)>();

  /// @partner
  /// @brief Sets a callback function for scanning stopped with an error.
  /// @since_tizen 3.0
  /// @remarks Callback for asynchronous scan functions.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] callback A callback function for scanning stopped due to an error
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a callback is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_scan_files_async()
  /// @see csr_cs_scan_dir_async()
  /// @see csr_cs_scan_dirs_async()
  int csr_cs_set_error_cb(
    csr_cs_context_h handle,
    csr_cs_error_cb callback,
  ) {
    return _csr_cs_set_error_cb(
      handle,
      callback,
    );
  }

  late final _csr_cs_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              csr_cs_context_h, csr_cs_error_cb)>>('csr_cs_set_error_cb');
  late final _csr_cs_set_error_cb = _csr_cs_set_error_cbPtr
      .asFunction<int Function(csr_cs_context_h, csr_cs_error_cb)>();

  /// @partner
  /// @brief Scan files specified by an array of file paths for malware.
  /// @details If scanning of the single file is done without detected malware,
  /// csr_cs_file_scanned_cb() is called and else if malware detected
  /// csr_cs_detected_cb() is called. If scanning is cancelled by
  /// csr_cs_cancel_scanning(), csr_cs_cancelled_cb() is called. If scanning is failed
  /// with error, csr_cs_error_cb() is called. If scanning is completed without
  /// error, csr_cs_completed_cb(). Every callbacks are registered by callback
  /// setter methods to @a handle and if callback is not registered, it will be just skipped to be called.
  /// @since_tizen 3.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/antivirus.scan
  /// @remarks Asynchronous function.
  /// @remarks The caller should set callback functions before calling this method.
  /// @remarks Detected malware which is provided to the callback will be released when
  /// @a handle is released using csr_cs_context_destroy().
  /// @remarks If multiple malwares exists in a file, the malware with the highest
  /// severity will be returned for the file via csr_cs_set_detected_cb().
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] file_paths An array of scan target files
  /// @param[in] count A number of scan target files
  /// @param[in] user_data The pointer of a user data. It can be null.
  /// It is delivered back to the client when a callback function is called
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a file_paths is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Access denied
  /// @retval #CSR_ERROR_NOT_SUPPORTED Device needed to run API is not supported
  /// @retval #CSR_ERROR_BUSY Busy for processing another request
  /// @retval #CSR_ERROR_FILE_DO_NOT_EXIST File not found
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_DB DB transaction error
  /// @retval #CSR_ERROR_ENGINE_PERMISSION Insufficient permission of engine
  /// @retval #CSR_ERROR_ENGINE_NOT_EXIST No engine exists
  /// @retval #CSR_ERROR_ENGINE_DISABLED Engine is in disabled state
  /// @retval #CSR_ERROR_ENGINE_NOT_ACTIVATED Engine is not activated
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @pre It is required to set callbacks, csr_cs_completed_cb, csr_cs_error_cb(),
  /// csr_cs_cancel_scanning(), csr_cs_detected_cb(), and/or csr_cs_file_scanned_cb().
  /// @see csr_cs_set_file_scanned_cb()
  /// @see csr_cs_set_detected_cb()
  /// @see csr_cs_set_completed_cb()
  /// @see csr_cs_set_cancelled_cb()
  /// @see csr_cs_set_error_cb()
  /// @see csr_cs_cancel_scanning()
  int csr_cs_scan_files_async(
    csr_cs_context_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> file_paths,
    int count,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _csr_cs_scan_files_async(
      handle,
      file_paths,
      count,
      user_data,
    );
  }

  late final _csr_cs_scan_files_asyncPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Size, ffi.Pointer<ffi.Void>)>>('csr_cs_scan_files_async');
  late final _csr_cs_scan_files_async = _csr_cs_scan_files_asyncPtr.asFunction<
      int Function(csr_cs_context_h, ffi.Pointer<ffi.Pointer<ffi.Char>>, int,
          ffi.Pointer<ffi.Void>)>();

  /// @partner
  /// @brief Scans a directory specified by directory path for malware.
  /// @details If scanning of the single file is done without detected malware,
  /// csr_cs_file_scanned_cb() is called and else if malware detected
  /// csr_cs_detected_cb() is called. If scanning is cancelled by
  /// csr_cs_cancel_scanning(), csr_cs_cancelled_cb() is called. If scanning is failed
  /// with error, csr_cs_error_cb() is called. If scanning is completed without
  /// error, csr_cs_completed_cb(). Every callbacks are registered by callback
  /// setter methods to @a handle and if callback is not registered, it will be just skipped to be called.
  /// @since_tizen 3.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/antivirus.scan
  /// @remarks Asynchronous function.
  /// @remarks The caller should set callback functions before calling this method.
  /// @remarks Detected malware which is provided to the callback will be released when
  /// @a handle is released using csr_cs_context_destroy().
  /// @remarks If multiple malwares exists in a file, the malware with the highest
  /// severity will be returned for the file via csr_cs_set_detected_cb().
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] dir_path A path of scan target directory
  /// @param[in] user_data The pointer of a user data. It can be null.
  /// It is used on the callback functions which are registered to @a handle
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a dir_path is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Access denied
  /// @retval #CSR_ERROR_NOT_SUPPORTED Device needed to run API is not supported
  /// @retval #CSR_ERROR_BUSY Busy for processing another request
  /// @retval #CSR_ERROR_FILE_DO_NOT_EXIST File not found
  /// @retval #CSR_ERROR_FILE_SYSTEM File type is invalid. It should be directory
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_DB DB transaction error
  /// @retval #CSR_ERROR_ENGINE_PERMISSION Insufficient permission of engine
  /// @retval #CSR_ERROR_ENGINE_NOT_EXIST No engine exists
  /// @retval #CSR_ERROR_ENGINE_DISABLED Engine is in disabled state
  /// @retval #CSR_ERROR_ENGINE_NOT_ACTIVATED Engine is not activated
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @pre It is required to set callbacks, csr_cs_completed_cb, csr_cs_error_cb(),
  /// csr_cs_cancel_scanning(), csr_cs_detected_cb(), and/or csr_cs_file_scanned_cb().
  /// @see csr_cs_set_file_scanned_cb()
  /// @see csr_cs_set_detected_cb()
  /// @see csr_cs_set_completed_cb()
  /// @see csr_cs_set_cancelled_cb()
  /// @see csr_cs_set_error_cb()
  /// @see csr_cs_cancel_scanning()
  int csr_cs_scan_dir_async(
    csr_cs_context_h handle,
    ffi.Pointer<ffi.Char> dir_path,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _csr_cs_scan_dir_async(
      handle,
      dir_path,
      user_data,
    );
  }

  late final _csr_cs_scan_dir_asyncPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Void>)>>('csr_cs_scan_dir_async');
  late final _csr_cs_scan_dir_async = _csr_cs_scan_dir_asyncPtr.asFunction<
      int Function(
          csr_cs_context_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>();

  /// @partner
  /// @brief Scan directories specified by an array of directory paths for malware.
  /// @details If scanning of the single file is done without detected malware,
  /// csr_cs_file_scanned_cb() is called and else if malware detected
  /// csr_cs_detected_cb() is called. If scanning is cancelled by
  /// csr_cs_cancel_scanning(), csr_cs_cancelled_cb() is called. If scanning is failed
  /// with error, csr_cs_error_cb() is called. If scanning is completed without
  /// error, csr_cs_completed_cb(). Every callbacks are registered by callback
  /// setter methods to @a handle and if callback is not registered, it will just be skipped to be called.
  /// @since_tizen 3.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/antivirus.scan
  /// @remarks Asynchronous function.
  /// @remarks The caller should set callback functions before calls this method.
  /// @remarks Detected malware which is provided to the callback will be released when
  /// @a handle is released using csr_cs_context_destroy().
  /// @remarks If multiple malwares exists in a file, the malware with the highest
  /// severity will be returned for the file via csr_cs_set_detected_cb().
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] dir_paths An array of scan target directories
  /// @param[in] count A number of scan target directories
  /// @param[in] user_data The pointer of a user data. It can be null. It is used on
  /// the callback functions which are registered to @a handle
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a dir_paths is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED Access denied
  /// @retval #CSR_ERROR_NOT_SUPPORTED Device needed to run API is not supported
  /// @retval #CSR_ERROR_BUSY Busy for processing another request
  /// @retval #CSR_ERROR_FILE_DO_NOT_EXIST File not found
  /// @retval #CSR_ERROR_FILE_SYSTEM File type is invalid. It should be directory
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_DB DB transaction error
  /// @retval #CSR_ERROR_ENGINE_PERMISSION Insufficient permission of engine
  /// @retval #CSR_ERROR_ENGINE_NOT_EXIST No engine exists
  /// @retval #CSR_ERROR_ENGINE_DISABLED Engine is in disabled state
  /// @retval #CSR_ERROR_ENGINE_NOT_ACTIVATED Engine is not activated
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @pre It is required to set callbacks, csr_cs_completed_cb, csr_cs_error_cb(),
  /// csr_cs_cancel_scanning(), csr_cs_detected_cb(), and/or csr_cs_file_scanned_cb().
  /// @see csr_cs_set_file_scanned_cb()
  /// @see csr_cs_set_detected_cb()
  /// @see csr_cs_set_completed_cb()
  /// @see csr_cs_set_cancelled_cb()
  /// @see csr_cs_set_error_cb()
  /// @see csr_cs_cancel_scanning()
  int csr_cs_scan_dirs_async(
    csr_cs_context_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> dir_paths,
    int count,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _csr_cs_scan_dirs_async(
      handle,
      dir_paths,
      count,
      user_data,
    );
  }

  late final _csr_cs_scan_dirs_asyncPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Size, ffi.Pointer<ffi.Void>)>>('csr_cs_scan_dirs_async');
  late final _csr_cs_scan_dirs_async = _csr_cs_scan_dirs_asyncPtr.asFunction<
      int Function(csr_cs_context_h, ffi.Pointer<ffi.Pointer<ffi.Char>>, int,
          ffi.Pointer<ffi.Void>)>();

  /// @partner
  /// @brief Cancels a running scanning task, asynchronously.
  /// @since_tizen 3.0
  /// @remarks Only for asynchronous scan functions.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_NO_TASK No task to cancel
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_scan_files_async()
  /// @see csr_cs_scan_dir_async()
  /// @see csr_cs_scan_dirs_async()
  int csr_cs_cancel_scanning(
    csr_cs_context_h handle,
  ) {
    return _csr_cs_cancel_scanning(
      handle,
    );
  }

  late final _csr_cs_cancel_scanningPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(csr_cs_context_h)>>(
          'csr_cs_cancel_scanning');
  late final _csr_cs_cancel_scanning =
      _csr_cs_cancel_scanningPtr.asFunction<int Function(csr_cs_context_h)>();

  /// @partner
  /// @brief Extracts the severity of a detected malware from the detected malware handle.
  /// @since_tizen 3.0
  /// @param[in] malware A detected malware handle returned by csr_cs_scan_data(),
  /// csr_cs_scan_file() or csr_cs_malware_list_get_malware()
  /// @param[out] severity A pointer of the severity of a detected malware
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid detected malware handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a severity is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_malware_get_severity(
    csr_cs_malware_h malware,
    ffi.Pointer<ffi.Int32> severity,
  ) {
    return _csr_cs_malware_get_severity(
      malware,
      severity,
    );
  }

  late final _csr_cs_malware_get_severityPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_malware_h,
              ffi.Pointer<ffi.Int32>)>>('csr_cs_malware_get_severity');
  late final _csr_cs_malware_get_severity = _csr_cs_malware_get_severityPtr
      .asFunction<int Function(csr_cs_malware_h, ffi.Pointer<ffi.Int32>)>();

  /// @partner
  /// @brief Extracts the name of a detected malware from the detected malware handle.
  /// @since_tizen 3.0
  /// @remarks @a name must be released using free().
  /// @param[in] malware A detected malware handle
  /// @param[out] name A pointer of the name of a detected malware
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid detected malware handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a name is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_malware_get_name(
    csr_cs_malware_h malware,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _csr_cs_malware_get_name(
      malware,
      name,
    );
  }

  late final _csr_cs_malware_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_malware_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('csr_cs_malware_get_name');
  late final _csr_cs_malware_get_name = _csr_cs_malware_get_namePtr.asFunction<
      int Function(csr_cs_malware_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @partner
  /// @brief Extracts an url that contains detailed information on vendor's web site from the detected malware handle.
  /// @since_tizen 3.0
  /// @remarks @a detailed_url must be released using free().
  /// @param[in] malware A detected malware handle
  /// @param[out] detailed_url A pointer of an url that contains detailed information on
  /// vendor's web site. It can be null if a vendor doesn't provide this information
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid detected malware handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a detailed_url is invalid.
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_malware_get_detailed_url(
    csr_cs_malware_h malware,
    ffi.Pointer<ffi.Pointer<ffi.Char>> detailed_url,
  ) {
    return _csr_cs_malware_get_detailed_url(
      malware,
      detailed_url,
    );
  }

  late final _csr_cs_malware_get_detailed_urlPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  csr_cs_malware_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'csr_cs_malware_get_detailed_url');
  late final _csr_cs_malware_get_detailed_url =
      _csr_cs_malware_get_detailed_urlPtr.asFunction<
          int Function(csr_cs_malware_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @partner
  /// @brief Extracts the time stamp when a malware is detected from the detected malware handle.
  /// @since_tizen 3.0
  /// @param[in] malware A detected malware handle
  /// @param[out] timestamp A pointer of the time stamp in milli second when a malware is detected
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid detected malware handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a timestamp is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_malware_get_timestamp(
    csr_cs_malware_h malware,
    ffi.Pointer<time_t> timestamp,
  ) {
    return _csr_cs_malware_get_timestamp(
      malware,
      timestamp,
    );
  }

  late final _csr_cs_malware_get_timestampPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_malware_h,
              ffi.Pointer<time_t>)>>('csr_cs_malware_get_timestamp');
  late final _csr_cs_malware_get_timestamp = _csr_cs_malware_get_timestampPtr
      .asFunction<int Function(csr_cs_malware_h, ffi.Pointer<time_t>)>();

  /// @partner
  /// @brief Extracts the file name where a malware is detected from the detected malware handle.
  /// @since_tizen 3.0
  /// @remarks @a file_name must be released using free().
  /// @param[in] malware A detected malware handle
  /// @param[out] file_name A pointer of the file name where a malware is detected. The file name is null for csr_cs_scan_data()
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid detected malware handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a file_name is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_malware_get_file_name(
    csr_cs_malware_h malware,
    ffi.Pointer<ffi.Pointer<ffi.Char>> file_name,
  ) {
    return _csr_cs_malware_get_file_name(
      malware,
      file_name,
    );
  }

  late final _csr_cs_malware_get_file_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  csr_cs_malware_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'csr_cs_malware_get_file_name');
  late final _csr_cs_malware_get_file_name =
      _csr_cs_malware_get_file_namePtr.asFunction<
          int Function(csr_cs_malware_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @partner
  /// @brief Extracts a user response of a popup from the detected malware handle.
  /// @since_tizen 3.0
  /// @param[in] malware A detected malware handle
  /// @param[out] response A pointer of the user response
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid result handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a response is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_malware_get_user_response(
    csr_cs_malware_h malware,
    ffi.Pointer<ffi.Int32> response,
  ) {
    return _csr_cs_malware_get_user_response(
      malware,
      response,
    );
  }

  late final _csr_cs_malware_get_user_responsePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_malware_h,
              ffi.Pointer<ffi.Int32>)>>('csr_cs_malware_get_user_response');
  late final _csr_cs_malware_get_user_response =
      _csr_cs_malware_get_user_responsePtr
          .asFunction<int Function(csr_cs_malware_h, ffi.Pointer<ffi.Int32>)>();

  /// @partner
  /// @brief Checks if a malware was detected in an application or in a file.
  /// @since_tizen 3.0
  /// @param[in] malware A detected malware handle
  /// @param[out] is_app A pointer of a flag indicating the position where a malware was detected.
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid result handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a is_app is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_malware_is_app(
    csr_cs_malware_h malware,
    ffi.Pointer<ffi.Bool> is_app,
  ) {
    return _csr_cs_malware_is_app(
      malware,
      is_app,
    );
  }

  late final _csr_cs_malware_is_appPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_malware_h,
              ffi.Pointer<ffi.Bool>)>>('csr_cs_malware_is_app');
  late final _csr_cs_malware_is_app = _csr_cs_malware_is_appPtr
      .asFunction<int Function(csr_cs_malware_h, ffi.Pointer<ffi.Bool>)>();

  /// @partner
  /// @brief Extracts the package id of an application where a malware is detected from detected malware handle.
  /// @since_tizen 3.0
  /// @remarks @a pkg_id must be released using free().
  /// @param[in] malware A detected malware handle
  /// @param[out] pkg_id A pointer of the package id where a malware is detected.
  /// It is null when a malware was not detected in an application
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid detected malware handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a pkg_id is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_malware_get_pkg_id(
    csr_cs_malware_h malware,
    ffi.Pointer<ffi.Pointer<ffi.Char>> pkg_id,
  ) {
    return _csr_cs_malware_get_pkg_id(
      malware,
      pkg_id,
    );
  }

  late final _csr_cs_malware_get_pkg_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  csr_cs_malware_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'csr_cs_malware_get_pkg_id');
  late final _csr_cs_malware_get_pkg_id =
      _csr_cs_malware_get_pkg_idPtr.asFunction<
          int Function(csr_cs_malware_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @platform
  /// @brief Judges how a detected malware file is handled.
  /// @details Detected malware will be removed by #CSR_CS_ACTION_REMOVE action.
  /// File or application which contains malware will be removed.
  /// Detected malware will be ignored by #CSR_CS_ACTION_IGNORE action.
  /// File or application which contains malware will be ignored and will not be treated
  /// as malware until this API is called with #CSR_CS_ACTION_UNIGNORE action.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/antivirus.admin
  /// @remarks Detected malware can be removed or ignored.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] malware A handle of a detected malware
  /// @param[in] action An action to be taken
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a malware or @a action is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED No permission to remove
  /// @retval #CSR_ERROR_FILE_DO_NOT_EXIST File to take action on not found
  /// @retval #CSR_ERROR_FILE_CHANGED File to take action on changed after detection
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_DB DB transaction error
  /// @retval #CSR_ERROR_REMOVE_FAILED Removing file or application is failed
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_judge_detected_malware(
    csr_cs_context_h handle,
    csr_cs_malware_h malware,
    int action,
  ) {
    return _csr_cs_judge_detected_malware(
      handle,
      malware,
      action,
    );
  }

  late final _csr_cs_judge_detected_malwarePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h, csr_cs_malware_h,
              ffi.Int32)>>('csr_cs_judge_detected_malware');
  late final _csr_cs_judge_detected_malware = _csr_cs_judge_detected_malwarePtr
      .asFunction<int Function(csr_cs_context_h, csr_cs_malware_h, int)>();

  /// @partner
  /// @brief Gets information on a detected malware file specified by file path.
  /// @since_tizen 3.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/antivirus.scan
  /// @remarks @a malware will be released when @a handle is destroyed.
  /// @remarks @a file_path will be null if it's result of csr_cs_scan_data().
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] file_path A path of a detected malware file
  /// @param[out] malware A pointer of the detected malware handle. It can be null when no malware file
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a file_path or @a malware is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED No permission to remove
  /// @retval #CSR_ERROR_FILE_DO_NOT_EXIST No malware file
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_DB DB transaction error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_cs_scan_data()
  /// @see csr_cs_scan_file()
  /// @see csr_cs_detected_cb
  int csr_cs_get_detected_malware(
    csr_cs_context_h handle,
    ffi.Pointer<ffi.Char> file_path,
    ffi.Pointer<csr_cs_malware_h> malware,
  ) {
    return _csr_cs_get_detected_malware(
      handle,
      file_path,
      malware,
    );
  }

  late final _csr_cs_get_detected_malwarePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<csr_cs_malware_h>)>>('csr_cs_get_detected_malware');
  late final _csr_cs_get_detected_malware =
      _csr_cs_get_detected_malwarePtr.asFunction<
          int Function(csr_cs_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<csr_cs_malware_h>)>();

  /// @partner
  /// @brief Gets information on a detected malware files specified by directory path.
  /// @since_tizen 3.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/antivirus.scan
  /// @remarks @a list will be released when @a handle is destroyed.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] dir_paths A directory path where detected malware files exists
  /// @param[in] count Count of array element of @a dir_paths
  /// @param[out] list A pointer of the detected malware list handle. It can be null when there is no malware file
  /// @param[out] list_count Count of detected malware files which existed in the specified directory
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a dir_paths, @a list, or @a count is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED No permission to remove
  /// @retval #CSR_ERROR_FILE_DO_NOT_EXIST No malware file
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_DB DB transaction error
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_get_detected_malwares(
    csr_cs_context_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> dir_paths,
    int count,
    ffi.Pointer<csr_cs_malware_list_h> list,
    ffi.Pointer<ffi.Size> list_count,
  ) {
    return _csr_cs_get_detected_malwares(
      handle,
      dir_paths,
      count,
      list,
      list_count,
    );
  }

  late final _csr_cs_get_detected_malwaresPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              csr_cs_context_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Size,
              ffi.Pointer<csr_cs_malware_list_h>,
              ffi.Pointer<ffi.Size>)>>('csr_cs_get_detected_malwares');
  late final _csr_cs_get_detected_malwares =
      _csr_cs_get_detected_malwaresPtr.asFunction<
          int Function(
              csr_cs_context_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              int,
              ffi.Pointer<csr_cs_malware_list_h>,
              ffi.Pointer<ffi.Size>)>();

  /// @partner
  /// @brief Gets information on a ignored malware file specified by file path.
  /// @since_tizen 3.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/antivirus.scan
  /// @remarks @a malware will be released when @a handle is destroyed.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] file_path A path of a ignored malware file
  /// @param[out] malware A pointer of the detected malware handle. It can be null when no ignored file
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a file_path or @a malware is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED No permission to remove
  /// @retval #CSR_ERROR_FILE_DO_NOT_EXIST No ignored file
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_DB DB transaction error
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_get_ignored_malware(
    csr_cs_context_h handle,
    ffi.Pointer<ffi.Char> file_path,
    ffi.Pointer<csr_cs_malware_h> malware,
  ) {
    return _csr_cs_get_ignored_malware(
      handle,
      file_path,
      malware,
    );
  }

  late final _csr_cs_get_ignored_malwarePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_cs_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<csr_cs_malware_h>)>>('csr_cs_get_ignored_malware');
  late final _csr_cs_get_ignored_malware =
      _csr_cs_get_ignored_malwarePtr.asFunction<
          int Function(csr_cs_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<csr_cs_malware_h>)>();

  /// @partner
  /// @brief Gets information on ignored malware files specified by directory path.
  /// @since_tizen 3.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/antivirus.scan
  /// @remarks @a list will be released when @a handle is destroyed.
  /// @param[in] handle CSR CS context handle returned by csr_cs_context_create()
  /// @param[in] dir_paths A directory path where ignored malware files exists
  /// @param[in] count Count of array element of @a dir_paths
  /// @param[out] list A pointer of the detected malware list handle. It can be null when no ignored file
  /// @param[out] list_count Count of ignored malware files which existed in the specified directory
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a dir_paths, @a list, or @a count is invalid
  /// @retval #CSR_ERROR_PERMISSION_DENIED No permission to remove
  /// @retval #CSR_ERROR_FILE_DO_NOT_EXIST No ignored file
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_DB DB transaction error
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_get_ignored_malwares(
    csr_cs_context_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> dir_paths,
    int count,
    ffi.Pointer<csr_cs_malware_list_h> list,
    ffi.Pointer<ffi.Size> list_count,
  ) {
    return _csr_cs_get_ignored_malwares(
      handle,
      dir_paths,
      count,
      list,
      list_count,
    );
  }

  late final _csr_cs_get_ignored_malwaresPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              csr_cs_context_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Size,
              ffi.Pointer<csr_cs_malware_list_h>,
              ffi.Pointer<ffi.Size>)>>('csr_cs_get_ignored_malwares');
  late final _csr_cs_get_ignored_malwares =
      _csr_cs_get_ignored_malwaresPtr.asFunction<
          int Function(
              csr_cs_context_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              int,
              ffi.Pointer<csr_cs_malware_list_h>,
              ffi.Pointer<ffi.Size>)>();

  /// @partner
  /// @brief Extracts the detected malware handle from the detected malware list handle.
  /// @since_tizen 3.0
  /// @remarks @a malware will be released when a context is released using csr_cs_context_destroy().
  /// @param[in] list A detected malware list handle returned by csr_cs_get_detected_malwares() or csr_cs_get_ignored_malwares()
  /// @param[in] index An index of a target detected malware handle to get
  /// @param[out] malware A pointer of the detected malware handle. It can be null when index is invalid
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid list
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a index or @a malware is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  int csr_cs_malware_list_get_malware(
    csr_cs_malware_list_h list,
    int index,
    ffi.Pointer<csr_cs_malware_h> malware,
  ) {
    return _csr_cs_malware_list_get_malware(
      list,
      index,
      malware,
    );
  }

  late final _csr_cs_malware_list_get_malwarePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(csr_cs_malware_list_h, ffi.Size,
                  ffi.Pointer<csr_cs_malware_h>)>>(
      'csr_cs_malware_list_get_malware');
  late final _csr_cs_malware_list_get_malware =
      _csr_cs_malware_list_get_malwarePtr.asFunction<
          int Function(
              csr_cs_malware_list_h, int, ffi.Pointer<csr_cs_malware_h>)>();

  /// @partner
  /// @brief Initializes and returns a CSR Web Protection API handle.
  /// @details A Web Protection API handle (or CSR WP handle) is obtained by this method.
  /// The handle is required for subsequent CSR WP API calls.
  /// @since_tizen 3.0
  /// @remarks @a handle should be released using csr_wp_context_destroy().
  /// @remarks Multiple handles can be obtained.
  /// @param[out] handle A pointer of CSR WP context handle
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a handle is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_wp_context_destroy()
  int csr_wp_context_create(
    ffi.Pointer<csr_wp_context_h> handle,
  ) {
    return _csr_wp_context_create(
      handle,
    );
  }

  late final _csr_wp_context_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<csr_wp_context_h>)>>(
      'csr_wp_context_create');
  late final _csr_wp_context_create = _csr_wp_context_createPtr
      .asFunction<int Function(ffi.Pointer<csr_wp_context_h>)>();

  /// @partner
  /// @brief Releases all system resources associated with a Web Protection API handle.
  /// @since_tizen 3.0
  /// @param[in] handle CSR WP context handle returned by csr_wp_context_create()
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_wp_context_create()
  int csr_wp_context_destroy(
    csr_wp_context_h handle,
  ) {
    return _csr_wp_context_destroy(
      handle,
    );
  }

  late final _csr_wp_context_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(csr_wp_context_h)>>(
          'csr_wp_context_destroy');
  late final _csr_wp_context_destroy =
      _csr_wp_context_destroyPtr.asFunction<int Function(csr_wp_context_h)>();

  /// @partner
  /// @brief Sets a popup option for risky URL checked.
  /// @details If #CSR_WP_ASK_USER_YES is set, a popup will be prompted to a user when a URL turns out risky.
  /// If #CSR_WP_ASK_USER_NO is set, no popup will be prompted even when a URL turns out risky.
  /// @since_tizen 3.0
  /// @remarks This option is disabled(#CSR_WP_ASK_USER_NO) as a default.
  /// @param[in] handle CSR WP context handle returned by csr_wp_context_create()
  /// @param[in] ask_user A popup option in case for a risky URL
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a ask_user is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_wp_context_create()
  int csr_wp_set_ask_user(
    csr_wp_context_h handle,
    int ask_user,
  ) {
    return _csr_wp_set_ask_user(
      handle,
      ask_user,
    );
  }

  late final _csr_wp_set_ask_userPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(csr_wp_context_h, ffi.Int32)>>(
      'csr_wp_set_ask_user');
  late final _csr_wp_set_ask_user =
      _csr_wp_set_ask_userPtr.asFunction<int Function(csr_wp_context_h, int)>();

  /// @partner
  /// @brief Sets a popup message of a client in case for a risky URL.
  /// @details Default message is "Risky URL which may harm your device is detected".
  /// @since_tizen 3.0
  /// @remarks Meaningful only when ask user option is set by csr_wp_set_ask_user().
  /// @remarks The message will be printed on popup for user.
  /// @remarks Default popup message will be used if it isn't set.
  /// @param[in] handle CSR WP context handle returned by csr_wp_context_create()
  /// @param[in] message A message to print on a popup
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a message is too long or empty. Max size is 64 bytes
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_wp_context_create()
  int csr_wp_set_popup_message(
    csr_wp_context_h handle,
    ffi.Pointer<ffi.Char> message,
  ) {
    return _csr_wp_set_popup_message(
      handle,
      message,
    );
  }

  late final _csr_wp_set_popup_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_wp_context_h,
              ffi.Pointer<ffi.Char>)>>('csr_wp_set_popup_message');
  late final _csr_wp_set_popup_message = _csr_wp_set_popup_messagePtr
      .asFunction<int Function(csr_wp_context_h, ffi.Pointer<ffi.Char>)>();

  /// @partner
  /// @brief Checks URL reputation against the engine vendor's database.
  /// @details Checks whether accessing the URL is risky or not and returns a result handle with the risk level for the URL.
  /// @since_tizen 3.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/antivirus.webprotect
  /// @remarks @a result will be released when @a handle is released using csr_wp_context_destroy().
  /// @param[in] handle CSR WP context handle returned by csr_wp_context_create()
  /// @param[in] url URL to check
  /// @param[out] result A pointer of the result handle with the Risk level for the URL
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid handle
  /// @retval #CSR_ERROR_OUT_OF_MEMORY Not enough memory
  /// @retval #CSR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CSR_ERROR_NOT_SUPPORTED Device needed to run API is not supported
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a url or @a result is invalid
  /// @retval #CSR_ERROR_SOCKET Socket error between client and server
  /// @retval #CSR_ERROR_SERVER Server has been failed for some reason
  /// @retval #CSR_ERROR_USER_RESPONSE_FAILED Getting user response is failed.
  /// @a result will be allocated on this error
  /// @retval #CSR_ERROR_ENGINE_NOT_EXIST No engine exists
  /// @retval #CSR_ERROR_ENGINE_DISABLED Engine is in disabled state
  /// @retval #CSR_ERROR_ENGINE_NOT_ACTIVATED Engine is not activated
  /// @retval #CSR_ERROR_ENGINE_INTERNAL Engine Internal error
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_wp_context_create()
  /// @see csr_wp_set_ask_user()
  /// @see csr_wp_set_popup_message()
  int csr_wp_check_url(
    csr_wp_context_h handle,
    ffi.Pointer<ffi.Char> url,
    ffi.Pointer<csr_wp_check_result_h> result,
  ) {
    return _csr_wp_check_url(
      handle,
      url,
      result,
    );
  }

  late final _csr_wp_check_urlPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_wp_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<csr_wp_check_result_h>)>>('csr_wp_check_url');
  late final _csr_wp_check_url = _csr_wp_check_urlPtr.asFunction<
      int Function(csr_wp_context_h, ffi.Pointer<ffi.Char>,
          ffi.Pointer<csr_wp_check_result_h>)>();

  /// @partner
  /// @brief Extracts a risk level of the url from the result handle.
  /// @since_tizen 3.0
  /// @param[in] result A result handle returned by csr_wp_check_url()
  /// @param[out] level A pointer of the risk level for the given URL
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid result handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a level is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_wp_check_url()
  int csr_wp_result_get_risk_level(
    csr_wp_check_result_h result,
    ffi.Pointer<ffi.Int32> level,
  ) {
    return _csr_wp_result_get_risk_level(
      result,
      level,
    );
  }

  late final _csr_wp_result_get_risk_levelPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_wp_check_result_h,
              ffi.Pointer<ffi.Int32>)>>('csr_wp_result_get_risk_level');
  late final _csr_wp_result_get_risk_level =
      _csr_wp_result_get_risk_levelPtr.asFunction<
          int Function(csr_wp_check_result_h, ffi.Pointer<ffi.Int32>)>();

  /// @partner
  /// @brief Extracts an url of vendor's web site that contains detailed information about the risk from the result handle.
  /// @since_tizen 3.0
  /// @remarks @a detailed_url must be released using free().
  /// @param[in] result A result handle returned by csr_wp_check_url()
  /// @param[out] detailed_url A pointer of an url that contains detailed information about the risk
  /// If the risk level is #CSR_WP_RISK_MEDIUM or #CSR_WP_RISK_HIGH,
  /// this url should be provided by the engine
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid result handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a detailed_url is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_wp_check_url()
  int csr_wp_result_get_detailed_url(
    csr_wp_check_result_h result,
    ffi.Pointer<ffi.Pointer<ffi.Char>> detailed_url,
  ) {
    return _csr_wp_result_get_detailed_url(
      result,
      detailed_url,
    );
  }

  late final _csr_wp_result_get_detailed_urlPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  csr_wp_check_result_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'csr_wp_result_get_detailed_url');
  late final _csr_wp_result_get_detailed_url =
      _csr_wp_result_get_detailed_urlPtr.asFunction<
          int Function(
              csr_wp_check_result_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @partner
  /// @brief Extracts a user response of a popup from the result handle.
  /// @since_tizen 3.0
  /// @param[in] result A result handle returned by csr_wp_check_url()
  /// @param[out] response A pointer of the user response
  /// @return #CSR_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CSR_ERROR_NONE Successful
  /// @retval #CSR_ERROR_INVALID_HANDLE Invalid result handle
  /// @retval #CSR_ERROR_INVALID_PARAMETER @a response is invalid
  /// @retval #CSR_ERROR_SYSTEM System error
  /// @see csr_wp_check_url()
  /// @see #csr_wp_user_response_e
  int csr_wp_result_get_user_response(
    csr_wp_check_result_h result,
    ffi.Pointer<ffi.Int32> response,
  ) {
    return _csr_wp_result_get_user_response(
      result,
      response,
    );
  }

  late final _csr_wp_result_get_user_responsePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(csr_wp_check_result_h,
              ffi.Pointer<ffi.Int32>)>>('csr_wp_result_get_user_response');
  late final _csr_wp_result_get_user_response =
      _csr_wp_result_get_user_responsePtr.asFunction<
          int Function(csr_wp_check_result_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief       Creates the device policy manager handle.
  /// @details     This API creates device policy manager handle required to
  /// the device policy APIs.
  /// This API is also used to verify whether caller is authorized
  /// or not.
  /// @since_tizen 3.0
  /// @return      Device policy manager handle on success, otherwise NULL
  /// @remarks      The specific error code can be obtained by using the
  /// get_last_result() method. Error codes are described in
  /// exception section.
  /// The returned handle should be released using dpm_manager_destroy().
  /// @exception   #DPM_ERROR_NONE No error
  /// @exception   #DPM_ERROR_CONNECTION_REFUSED Connection refused
  /// @exception   #DPM_ERROR_OUT_OF_MEMORY Out of memory
  /// @see         dpm_manager_destroy()
  /// @see         get_last_result()
  device_policy_manager_h dpm_manager_create() {
    return _dpm_manager_create();
  }

  late final _dpm_manager_createPtr =
      _lookup<ffi.NativeFunction<device_policy_manager_h Function()>>(
          'dpm_manager_create');
  late final _dpm_manager_create =
      _dpm_manager_createPtr.asFunction<device_policy_manager_h Function()>();

  /// @brief       Releases the device policy manager handle.
  /// @details     This API must be called if interaction with the device
  /// policy manager is no longer required.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_manager_destroy(
    device_policy_manager_h handle,
  ) {
    return _dpm_manager_destroy(
      handle,
    );
  }

  late final _dpm_manager_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(device_policy_manager_h)>>(
          'dpm_manager_destroy');
  late final _dpm_manager_destroy = _dpm_manager_destroyPtr
      .asFunction<int Function(device_policy_manager_h)>();

  /// @brief       Adds policy change callback to the device policy
  /// manager.
  /// @details     This API can be used to subscribe policy change callback.
  /// The callback specified to this API is asynchronously called when
  /// policy is changed on runtime.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   name Policy name to subscribe(see @ref CAPI_SECURITY_DPM_MODULE_POLICY)
  /// @param[in]   callback The callback when policy is changed
  /// @param[in]   user_data User specified data passed to the callback
  /// @param[out]  id Policy change callback identifier
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @remark      See @ref CAPI_SECURITY_DPM_MODULE_POLICY section for available policy name
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_remove_policy_changed_cb()
  int dpm_add_policy_changed_cb(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Char> name,
    dpm_policy_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _dpm_add_policy_changed_cb(
      handle,
      name,
      callback,
      user_data,
      id,
    );
  }

  late final _dpm_add_policy_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              device_policy_manager_h,
              ffi.Pointer<ffi.Char>,
              dpm_policy_changed_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('dpm_add_policy_changed_cb');
  late final _dpm_add_policy_changed_cb =
      _dpm_add_policy_changed_cbPtr.asFunction<
          int Function(
              device_policy_manager_h,
              ffi.Pointer<ffi.Char>,
              dpm_policy_changed_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief       Removes policy change callback from the device policy
  /// manager.
  /// @details     This API should be called if policy change subscription is no longer
  /// required.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   id Policy change callback identifier
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @pre         The handle must be created by dpm_manager_create().
  /// @pre         The callback identifier must be created by dpm_manager_add_policy_changed_cb().
  /// @see         dpm_manager_create()
  /// @see         dpm_add_policy_changed_cb()
  int dpm_remove_policy_changed_cb(
    device_policy_manager_h handle,
    int id,
  ) {
    return _dpm_remove_policy_changed_cb(
      handle,
      id,
    );
  }

  late final _dpm_remove_policy_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_remove_policy_changed_cb');
  late final _dpm_remove_policy_changed_cb = _dpm_remove_policy_changed_cbPtr
      .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Adds signal callback.
  /// @details     This API can be used to receive signals raised by the device policy manager.
  /// The callback specified to this function is automatically called when
  /// the device policy manager raises signal.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   signal The signal name to receive(see @ref CAPI_DPM_SECURITY_MODULE_SIGNAL)
  /// @param[in]   callback The signal callback
  /// @param[in]   user_data The user data passed to the callback function
  /// @param[out]  id Signal identifier
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @remark      See @ref CAPI_DPM_SECURITY_MODULE_SIGNAL section for signals
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_manager_destroy()
  /// @see         dpm_remove_signal_cb()
  int dpm_add_signal_cb(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Char> signal,
    dpm_signal_cb callback,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _dpm_add_signal_cb(
      handle,
      signal,
      callback,
      user_data,
      id,
    );
  }

  late final _dpm_add_signal_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              device_policy_manager_h,
              ffi.Pointer<ffi.Char>,
              dpm_signal_cb,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Int>)>>('dpm_add_signal_cb');
  late final _dpm_add_signal_cb = _dpm_add_signal_cbPtr.asFunction<
      int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>,
          dpm_signal_cb, ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Int>)>();

  /// @brief       Removes signal callback.
  /// @details     This API removes signal callback.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   id Signal identifier
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @pre         The context must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_manager_destroy()
  /// @see         dpm_add_signal_cb()
  int dpm_remove_signal_cb(
    device_policy_manager_h handle,
    int id,
  ) {
    return _dpm_remove_signal_cb(
      handle,
      id,
    );
  }

  late final _dpm_remove_signal_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              device_policy_manager_h, ffi.Int)>>('dpm_remove_signal_cb');
  late final _dpm_remove_signal_cb = _dpm_remove_signal_cbPtr
      .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Sets password quality.
  /// @details     An administrator can set the password restrictions it is imposing.
  /// After setting this, the user will not be able to
  /// enter a new password that is not at least as restrictive as what has been set.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   quality Password quality type, values of #dpm_password_quality_e combined with bitwise 'or'
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_quality(
    device_policy_manager_h handle,
    int quality,
  ) {
    return _dpm_password_set_quality(
      handle,
      quality,
    );
  }

  late final _dpm_password_set_qualityPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              device_policy_manager_h, ffi.Int)>>('dpm_password_set_quality');
  late final _dpm_password_set_quality = _dpm_password_set_qualityPtr
      .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Gets password quality.
  /// @details     An administrator can get the password restrictions it is imposing.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[out]   quality Password quality type, values of #dpm_password_quality_e combined with bitwise 'or'
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_quality(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> quality,
  ) {
    return _dpm_password_get_quality(
      handle,
      quality,
    );
  }

  late final _dpm_password_get_qualityPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_password_get_quality');
  late final _dpm_password_get_quality =
      _dpm_password_get_qualityPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Sets password minimum length.
  /// @details     Sets the minimum allowed password length. After setting this,
  /// the user will not be able to enter a new password that is
  /// shorter than the setting length.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   value Allowed minimum password length
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_minimum_length(
    device_policy_manager_h handle,
    int value,
  ) {
    return _dpm_password_set_minimum_length(
      handle,
      value,
    );
  }

  late final _dpm_password_set_minimum_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_password_set_minimum_length');
  late final _dpm_password_set_minimum_length =
      _dpm_password_set_minimum_lengthPtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Gets password minimum length.
  /// @details     Gets the minimum allowed password length.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[out]   value Allowed minimum password length
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_minimum_length(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _dpm_password_get_minimum_length(
      handle,
      value,
    );
  }

  late final _dpm_password_get_minimum_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_password_get_minimum_length');
  late final _dpm_password_get_minimum_length =
      _dpm_password_get_minimum_lengthPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Sets minimum complex char in password.
  /// @details     Complex characters are all non-alphabetic characters;
  /// that is, numbers and symbols. Admin can configure this
  /// setting and make the password more secure.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   value Number of minimum complex char in password.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_min_complex_chars(
    device_policy_manager_h handle,
    int value,
  ) {
    return _dpm_password_set_min_complex_chars(
      handle,
      value,
    );
  }

  late final _dpm_password_set_min_complex_charsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_password_set_min_complex_chars');
  late final _dpm_password_set_min_complex_chars =
      _dpm_password_set_min_complex_charsPtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Gets minimum complex char in password.
  /// @details     Complex characters are all non-alphabetic characters;
  /// that is, numbers and symbols.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[out]   value Number of minimum complex char in password.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_min_complex_chars(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _dpm_password_get_min_complex_chars(
      handle,
      value,
    );
  }

  late final _dpm_password_get_min_complex_charsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_password_get_min_complex_chars');
  late final _dpm_password_get_min_complex_chars =
      _dpm_password_get_min_complex_charsPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Sets maximum number of failed attempts before device is wiped.
  /// @details     If user fails the last attempt, device will be wiped.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   value Maximum count for failed passwords.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_maximum_failed_attempts_for_wipe(
    device_policy_manager_h handle,
    int value,
  ) {
    return _dpm_password_set_maximum_failed_attempts_for_wipe(
      handle,
      value,
    );
  }

  late final _dpm_password_set_maximum_failed_attempts_for_wipePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_password_set_maximum_failed_attempts_for_wipe');
  late final _dpm_password_set_maximum_failed_attempts_for_wipe =
      _dpm_password_set_maximum_failed_attempts_for_wipePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Gets maximum number of failed attempts before device is wiped.
  /// @details     If user fails the last attempt, device will be wiped.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[out]   value Maximum count for failed passwords.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_maximum_failed_attempts_for_wipe(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _dpm_password_get_maximum_failed_attempts_for_wipe(
      handle,
      value,
    );
  }

  late final _dpm_password_get_maximum_failed_attempts_for_wipePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_password_get_maximum_failed_attempts_for_wipe');
  late final _dpm_password_get_maximum_failed_attempts_for_wipe =
      _dpm_password_get_maximum_failed_attempts_for_wipePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Sets the number of days password expires.
  /// @details     An administrator can configure the password age to force
  /// the user to enter a new password after every expiration period.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   value Number of days after which the password expires.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_expires(
    device_policy_manager_h handle,
    int value,
  ) {
    return _dpm_password_set_expires(
      handle,
      value,
    );
  }

  late final _dpm_password_set_expiresPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              device_policy_manager_h, ffi.Int)>>('dpm_password_set_expires');
  late final _dpm_password_set_expires = _dpm_password_set_expiresPtr
      .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Gets the number of days password expires.
  /// @details     An administrator can get the password age to force
  /// the user to enter a new password after every expiration period.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[out]   value Number of days after which the password expires.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_expires(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _dpm_password_get_expires(
      handle,
      value,
    );
  }

  late final _dpm_password_get_expiresPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_password_get_expires');
  late final _dpm_password_get_expires =
      _dpm_password_get_expiresPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Sets the number of min password history to avoid previous password.
  /// @details     An administrator can configure the number of previous
  /// passwords which cannot be used when entering a new password.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   value Number of previous passwords which cannot be used when
  /// settings a new password.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_history(
    device_policy_manager_h handle,
    int value,
  ) {
    return _dpm_password_set_history(
      handle,
      value,
    );
  }

  late final _dpm_password_set_historyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              device_policy_manager_h, ffi.Int)>>('dpm_password_set_history');
  late final _dpm_password_set_history = _dpm_password_set_historyPtr
      .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Gets the number of min password history to avoid previous password.
  /// @details     An administrator can get the number of previous
  /// passwords which cannot be used when entering a new password.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[out]   value Number of previous passwords which cannot be used when
  /// settings a new password.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_history(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _dpm_password_get_history(
      handle,
      value,
    );
  }

  late final _dpm_password_get_historyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_password_get_history');
  late final _dpm_password_get_history =
      _dpm_password_get_historyPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Sets the required password pattern.
  /// @details     An administrator can force User to enter password based on
  /// a regular expression.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   pattern Password pattern. If regular expression is
  /// [a-zA-Z]{4}[0-9]{4}, we can force user to enter a 8 character
  /// password with first 4 alphabetic characters and next 4
  /// numeric characters. An administrator must take care when
  /// setting this pattern.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_pattern(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Char> pattern,
  ) {
    return _dpm_password_set_pattern(
      handle,
      pattern,
    );
  }

  late final _dpm_password_set_patternPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Char>)>>('dpm_password_set_pattern');
  late final _dpm_password_set_pattern =
      _dpm_password_set_patternPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>)>();

  /// @partner
  /// @brief       Resets password.
  /// @details     This takes effect immediately to the device password.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   password New password
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_reset(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Char> password,
  ) {
    return _dpm_password_reset(
      handle,
      password,
    );
  }

  late final _dpm_password_resetPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Char>)>>('dpm_password_reset');
  late final _dpm_password_reset = _dpm_password_resetPtr.asFunction<
      int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>)>();

  /// @partner
  /// @brief       Enforces password change.
  /// @details     An administrator can enforce password change. PasswordPolicy
  /// change setting is launched.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_enforce_change(
    device_policy_manager_h handle,
  ) {
    return _dpm_password_enforce_change(
      handle,
    );
  }

  late final _dpm_password_enforce_changePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(device_policy_manager_h)>>(
          'dpm_password_enforce_change');
  late final _dpm_password_enforce_change = _dpm_password_enforce_changePtr
      .asFunction<int Function(device_policy_manager_h)>();

  /// @partner
  /// @brief       Sets the maximum number of seconds of inactivity time
  /// before the screen timeout occurs.
  /// @details     An administrator sets the maximum number of seconds of inactivity
  /// time before the screen timeout occurs and a device user must
  /// type the password to unlock the device.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   value Maximum inactivity time for device lock. Specifies how soon
  /// the device can be unlocked again after use, without reprompting for
  /// the passcode.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_max_inactivity_time_device_lock(
    device_policy_manager_h handle,
    int value,
  ) {
    return _dpm_password_set_max_inactivity_time_device_lock(
      handle,
      value,
    );
  }

  late final _dpm_password_set_max_inactivity_time_device_lockPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_password_set_max_inactivity_time_device_lock');
  late final _dpm_password_set_max_inactivity_time_device_lock =
      _dpm_password_set_max_inactivity_time_device_lockPtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Gets the maximum number of seconds of inactivity time
  /// before the screen timeout occurs.
  /// @details     Called by an application that is managing the device to get
  /// the value of timeout period.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  value Pointer of Maximum inactivity time for device lock.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_max_inactivity_time_device_lock(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _dpm_password_get_max_inactivity_time_device_lock(
      handle,
      value,
    );
  }

  late final _dpm_password_get_max_inactivity_time_device_lockPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_password_get_max_inactivity_time_device_lock');
  late final _dpm_password_get_max_inactivity_time_device_lock =
      _dpm_password_get_max_inactivity_time_device_lockPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Sets password status
  /// @details     An administrator can know password status for this API.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   status Password status
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_status(
    device_policy_manager_h handle,
    int status,
  ) {
    return _dpm_password_set_status(
      handle,
      status,
    );
  }

  late final _dpm_password_set_statusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              device_policy_manager_h, ffi.Int32)>>('dpm_password_set_status');
  late final _dpm_password_set_status = _dpm_password_set_statusPtr
      .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Gets password status
  /// @details     An administrator can know password status for this API.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]   status Password status
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_status(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int32> status,
  ) {
    return _dpm_password_get_status(
      handle,
      status,
    );
  }

  late final _dpm_password_get_statusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int32>)>>('dpm_password_get_status');
  late final _dpm_password_get_status = _dpm_password_get_statusPtr.asFunction<
      int Function(device_policy_manager_h, ffi.Pointer<ffi.Int32>)>();

  /// @partner
  /// @brief       Removes all password patterns.
  /// @details     An administrator can remove all password patterns.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_delete_pattern(
    device_policy_manager_h handle,
  ) {
    return _dpm_password_delete_pattern(
      handle,
    );
  }

  late final _dpm_password_delete_patternPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(device_policy_manager_h)>>(
          'dpm_password_delete_pattern');
  late final _dpm_password_delete_pattern = _dpm_password_delete_patternPtr
      .asFunction<int Function(device_policy_manager_h)>();

  /// @partner
  /// @brief       Gets password pattern.
  /// @details     This API can be used for applying complexity on new password value.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @remarks     The @a pattern should be freed using free().
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  pattern Password pattern
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_pattern(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> pattern,
  ) {
    return _dpm_password_get_pattern(
      handle,
      pattern,
    );
  }

  late final _dpm_password_get_patternPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('dpm_password_get_pattern');
  late final _dpm_password_get_pattern =
      _dpm_password_get_patternPtr.asFunction<
          int Function(
              device_policy_manager_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @partner
  /// @brief       Sets the maximum number of times a character can occur in
  /// the device password.
  /// @details     Called by an admin that is managing the device to specify that
  /// any character in the device password cannot occur more than
  /// the specified maximum number of times. Characters can be numeric
  /// or alphabetic or symbolic. "aaabcde" has 'a' which occurs 3 times,
  /// "1b1c1de" has '1' which occurs 3 times and "a@b@c@" has '@' which
  /// occurs 3 times. A value of '0' specifies that no restrictions are
  /// applied.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   value Maximum character occurrences
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_maximum_character_occurrences(
    device_policy_manager_h handle,
    int value,
  ) {
    return _dpm_password_set_maximum_character_occurrences(
      handle,
      value,
    );
  }

  late final _dpm_password_set_maximum_character_occurrencesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_password_set_maximum_character_occurrences');
  late final _dpm_password_set_maximum_character_occurrences =
      _dpm_password_set_maximum_character_occurrencesPtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Gets the maximum number of times a character can occur in
  /// the device password.
  /// @details     An administrator can retrieve the maximum number of times
  /// a character can occur in the device password. If more than
  /// one admin has set this value then the least value will take
  /// preference.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[out]   value Pointer of Maximum Character Occurrences
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_maximum_character_occurrences(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _dpm_password_get_maximum_character_occurrences(
      handle,
      value,
    );
  }

  late final _dpm_password_get_maximum_character_occurrencesPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_password_get_maximum_character_occurrences');
  late final _dpm_password_get_maximum_character_occurrences =
      _dpm_password_get_maximum_character_occurrencesPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Sets the maximum length of the numeric sequence
  /// which is allowed in the device password.
  /// @details     Called by an administrator that is managing the device to set
  /// the maximum numeric sequence length. This specifies that
  /// the device password must not contain numeric sequences greater
  /// than the given length.
  /// Numeric sequences can be increasing successively by one like
  /// "12345", or decreasing successively by one like "98765", or
  /// repeating like "55555".
  /// These are all numeric sequences of length '5'.
  /// If maximum value is set to '5' then "123456" or "987654" or
  /// "555555" are not allowed.
  /// A value of '0' specifies that no such numeric sequence
  /// restrictions are applied.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   value Maximum numeric sequence length
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_maximum_numeric_sequence_length(
    device_policy_manager_h handle,
    int value,
  ) {
    return _dpm_password_set_maximum_numeric_sequence_length(
      handle,
      value,
    );
  }

  late final _dpm_password_set_maximum_numeric_sequence_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_password_set_maximum_numeric_sequence_length');
  late final _dpm_password_set_maximum_numeric_sequence_length =
      _dpm_password_set_maximum_numeric_sequence_lengthPtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Gets the maximum numeric sequence length allowed in
  /// the device password.
  /// @details     An administrator can retrieve the length of numeric sequences
  /// which are allowed in the device password.
  /// For instance, if the return value is '3' then "123", "987",
  /// "555" would all be numeric sequences of length '3' and will be
  /// allowed in the device password.
  /// If more than one admin has set this value then the least value
  /// will take preference.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  value Pointer of maximum numeric sequence length
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_get_maximum_numeric_sequence_length(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _dpm_password_get_maximum_numeric_sequence_length(
      handle,
      value,
    );
  }

  late final _dpm_password_get_maximum_numeric_sequence_lengthPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_password_get_maximum_numeric_sequence_length');
  late final _dpm_password_get_maximum_numeric_sequence_length =
      _dpm_password_get_maximum_numeric_sequence_lengthPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Creates a password forbidden string list iterator.
  /// @details     The password forbidden string list iterator can be used to get all forbidden strings.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @return      A password forbidden string list iterator on success, otherwise
  /// null value
  /// @remarks     The specific error code can be obtained by using the
  /// get_last_result() method. Error codes are described in
  /// exception section.
  /// The returned iterator should be released using dpm_password_destroy_iterator().
  /// @exception   #DPM_ERROR_NONE No error
  /// @exception   #DPM_ERROR_OUT_OF_MEMORY Out of memory
  /// @exception   #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception   #DPM_ERROR_TIMED_OUT Time out
  /// @exception   #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_password_iterator_next()
  /// @see         dpm_password_destroy_iterator()
  /// @see         get_last_result()
  dpm_password_iterator_h dpm_password_create_iterator(
    device_policy_manager_h handle,
  ) {
    return _dpm_password_create_iterator(
      handle,
    );
  }

  late final _dpm_password_create_iteratorPtr = _lookup<
      ffi.NativeFunction<
          dpm_password_iterator_h Function(
              device_policy_manager_h)>>('dpm_password_create_iterator');
  late final _dpm_password_create_iterator = _dpm_password_create_iteratorPtr
      .asFunction<dpm_password_iterator_h Function(device_policy_manager_h)>();

  /// @partner
  /// @brief       Fetches a password forbidden string and forwards the iterator.
  /// @details     This API returns a password forbidden string indicated by the iterator, and then
  /// the iterator is moved to the next position. If the iterator reaches
  /// the end of the list, null value will be returned.
  /// @since_tizen 3.0
  /// @param[in]   iter The iterator to be controlled
  /// @param[out]  forbidden_string The forbidden string got from the iterator
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @remarks     The @a forbidden_string should not be freed using free().
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @pre         The iter must be created by dpm_password_create_iterator().
  /// @see         dpm_passsword_create_iterator()
  /// @see         dpm_password_destroy_iterator()
  int dpm_password_iterator_next(
    dpm_password_iterator_h iter,
    ffi.Pointer<ffi.Pointer<ffi.Char>> forbidden_string,
  ) {
    return _dpm_password_iterator_next(
      iter,
      forbidden_string,
    );
  }

  late final _dpm_password_iterator_nextPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(dpm_password_iterator_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'dpm_password_iterator_next');
  late final _dpm_password_iterator_next =
      _dpm_password_iterator_nextPtr.asFunction<
          int Function(
              dpm_password_iterator_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @partner
  /// @brief       Frees the password forbidden string iterator.
  /// @details     This API frees the password forbidden string iterator. This API must be called
  /// if the iterator no longer used.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   iter The iterator to be removed
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The iter must be created by dpm_password_create_iterator()
  /// @see         dpm_password_create_iterator()
  /// @see         dpm_password_iterator_next()
  int dpm_password_destroy_iterator(
    dpm_password_iterator_h iter,
  ) {
    return _dpm_password_destroy_iterator(
      iter,
    );
  }

  late final _dpm_password_destroy_iteratorPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(dpm_password_iterator_h)>>(
          'dpm_password_destroy_iterator');
  late final _dpm_password_destroy_iterator = _dpm_password_destroy_iteratorPtr
      .asFunction<int Function(dpm_password_iterator_h)>();

  /// @partner
  /// @brief       Sets strings which are forbidden in the device password.
  /// @details     Called by an admin that is managing the device to set strings that are forbidden to be used in the device password.
  /// This specifies any strings which must not be present in the device password such as personal data (variations on the user's name, email address or X400 address), or any other strings.
  /// If the parameter list has only one blank string(""), then the stored strings are cleared.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.password
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   strings The forbidden strings
  /// @param[in]   length The length of the strings
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_password_set_forbidden_strings(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> strings,
    int length,
  ) {
    return _dpm_password_set_forbidden_strings(
      handle,
      strings,
      length,
    );
  }

  late final _dpm_password_set_forbidden_stringsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              device_policy_manager_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Int)>>('dpm_password_set_forbidden_strings');
  late final _dpm_password_set_forbidden_strings =
      _dpm_password_set_forbidden_stringsPtr.asFunction<
          int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>, int)>();

  /// @partner
  /// @brief       Allows or disallows the use of camera.
  /// @details     An administrator can use this API to set whether the use of camera
  /// is allowed or not.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.camera
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow the use of camera, if false, disallow the use of camera
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_camera_state()
  int dpm_restriction_set_camera_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_camera_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_camera_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_camera_state');
  late final _dpm_restriction_set_camera_state =
      _dpm_restriction_set_camera_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Check whether the use of camera is allowed or not.
  /// @details     An administrator can use this API to check whether the use of camera
  /// is allowed or not.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the use of camera is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_camera_state()
  int dpm_restriction_get_camera_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_camera_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_camera_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_restriction_get_camera_state');
  late final _dpm_restriction_get_camera_state =
      _dpm_restriction_get_camera_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows the use of microphone.
  /// @details     An administrator can use this API to set whether the use of microphone
  /// is allowed or not.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.microphone
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow the use of microphone,
  /// if false, disallow the use of microphone
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_microphone_state()
  int dpm_restriction_set_microphone_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_microphone_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_microphone_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_microphone_state');
  late final _dpm_restriction_set_microphone_state =
      _dpm_restriction_set_microphone_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the use of microphone is allowed or not.
  /// @details     An administrator can use this API to check whether the use of microphone
  /// is allowed of not.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the use of microphone is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_microphone_state()
  int dpm_restriction_get_microphone_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_microphone_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_microphone_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_restriction_get_microphone_state');
  late final _dpm_restriction_get_microphone_state =
      _dpm_restriction_get_microphone_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows user to change the location state.
  /// @details     An administrator can use this API to allow or disallow user to change
  /// the location state.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.location
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow user to change the location state, if false, disallow
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_location_state()
  int dpm_restriction_set_location_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_location_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_location_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_location_state');
  late final _dpm_restriction_set_location_state =
      _dpm_restriction_set_location_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Check whether user is allowed to change location state or not.
  /// @details     An administrator can use this API to check whether user is allowed to change
  /// the location state or not.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the location state change is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_location_state()
  int dpm_restriction_get_location_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_location_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_location_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_restriction_get_location_state');
  late final _dpm_restriction_get_location_state =
      _dpm_restriction_get_location_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows user to use usb mass storage.
  /// @details     An administrator can use this API to set whether the usb mass
  /// storage is allowed or not.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.storage
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow user to use the external storages, if false, disallow
  /// the external storage
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_storage_get_external_storage_state()
  int dpm_restriction_set_external_storage_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_external_storage_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_external_storage_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_external_storage_state');
  late final _dpm_restriction_set_external_storage_state =
      _dpm_restriction_set_external_storage_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the use of external storage is allowed or not.
  /// @details     An administrator can use this API to check whether the use of external storage is
  /// allowed or not.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the use of external storage is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_storage_set_external_storage_state()
  int dpm_restriction_get_external_storage_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_external_storage_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_external_storage_statePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_restriction_get_external_storage_state');
  late final _dpm_restriction_get_external_storage_state =
      _dpm_restriction_get_external_storage_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows user to access the clipboard.
  /// @details     An administrator can use this API to set whether the clipboard access.
  /// is allowed or not
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.clipboard
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow the clipboard access, if false, disallow the clipboard access.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_clipboard_state()
  int dpm_restriction_set_clipboard_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_clipboard_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_clipboard_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_clipboard_state');
  late final _dpm_restriction_set_clipboard_state =
      _dpm_restriction_set_clipboard_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the clipboard access is allowed or not.
  /// @details     An administrator can use this API to check whether the clipboard access
  /// is allowed or not.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the access is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_clipboard_state()
  int dpm_restriction_get_clipboard_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_clipboard_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_clipboard_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_restriction_get_clipboard_state');
  late final _dpm_restriction_get_clipboard_state =
      _dpm_restriction_get_clipboard_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows the usb debugging.
  /// @details     An administrator can use this API to set whether the usb debugging
  /// is allowed or not.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.debugging
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow the usb debugging, if false, disallow the usb
  /// debugging
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_usb_debugging_state()
  int dpm_restriction_set_usb_debugging_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_usb_debugging_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_usb_debugging_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_usb_debugging_state');
  late final _dpm_restriction_set_usb_debugging_state =
      _dpm_restriction_set_usb_debugging_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the usb debugging is allowed or not.
  /// @details     An administrator can use this API to check whether the usb debugging
  /// is allowed or not.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]   is_allowed true if the usb debugging is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_usb_debugging_state()
  int dpm_restriction_get_usb_debugging_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_usb_debugging_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_usb_debugging_statePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_restriction_get_usb_debugging_state');
  late final _dpm_restriction_get_usb_debugging_state =
      _dpm_restriction_get_usb_debugging_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows user to change the Wi-Fi state.
  /// @details     An administrator can use this API to allow or disallow user to
  /// change the Wi-Fi state. If it is disallowed, user does not have UI
  /// access to change the state.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.wifi
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow user to change Wi-Fi state,
  /// if false, disallow user to change Wi-Fi state.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_wifi_state()
  int dpm_restriction_set_wifi_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_wifi_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_wifi_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_wifi_state');
  late final _dpm_restriction_set_wifi_state =
      _dpm_restriction_set_wifi_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the Wi-Fi state change is allowed or not.
  /// @details     An administrator can use this API to check whether user is
  /// allowed to change Wi-Fi state or not.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the change is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_wifi_state()
  int dpm_restriction_get_wifi_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_wifi_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_wifi_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_restriction_get_wifi_state');
  late final _dpm_restriction_get_wifi_state =
      _dpm_restriction_get_wifi_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows user to change Wi-Fi hotspot state change.
  /// @details     An administrator can use this API to allow or disallow user to change Wi-Fi
  /// hotspot state. When it is disallowed, the UI is grayed out so user cannot
  /// change Wi-Fi hotspot state.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.wifi
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow user to change Wi-Fi hostspot state,
  /// if false, disallow user to change Wi-Fi hotspot state.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_wifi_hotspot_state()
  int dpm_restriction_set_wifi_hotspot_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_wifi_hotspot_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_wifi_hotspot_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_wifi_hotspot_state');
  late final _dpm_restriction_set_wifi_hotspot_state =
      _dpm_restriction_set_wifi_hotspot_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the the Wi-Fi hotspot state change is allowed or not.
  /// @details     An administrator can use this API to check whether user is allowed to change
  /// Wi-Fi hotspot state or not.
  /// If the Wi-Fi hotspot state change is disallowed, the UI is grayed out so user can not
  /// change its state.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the state change is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_wifi_hotspot_state()
  int dpm_restriction_get_wifi_hotspot_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_wifi_hotspot_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_wifi_hotspot_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_restriction_get_wifi_hotspot_state');
  late final _dpm_restriction_get_wifi_hotspot_state =
      _dpm_restriction_get_wifi_hotspot_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows user to change the bluetooth tethering state.
  /// @details     An administrator can use this API to allow of disallow user
  /// to chanage the bluetooth tethering state.
  /// When disallowed, the UI is grayed out so user cannot change the state.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.bluetooth
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow user to change the bluetooth tethering state,
  /// if false, disallow user to change the bluetooth tethering state.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_bluetooth_tethering_state()
  int dpm_restriction_set_bluetooth_tethering_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_bluetooth_tethering_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_bluetooth_tethering_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_bluetooth_tethering_state');
  late final _dpm_restriction_set_bluetooth_tethering_state =
      _dpm_restriction_set_bluetooth_tethering_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the bluetooth tethering state change is allowed.
  /// @details     An administrator can use this API to check whether user is allowed
  /// to change bluetooth tethering state.
  /// is allowed or not.
  /// If the bluetooth tethering state change is disallowed, the UI is grayed out
  /// so user can not change its state.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the change is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_bluetooth_tethering_state()
  int dpm_restriction_get_bluetooth_tethering_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_bluetooth_tethering_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_bluetooth_tethering_statePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_restriction_get_bluetooth_tethering_state');
  late final _dpm_restriction_get_bluetooth_tethering_state =
      _dpm_restriction_get_bluetooth_tethering_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows user to change USB tethering settings.
  /// @details     An administrator can use this API to allow or disallow user
  /// to change USB tethering settings.
  /// When disallowed, the UI is grayed out so user cannot change the state.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.usb
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow USB tethering state change,
  /// if false, disallow USB tethering state change.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_usb_tethering_state()
  int dpm_restriction_set_usb_tethering_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_usb_tethering_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_usb_tethering_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_usb_tethering_state');
  late final _dpm_restriction_set_usb_tethering_state =
      _dpm_restriction_set_usb_tethering_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the USB tethering state change is allowed.
  /// @details     An administrator can use this API to check whether the USB tethering state change
  /// is allowed or not.
  /// If the USB tethering state change is disallowed, the UI is grayed out
  /// so user can not change its state.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the change is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_usb_tethering_state()
  int dpm_restriction_get_usb_tethering_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_usb_tethering_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_usb_tethering_statePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_restriction_get_usb_tethering_state');
  late final _dpm_restriction_get_usb_tethering_state =
      _dpm_restriction_get_usb_tethering_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows user to change the bluetooth state.
  /// @details     An administrator can use this API to allow or disallow user
  /// to change the bluetooth state.
  /// When disallowed, the UI is grayed out so user cannot change the state.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.bluetooth
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow user to change bluetooth state,
  /// if false, disallow user to change bluetooth state.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_bluetooth_mode_change_state()
  int dpm_restriction_set_bluetooth_mode_change_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_bluetooth_mode_change_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_bluetooth_mode_change_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_bluetooth_mode_change_state');
  late final _dpm_restriction_set_bluetooth_mode_change_state =
      _dpm_restriction_set_bluetooth_mode_change_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the the bluetooth state change is allowed of not.
  /// @details     An administrator can use this API to check whether the bluetooth state change
  /// is allowed or not.
  /// If the bluetooth state change is disallowed, the UI is grayed out
  /// so user can not change its state.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the change is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_bluetooth_mode_change_state()
  int dpm_restriction_get_bluetooth_mode_change_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_bluetooth_mode_change_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_bluetooth_mode_change_statePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_restriction_get_bluetooth_mode_change_state');
  late final _dpm_restriction_get_bluetooth_mode_change_state =
      _dpm_restriction_get_bluetooth_mode_change_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows the bluetooth desktop connectivity.
  /// @details     An administrator can use this API to allow or disallow the bluetooth
  /// desktop connectivity.
  /// If the bluetooth desktop connectivity is disallowed, the UI is grayed out
  /// so user can not
  /// change its state.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.bluetooth
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  allow If true, allow the bluetooth desktop connectivity,
  /// if false, disallow the bluetooth desktop connectivitiy
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_bluetooth_desktop_connectivity_state()
  int dpm_restriction_set_bluetooth_desktop_connectivity_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_bluetooth_desktop_connectivity_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_bluetooth_desktop_connectivity_statePtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(device_policy_manager_h, ffi.Int)>>(
          'dpm_restriction_set_bluetooth_desktop_connectivity_state');
  late final _dpm_restriction_set_bluetooth_desktop_connectivity_state =
      _dpm_restriction_set_bluetooth_desktop_connectivity_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the the Bluetooth desktop connectivity is allowed or not.
  /// @details     An administrator can use this API to check whether the Bluetooth desktop
  /// connectivity is allowed or not.
  /// If the Bluetooth desktop connectivity is disallowed, the UI is grayed out
  /// so user can not change its state.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the connectivity is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_bluetooth_desktop_connectivity_state()
  int dpm_restriction_get_bluetooth_desktop_connectivity_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_bluetooth_desktop_connectivity_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_bluetooth_desktop_connectivity_statePtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
          'dpm_restriction_get_bluetooth_desktop_connectivity_state');
  late final _dpm_restriction_get_bluetooth_desktop_connectivity_state =
      _dpm_restriction_get_bluetooth_desktop_connectivity_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows user to change the bluetooth pairing.
  /// @details     An administrator can use this API to allow or disallow the bluetooth pairing.
  /// If the bluetooth pairing is disallowed, the UI is grayed out
  /// so user can not change its state.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.bluetooth
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  allow If true, allow the bluetooth pairing, if false, disallow the bluetooth pairing.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_get_bluetooth_pairing_state()
  int dpm_restriction_set_bluetooth_pairing_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_bluetooth_pairing_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_bluetooth_pairing_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_bluetooth_pairing_state');
  late final _dpm_restriction_set_bluetooth_pairing_state =
      _dpm_restriction_set_bluetooth_pairing_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the the bluetooth pairing is allowed or not.
  /// @details     An administrator can use this API to check whether the bluetooth
  /// pairing is allowed or not.
  /// If the bluetooth pairing is disallowed, the UI is grayed out
  /// so user can not change its state.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the pairing is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_restriction_set_bluetooth_pairing_state()
  int dpm_restriction_get_bluetooth_pairing_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_bluetooth_pairing_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_bluetooth_pairing_statePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_restriction_get_bluetooth_pairing_state');
  late final _dpm_restriction_get_bluetooth_pairing_state =
      _dpm_restriction_get_bluetooth_pairing_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows user to use of SMS or text messaging.
  /// @details     An administrator can disable the text messaging capability
  /// without any user interaction
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.message
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   sim_id SIM identifier
  /// @param[in]   allow If true, allow the use of SMS or text messaging,
  /// if false, disallow the use of SMS or text messaging.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_restriction_get_messaging_state()
  int dpm_restriction_set_messaging_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Char> sim_id,
    int allow,
  ) {
    return _dpm_restriction_set_messaging_state(
      handle,
      sim_id,
      allow,
    );
  }

  late final _dpm_restriction_set_messaging_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>,
              ffi.Int)>>('dpm_restriction_set_messaging_state');
  late final _dpm_restriction_set_messaging_state =
      _dpm_restriction_set_messaging_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief       Checks whether the text messaging is allowed or not.
  /// @details     An administrator can use this API to check whether text messaging capability
  /// is enabled or not.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   sim_id SIM identifier
  /// @param[out]  is_allowed true if the messaging is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_restriction_set_messaging_state()
  int dpm_restriction_get_messaging_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Char> sim_id,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_messaging_state(
      handle,
      sim_id,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_messaging_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('dpm_restriction_get_messaging_state');
  late final _dpm_restriction_get_messaging_state =
      _dpm_restriction_get_messaging_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows the access to POP or IMAP email.
  /// @details     An administrator can disable the email capability without any user interaction
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.email
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If ture, allow POP or IMAP email, if false, disallow POP or IMAP email.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_restriction_get_popimap_email_state()
  int dpm_restriction_set_popimap_email_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_popimap_email_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_popimap_email_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_popimap_email_state');
  late final _dpm_restriction_set_popimap_email_state =
      _dpm_restriction_set_popimap_email_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the access to POP or IMAP email is allowed or not.
  /// @details     An administrator can use this API to check the access to POP or IMAP email
  /// is allowed or not.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the POP or IMAP email is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_restriction_set_popimap_email_state()
  int dpm_restriction_get_popimap_email_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_popimap_email_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_popimap_email_statePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_restriction_get_popimap_email_state');
  late final _dpm_restriction_get_popimap_email_state =
      _dpm_restriction_get_popimap_email_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Allows or disallows the use of web browser.
  /// @details     An administrator can allows or disallow the use of web browser without
  /// any user interaction
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.browser
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   allow If true, allow the use of web browser,
  /// if false, disallow the use of web browser.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_restriction_get_browser_state()
  int dpm_restriction_set_browser_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_browser_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_browser_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_browser_state');
  late final _dpm_restriction_set_browser_state =
      _dpm_restriction_set_browser_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks whether the use of web browser is allowed or not.
  /// @details     An administrator can use this API to check whether the use of web browser
  /// is allowed or not.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_allowed true if the use of web browser is allowed, false otherwise.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_restriction_set_browser_state()
  int dpm_restriction_get_browser_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_browser_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_browser_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_restriction_get_browser_state');
  late final _dpm_restriction_get_browser_state =
      _dpm_restriction_get_browser_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  int dpm_restriction_set_usb_client_state(
    device_policy_manager_h handle,
    int allow,
  ) {
    return _dpm_restriction_set_usb_client_state(
      handle,
      allow,
    );
  }

  late final _dpm_restriction_set_usb_client_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_restriction_set_usb_client_state');
  late final _dpm_restriction_set_usb_client_state =
      _dpm_restriction_set_usb_client_statePtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  int dpm_restriction_get_usb_client_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_allowed,
  ) {
    return _dpm_restriction_get_usb_client_state(
      handle,
      is_allowed,
    );
  }

  late final _dpm_restriction_get_usb_client_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Int>)>>('dpm_restriction_get_usb_client_state');
  late final _dpm_restriction_get_usb_client_state =
      _dpm_restriction_get_usb_client_statePtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Locks device screen immediately.
  /// @details     An administrator can use this API to lock the device screen
  /// immediately
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.lock
  /// @param[in]   handle Device policy manager handle
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_security_lockout_screen(
    device_policy_manager_h handle,
  ) {
    return _dpm_security_lockout_screen(
      handle,
    );
  }

  late final _dpm_security_lockout_screenPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(device_policy_manager_h)>>(
          'dpm_security_lockout_screen');
  late final _dpm_security_lockout_screen = _dpm_security_lockout_screenPtr
      .asFunction<int Function(device_policy_manager_h)>();

  /// @partner
  /// @brief       Encrypts or decrypts internal storage.
  /// @details     An administrator can use this API to enable full device
  /// encryption, which includes device memory and internal SD card.
  /// Before calling this API, administrator must ensure that
  /// the device password is set to alphanumeric quality.
  /// The administrator can set an alphanumeric password by using
  /// dpm_set_password_quality() API
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.security
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   encrypt true if encryption is required, false if decryption is
  /// required
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_security_is_internal_storage_encrypted()
  int dpm_security_set_internal_storage_encryption(
    device_policy_manager_h handle,
    int encrypt,
  ) {
    return _dpm_security_set_internal_storage_encryption(
      handle,
      encrypt,
    );
  }

  late final _dpm_security_set_internal_storage_encryptionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_security_set_internal_storage_encryption');
  late final _dpm_security_set_internal_storage_encryption =
      _dpm_security_set_internal_storage_encryptionPtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks the internal storage encryption state.
  /// @details     An administrator can use this API to check whether internal
  /// storage encryption is enabled.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]  is_encrypted true if internal storage is encrypted or being encrypted,
  /// else false.
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_security_set_internal_storage_encryption()
  int dpm_security_is_internal_storage_encrypted(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_encrypted,
  ) {
    return _dpm_security_is_internal_storage_encrypted(
      handle,
      is_encrypted,
    );
  }

  late final _dpm_security_is_internal_storage_encryptedPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_security_is_internal_storage_encrypted');
  late final _dpm_security_is_internal_storage_encrypted =
      _dpm_security_is_internal_storage_encryptedPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Encrypts or decrypts external storage.
  /// @details     An administrator can use this API to enable external SD card
  /// encryption. Before calling this API, administrator must
  /// ensure that the device password is set to alphanumeric quality.
  /// The administrator can set an alphanumeric password by using
  /// dpm_set_password_quality() API
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.security
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   encrypt true if encryption is required, false if decryption is
  /// required
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_security_is_external_storage_encryped()
  int dpm_security_set_external_storage_encryption(
    device_policy_manager_h handle,
    int encrypt,
  ) {
    return _dpm_security_set_external_storage_encryption(
      handle,
      encrypt,
    );
  }

  late final _dpm_security_set_external_storage_encryptionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Int)>>('dpm_security_set_external_storage_encryption');
  late final _dpm_security_set_external_storage_encryption =
      _dpm_security_set_external_storage_encryptionPtr
          .asFunction<int Function(device_policy_manager_h, int)>();

  /// @brief       Checks the external storage encryption state.
  /// @details     An administrator can use this API to check whether external
  /// storage encryption is enabled.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[out]   is_encrypted true if external storage is encrypted or being encrypted,
  /// else false
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_security_set_external_storage_encryption()
  int dpm_security_is_external_storage_encrypted(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Int> is_encrypted,
  ) {
    return _dpm_security_is_external_storage_encrypted(
      handle,
      is_encrypted,
    );
  }

  late final _dpm_security_is_external_storage_encryptedPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>>(
      'dpm_security_is_external_storage_encrypted');
  late final _dpm_security_is_external_storage_encrypted =
      _dpm_security_is_external_storage_encryptedPtr.asFunction<
          int Function(device_policy_manager_h, ffi.Pointer<ffi.Int>)>();

  /// @partner
  /// @brief       Wipes external memory, internal memory, or both selectively.
  /// @details     Device Admin can use this API to wipe both SD card data
  /// and application data.
  /// Calling this API may require rebooting the device.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.wipe
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   type The target storage for wipe
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  int dpm_security_wipe_data(
    device_policy_manager_h handle,
    int type,
  ) {
    return _dpm_security_wipe_data(
      handle,
      type,
    );
  }

  late final _dpm_security_wipe_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              device_policy_manager_h, ffi.Int32)>>('dpm_security_wipe_data');
  late final _dpm_security_wipe_data = _dpm_security_wipe_dataPtr
      .asFunction<int Function(device_policy_manager_h, int)>();

  /// @partner
  /// @brief       Creates a new zone.
  /// @details     An administrator can use this API to create a container. Once the container
  /// is created, the admin package given to the parameter will be installed inside
  /// the container. Then ownership of the container gets transferred to the admin
  /// package from the client which triggered the container creation process.
  /// @since_tizen 3.0
  /// @privlevel   partner
  /// @privilege   %http://tizen.org/privilege/dpm.zone
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   name The zone name to be created
  /// @param[in]   pkgname Admin package container ownership will be transferred
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_zone_destroy()
  /// @see         dpm_zone_create_iterator()
  int dpm_zone_create(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Char> pkgname,
  ) {
    return _dpm_zone_create(
      handle,
      name,
      pkgname,
    );
  }

  late final _dpm_zone_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('dpm_zone_create');
  late final _dpm_zone_create = _dpm_zone_createPtr.asFunction<
      int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>)>();

  /// @partner
  /// @brief       Removes existing zone.
  /// @details     Administrator can use this API to remove zone. All file system objects
  /// created for the zone will be also erased.
  /// @since_tizen 3.0
  /// @privlevel	partner
  /// @privilege	%http://tizen.org/privilege/dpm.zone
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   name The zone name to be removed
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_PERMISSION_DENIED The application does not have
  /// the privilege to call this API or the caller is not the owner
  /// of the zone
  /// @pre         The handle must be created by dpm_manager_create().
  /// @pre         The zone corresponding to the given name must be
  /// created before use of this API.
  /// @see         dpm_manager_create()
  /// @see         dpm_zone_create()
  /// @see         dpm_zone_create_iterator()
  int dpm_zone_destroy(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Char> name,
  ) {
    return _dpm_zone_destroy(
      handle,
      name,
    );
  }

  late final _dpm_zone_destroyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h,
              ffi.Pointer<ffi.Char>)>>('dpm_zone_destroy');
  late final _dpm_zone_destroy = _dpm_zone_destroyPtr.asFunction<
      int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>)>();

  /// @brief       Gets the zone state.
  /// @details     This API can be used to get the state of the zone. The zone can
  /// have one of the three states(running, locked).
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   name The zone name
  /// @param[out]  state The zone state
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_NO_DATA No such zone to get state
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_zone_create()
  /// @see         dpm_zone_destroy()
  int dpm_zone_get_state(
    device_policy_manager_h handle,
    ffi.Pointer<ffi.Char> name,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _dpm_zone_get_state(
      handle,
      name,
      state,
    );
  }

  late final _dpm_zone_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>>('dpm_zone_get_state');
  late final _dpm_zone_get_state = _dpm_zone_get_statePtr.asFunction<
      int Function(device_policy_manager_h, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Int32>)>();

  /// @brief       Retrieves all the name of created zones
  /// @details     This API calls dpm_zone_foreach_cb() once for each zone name
  /// with traversing the created zones list.
  /// @since_tizen 3.0
  /// @param[in]   handle Device policy manager handle
  /// @param[in]   state a combination of the zone state to look
  /// @param[in]   callback The iteration callback function
  /// @param[in]   user_data The user data passed to the callback function
  /// @return      #DPM_ERROR_NONE on success, otherwise a negative value
  /// @retval      #DPM_ERROR_NONE Successful
  /// @retval      #DPM_ERROR_TIMED_OUT Time out
  /// @retval      #DPM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre         The handle must be created by dpm_manager_create().
  /// @see         dpm_manager_create()
  /// @see         dpm_zone_create()
  /// @see         dpm_zone_destroy()
  int dpm_zone_foreach_name(
    device_policy_manager_h handle,
    int state,
    dpm_zone_foreach_name_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _dpm_zone_foreach_name(
      handle,
      state,
      callback,
      user_data,
    );
  }

  late final _dpm_zone_foreach_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              device_policy_manager_h,
              ffi.Int32,
              dpm_zone_foreach_name_cb,
              ffi.Pointer<ffi.Void>)>>('dpm_zone_foreach_name');
  late final _dpm_zone_foreach_name = _dpm_zone_foreach_namePtr.asFunction<
      int Function(device_policy_manager_h, int, dpm_zone_foreach_name_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @deprecated Deprecated since 3.0. [Use ckmc_owner_id_separator instead]
  /// @brief Separator between alias and label.
  /// @since_tizen 2.3
  /// @remarks Alias can be provided as an alias alone, or together with label - in this
  /// case, separator " " (space bar) is used to separate label and alias.
  /// @see #ckmc_owner_id_separator
  late final ffi.Pointer<ffi.Pointer<ffi.Char>> _ckmc_label_name_separator =
      _lookup<ffi.Pointer<ffi.Char>>('ckmc_label_name_separator');

  ffi.Pointer<ffi.Char> get ckmc_label_name_separator =>
      _ckmc_label_name_separator.value;

  set ckmc_label_name_separator(ffi.Pointer<ffi.Char> value) =>
      _ckmc_label_name_separator.value = value;

  /// @brief Separator between alias and owner id.
  /// @since_tizen 3.0
  /// @remarks Alias can be provided as an alias alone, or together with owner id.
  /// In this case, separator " " (space bar) is used to separate id and alias.
  /// @see ckmc_alias_new()
  late final ffi.Pointer<ffi.Pointer<ffi.Char>> _ckmc_owner_id_separator =
      _lookup<ffi.Pointer<ffi.Char>>('ckmc_owner_id_separator');

  ffi.Pointer<ffi.Char> get ckmc_owner_id_separator =>
      _ckmc_owner_id_separator.value;

  set ckmc_owner_id_separator(ffi.Pointer<ffi.Char> value) =>
      _ckmc_owner_id_separator.value = value;

  /// @brief The owner of system database.
  /// @since_tizen 3.0
  /// @remarks #ckmc_owner_id_system constains id connected with all system applications that run with uid less than 5000.
  /// Client should use #ckmc_owner_id_system to access data owned by system application and stored in system database.
  /// Client must have permission to access proper row.
  /// @see ckmc_alias_new()
  late final ffi.Pointer<ffi.Pointer<ffi.Char>> _ckmc_owner_id_system =
      _lookup<ffi.Pointer<ffi.Char>>('ckmc_owner_id_system');

  ffi.Pointer<ffi.Char> get ckmc_owner_id_system => _ckmc_owner_id_system.value;

  set ckmc_owner_id_system(ffi.Pointer<ffi.Char> value) =>
      _ckmc_owner_id_system.value = value;

  /// @brief Creates a new full alias which is a concatenation of @a owner_id and @a alias.
  /// @since_tizen 3.0
  /// @remarks @a full_alias should be freed with free() after use.
  /// @remarks Returns #CKMC_ERROR_INVALID_PARAMETER if any of parameter is NULL.
  /// @remarks Returns #CKMC_ERROR_INVALID_PARAMETER if @a owner_id is empty.
  /// @param[in] owner_id Data owner's id. This should be package id if data owner is
  /// application. If you want to access data stored by system
  /// services, it should be #ckmc_owner_id_system
  /// @param[in] alias Data alias
  /// @param[out] full_alias The newly created alias which is a concatenation of
  /// @a owner_id, #ckmc_owner_id_separator and @a alias.
  /// Destroy by free() after use
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory
  /// @see #ckmc_owner_id_separator
  /// @see #ckmc_owner_id_system
  int ckmc_alias_new(
    ffi.Pointer<ffi.Char> owner_id,
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ffi.Pointer<ffi.Char>> full_alias,
  ) {
    return _ckmc_alias_new(
      owner_id,
      alias,
      full_alias,
    );
  }

  late final _ckmc_alias_newPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('ckmc_alias_new');
  late final _ckmc_alias_new = _ckmc_alias_newPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Creates a new #ckmc_key_s handle and returns it.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must destroy the newly created #ckmc_key_s by calling ckmc_key_free() if it is no longer needed.
  /// @param[in] raw_key The byte array of key \n
  /// @a raw_key may be encrypted with password
  /// @param[in] key_size The byte size of @a raw_key
  /// @param[in] key_type The @a raw_key's type
  /// @param[in] password The byte array used to decrypt @a raw_key inside key manager \n
  /// If @a raw_key is not encrypted, @a password can be null
  /// @param[out] ppkey The pointer to a newly created #ckmc_key_s handle
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory
  /// @see ckmc_key_free()
  /// @see #ckmc_key_s
  int ckmc_key_new(
    ffi.Pointer<ffi.UnsignedChar> raw_key,
    int key_size,
    int key_type,
    ffi.Pointer<ffi.Char> password,
    ffi.Pointer<ffi.Pointer<ckmc_key_s>> ppkey,
  ) {
    return _ckmc_key_new(
      raw_key,
      key_size,
      key_type,
      password,
      ppkey,
    );
  }

  late final _ckmc_key_newPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Size,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ckmc_key_s>>)>>('ckmc_key_new');
  late final _ckmc_key_new = _ckmc_key_newPtr.asFunction<
      int Function(ffi.Pointer<ffi.UnsignedChar>, int, int,
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ckmc_key_s>>)>();

  /// @brief Destroys the #ckmc_key_s handle and releases all its resources.
  /// @since_tizen 2.3
  /// @param[in] key The #ckmc_key_s handle to destroy
  void ckmc_key_free(
    ffi.Pointer<ckmc_key_s> key,
  ) {
    return _ckmc_key_free(
      key,
    );
  }

  late final _ckmc_key_freePtr =
      _lookup<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ckmc_key_s>)>>(
          'ckmc_key_free');
  late final _ckmc_key_free =
      _ckmc_key_freePtr.asFunction<void Function(ffi.Pointer<ckmc_key_s>)>();

  /// @brief Creates a new #ckmc_raw_buffer_s handle and returns it.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must destroy the newly created #ckmc_raw_buffer_s by calling ckmc_buffer_free() if it is no longer needed.
  /// @param[in] data The byte array of buffer
  /// @param[in] size The byte size of buffer
  /// @param[out] ppbuffer The pointer to a newly created #ckmc_raw_buffer_s handle
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory
  /// @see ckmc_buffer_free()
  /// @see #ckmc_raw_buffer_s
  int ckmc_buffer_new(
    ffi.Pointer<ffi.UnsignedChar> data,
    int size,
    ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>> ppbuffer,
  ) {
    return _ckmc_buffer_new(
      data,
      size,
      ppbuffer,
    );
  }

  late final _ckmc_buffer_newPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.UnsignedChar>, ffi.Size,
              ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>>('ckmc_buffer_new');
  late final _ckmc_buffer_new = _ckmc_buffer_newPtr.asFunction<
      int Function(ffi.Pointer<ffi.UnsignedChar>, int,
          ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>();

  /// @brief Destroys the #ckmc_raw_buffer_s handle and releases all its resources.
  /// @since_tizen 2.3
  /// @param[in] buffer The #ckmc_raw_buffer_s structure to destroy
  void ckmc_buffer_free(
    ffi.Pointer<ckmc_raw_buffer_s> buffer,
  ) {
    return _ckmc_buffer_free(
      buffer,
    );
  }

  late final _ckmc_buffer_freePtr = _lookup<
      ffi.NativeFunction<
          ffi.Void Function(
              ffi.Pointer<ckmc_raw_buffer_s>)>>('ckmc_buffer_free');
  late final _ckmc_buffer_free = _ckmc_buffer_freePtr
      .asFunction<void Function(ffi.Pointer<ckmc_raw_buffer_s>)>();

  /// @brief Creates a new #ckmc_cert_s handle and returns it.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must destroy the newly created #ckmc_cert_s by calling ckmc_cert_free() if it is no longer needed.
  /// @param[in] raw_cert The byte array of certificate
  /// @param[in] cert_size The byte size of raw_cert
  /// @param[in] data_format The encoding format of raw_cert
  /// @param[out] ppcert The pointer to a newly created #ckmc_cert_s handle
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory
  /// @see ckmc_cert_free()
  /// @see ckmc_load_cert_from_file()
  /// @see #ckmc_cert_s
  int ckmc_cert_new(
    ffi.Pointer<ffi.UnsignedChar> raw_cert,
    int cert_size,
    int data_format,
    ffi.Pointer<ffi.Pointer<ckmc_cert_s>> ppcert,
  ) {
    return _ckmc_cert_new(
      raw_cert,
      cert_size,
      data_format,
      ppcert,
    );
  }

  late final _ckmc_cert_newPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.UnsignedChar>, ffi.Size, ffi.Int32,
              ffi.Pointer<ffi.Pointer<ckmc_cert_s>>)>>('ckmc_cert_new');
  late final _ckmc_cert_new = _ckmc_cert_newPtr.asFunction<
      int Function(ffi.Pointer<ffi.UnsignedChar>, int, int,
          ffi.Pointer<ffi.Pointer<ckmc_cert_s>>)>();

  /// @brief Destroys the #ckmc_cert_s handle and releases all its resources.
  /// @since_tizen 2.3
  /// @param[in] cert The #ckmc_cert_s handle to destroy
  /// @see ckmc_load_cert_from_file()
  void ckmc_cert_free(
    ffi.Pointer<ckmc_cert_s> cert,
  ) {
    return _ckmc_cert_free(
      cert,
    );
  }

  late final _ckmc_cert_freePtr =
      _lookup<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ckmc_cert_s>)>>(
          'ckmc_cert_free');
  late final _ckmc_cert_free =
      _ckmc_cert_freePtr.asFunction<void Function(ffi.Pointer<ckmc_cert_s>)>();

  /// @brief Creates a new #ckmc_cert_s handle from a given file and returns it.
  /// @since_tizen 2.3
  /// @remarks You must destroy the newly created #ckmc_cert_s by calling ckmc_cert_free() if it is no longer needed.
  /// @param[in] file_path The path of certificate file to be loaded \n
  /// The only DER or PEM encoded certificate file is supported
  /// @param[out] cert The pointer of newly created #ckmc_cert_s handle
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory space
  /// @retval #CKMC_ERROR_INVALID_FORMAT Invalid certificate file format
  /// @retval #CKMC_ERROR_FILE_ACCESS_DENIED Provided file does not exist or cannot be accessed
  /// @see ckmc_cert_free()
  /// @see #ckmc_cert_s
  int ckmc_load_cert_from_file(
    ffi.Pointer<ffi.Char> file_path,
    ffi.Pointer<ffi.Pointer<ckmc_cert_s>> cert,
  ) {
    return _ckmc_load_cert_from_file(
      file_path,
      cert,
    );
  }

  late final _ckmc_load_cert_from_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ckmc_cert_s>>)>>(
      'ckmc_load_cert_from_file');
  late final _ckmc_load_cert_from_file =
      _ckmc_load_cert_from_filePtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ckmc_cert_s>>)>();

  /// @brief Creates a new #ckmc_pkcs12_s handle and returns it.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must destroy the newly created #ckmc_pkcs12_s by calling ckmc_pkcs12_free() if it is no longer needed.
  /// @remarks On success, private_key, cert && ca_cert_list ownership is transferred into newly returned ckmc_pkcs12_s.
  /// @param[in] private_key #ckmc_key_s handle to the private key (optional)
  /// @param[in] cert #ckmc_cert_s handle to the certificate (optional)
  /// @param[in] ca_cert_list #ckmc_cert_list_s list of chain certificate handles (optional)
  /// @param[out] pkcs12_bundle The pointer to a newly created #ckmc_pkcs12_s handle
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid or private_key, cert and ca_cert_list all are null
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory
  /// @see ckmc_pkcs12_free()
  /// @see ckmc_pkcs12_load()
  /// @see #ckmc_key_s
  /// @see #ckmc_cert_s
  /// @see #ckmc_cert_list_s
  /// @see #ckmc_pkcs12_s
  int ckmc_pkcs12_new(
    ffi.Pointer<ckmc_key_s> private_key,
    ffi.Pointer<ckmc_cert_s> cert,
    ffi.Pointer<ckmc_cert_list_s> ca_cert_list,
    ffi.Pointer<ffi.Pointer<ckmc_pkcs12_s>> pkcs12_bundle,
  ) {
    return _ckmc_pkcs12_new(
      private_key,
      cert,
      ca_cert_list,
      pkcs12_bundle,
    );
  }

  late final _ckmc_pkcs12_newPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ckmc_key_s>,
              ffi.Pointer<ckmc_cert_s>,
              ffi.Pointer<ckmc_cert_list_s>,
              ffi.Pointer<ffi.Pointer<ckmc_pkcs12_s>>)>>('ckmc_pkcs12_new');
  late final _ckmc_pkcs12_new = _ckmc_pkcs12_newPtr.asFunction<
      int Function(
          ffi.Pointer<ckmc_key_s>,
          ffi.Pointer<ckmc_cert_s>,
          ffi.Pointer<ckmc_cert_list_s>,
          ffi.Pointer<ffi.Pointer<ckmc_pkcs12_s>>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4. @elseif WEARABLE 3.0. @endif [Use ckmc_pkcs12_load() instead]
  /// @brief Creates a new #ckmc_key_s (@a private_key), #ckmc_cert_s (@a cert), and #ckmc_cert_list_s (@a ca_cert_list) handle from a given PKCS#12 file and returns them.
  /// @since_tizen 2.3
  /// @remarks You must destroy the newly created #ckmc_key_s, #ckmc_cert_s, and
  /// #ckmc_cert_list_s by calling ckmc_key_free(), ckmc_cert_free(), and
  /// ckmc_cert_list_all_free() if they are no longer needed.
  /// @param[in] file_path The path of PKCS12 file to be loaded
  /// @param[in] passphrase The passphrase used to decrypt the PCKS12 file \n
  /// If PKCS12 file is not encrypted, passphrase can be null
  /// @param[out] private_key The pointer of newly created #ckmc_key_s handle for a private key
  /// @param[out] cert The pointer of newly created #ckmc_cert_s handle for a certificate \n
  /// It is null if the PKCS12 file does not contain a certificate
  /// @param[out] ca_cert_list The pointer of newly created #ckmc_cert_list_s handle for CA certificates \n
  /// It is null if the PKCS12 file does not contain CA certificates
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory space
  /// @retval #CKMC_ERROR_INVALID_FORMAT Invalid PKCS12 file format
  /// @retval #CKMC_ERROR_FILE_ACCESS_DENIED Provided file does not exist or cannot be accessed
  /// @see ckmc_pkcs12_new()
  /// @see ckmc_pkcs12_load()
  /// @see ckmc_key_free()
  /// @see ckmc_cert_free()
  /// @see ckmc_cert_list_all_free()
  /// @see #ckmc_key_s
  /// @see #ckmc_cert_s
  /// @see #ckmc_cert_list_s
  int ckmc_load_from_pkcs12_file(
    ffi.Pointer<ffi.Char> file_path,
    ffi.Pointer<ffi.Char> passphrase,
    ffi.Pointer<ffi.Pointer<ckmc_key_s>> private_key,
    ffi.Pointer<ffi.Pointer<ckmc_cert_s>> cert,
    ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>> ca_cert_list,
  ) {
    return _ckmc_load_from_pkcs12_file(
      file_path,
      passphrase,
      private_key,
      cert,
      ca_cert_list,
    );
  }

  late final _ckmc_load_from_pkcs12_filePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ckmc_key_s>>,
                  ffi.Pointer<ffi.Pointer<ckmc_cert_s>>,
                  ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>>(
      'ckmc_load_from_pkcs12_file');
  late final _ckmc_load_from_pkcs12_file =
      _ckmc_load_from_pkcs12_filePtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ckmc_key_s>>,
              ffi.Pointer<ffi.Pointer<ckmc_cert_s>>,
              ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>();

  /// @brief Creates a new #ckmc_pkcs12_s handle from a given PKCS#12 file and returns it.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must destroy the newly created #ckmc_pkcs12_s by calling ckmc_pkcs12_free() if they are no longer needed.
  /// @param[in] file_path The path of PKCS12 file to be loaded
  /// @param[in] passphrase The passphrase used to decrypt the PCKS12 file \n
  /// If PKCS12 file is not encrypted, passphrase can be null
  /// @param[out] pkcs12_bundle The pointer of newly created #ckmc_cert_list_s handle for CA certificates \n
  /// It is null if the PKCS12 file does not contain CA certificates
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory space
  /// @retval #CKMC_ERROR_INVALID_FORMAT Invalid PKCS12 file format
  /// @retval #CKMC_ERROR_FILE_ACCESS_DENIED Provided file does not exist or cannot be accessed
  /// @see ckmc_pkcs12_free()
  /// @see #ckmc_pkcs12_s
  int ckmc_pkcs12_load(
    ffi.Pointer<ffi.Char> file_path,
    ffi.Pointer<ffi.Char> passphrase,
    ffi.Pointer<ffi.Pointer<ckmc_pkcs12_s>> pkcs12_bundle,
  ) {
    return _ckmc_pkcs12_load(
      file_path,
      passphrase,
      pkcs12_bundle,
    );
  }

  late final _ckmc_pkcs12_loadPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ckmc_pkcs12_s>>)>>('ckmc_pkcs12_load');
  late final _ckmc_pkcs12_load = _ckmc_pkcs12_loadPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ckmc_pkcs12_s>>)>();

  /// @brief Destroys the #ckmc_pkcs12_s handle and releases all its resources.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] pkcs12 The #ckmc_pkcs12_s handle to destroy
  /// @see ckmc_pkcs12_new()
  /// @see ckmc_pkcs12_load()
  void ckmc_pkcs12_free(
    ffi.Pointer<ckmc_pkcs12_s> pkcs12,
  ) {
    return _ckmc_pkcs12_free(
      pkcs12,
    );
  }

  late final _ckmc_pkcs12_freePtr = _lookup<
          ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ckmc_pkcs12_s>)>>(
      'ckmc_pkcs12_free');
  late final _ckmc_pkcs12_free = _ckmc_pkcs12_freePtr
      .asFunction<void Function(ffi.Pointer<ckmc_pkcs12_s>)>();

  /// @brief Creates a new #ckmc_alias_list_s handle and returns it.
  /// The alias pointer in the returned #ckmc_alias_list_s handle points to the provided characters and next is null.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must destroy the newly created #ckmc_alias_list_s
  /// by calling ckmc_alias_list_free() or ckmc_alias_list_all_free() if it is no longer needed.
  /// @param[in] alias The first item to be set in the newly created #ckmc_alias_list_s
  /// @param[out] ppalias_list The pointer to a newly created #ckmc_alias_list_s handle
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory
  /// @see ckmc_alias_list_all_free()
  /// @see #ckmc_alias_list_s
  int ckmc_alias_list_new(
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>> ppalias_list,
  ) {
    return _ckmc_alias_list_new(
      alias,
      ppalias_list,
    );
  }

  late final _ckmc_alias_list_newPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>>)>>(
      'ckmc_alias_list_new');
  late final _ckmc_alias_list_new = _ckmc_alias_list_newPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>>)>();

  /// @brief Creates a new #ckmc_alias_list_s handle, adds it to a previous #ckmc_alias_list_s and returns it.
  /// The alias pointer in the returned #ckmc_alias_list_s handle points to the provided characters and next is null.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] previous The last #ckmc_alias_list_s handle to which a newly created #ckmc_alias_list_s is added
  /// @param[in] alias The item to be set in the newly created #ckmc_alias_list_s
  /// @param[out] pplast The pointer to a newly created and added #ckmc_alias_list_s handle
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory
  /// @see ckmc_alias_list_all_free()
  /// @see #ckmc_alias_list_s
  int ckmc_alias_list_add(
    ffi.Pointer<ckmc_alias_list_s> previous,
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>> pplast,
  ) {
    return _ckmc_alias_list_add(
      previous,
      alias,
      pplast,
    );
  }

  late final _ckmc_alias_list_addPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ckmc_alias_list_s>,
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>>)>>(
      'ckmc_alias_list_add');
  late final _ckmc_alias_list_add = _ckmc_alias_list_addPtr.asFunction<
      int Function(ffi.Pointer<ckmc_alias_list_s>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>>)>();

  /// @brief Destroys the #ckmc_alias_list_s handle and releases resources of #ckmc_alias_list_s from the provided first handle cascadingly.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks It does not destroy an alias itself in #ckmc_alias_list_s.
  /// @param[in] first The first #ckmc_alias_list_s handle to destroy
  /// @see ckmc_alias_list_all_free()
  /// @see #ckmc_alias_list_s
  void ckmc_alias_list_free(
    ffi.Pointer<ckmc_alias_list_s> first,
  ) {
    return _ckmc_alias_list_free(
      first,
    );
  }

  late final _ckmc_alias_list_freePtr = _lookup<
      ffi.NativeFunction<
          ffi.Void Function(
              ffi.Pointer<ckmc_alias_list_s>)>>('ckmc_alias_list_free');
  late final _ckmc_alias_list_free = _ckmc_alias_list_freePtr
      .asFunction<void Function(ffi.Pointer<ckmc_alias_list_s>)>();

  /// @brief Destroys the #ckmc_alias_list_s handle and releases all its resources from the provided first handle cascadingly.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks It also destroys the alias in #ckmc_alias_list_s.
  /// @param[in] first The first #ckmc_alias_list_s handle to destroy
  /// @see #ckmc_alias_list_s
  void ckmc_alias_list_all_free(
    ffi.Pointer<ckmc_alias_list_s> first,
  ) {
    return _ckmc_alias_list_all_free(
      first,
    );
  }

  late final _ckmc_alias_list_all_freePtr = _lookup<
      ffi.NativeFunction<
          ffi.Void Function(
              ffi.Pointer<ckmc_alias_list_s>)>>('ckmc_alias_list_all_free');
  late final _ckmc_alias_list_all_free = _ckmc_alias_list_all_freePtr
      .asFunction<void Function(ffi.Pointer<ckmc_alias_list_s>)>();

  /// @brief Creates a new #ckmc_cert_list_s handle and returns it.
  /// The cert pointer in the returned #ckmc_cert_list_s handle points to the provided #ckmc_cert_s and next is null.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must destroy the newly created #ckmc_cert_list_s by calling ckmc_cert_list_free() or ckmc_cert_list_all_free() if it is no longer needed.
  /// @param[in] cert The first item to be set in the newly created #ckmc_cert_list_s
  /// @param[out] ppalias_list The pointer to a newly created #ckmc_alias_list_s handle
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory
  /// @see ckmc_cert_list_all_free()
  /// @see #ckmc_cert_list_s
  int ckmc_cert_list_new(
    ffi.Pointer<ckmc_cert_s> cert,
    ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>> ppalias_list,
  ) {
    return _ckmc_cert_list_new(
      cert,
      ppalias_list,
    );
  }

  late final _ckmc_cert_list_newPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ckmc_cert_s>,
                  ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>>(
      'ckmc_cert_list_new');
  late final _ckmc_cert_list_new = _ckmc_cert_list_newPtr.asFunction<
      int Function(ffi.Pointer<ckmc_cert_s>,
          ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>();

  /// @brief Creates a new #ckmc_cert_list_s handle, adds it to a previous #ckmc_cert_list_s and returns it.
  /// The cert pointer in the returned #ckmc_alias_list_s handle points to the provided #ckmc_cert_s and next is null.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] previous The last #ckmc_cert_list_s handle to which a newly created #ckmc_cert_list_s is added
  /// @param[in] cert The item to be set in the newly created #ckmc_cert_list_s
  /// @param[out] pplast The pointer to a newly created and added #ckmc_alias_list_s handle
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_OUT_OF_MEMORY Not enough memory
  /// @see ckmc_cert_list_all_free()
  /// @see #ckmc_cert_list_s
  int ckmc_cert_list_add(
    ffi.Pointer<ckmc_cert_list_s> previous,
    ffi.Pointer<ckmc_cert_s> cert,
    ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>> pplast,
  ) {
    return _ckmc_cert_list_add(
      previous,
      cert,
      pplast,
    );
  }

  late final _ckmc_cert_list_addPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ckmc_cert_list_s>,
                  ffi.Pointer<ckmc_cert_s>,
                  ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>>(
      'ckmc_cert_list_add');
  late final _ckmc_cert_list_add = _ckmc_cert_list_addPtr.asFunction<
      int Function(ffi.Pointer<ckmc_cert_list_s>, ffi.Pointer<ckmc_cert_s>,
          ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>();

  /// @brief Destroys the #ckmc_cert_list_s handle and releases resources of #ckmc_cert_list_s from the provided first handle cascadingly.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks It does not destroy #ckmc_cert_s itself in #ckmc_cert_list_s.
  /// @param[in] first The first #ckmc_cert_list_s handle to destroy
  /// @see ckmc_cert_list_all_free()
  /// @see #ckmc_cert_list_s
  void ckmc_cert_list_free(
    ffi.Pointer<ckmc_cert_list_s> first,
  ) {
    return _ckmc_cert_list_free(
      first,
    );
  }

  late final _ckmc_cert_list_freePtr = _lookup<
          ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ckmc_cert_list_s>)>>(
      'ckmc_cert_list_free');
  late final _ckmc_cert_list_free = _ckmc_cert_list_freePtr
      .asFunction<void Function(ffi.Pointer<ckmc_cert_list_s>)>();

  /// @brief Destroys the #ckmc_cert_list_s handle and releases all its resources from the provided first handle cascadingly.
  /// @since_tizen 2.3
  /// @remarks It also destroys #ckmc_cert_s in #ckmc_cert_list_s.
  /// @param[in] first The first #ckmc_cert_list_s handle to destroy
  /// @see #ckmc_cert_list_s
  void ckmc_cert_list_all_free(
    ffi.Pointer<ckmc_cert_list_s> first,
  ) {
    return _ckmc_cert_list_all_free(
      first,
    );
  }

  late final _ckmc_cert_list_all_freePtr = _lookup<
          ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ckmc_cert_list_s>)>>(
      'ckmc_cert_list_all_free');
  late final _ckmc_cert_list_all_free = _ckmc_cert_list_all_freePtr
      .asFunction<void Function(ffi.Pointer<ckmc_cert_list_s>)>();

  /// @brief Creates new parameter list.
  /// @since_tizen 3.0
  /// @remarks Caller is responsible for freeing it with ckmc_param_list_free().
  /// @param[in] pparams Double pointer to the handle of param list to which the newly created algorithm param list will be assigned
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @see ckmc_param_list_set_integer()
  /// @see ckmc_param_list_set_buffer()
  /// @see ckmc_param_list_free()
  /// @see ckmc_generate_new_params()
  /// @see #ckmc_param_list_h
  /// @see #ckmc_param_name_e
  /// @see #ckmc_algo_type_e
  int ckmc_param_list_new(
    ffi.Pointer<ckmc_param_list_h> pparams,
  ) {
    return _ckmc_param_list_new(
      pparams,
    );
  }

  late final _ckmc_param_list_newPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ckmc_param_list_h>)>>(
      'ckmc_param_list_new');
  late final _ckmc_param_list_new = _ckmc_param_list_newPtr
      .asFunction<int Function(ffi.Pointer<ckmc_param_list_h>)>();

  /// @brief Sets integer parameter to the list.
  /// @since_tizen 3.0
  /// @remarks Caller is responsible for #ckmc_param_list_h creation.
  /// @param[in] params Algorithm param list handle created with ckmc_param_list_new() or ckmc_generate_new_params() \n
  /// New param with @a name and @a value will be set here
  /// @param[in] name Name of parameter to set \n
  /// Existing parameter will be overwritten \n
  /// Passing invalid parameter name will result in an error
  /// @param[in] value Value of the parameter in form of a integer
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @see ckmc_param_list_new()
  /// @see ckmc_param_list_set_buffer()
  /// @see ckmc_param_list_get_integer()
  /// @see ckmc_param_list_get_buffer()
  /// @see ckmc_param_list_free()
  /// @see ckmc_generate_new_params()
  /// @see #ckmc_param_list_h
  /// @see #ckmc_param_name_e
  /// @see #ckmc_algo_type_e
  int ckmc_param_list_set_integer(
    ckmc_param_list_h params,
    int name,
    int value,
  ) {
    return _ckmc_param_list_set_integer(
      params,
      name,
      value,
    );
  }

  late final _ckmc_param_list_set_integerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ckmc_param_list_h, ffi.Int32,
              ffi.Uint64)>>('ckmc_param_list_set_integer');
  late final _ckmc_param_list_set_integer = _ckmc_param_list_set_integerPtr
      .asFunction<int Function(ckmc_param_list_h, int, int)>();

  /// @brief Sets buffer parameter to the list.
  /// @since_tizen 3.0
  /// @remarks Caller is responsible for #ckmc_param_list_h creation.
  /// @param[in] params Algorithm param list handle created with ckmc_param_list_new() or ckmc_generate_new_params()
  /// New param with @a name and @a buffer will be set here
  /// @param[in] name Name of parameter to set \n
  /// Existing parameter will be overwritten \n
  /// Passing invalid parameter name will result in an error
  /// @param[in] buffer Value of the parameter in form of a buffer \n
  /// Caller is responsible for creating and freeing the buffer
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @see ckmc_param_list_new()
  /// @see ckmc_param_list_set_integer()
  /// @see ckmc_param_list_get_integer()
  /// @see ckmc_param_list_get_buffer()
  /// @see ckmc_param_list_free()
  /// @see ckmc_generate_new_params()
  /// @see #ckmc_param_list_h
  /// @see #ckmc_param_name_e
  /// @see #ckmc_algo_type_e
  int ckmc_param_list_set_buffer(
    ckmc_param_list_h params,
    int name,
    ffi.Pointer<ckmc_raw_buffer_s> buffer,
  ) {
    return _ckmc_param_list_set_buffer(
      params,
      name,
      buffer,
    );
  }

  late final _ckmc_param_list_set_bufferPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ckmc_param_list_h, ffi.Int32,
              ffi.Pointer<ckmc_raw_buffer_s>)>>('ckmc_param_list_set_buffer');
  late final _ckmc_param_list_set_buffer =
      _ckmc_param_list_set_bufferPtr.asFunction<
          int Function(
              ckmc_param_list_h, int, ffi.Pointer<ckmc_raw_buffer_s>)>();

  /// @brief Gets integer parameter from the list.
  /// @since_tizen 3.0
  /// @remarks Caller is responsible for #ckmc_param_list_h creation.
  /// @param[in] params Algorithm param list handle created with ckmc_param_list_new() or ckmc_generate_new_params()
  /// which contains param with @a name
  /// @param[in] name Name of parameter to get
  /// @param[out] pvalue Value of the parameter in form of a integer
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @see ckmc_param_list_new()
  /// @see ckmc_param_list_set_integer()
  /// @see ckmc_param_list_set_buffer()
  /// @see ckmc_param_list_get_buffer()
  /// @see ckmc_param_list_free()
  /// @see ckmc_generate_new_params()
  /// @see #ckmc_param_list_h
  /// @see #ckmc_param_name_e
  /// @see #ckmc_algo_type_e
  int ckmc_param_list_get_integer(
    ckmc_param_list_h params,
    int name,
    ffi.Pointer<ffi.Uint64> pvalue,
  ) {
    return _ckmc_param_list_get_integer(
      params,
      name,
      pvalue,
    );
  }

  late final _ckmc_param_list_get_integerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ckmc_param_list_h, ffi.Int32,
              ffi.Pointer<ffi.Uint64>)>>('ckmc_param_list_get_integer');
  late final _ckmc_param_list_get_integer =
      _ckmc_param_list_get_integerPtr.asFunction<
          int Function(ckmc_param_list_h, int, ffi.Pointer<ffi.Uint64>)>();

  /// @brief Gets buffer parameter from the list.
  /// @since_tizen 3.0
  /// @remarks Caller is responsible for #ckmc_param_list_h creation.
  /// @param[in] params Algorithm param list handle created with ckmc_param_list_new() or ckmc_generate_new_params()
  /// which contains param with @a name
  /// @param[in] name Name of parameter to get
  /// @param[out] ppbuffer Value of the parameter in form of a buffer \n
  /// Caller is responsible for creating and freeing the buffer
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @see ckmc_param_list_new()
  /// @see ckmc_param_list_set_integer()
  /// @see ckmc_param_list_set_buffer()
  /// @see ckmc_param_list_get_integer()
  /// @see ckmc_param_list_free()
  /// @see ckmc_generate_new_params()
  /// @see ckmc_buffer_free()
  /// @see #ckmc_param_list_h
  /// @see #ckmc_param_name_e
  /// @see #ckmc_algo_type_e
  int ckmc_param_list_get_buffer(
    ckmc_param_list_h params,
    int name,
    ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>> ppbuffer,
  ) {
    return _ckmc_param_list_get_buffer(
      params,
      name,
      ppbuffer,
    );
  }

  late final _ckmc_param_list_get_bufferPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ckmc_param_list_h, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>>(
      'ckmc_param_list_get_buffer');
  late final _ckmc_param_list_get_buffer =
      _ckmc_param_list_get_bufferPtr.asFunction<
          int Function(ckmc_param_list_h, int,
              ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>();

  /// @brief Frees previously allocated list of algorithm params.
  /// @since_tizen 3.0
  /// @param[in] params First element of the list to be freed
  /// @see ckmc_param_list_new()
  /// @see ckmc_param_list_set_integer()
  /// @see ckmc_param_list_set_buffer()
  /// @see ckmc_param_list_get_integer()
  /// @see ckmc_param_list_get_buffer()
  /// @see ckmc_generate_new_params()
  /// @see #ckmc_param_list_h
  /// @see #ckmc_param_name_e
  /// @see #ckmc_algo_type_e
  void ckmc_param_list_free(
    ckmc_param_list_h params,
  ) {
    return _ckmc_param_list_free(
      params,
    );
  }

  late final _ckmc_param_list_freePtr =
      _lookup<ffi.NativeFunction<ffi.Void Function(ckmc_param_list_h)>>(
          'ckmc_param_list_free');
  late final _ckmc_param_list_free =
      _ckmc_param_list_freePtr.asFunction<void Function(ckmc_param_list_h)>();

  /// @brief Generates algorithm parameters for a given algorithm type and set them to the list.
  /// @since_tizen 3.0
  /// @remarks Caller is responsible for #ckmc_param_list_h destruction.
  /// @remarks Algorithm parameters are set to default values. Optional fields are left empty.
  /// Initialization vectors are left empty (they have to be set manually).
  /// Caller is responsible for freeing the list with ckmc_param_list_free().
  /// @remarks If the function returns error, provided param list may contain some of default parameters.
  /// @param[in] type Type of the algorithm
  /// @param[out] pparams Newly generated handle of param list which should be freed by caller after use
  /// @return #CKMC_ERROR_NONE on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @see ckmc_param_list_new()
  /// @see ckmc_param_list_set_integer()
  /// @see ckmc_param_list_set_buffer()
  /// @see ckmc_param_list_get_integer()
  /// @see ckmc_param_list_get_buffer()
  /// @see ckmc_param_list_free()
  /// @see #ckmc_param_list_h
  /// @see #ckmc_param_name_e
  /// @see #ckmc_algo_type_e
  int ckmc_generate_new_params(
    int type,
    ffi.Pointer<ckmc_param_list_h> pparams,
  ) {
    return _ckmc_generate_new_params(
      type,
      pparams,
    );
  }

  late final _ckmc_generate_new_paramsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ckmc_param_list_h>)>>('ckmc_generate_new_params');
  late final _ckmc_generate_new_params = _ckmc_generate_new_paramsPtr
      .asFunction<int Function(int, ffi.Pointer<ckmc_param_list_h>)>();

  /// @brief Stores a key inside key manager based on the provided policy.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks Currently API supports seven types of keys. These are RSA public/private key, DSA public/private key, ECDSA public/private key, and AES symmetric key.
  /// @remarks key_type in key may be set to #CKMC_KEY_NONE as an input. key_type is determined inside key manager during storing keys.
  /// @remarks Some private key files are protected by a password. If raw_key in key read from those encrypted files is encrypted with a password, the password should be provided in the #ckmc_key_s structure.
  /// @remarks If password in policy is provided, the key is additionally encrypted with the password in the policy.
  /// @param[in] alias The name of a key to be stored
  /// @param[in] key The key's binary value to be stored
  /// @param[in] policy The policy about how to store a key securely
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ALIAS_EXISTS Alias already exists
  /// @retval #CKMC_ERROR_INVALID_FORMAT The format of raw_key is not valid
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_remove_alias()
  /// @see ckmc_get_key()
  /// @see ckmc_get_key_alias_list()
  /// @see #ckmc_key_s
  /// @see #ckmc_policy_s
  int ckmc_save_key(
    ffi.Pointer<ffi.Char> alias,
    ckmc_key_s key,
    ckmc_policy_s policy,
  ) {
    return _ckmc_save_key(
      alias,
      key,
      policy,
    );
  }

  late final _ckmc_save_keyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ckmc_key_s,
              ckmc_policy_s)>>('ckmc_save_key');
  late final _ckmc_save_key = _ckmc_save_keyPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ckmc_key_s, ckmc_policy_s)>();

  /// @deprecated Deprecated since @if MOBILE 2.4. @elseif WEARABLE 3.0. @endif [Use ckmc_remove_alias() instead]
  /// @brief Removes a key from key manager.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks To remove key, client must have remove permission to the specified key.
  /// @remarks The key owner can remove by default.
  /// @param[in] alias The name of a key to be removed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_key()
  /// @see ckmc_get_key()
  /// @see ckmc_get_key_alias_list()
  int ckmc_remove_key(
    ffi.Pointer<ffi.Char> alias,
  ) {
    return _ckmc_remove_key(
      alias,
    );
  }

  late final _ckmc_remove_keyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'ckmc_remove_key');
  late final _ckmc_remove_key =
      _ckmc_remove_keyPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Gets a key from key manager.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks A client can access only data stored by the client.
  /// @remarks You must destroy the newly created @a ppkey by calling ckmc_key_free() if it is no longer needed.
  /// @param[in] alias The name of a key to retrieve
  /// @param[in] password The password used in decrypting a key value \n
  /// If password of policy is provided in ckmc_save_key(), the same password should be provided
  /// @param[out] ppkey The pointer to a newly created ckmc_key_s handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_AUTHENTICATION_FAILED Decryption failed because password is incorrect
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_key()
  /// @see ckmc_remove_alias()
  /// @see ckmc_get_key_alias_list()
  int ckmc_get_key(
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ffi.Char> password,
    ffi.Pointer<ffi.Pointer<ckmc_key_s>> ppkey,
  ) {
    return _ckmc_get_key(
      alias,
      password,
      ppkey,
    );
  }

  late final _ckmc_get_keyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ckmc_key_s>>)>>('ckmc_get_key');
  late final _ckmc_get_key = _ckmc_get_keyPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ckmc_key_s>>)>();

  /// @brief Gets all the alias of keys that the client can access.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks A client can access only data stored by the client.
  /// @remarks You must destroy the newly created @a ppalias_list by calling ckmc_alias_list_all_free()
  /// if it is no longer needed.
  /// @param[out] ppalias_list The pointer to a newly created ckmc_alias_list_s handle containing all
  /// available alias of keys \n
  /// If there is no available key alias, *ppalias_list will be null
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_key()
  /// @see ckmc_remove_alias()
  /// @see ckmc_get_key()
  int ckmc_get_key_alias_list(
    ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>> ppalias_list,
  ) {
    return _ckmc_get_key_alias_list(
      ppalias_list,
    );
  }

  late final _ckmc_get_key_alias_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>>)>>(
      'ckmc_get_key_alias_list');
  late final _ckmc_get_key_alias_list = _ckmc_get_key_alias_listPtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>>)>();

  /// @brief Stores a certificate inside key manager based on the provided policy.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0
  /// @remarks The certificate's binary value will be converted and saved as binary DER encoded certificates.
  /// @param[in] alias The name of a certificate to be stored
  /// @param[in] cert The certificate's binary value to be stored
  /// @param[in] policy The policy about how to store a certificate securely
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ALIAS_EXISTS Alias already exists
  /// @retval #CKMC_ERROR_INVALID_FORMAT The format of raw_cert is not valid
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_remove_alias()
  /// @see ckmc_get_cert()
  /// @see ckmc_get_cert_alias_list()
  /// @see #ckmc_cert_s
  /// @see #ckmc_policy_s
  int ckmc_save_cert(
    ffi.Pointer<ffi.Char> alias,
    ckmc_cert_s cert,
    ckmc_policy_s policy,
  ) {
    return _ckmc_save_cert(
      alias,
      cert,
      policy,
    );
  }

  late final _ckmc_save_certPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ckmc_cert_s,
              ckmc_policy_s)>>('ckmc_save_cert');
  late final _ckmc_save_cert = _ckmc_save_certPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ckmc_cert_s, ckmc_policy_s)>();

  /// @deprecated Deprecated since @if MOBILE 2.4. @elseif WEARABLE 3.0. @endif [Use ckmc_remove_alias() instead]
  /// @brief Removes a certificate from key manager.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks To remove certificate, client must have remove permission to the specified certificate.
  /// @remarks The key owner can remove by default.
  /// @param[in] alias The name of a certificate to be removed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_cert()
  /// @see ckmc_get_cert()
  /// @see ckmc_get_cert_alias_list()
  int ckmc_remove_cert(
    ffi.Pointer<ffi.Char> alias,
  ) {
    return _ckmc_remove_cert(
      alias,
    );
  }

  late final _ckmc_remove_certPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'ckmc_remove_cert');
  late final _ckmc_remove_cert =
      _ckmc_remove_certPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Gets a certificate from key manager.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks A client can access only certificate stored by the client.
  /// @remarks A DER encoded certificate will be returned as a return value.
  /// @remarks You must destroy the newly created @a ppcert by calling ckmc_cert_free() if it is no longer needed.
  /// @param[in] alias The name of a certificate to retrieve
  /// @param[in] password The password used in decrypting a certificate value \n
  /// If password of policy is provided in ckmc_save_cert(), the same password
  /// should be provided
  /// @param[out] ppcert The pointer to a newly created ckmc_cert_s handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exists
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_AUTHENTICATION_FAILED Decryption failed because password is incorrect
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_cert()
  /// @see ckmc_remove_alias()
  /// @see ckmc_get_cert_alias_list()
  int ckmc_get_cert(
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ffi.Char> password,
    ffi.Pointer<ffi.Pointer<ckmc_cert_s>> ppcert,
  ) {
    return _ckmc_get_cert(
      alias,
      password,
      ppcert,
    );
  }

  late final _ckmc_get_certPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ckmc_cert_s>>)>>('ckmc_get_cert');
  late final _ckmc_get_cert = _ckmc_get_certPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ckmc_cert_s>>)>();

  /// @brief Gets all alias of certificates which the client can access.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks A client can access only data stored by the client.
  /// @remarks You must destroy the newly created @a ppalias_list by calling ckmc_alias_list_all_free() if it is no longer needed.
  /// @param[out] ppalias_list The pointer to a newly created ckmc_alias_list_s handle containing all available alias of keys \n
  /// If there is no available key alias, *ppalias_list will be null
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_cert()
  /// @see ckmc_remove_alias()
  /// @see ckmc_get_cert()
  int ckmc_get_cert_alias_list(
    ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>> ppalias_list,
  ) {
    return _ckmc_get_cert_alias_list(
      ppalias_list,
    );
  }

  late final _ckmc_get_cert_alias_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>>)>>(
      'ckmc_get_cert_alias_list');
  late final _ckmc_get_cert_alias_list = _ckmc_get_cert_alias_listPtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>>)>();

  /// @brief Stores PKCS12's contents inside key manager based on the provided policies. All items from the PKCS12 will use the same alias.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @param[in] alias The name of a data to be stored
  /// @param[in] pkcs Pointer to the pkcs12 structure to be saved
  /// @param[in] key_policy The policy about how to store pkcs's private key
  /// @param[in] cert_policy The policy about how to store pkcs's certificate
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ALIAS_EXISTS Alias already exists
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_remove_alias()
  /// @see ckmc_get_pkcs12()
  /// @see ckmc_get_data_alias_list()
  /// @see ckmc_pkcs12_load()
  /// @see #ckmc_pkcs12_s
  /// @see #ckmc_policy_s
  int ckmc_save_pkcs12(
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ckmc_pkcs12_s> pkcs,
    ckmc_policy_s key_policy,
    ckmc_policy_s cert_policy,
  ) {
    return _ckmc_save_pkcs12(
      alias,
      pkcs,
      key_policy,
      cert_policy,
    );
  }

  late final _ckmc_save_pkcs12Ptr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ckmc_pkcs12_s>,
              ckmc_policy_s, ckmc_policy_s)>>('ckmc_save_pkcs12');
  late final _ckmc_save_pkcs12 = _ckmc_save_pkcs12Ptr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ckmc_pkcs12_s>,
          ckmc_policy_s, ckmc_policy_s)>();

  /// @brief Gets a pkcs12 from key manager.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks A client can access only data stored by the client.
  /// @remarks You must destroy the newly created @a pkcs12 by calling ckmc_pkcs12_free() if it is no longer needed.
  /// @param[in] alias The name of a data to retrieve
  /// @param[in] key_password Password that was used to encrypt privateKey (may be NULL)
  /// @param[in] cert_password Password used to encrypt certificates (may be NULL)
  /// @param[out] pkcs12 The pointer to a newly created ckmc_pkcs12_s handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_AUTHENTICATION_FAILED key_password or cert_password does not match with password used to encrypt data
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_pkcs12()
  /// @see ckmc_remove_alias()
  int ckmc_get_pkcs12(
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ffi.Char> key_password,
    ffi.Pointer<ffi.Char> cert_password,
    ffi.Pointer<ffi.Pointer<ckmc_pkcs12_s>> pkcs12,
  ) {
    return _ckmc_get_pkcs12(
      alias,
      key_password,
      cert_password,
      pkcs12,
    );
  }

  late final _ckmc_get_pkcs12Ptr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ckmc_pkcs12_s>>)>>('ckmc_get_pkcs12');
  late final _ckmc_get_pkcs12 = _ckmc_get_pkcs12Ptr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ckmc_pkcs12_s>>)>();

  /// @brief Stores a data inside key manager based on the provided policy.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @param[in] alias The name of a data to be stored
  /// @param[in] data The binary value to be stored
  /// @param[in] policy The policy about how to store a data securely
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ALIAS_EXISTS Alias already exists
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_remove_alias()
  /// @see ckmc_get_data()
  /// @see ckmc_get_data_alias_list()
  /// @see #ckmc_raw_buffer_s
  /// @see #ckmc_policy_s
  int ckmc_save_data(
    ffi.Pointer<ffi.Char> alias,
    ckmc_raw_buffer_s data,
    ckmc_policy_s policy,
  ) {
    return _ckmc_save_data(
      alias,
      data,
      policy,
    );
  }

  late final _ckmc_save_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ckmc_raw_buffer_s,
              ckmc_policy_s)>>('ckmc_save_data');
  late final _ckmc_save_data = _ckmc_save_dataPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ckmc_raw_buffer_s, ckmc_policy_s)>();

  /// @deprecated Deprecated since @if MOBILE 2.4. @elseif WEARABLE 3.0. @endif [Use ckmc_remove_alias() instead]
  /// @brief Removes a data from key manager.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks To remove data, client must have remove permission to the specified data object.
  /// @remarks The data owner can remove by default.
  /// @param[in] alias The name of a data to be removed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_data()
  /// @see ckmc_get_data()
  /// @see ckmc_get_data_alias_list()
  int ckmc_remove_data(
    ffi.Pointer<ffi.Char> alias,
  ) {
    return _ckmc_remove_data(
      alias,
    );
  }

  late final _ckmc_remove_dataPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'ckmc_remove_data');
  late final _ckmc_remove_data =
      _ckmc_remove_dataPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Gets a data from key manager.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks A client can access only data stored by the client.
  /// @remarks You must destroy the newly created @a ppdata by calling ckmc_buffer_free() if it is no longer needed.
  /// @param[in] alias The name of a data to retrieve
  /// @param[in] password The password used in decrypting a data value \n
  /// If password of policy is provided in ckmc_save_data(), the same password
  /// should be provided
  /// @param[out] ppdata The pointer to a newly created ckmc_raw_buffer_s handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_AUTHENTICATION_FAILED Decryption failed because password is incorrect
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_data()
  /// @see ckmc_remove_alias()
  /// @see ckmc_get_data_alias_list()
  int ckmc_get_data(
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ffi.Char> password,
    ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>> ppdata,
  ) {
    return _ckmc_get_data(
      alias,
      password,
      ppdata,
    );
  }

  late final _ckmc_get_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>>('ckmc_get_data');
  late final _ckmc_get_data = _ckmc_get_dataPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>();

  /// @brief Gets all alias of data which the client can access.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks A client can access only data stored by the client.
  /// @remarks You must destroy the newly created @a ppalias_list by calling ckmc_alias_list_all_free() if it is no longer needed.
  /// @param[out] ppalias_list The pointer to a newly created ckmc_alias_list_s handle containing all available alias of keys \n
  /// If there is no available key alias, *ppalias_list will be null
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_data()
  /// @see ckmc_remove_alias()
  /// @see ckmc_get_data()
  int ckmc_get_data_alias_list(
    ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>> ppalias_list,
  ) {
    return _ckmc_get_data_alias_list(
      ppalias_list,
    );
  }

  late final _ckmc_get_data_alias_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>>)>>(
      'ckmc_get_data_alias_list');
  late final _ckmc_get_data_alias_list = _ckmc_get_data_alias_listPtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ckmc_alias_list_s>>)>();

  /// @brief Creates RSA private/public key pair and stores them inside key manager based on each policy.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks If password in the policy is provided, the key is additionally encrypted with the password in the policy.
  /// @param[in] size The size of key strength to be created \n
  /// @c 1024, @c 2048, and @c 4096 are supported
  /// @param[in] private_key_alias The name of private key to be stored
  /// @param[in] public_key_alias The name of public key to be stored
  /// @param[in] policy_private_key The policy about how to store a private key securely
  /// @param[in] policy_public_key The policy about how to store a public key securely
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ALIAS_EXISTS Alias already exists
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to other DB transaction unexpectedly
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_create_key_pair_dsa()
  /// @see ckmc_create_key_pair_ecdsa()
  /// @see ckmc_create_signature()
  /// @see ckmc_verify_signature()
  int ckmc_create_key_pair_rsa(
    int size,
    ffi.Pointer<ffi.Char> private_key_alias,
    ffi.Pointer<ffi.Char> public_key_alias,
    ckmc_policy_s policy_private_key,
    ckmc_policy_s policy_public_key,
  ) {
    return _ckmc_create_key_pair_rsa(
      size,
      private_key_alias,
      public_key_alias,
      policy_private_key,
      policy_public_key,
    );
  }

  late final _ckmc_create_key_pair_rsaPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Size,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ckmc_policy_s,
              ckmc_policy_s)>>('ckmc_create_key_pair_rsa');
  late final _ckmc_create_key_pair_rsa =
      _ckmc_create_key_pair_rsaPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ckmc_policy_s, ckmc_policy_s)>();

  /// @brief Creates DSA private/public key pair and stores them inside key manager based on each policy.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks If password in the policy is provided, the key is additionally encrypted with the password in the policy.
  /// @param[in] size The size of key strength to be created \n
  /// @c 1024, @c 2048, @c 3072 and @c 4096 are supported
  /// @param[in] private_key_alias The name of private key to be stored
  /// @param[in] public_key_alias The name of public key to be stored
  /// @param[in] policy_private_key The policy about how to store a private key securely
  /// @param[in] policy_public_key The policy about how to store a public key securely
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ALIAS_EXISTS Alias already exists
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to other DB transaction unexpectedly
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_create_key_pair_rsa()
  /// @see ckmc_create_key_pair_ecdsa()
  /// @see ckmc_create_signature()
  /// @see ckmc_verify_signature()
  int ckmc_create_key_pair_dsa(
    int size,
    ffi.Pointer<ffi.Char> private_key_alias,
    ffi.Pointer<ffi.Char> public_key_alias,
    ckmc_policy_s policy_private_key,
    ckmc_policy_s policy_public_key,
  ) {
    return _ckmc_create_key_pair_dsa(
      size,
      private_key_alias,
      public_key_alias,
      policy_private_key,
      policy_public_key,
    );
  }

  late final _ckmc_create_key_pair_dsaPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Size,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ckmc_policy_s,
              ckmc_policy_s)>>('ckmc_create_key_pair_dsa');
  late final _ckmc_create_key_pair_dsa =
      _ckmc_create_key_pair_dsaPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ckmc_policy_s, ckmc_policy_s)>();

  /// @brief Creates ECDSA private/public key pair and stores them inside key manager based on each policy.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks If password in the policy is provided, the key is additionally encrypted with the password in the policy.
  /// @param[in] type The type of elliptic curve of ECDSA
  /// @param[in] private_key_alias The name of private key to be stored
  /// @param[in] public_key_alias The name of public key to be stored
  /// @param[in] policy_private_key The policy about how to store a private key securely
  /// @param[in] policy_public_key The policy about how to store a public key securely
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ALIAS_EXISTS Alias already exists
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to other DB transaction unexpectedly
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_create_key_pair_rsa()
  /// @see ckmc_create_key_pair_dsa()
  /// @see ckmc_create_signature()
  /// @see ckmc_verify_signature()
  /// @see #ckmc_ec_type_e
  int ckmc_create_key_pair_ecdsa(
    int type,
    ffi.Pointer<ffi.Char> private_key_alias,
    ffi.Pointer<ffi.Char> public_key_alias,
    ckmc_policy_s policy_private_key,
    ckmc_policy_s policy_public_key,
  ) {
    return _ckmc_create_key_pair_ecdsa(
      type,
      private_key_alias,
      public_key_alias,
      policy_private_key,
      policy_public_key,
    );
  }

  late final _ckmc_create_key_pair_ecdsaPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ckmc_policy_s,
              ckmc_policy_s)>>('ckmc_create_key_pair_ecdsa');
  late final _ckmc_create_key_pair_ecdsa =
      _ckmc_create_key_pair_ecdsaPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ckmc_policy_s, ckmc_policy_s)>();

  /// @brief Creates AES key and stores it inside key manager based on the policy.
  /// @since_tizen 3.0
  /// @remarks If password in the policy is provided, the key is additionally encrypted with the password in the policy.
  /// @param[in] size The size of key strength to be created \n
  /// @c 128, @c 192 and @c 256 are supported
  /// @param[in] key_alias The name of key to be stored
  /// @param[in] key_policy The policy about how to store the key securely
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ALIAS_EXISTS Alias already exists
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to other DB transaction unexpectedly
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_create_key_pair_rsa()
  /// @see ckmc_create_key_pair_dsa()
  /// @see ckmc_create_key_pair_ecdsa()
  /// @see #ckmc_policy_s
  int ckmc_create_key_aes(
    int size,
    ffi.Pointer<ffi.Char> key_alias,
    ckmc_policy_s key_policy,
  ) {
    return _ckmc_create_key_aes(
      size,
      key_alias,
      key_policy,
    );
  }

  late final _ckmc_create_key_aesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Size, ffi.Pointer<ffi.Char>,
              ckmc_policy_s)>>('ckmc_create_key_aes');
  late final _ckmc_create_key_aes = _ckmc_create_key_aesPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>, ckmc_policy_s)>();

  /// @brief Creates a signature on a given message using a private key and returns the signature.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks If password of policy is provided during storing a key, the same password should be provided.
  /// @remarks You must destroy the newly created @a ppsignature by calling ckmc_buffer_free() if it is no longer needed.
  /// @param[in] private_key_alias The name of private key
  /// @param[in] password The password used in decrypting a private key value
  /// @param[in] message The message that is signed with a private key
  /// @param[in] hash The hash algorithm used in creating signature
  /// @param[in] padding The RSA padding algorithm used in creating signature \n
  /// It is used only when the signature algorithm is RSA. If
  /// @a padding is CKMC_NONE_PADDING you must use CKMC_HASH_NONE
  /// and the message must be equal to key length
  /// @param[out] ppsignature The pointer to a newly created signature \n
  /// If an error occurs, @a *ppsignature will be null
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_AUTHENTICATION_FAILED Decryption failed because password is incorrect
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_create_key_pair_rsa()
  /// @see ckmc_create_key_pair_ecdsa()
  /// @see ckmc_verify_signature()
  /// @see ckmc_buffer_free()
  /// @see #ckmc_hash_algo_e
  /// @see #ckmc_rsa_padding_algo_e
  int ckmc_create_signature(
    ffi.Pointer<ffi.Char> private_key_alias,
    ffi.Pointer<ffi.Char> password,
    ckmc_raw_buffer_s message,
    int hash,
    int padding,
    ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>> ppsignature,
  ) {
    return _ckmc_create_signature(
      private_key_alias,
      password,
      message,
      hash,
      padding,
      ppsignature,
    );
  }

  late final _ckmc_create_signaturePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ckmc_raw_buffer_s,
                  ffi.Int32,
                  ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>>(
      'ckmc_create_signature');
  late final _ckmc_create_signature = _ckmc_create_signaturePtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>,
          ckmc_raw_buffer_s,
          int,
          int,
          ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>();

  /// @brief Verifies a given signature on a given message using a public key and returns the signature status.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks If password of policy is provided during storing a key, the same password should be provided.
  /// @param[in] public_key_alias The name of public key
  /// @param[in] password The password used in decrypting a public key value
  /// @param[in] message The input on which the signature is created
  /// @param[in] signature The signature that is verified with public key
  /// @param[in] hash The hash algorithm used in verifying signature
  /// @param[in] padding The RSA padding algorithm used in verifying signature \n
  /// It is used only when the signature algorithm is RSA. If
  /// @a padding is CKMC_NONE_PADDING you must use CKMC_HASH_NONE
  /// and the message must be equal to key length
  /// @return @c 0 on success and the signature is valid,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_VERIFICATION_FAILED The signature is invalid
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_AUTHENTICATION_FAILED Decryption failed because password is incorrect
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_create_key_pair_rsa()
  /// @see ckmc_create_key_pair_ecdsa()
  /// @see ckmc_verify_signature()
  /// @see #ckmc_hash_algo_e
  /// @see #ckmc_rsa_padding_algo_e
  int ckmc_verify_signature(
    ffi.Pointer<ffi.Char> public_key_alias,
    ffi.Pointer<ffi.Char> password,
    ckmc_raw_buffer_s message,
    ckmc_raw_buffer_s signature,
    int hash,
    int padding,
  ) {
    return _ckmc_verify_signature(
      public_key_alias,
      password,
      message,
      signature,
      hash,
      padding,
    );
  }

  late final _ckmc_verify_signaturePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ckmc_raw_buffer_s,
              ckmc_raw_buffer_s,
              ffi.Int32,
              ffi.Int32)>>('ckmc_verify_signature');
  late final _ckmc_verify_signature = _ckmc_verify_signaturePtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ckmc_raw_buffer_s, ckmc_raw_buffer_s, int, int)>();

  /// @brief Verifies a certificate chain and returns that chain.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks The trusted root certificate of the chain should exist in the system's certificate storage.
  /// @remarks You must destroy the newly created @a ppcert_chain_list by calling ckmc_cert_list_all_free() if it is no longer needed.
  /// @param[in] cert The certificate to be verified
  /// @param[in] untrustedcerts The untrusted CA certificates to be used in verifying a certificate chain
  /// @param[out] ppcert_chain_list The pointer to a newly created certificate chain's handle \n
  /// If an error occurs, @a *ppcert_chain_list will be null
  /// @return @c 0 on success and the signature is valid,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_VERIFICATION_FAILED The certificate chain is not valid
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_INVALID_FORMAT The format of certificate is not valid
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_AUTHENTICATION_FAILED Decryption failed because password is incorrect
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_cert_list_all_free()
  int ckmc_get_cert_chain(
    ffi.Pointer<ckmc_cert_s> cert,
    ffi.Pointer<ckmc_cert_list_s> untrustedcerts,
    ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>> ppcert_chain_list,
  ) {
    return _ckmc_get_cert_chain(
      cert,
      untrustedcerts,
      ppcert_chain_list,
    );
  }

  late final _ckmc_get_cert_chainPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ckmc_cert_s>,
                  ffi.Pointer<ckmc_cert_list_s>,
                  ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>>(
      'ckmc_get_cert_chain');
  late final _ckmc_get_cert_chain = _ckmc_get_cert_chainPtr.asFunction<
      int Function(ffi.Pointer<ckmc_cert_s>, ffi.Pointer<ckmc_cert_list_s>,
          ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4. @elseif WEARABLE 3.0. @endif [Use ckmc_get_cert_chain() instead]
  /// @brief Verifies a certificate chain using an alias list of untrusted certificates and return that chain.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks The trusted root certificate of the chain should exist in the system's certificate storage.
  /// @remarks You must destroy the newly created @a ppcert_chain_list by calling ckmc_cert_list_all_free() if it is no longer needed.
  /// @remarks @a untrustedcerts shouldn't be protected with optional password.
  /// @param[in] cert The certificate to be verified
  /// @param[in] untrustedcerts The alias list of untrusted CA certificates stored in key manager to be used in verifying a certificate chain
  /// @param[out] ppcert_chain_list The pointer to a newly created certificate chain's handle \n
  /// If an error occurs, @a *ppcert_chain_list will be null
  /// @return @c 0 on success and the signature is valid,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_VERIFICATION_FAILED The certificate chain is not valid
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_INVALID_FORMAT The format of certificate is not valid
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_AUTHENTICATION_FAILED Some certificates were encrypted with password and could not be used
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_get_cert_chain()
  /// @see ckmc_cert_list_all_free()
  int ckmc_get_cert_chain_with_alias(
    ffi.Pointer<ckmc_cert_s> cert,
    ffi.Pointer<ckmc_alias_list_s> untrustedcerts,
    ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>> ppcert_chain_list,
  ) {
    return _ckmc_get_cert_chain_with_alias(
      cert,
      untrustedcerts,
      ppcert_chain_list,
    );
  }

  late final _ckmc_get_cert_chain_with_aliasPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ckmc_cert_s>,
                  ffi.Pointer<ckmc_alias_list_s>,
                  ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>>(
      'ckmc_get_cert_chain_with_alias');
  late final _ckmc_get_cert_chain_with_alias =
      _ckmc_get_cert_chain_with_aliasPtr.asFunction<
          int Function(ffi.Pointer<ckmc_cert_s>, ffi.Pointer<ckmc_alias_list_s>,
              ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>();

  /// @brief Verifies a certificate chain and returns that chain using user-entered, trusted, and untrusted CA certificates.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks If the trusted root certificates are provided as a user input, these certificates do not need to exist in the system's certificate storage.
  /// @remarks You must destroy the newly created @a ppcert_chain_list by calling ckmc_cert_list_all_free() if it is no longer needed.
  /// @param[in] cert The certificate to be verified
  /// @param[in] untrustedcerts The untrusted CA certificates to be used in verifying a certificate chain
  /// @param[in] trustedcerts The trusted CA certificates to be used in verifying a certificate chain
  /// @param[in] use_trustedsystemcerts The flag indicating the use of the trusted root certificates in the system's certificate storage
  /// @param[out] ppcert_chain_list The pointer to a newly created certificate chain's handle \n
  /// If an error occurs, @a *ppcert_chain_list will be null
  /// @return @c 0 on success and the signature is valid,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_VERIFICATION_FAILED The certificate chain is not valid
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_INVALID_FORMAT The format of certificate is not valid
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_cert_list_all_free()
  int ckmc_get_cert_chain_with_trustedcert(
    ffi.Pointer<ckmc_cert_s> cert,
    ffi.Pointer<ckmc_cert_list_s> untrustedcerts,
    ffi.Pointer<ckmc_cert_list_s> trustedcerts,
    bool use_trustedsystemcerts,
    ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>> ppcert_chain_list,
  ) {
    return _ckmc_get_cert_chain_with_trustedcert(
      cert,
      untrustedcerts,
      trustedcerts,
      use_trustedsystemcerts,
      ppcert_chain_list,
    );
  }

  late final _ckmc_get_cert_chain_with_trustedcertPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ckmc_cert_s>,
                  ffi.Pointer<ckmc_cert_list_s>,
                  ffi.Pointer<ckmc_cert_list_s>,
                  ffi.Bool,
                  ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>>(
      'ckmc_get_cert_chain_with_trustedcert');
  late final _ckmc_get_cert_chain_with_trustedcert =
      _ckmc_get_cert_chain_with_trustedcertPtr.asFunction<
          int Function(
              ffi.Pointer<ckmc_cert_s>,
              ffi.Pointer<ckmc_cert_list_s>,
              ffi.Pointer<ckmc_cert_list_s>,
              bool,
              ffi.Pointer<ffi.Pointer<ckmc_cert_list_s>>)>();

  /// @brief Perform OCSP that checks certificate is whether revoked or not.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/internet
  /// @remarks %http://tizen.org/privilege/internet (public level privilege) is required to use this API instead of %http://tizen.org/privilege/keymanager (public level privilege) since 3.0.
  /// @param[in] pcert_chain_list Valid certificate chain to perform OCSP check
  /// @param[out] ocsp_status The pointer to status result of OCSP check
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_NOT_SUPPORTED Device needed to run API is not supported
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @pre @a pcert_chain_list is created with ckmc_get_certificate_chain() or
  /// ckmc_get_certificate_chain_with_alias().
  /// @see ckmc_get_cert_chain())
  /// @see ckmc_cert_list_all_free()
  int ckmc_ocsp_check(
    ffi.Pointer<ckmc_cert_list_s> pcert_chain_list,
    ffi.Pointer<ffi.Int32> ocsp_status,
  ) {
    return _ckmc_ocsp_check(
      pcert_chain_list,
      ocsp_status,
    );
  }

  late final _ckmc_ocsp_checkPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ckmc_cert_list_s>,
              ffi.Pointer<ffi.Int32>)>>('ckmc_ocsp_check');
  late final _ckmc_ocsp_check = _ckmc_ocsp_checkPtr.asFunction<
      int Function(ffi.Pointer<ckmc_cert_list_s>, ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated since @if MOBILE 2.4. @elseif WEARABLE 3.0. @endif [Use ckmc_set_permission() instead]
  /// @brief Allows another application to access client's application data.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks Data identified by @a alias should exist.
  /// @param[in] alias Data alias for which access will be granted
  /// @param[in] accessor Package id of the application that will gain access rights
  /// @param[in] granted Rights granted for @a accessor application
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_deny_access()
  int ckmc_allow_access(
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ffi.Char> accessor,
    int granted,
  ) {
    return _ckmc_allow_access(
      alias,
      accessor,
      granted,
    );
  }

  late final _ckmc_allow_accessPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Int32)>>('ckmc_allow_access');
  late final _ckmc_allow_access = _ckmc_allow_accessPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, int)>();

  /// @brief Allows another application to access client's application data.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks Data identified by @a alias should exist.
  /// @param[in] alias Data alias for which access will be granted
  /// @param[in] accessor Package id of the application that will gain access rights
  /// @param[in] permissions Mask of permissions granted for @a accessor application
  /// (#ckmc_permission_e)
  /// (previous permission mask will be replaced with the new mask value)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  int ckmc_set_permission(
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ffi.Char> accessor,
    int permissions,
  ) {
    return _ckmc_set_permission(
      alias,
      accessor,
      permissions,
    );
  }

  late final _ckmc_set_permissionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Int)>>('ckmc_set_permission');
  late final _ckmc_set_permission = _ckmc_set_permissionPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, int)>();

  /// @deprecated Deprecated since @if MOBILE 2.4. @elseif WEARABLE 3.0. @endif [Use ckmc_set_permission() instead]
  /// @brief Revokes another application's access to client's application data.
  /// @since_tizen 2.3
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks Data identified by @a alias should exist.
  /// @remarks Only access previously granted with ckmc_allow_access can be revoked.
  /// @param[in] alias Data alias for which access will be revoked
  /// @param[in] accessor Package id of the application that will lose access rights
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid or the @a accessor doesn't have access to @a alias
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_allow_access()
  /// @see ckmc_set_permission()
  int ckmc_deny_access(
    ffi.Pointer<ffi.Char> alias,
    ffi.Pointer<ffi.Char> accessor,
  ) {
    return _ckmc_deny_access(
      alias,
      accessor,
    );
  }

  late final _ckmc_deny_accessPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('ckmc_deny_access');
  late final _ckmc_deny_access = _ckmc_deny_accessPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Removes an entry (no matter of type) from the key manager.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks %http://tizen.org/privilege/keymanager (public level privilege) is no longer required to use this API since 3.0.
  /// @remarks To remove item, client must have remove permission to the specified item.
  /// @remarks The item owner can remove by default.
  /// @param[in] alias Item alias to be removed
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to a database error
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_save_key()
  /// @see ckmc_save_cert()
  /// @see ckmc_save_data()
  /// @see ckmc_save_pkcs12()
  /// @see ckmc_create_key_pair_rsa()
  /// @see ckmc_create_key_pair_dsa()
  /// @see ckmc_create_key_pair_ecdsa()
  int ckmc_remove_alias(
    ffi.Pointer<ffi.Char> alias,
  ) {
    return _ckmc_remove_alias(
      alias,
    );
  }

  late final _ckmc_remove_aliasPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'ckmc_remove_alias');
  late final _ckmc_remove_alias =
      _ckmc_remove_aliasPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Encrypts data using selected key and algorithm.
  /// @since_tizen 3.0
  /// @remarks Key identified by @a key_alias should exist.
  /// @param[in] params Algorithm parameter list handle. See #ckmc_param_list_h and
  /// #ckmc_algo_type_e for details
  /// @param[in] key_alias Alias of the key to be used for encryption
  /// @param[in] password The password used in decrypting a key value \n
  /// If password of the policy is provided in ckmc_save_key(), the same
  /// password should be provided
  /// @param[in] decrypted Data to be encrypted. In case of AES algorithm there are no restrictions on the size of data.
  /// For RSA the size must be smaller or equal to key size in bytes - 42.
  /// Example: for 1024 RSA key the maximum data size is 1024/8 - 42 = 86
  /// @param[out] ppencrypted Encrypted data (some algorithms may return additional information embedded in encrypted data.
  /// AES GCM is an example) \n
  /// The caller is responsible for freeing @a encrypted with ckmc_buffer_free()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid (missing or invalid
  /// mandatory algorithm parameter, decrypted = NULL,
  /// ppencrypted = NULL)
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Key with given alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_AUTHENTICATION_FAILED Key decryption failed because password is incorrect
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_buffer_free()
  /// @see ckmc_param_list_new()
  /// @see ckmc_param_list_free()
  /// @see ckmc_param_list_set_integer()
  /// @see ckmc_param_list_set_buffer()
  /// @see ckmc_generate_new_params()
  /// @see #ckmc_param_list_h
  /// @see #ckmc_param_name_e
  /// @see #ckmc_algo_type_e
  int ckmc_encrypt_data(
    ckmc_param_list_h params,
    ffi.Pointer<ffi.Char> key_alias,
    ffi.Pointer<ffi.Char> password,
    ckmc_raw_buffer_s decrypted,
    ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>> ppencrypted,
  ) {
    return _ckmc_encrypt_data(
      params,
      key_alias,
      password,
      decrypted,
      ppencrypted,
    );
  }

  late final _ckmc_encrypt_dataPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ckmc_param_list_h,
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ckmc_raw_buffer_s,
                  ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>>(
      'ckmc_encrypt_data');
  late final _ckmc_encrypt_data = _ckmc_encrypt_dataPtr.asFunction<
      int Function(
          ckmc_param_list_h,
          ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>,
          ckmc_raw_buffer_s,
          ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>();

  /// @brief Decrypts data using selected key and algorithm.
  /// @since_tizen 3.0
  /// @remarks Key identified by @a key_alias should exist.
  /// @param[in] params Algorithm parameter list handle. You should use the same parameters that were used for encryption.
  /// See #ckmc_param_list_h and #ckmc_algo_type_e for details
  /// @param[in] key_alias Alias of the key to be used for encryption
  /// @param[in] password The password used in decrypting a key value \n
  /// If password of the policy is provided in ckmc_save_key(), the same password should be provided
  /// @param[in] encrypted Data to be decrypted (some algorithms may require additional information embedded in encrypted data. AES GCM is an example)
  /// @param[out] ppdecrypted Decrypted data \n
  /// The caller is responsible for freeing @a decrypted with ckmc_buffer_free()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CKMC_ERROR_NONE Successful
  /// @retval #CKMC_ERROR_INVALID_PARAMETER Input parameter is invalid (missing or invalid
  /// mandatory algorithm parameter, encrypted = NULL,
  /// ppdecrypted = NULL)
  /// @retval #CKMC_ERROR_DB_LOCKED A user key is not loaded in memory (a user is not logged in)
  /// @retval #CKMC_ERROR_DB_ERROR Failed due to the error with unknown reason
  /// @retval #CKMC_ERROR_DB_ALIAS_UNKNOWN Key with given alias does not exist
  /// @retval #CKMC_ERROR_PERMISSION_DENIED Failed to access key manager
  /// @retval #CKMC_ERROR_AUTHENTICATION_FAILED Key decryption failed because password is incorrect
  /// @pre User is already logged in and the user key is already loaded into memory in plain text form.
  /// @see ckmc_buffer_free()
  /// @see ckmc_param_list_new()
  /// @see ckmc_param_list_free()
  /// @see ckmc_param_list_set_integer()
  /// @see ckmc_param_list_set_buffer()
  /// @see ckmc_generate_new_params()
  /// @see #ckmc_param_list_h
  /// @see #ckmc_param_name_e
  /// @see #ckmc_algo_type_e
  int ckmc_decrypt_data(
    ckmc_param_list_h params,
    ffi.Pointer<ffi.Char> key_alias,
    ffi.Pointer<ffi.Char> password,
    ckmc_raw_buffer_s encrypted,
    ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>> ppdecrypted,
  ) {
    return _ckmc_decrypt_data(
      params,
      key_alias,
      password,
      encrypted,
      ppdecrypted,
    );
  }

  late final _ckmc_decrypt_dataPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ckmc_param_list_h,
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ckmc_raw_buffer_s,
                  ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>>(
      'ckmc_decrypt_data');
  late final _ckmc_decrypt_data = _ckmc_decrypt_dataPtr.asFunction<
      int Function(
          ckmc_param_list_h,
          ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>,
          ckmc_raw_buffer_s,
          ffi.Pointer<ffi.Pointer<ckmc_raw_buffer_s>>)>();

  /// @brief Checks if an application, which calls this function, has permission to use the
  /// given privilege.
  ///
  /// @since_tizen 4.0
  ///
  /// @param[in]   privilege   The privilege that is to be checked.
  /// @param[out]  result      The result of the privilege check.
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_NONE               Successful
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_IO_ERROR           I/O error
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_UNKNOWN            Unknown error
  int ppm_check_permission(
    ffi.Pointer<ffi.Char> privilege,
    ffi.Pointer<ffi.Int32> result,
  ) {
    return _ppm_check_permission(
      privilege,
      result,
    );
  }

  late final _ppm_check_permissionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>>('ppm_check_permission');
  late final _ppm_check_permission = _ppm_check_permissionPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int32>)>();

  /// @brief Requests a user's response to obtain permission for using the given privilege.
  ///
  /// @details When this function is called, an underlying service may show an appropriate
  /// UI dialogue box (pop-up) with a question about granting the application access
  /// to the given privilege. Once a user makes a decision, the service may modify
  /// the privacy policy (when it is a definitive decision). After that, the service
  /// sends the response back to the application. The possible response values are as follows:
  /// #PRIVACY_PRIVILEGE_MANAGER_REQUEST_RESULT_ALLOW_FOREVER\n
  /// #PRIVACY_PRIVILEGE_MANAGER_REQUEST_RESULT_DENY_FOREVER\n
  /// #PRIVACY_PRIVILEGE_MANAGER_REQUEST_RESULT_DENY_ONCE\n
  /// The application receives #PRIVACY_PRIVILEGE_MANAGER_REQUEST_RESULT_DENY_ONCE value after
  /// pressing 'Deny' button while not having selected the 'Don't ask again?' checkbox. If the device
  /// has the home and back buttons, pressing either of them gives the
  /// #PRIVACY_PRIVILEGE_MANAGER_REQUEST_RESULT_DENY_ONCE response.
  /// The application is informed about the user's decision by invoking ppm_request_response_cb().
  /// When a privacy policy for the given privilege has already been resolved, no pop-up will
  /// be shown and the service will reply immediately with an appropriate result:
  /// #PRIVACY_PRIVILEGE_MANAGER_REQUEST_RESULT_ALLOW_FOREVER\n
  /// #PRIVACY_PRIVILEGE_MANAGER_REQUEST_RESULT_DENY_FOREVER\n
  ///
  /// @since_tizen 4.0
  ///
  /// @remarks Before calling this function, call ppm_check_permission() to check if the application has
  /// permission to use the given privilege. If the result of calling ppm_check_permission() is
  /// #PRIVACY_PRIVILEGE_MANAGER_CHECK_RESULT_ASK, the application should call
  /// this function to determine access to the privilege.
  ///
  /// @param[in]   privilege   The given privilege for which a pop-up must be shown.
  /// @param[in]   callback    The given callback function which will be invoked
  /// when the API receives a response.
  /// @param[in]   user_data   User specific data which will be passed to
  /// the given callback.
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_NONE                Successful
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_IO_ERROR            I/O error
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_OUT_OF_MEMORY       Out of memory
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_ALREADY_IN_PROGRESS Operation already in progress
  /// @retval #PRIVACY_PRIVILEGE_MANAGER_ERROR_UNKNOWN             Unknown error
  ///
  /// @post ppm_request_response_cb() will be invoked.
  /// @see ppm_request_response_cb()
  int ppm_request_permission(
    ffi.Pointer<ffi.Char> privilege,
    ppm_request_response_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ppm_request_permission(
      privilege,
      callback,
      user_data,
    );
  }

  late final _ppm_request_permissionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ppm_request_response_cb,
              ffi.Pointer<ffi.Void>)>>('ppm_request_permission');
  late final _ppm_request_permission = _ppm_request_permissionPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ppm_request_response_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the display name of the given privilege.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @remarks @a display_name must be released using free().
  /// @param[in] api_version The API version of the application to get privilege information
  /// @param[in] privilege The privilege
  /// @param[out] display_name The display name of the privilege
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PRVINFO_ERROR_NONE Successful
  /// @retval #PRVINFO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PRVINFO_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #PRVINFO_ERROR_INTERNAL_ERROR Unknown error
  int privilege_info_get_display_name(
    ffi.Pointer<ffi.Char> api_version,
    ffi.Pointer<ffi.Char> privilege,
    ffi.Pointer<ffi.Pointer<ffi.Char>> display_name,
  ) {
    return _privilege_info_get_display_name(
      api_version,
      privilege,
      display_name,
    );
  }

  late final _privilege_info_get_display_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'privilege_info_get_display_name');
  late final _privilege_info_get_display_name =
      _privilege_info_get_display_namePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the display name of the given privilege.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @remarks @a display_name must be released using free().
  /// @remarks package_type must be one of followings: PRVINFO_PACKAGE_TYPE_NATIVE, PRVINFO_PACKAGE_TYPE_WEB
  /// @param[in] package_type The type of application package
  /// @param[in] api_version The API version of the application to get privilege information
  /// @param[in] privilege The privilege
  /// @param[out] display_name The display name of the privilege
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PRVINFO_ERROR_NONE Successful
  /// @retval #PRVINFO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PRVINFO_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #PRVINFO_ERROR_INTERNAL_ERROR Unknown error
  int privilege_info_get_display_name_by_pkgtype(
    ffi.Pointer<ffi.Char> package_type,
    ffi.Pointer<ffi.Char> api_version,
    ffi.Pointer<ffi.Char> privilege,
    ffi.Pointer<ffi.Pointer<ffi.Char>> display_name,
  ) {
    return _privilege_info_get_display_name_by_pkgtype(
      package_type,
      api_version,
      privilege,
      display_name,
    );
  }

  late final _privilege_info_get_display_name_by_pkgtypePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'privilege_info_get_display_name_by_pkgtype');
  late final _privilege_info_get_display_name_by_pkgtype =
      _privilege_info_get_display_name_by_pkgtypePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the description of the given privilege.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @remarks @a description must be released using free().
  /// @param[in] api_version The API version of the application to get privilege information
  /// @param[in] privilege The privilege
  /// @param[out] description The description of the privilege
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PRVINFO_ERROR_NONE Successful
  /// @retval #PRVINFO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PRVINFO_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #PRVINFO_ERROR_INTERNAL_ERROR Unknown error
  int privilege_info_get_description(
    ffi.Pointer<ffi.Char> api_version,
    ffi.Pointer<ffi.Char> privilege,
    ffi.Pointer<ffi.Pointer<ffi.Char>> description,
  ) {
    return _privilege_info_get_description(
      api_version,
      privilege,
      description,
    );
  }

  late final _privilege_info_get_descriptionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'privilege_info_get_description');
  late final _privilege_info_get_description =
      _privilege_info_get_descriptionPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the description of the given privilege.
  /// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
  /// @remarks @a description must be released using free().
  /// @remarks package_type must be one of followings: PRVINFO_PACKAGE_TYPE_NATIVE, PRVINFO_PACKAGE_TYPE_WEB
  /// @param[in] package_type The type of application package
  /// @param[in] api_version The API version of the application to get privilege information
  /// @param[in]  privilege The privilege
  /// @param[out] description The description of the privilege
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PRVINFO_ERROR_NONE Successful
  /// @retval #PRVINFO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PRVINFO_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #PRVINFO_ERROR_INTERNAL_ERROR Unknown error
  int privilege_info_get_description_by_pkgtype(
    ffi.Pointer<ffi.Char> package_type,
    ffi.Pointer<ffi.Char> api_version,
    ffi.Pointer<ffi.Char> privilege,
    ffi.Pointer<ffi.Pointer<ffi.Char>> description,
  ) {
    return _privilege_info_get_description_by_pkgtype(
      package_type,
      api_version,
      privilege,
      description,
    );
  }

  late final _privilege_info_get_description_by_pkgtypePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'privilege_info_get_description_by_pkgtype');
  late final _privilege_info_get_description_by_pkgtype =
      _privilege_info_get_description_by_pkgtypePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the display name of the privacy group in which the given privilege is included.
  /// @since_tizen 3.0
  /// @remarks @a privacy_name must be released using free().
  /// @remarks @a privilege must be privacy related, otherwise #PRVINFO_ERROR_INVALID_PARAMETER is returned.
  /// @param[in] privilege The privilege
  /// @param[out] privacy_name The privacy group's display name that the given privilege is included in
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PRVINFO_ERROR_NONE Successful
  /// @retval #PRVINFO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PRVINFO_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #PRVINFO_ERROR_INTERNAL_ERROR Unknown error
  int privilege_info_get_privacy_display_name(
    ffi.Pointer<ffi.Char> privilege,
    ffi.Pointer<ffi.Pointer<ffi.Char>> privacy_name,
  ) {
    return _privilege_info_get_privacy_display_name(
      privilege,
      privacy_name,
    );
  }

  late final _privilege_info_get_privacy_display_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'privilege_info_get_privacy_display_name');
  late final _privilege_info_get_privacy_display_name =
      _privilege_info_get_privacy_display_namePtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the status of the given privacy related privilege.
  /// @since_tizen 3.0
  /// @remarks @a privilege must be privacy related, otherwise #PRVINFO_ERROR_INVALID_PARAMETER is returned.
  /// In case of errors, @a status is set to @c true.
  /// @param[in] privilege The privilege
  /// @param[out] status @c true if the privilege is on,
  /// and @c false if the privilege is off
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PRVINFO_ERROR_NONE Successful
  /// @retval #PRVINFO_ERROR_INVALID_PARAMETER Invalid function parameter
  /// @retval #PRVINFO_ERROR_INTERNAL_ERROR Unknown error
  int privilege_info_get_privacy_privilege_status(
    ffi.Pointer<ffi.Char> privilege,
    ffi.Pointer<ffi.Bool> status,
  ) {
    return _privilege_info_get_privacy_privilege_status(
      privilege,
      status,
    );
  }

  late final _privilege_info_get_privacy_privilege_statusPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>>(
      'privilege_info_get_privacy_privilege_status');
  late final _privilege_info_get_privacy_privilege_status =
      _privilege_info_get_privacy_privilege_statusPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief  Initializes the library. Must be called before any other crypto
  /// function. Should be called once in each thread that uses yaca.
  ///
  /// @since_tizen 3.0
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_cleanup()
  int yaca_initialize() {
    return _yaca_initialize();
  }

  late final _yaca_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('yaca_initialize');
  late final _yaca_initialize =
      _yaca_initializePtr.asFunction<int Function()>();

  /// @brief  Cleans up the library. Must be called before exiting the thread that
  /// called yaca_initialize().
  ///
  /// @since_tizen 3.0
  ///
  /// @see yaca_initialize()
  void yaca_cleanup() {
    return _yaca_cleanup();
  }

  late final _yaca_cleanupPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function()>>('yaca_cleanup');
  late final _yaca_cleanup = _yaca_cleanupPtr.asFunction<void Function()>();

  /// @brief  Allocates the memory.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a memory should be freed using yaca_free().
  ///
  /// @param[in]  size   Size of the allocation (bytes)
  /// @param[out] memory Allocated memory
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  ///
  /// @see yaca_zalloc()
  /// @see yaca_realloc()
  /// @see yaca_free()
  int yaca_malloc(
    int size,
    ffi.Pointer<ffi.Pointer<ffi.Void>> memory,
  ) {
    return _yaca_malloc(
      size,
      memory,
    );
  }

  late final _yaca_mallocPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Size, ffi.Pointer<ffi.Pointer<ffi.Void>>)>>('yaca_malloc');
  late final _yaca_malloc = _yaca_mallocPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Void>>)>();

  /// @brief  Allocates the zeroed memory.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a memory should be freed using yaca_free().
  ///
  /// @param[in]  size    Size of the allocation (bytes)
  /// @param[out] memory  Allocated memory
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  ///
  /// @see yaca_malloc()
  /// @see yaca_realloc()
  /// @see yaca_free()
  int yaca_zalloc(
    int size,
    ffi.Pointer<ffi.Pointer<ffi.Void>> memory,
  ) {
    return _yaca_zalloc(
      size,
      memory,
    );
  }

  late final _yaca_zallocPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Size, ffi.Pointer<ffi.Pointer<ffi.Void>>)>>('yaca_zalloc');
  late final _yaca_zalloc = _yaca_zallocPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Void>>)>();

  /// @brief  Re-allocates the memory.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  In case of failure the function doesn't free the memory pointed by @a memory.
  ///
  /// @remarks  If @a memory is NULL then the call is equivalent to yaca_malloc().
  ///
  /// @remarks  If the function fails the contents of @a memory will be left unchanged.
  ///
  /// @remarks  The @a memory should be freed using yaca_free().
  ///
  /// @param[in]     size    Size of the new allocation (bytes)
  /// @param[in,out] memory  Memory to be reallocated
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  ///
  /// @see yaca_malloc()
  /// @see yaca_zalloc()
  /// @see yaca_free()
  int yaca_realloc(
    int size,
    ffi.Pointer<ffi.Pointer<ffi.Void>> memory,
  ) {
    return _yaca_realloc(
      size,
      memory,
    );
  }

  late final _yaca_reallocPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Size, ffi.Pointer<ffi.Pointer<ffi.Void>>)>>('yaca_realloc');
  late final _yaca_realloc = _yaca_reallocPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Void>>)>();

  /// @brief  Frees the memory allocated by yaca_malloc(), yaca_zalloc(),
  /// yaca_realloc() or one of the cryptographic operations.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in] memory  Pointer to the memory to be freed
  ///
  /// @see yaca_malloc()
  /// @see yaca_zalloc()
  /// @see yaca_realloc()
  void yaca_free(
    ffi.Pointer<ffi.Void> memory,
  ) {
    return _yaca_free(
      memory,
    );
  }

  late final _yaca_freePtr =
      _lookup<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>(
          'yaca_free');
  late final _yaca_free =
      _yaca_freePtr.asFunction<void Function(ffi.Pointer<ffi.Void>)>();

  /// @brief  Safely compares first @a len bytes of two buffers.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in]  first  Pointer to the first buffer
  /// @param[in]  second Pointer to the second buffer
  /// @param[in]  len    Length to compare
  ///
  /// @return #YACA_ERROR_NONE when buffers are equal otherwise #YACA_ERROR_DATA_MISMATCH
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0)
  /// @retval #YACA_ERROR_DATA_MISMATCH Buffers are different
  int yaca_memcmp(
    ffi.Pointer<ffi.Void> first,
    ffi.Pointer<ffi.Void> second,
    int len,
  ) {
    return _yaca_memcmp(
      first,
      second,
      len,
    );
  }

  late final _yaca_memcmpPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Void>,
              ffi.Size)>>('yaca_memcmp');
  late final _yaca_memcmp = _yaca_memcmpPtr.asFunction<
      int Function(ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Void>, int)>();

  /// @brief  Generates random data.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] data      Pointer to the memory to be randomized
  /// @param[in]     data_len  Length of the memory to be randomized
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  int yaca_randomize_bytes(
    ffi.Pointer<ffi.Char> data,
    int data_len,
  ) {
    return _yaca_randomize_bytes(
      data,
      data_len,
    );
  }

  late final _yaca_randomize_bytesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>, ffi.Size)>>('yaca_randomize_bytes');
  late final _yaca_randomize_bytes = _yaca_randomize_bytesPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @brief  Sets the non-standard context properties. Can only be called on an
  /// initialized context.
  ///
  /// @remarks  The @a value has to be of type appropriate for given property. See #yaca_property_e
  /// for details on corresponding types.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx        Previously initialized crypto context
  /// @param[in]     property   Property to be set
  /// @param[in]     value      Property value
  /// @param[in]     value_len  Length of the property value
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a ctx or @a property)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_property_e
  /// @see yaca_context_get_property()
  int yaca_context_set_property(
    yaca_context_h ctx,
    int property,
    ffi.Pointer<ffi.Void> value,
    int value_len,
  ) {
    return _yaca_context_set_property(
      ctx,
      property,
      value,
      value_len,
    );
  }

  late final _yaca_context_set_propertyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Int32, ffi.Pointer<ffi.Void>,
              ffi.Size)>>('yaca_context_set_property');
  late final _yaca_context_set_property =
      _yaca_context_set_propertyPtr.asFunction<
          int Function(yaca_context_h, int, ffi.Pointer<ffi.Void>, int)>();

  /// @brief  Returns the non-standard context properties. Can only be called on an
  /// initialized context.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a value should be freed using yaca_free().
  ///
  /// @remarks  The @a value has to be of type appropriate for given property. See #yaca_property_e
  /// for details on corresponding types.
  ///
  /// @remarks  The @a value_len can be NULL if returned @a value is a single object
  /// (i.e. not an array/buffer).
  ///
  /// @param[in]  ctx        Previously initialized crypto context
  /// @param[in]  property   Property to be read
  /// @param[out] value      Copy of the property value
  /// @param[out] value_len  Length of the property value will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a ctx or @a property)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_property_e
  /// @see yaca_context_set_property()
  /// @see yaca_free()
  int yaca_context_get_property(
    yaca_context_h ctx,
    int property,
    ffi.Pointer<ffi.Pointer<ffi.Void>> value,
    ffi.Pointer<ffi.Size> value_len,
  ) {
    return _yaca_context_get_property(
      ctx,
      property,
      value,
      value_len,
    );
  }

  late final _yaca_context_get_propertyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              yaca_context_h,
              ffi.Int32,
              ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.Size>)>>('yaca_context_get_property');
  late final _yaca_context_get_property =
      _yaca_context_get_propertyPtr.asFunction<
          int Function(yaca_context_h, int, ffi.Pointer<ffi.Pointer<ffi.Void>>,
              ffi.Pointer<ffi.Size>)>();

  /// @brief  Returns the minimum required size of the output buffer for a single crypto function call.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  This function should be used to learn the required size of the output buffer
  /// for a single function call (eg. *_update or *_finalize). The actual output length
  /// (number of bytes that has been used) will be returned by the function call itself.
  ///
  /// @remarks  In case the function call has no output (e.g. yaca_sign_update(),
  /// yaca_digest_update()), there is no need to use this function.
  ///
  /// @remarks  In case the function call has no input (eg. *_finalize), the value of
  /// @a input_len has to be set to 0.
  ///
  /// @param[in]  ctx         Previously initialized crypto context
  /// @param[in]  input_len   Length of the input data to be processed
  /// @param[out] output_len  Required length of the output
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a ctx or too big @a input_len)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  int yaca_context_get_output_length(
    yaca_context_h ctx,
    int input_len,
    ffi.Pointer<ffi.Size> output_len,
  ) {
    return _yaca_context_get_output_length(
      ctx,
      input_len,
      output_len,
    );
  }

  late final _yaca_context_get_output_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Size,
              ffi.Pointer<ffi.Size>)>>('yaca_context_get_output_length');
  late final _yaca_context_get_output_length =
      _yaca_context_get_output_lengthPtr.asFunction<
          int Function(yaca_context_h, int, ffi.Pointer<ffi.Size>)>();

  /// @brief  Destroys the crypto context. Must be called on all contexts that are
  /// no longer used. Passing #YACA_CONTEXT_NULL is allowed.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx  Crypto context
  ///
  /// @see #yaca_context_h
  void yaca_context_destroy(
    yaca_context_h ctx,
  ) {
    return _yaca_context_destroy(
      ctx,
    );
  }

  late final _yaca_context_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function(yaca_context_h)>>(
          'yaca_context_destroy');
  late final _yaca_context_destroy =
      _yaca_context_destroyPtr.asFunction<void Function(yaca_context_h)>();

  /// @brief  Returns the recommended/default length of the Initialization Vector
  /// for a given encryption configuration.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  If returned @a iv_bit_len equals 0 that means that for this
  /// specific algorithm and its parameters Initialization Vector is not used.
  ///
  /// @param[in]  algo         Encryption algorithm
  /// @param[in]  bcm          Chain mode
  /// @param[in]  key_bit_len  Key length in bits
  /// @param[out] iv_bit_len   Recommended Initialization Vector length in bits
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a algo, @a bcm or @a key_bit_len)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  int yaca_encrypt_get_iv_bit_length(
    int algo,
    int bcm,
    int key_bit_len,
    ffi.Pointer<ffi.Size> iv_bit_len,
  ) {
    return _yaca_encrypt_get_iv_bit_length(
      algo,
      bcm,
      key_bit_len,
      iv_bit_len,
    );
  }

  late final _yaca_encrypt_get_iv_bit_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Int32, ffi.Size,
              ffi.Pointer<ffi.Size>)>>('yaca_encrypt_get_iv_bit_length');
  late final _yaca_encrypt_get_iv_bit_length =
      _yaca_encrypt_get_iv_bit_lengthPtr
          .asFunction<int Function(int, int, int, ffi.Pointer<ffi.Size>)>();

  /// @brief  Initializes an encryption context.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a ctx should be released using yaca_context_destroy().
  ///
  /// @param[out] ctx      Newly created context
  /// @param[in]  algo     Encryption algorithm that will be used
  /// @param[in]  bcm      Chaining mode that will be used
  /// @param[in]  sym_key  Symmetric key that will be used
  /// @param[in]  iv       Initialization Vector that will be used
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a algo, @a bcm, @a sym_key or @a iv)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_encrypt_algorithm_e
  /// @see #yaca_block_cipher_mode_e
  /// @see yaca_encrypt_update()
  /// @see yaca_encrypt_finalize()
  /// @see yaca_context_destroy()
  int yaca_encrypt_initialize(
    ffi.Pointer<yaca_context_h> ctx,
    int algo,
    int bcm,
    yaca_key_h sym_key,
    yaca_key_h iv,
  ) {
    return _yaca_encrypt_initialize(
      ctx,
      algo,
      bcm,
      sym_key,
      iv,
    );
  }

  late final _yaca_encrypt_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<yaca_context_h>, ffi.Int32, ffi.Int32,
              yaca_key_h, yaca_key_h)>>('yaca_encrypt_initialize');
  late final _yaca_encrypt_initialize = _yaca_encrypt_initializePtr.asFunction<
      int Function(
          ffi.Pointer<yaca_context_h>, int, int, yaca_key_h, yaca_key_h)>();

  /// @brief  Encrypts chunk of the data.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx             Context created by yaca_encrypt_initialize()
  /// @param[in]     plaintext       Plaintext to be encrypted
  /// @param[in]     plaintext_len   Length of the plaintext
  /// @param[out]    ciphertext      Buffer for the encrypted data
  /// (must be allocated by client, see yaca_context_get_output_length())
  /// @param[out]    ciphertext_len  Length of the encrypted data,
  /// actual number of bytes written will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a ctx)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_encrypt_initialize()
  /// @see yaca_encrypt_finalize()
  /// @see yaca_context_get_output_length()
  int yaca_encrypt_update(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> plaintext,
    int plaintext_len,
    ffi.Pointer<ffi.Char> ciphertext,
    ffi.Pointer<ffi.Size> ciphertext_len,
  ) {
    return _yaca_encrypt_update(
      ctx,
      plaintext,
      plaintext_len,
      ciphertext,
      ciphertext_len,
    );
  }

  late final _yaca_encrypt_updatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              yaca_context_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Size>)>>('yaca_encrypt_update');
  late final _yaca_encrypt_update = _yaca_encrypt_updatePtr.asFunction<
      int Function(yaca_context_h, ffi.Pointer<ffi.Char>, int,
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Encrypts the final chunk of the data.
  ///
  /// @remarks  Skipping yaca_encrypt_update() and calling only yaca_encrypt_finalize() will produce an
  /// encryption of an empty message.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx             A valid encrypt context
  /// @param[out]    ciphertext      Final piece of the encrypted data
  /// (must be allocated by client, see yaca_context_get_output_length())
  /// @param[out]    ciphertext_len  Length of the final piece,
  /// actual number of bytes written will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a ctx)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_encrypt_initialize()
  /// @see yaca_encrypt_update()
  /// @see yaca_context_get_output_length()
  int yaca_encrypt_finalize(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> ciphertext,
    ffi.Pointer<ffi.Size> ciphertext_len,
  ) {
    return _yaca_encrypt_finalize(
      ctx,
      ciphertext,
      ciphertext_len,
    );
  }

  late final _yaca_encrypt_finalizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Size>)>>('yaca_encrypt_finalize');
  late final _yaca_encrypt_finalize = _yaca_encrypt_finalizePtr.asFunction<
      int Function(
          yaca_context_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Initializes an decryption context.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a ctx should be released using yaca_context_destroy().
  ///
  /// @param[out] ctx      Newly created context
  /// @param[in]  algo     Encryption algorithm that was used to encrypt the data
  /// @param[in]  bcm      Chaining mode that was used to encrypt the data
  /// @param[in]  sym_key  Symmetric key that was used to encrypt the data
  /// @param[in]  iv       Initialization Vector that was used to encrypt the data
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a algo, @a bcm, @a sym_key or @a iv)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_encrypt_algorithm_e
  /// @see #yaca_block_cipher_mode_e
  /// @see yaca_decrypt_update()
  /// @see yaca_decrypt_finalize()
  /// @see yaca_context_destroy()
  int yaca_decrypt_initialize(
    ffi.Pointer<yaca_context_h> ctx,
    int algo,
    int bcm,
    yaca_key_h sym_key,
    yaca_key_h iv,
  ) {
    return _yaca_decrypt_initialize(
      ctx,
      algo,
      bcm,
      sym_key,
      iv,
    );
  }

  late final _yaca_decrypt_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<yaca_context_h>, ffi.Int32, ffi.Int32,
              yaca_key_h, yaca_key_h)>>('yaca_decrypt_initialize');
  late final _yaca_decrypt_initialize = _yaca_decrypt_initializePtr.asFunction<
      int Function(
          ffi.Pointer<yaca_context_h>, int, int, yaca_key_h, yaca_key_h)>();

  /// @brief  Decrypts chunk of the data.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx             Context created by yaca_decrypt_initialize()
  /// @param[in]     ciphertext      Ciphertext to be decrypted
  /// @param[in]     ciphertext_len  Length of the ciphertext
  /// @param[out]    plaintext       Buffer for the decrypted data
  /// (must be allocated by client, see yaca_context_get_output_length())
  /// @param[out]    plaintext_len   Length of the decrypted data,
  /// actual number of bytes written will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a ctx), wrong #YACA_PROPERTY_CCM_AAD or
  /// wrong #YACA_PROPERTY_CCM_TAG was used
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_decrypt_initialize()
  /// @see yaca_decrypt_finalize()
  /// @see yaca_context_get_output_length()
  int yaca_decrypt_update(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> ciphertext,
    int ciphertext_len,
    ffi.Pointer<ffi.Char> plaintext,
    ffi.Pointer<ffi.Size> plaintext_len,
  ) {
    return _yaca_decrypt_update(
      ctx,
      ciphertext,
      ciphertext_len,
      plaintext,
      plaintext_len,
    );
  }

  late final _yaca_decrypt_updatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              yaca_context_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Size>)>>('yaca_decrypt_update');
  late final _yaca_decrypt_update = _yaca_decrypt_updatePtr.asFunction<
      int Function(yaca_context_h, ffi.Pointer<ffi.Char>, int,
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Decrypts the final chunk of the data.
  ///
  /// @remarks  Skipping yaca_decrypt_update() and calling only yaca_decrypt_finalize() will produce a
  /// decryption of an empty ciphertext.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx            A valid decrypt context
  /// @param[out]    plaintext      Final piece of the decrypted data
  /// (must be allocated by client, see yaca_context_get_output_length())
  /// @param[out]    plaintext_len  Length of the final piece,
  /// actual number of bytes written will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a ctx), wrong #YACA_PROPERTY_GCM_AAD or
  /// wrong #YACA_PROPERTY_GCM_TAG was used
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_decrypt_initialize()
  /// @see yaca_decrypt_update()
  /// @see yaca_context_get_output_length()
  int yaca_decrypt_finalize(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> plaintext,
    ffi.Pointer<ffi.Size> plaintext_len,
  ) {
    return _yaca_decrypt_finalize(
      ctx,
      plaintext,
      plaintext_len,
    );
  }

  late final _yaca_decrypt_finalizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Size>)>>('yaca_decrypt_finalize');
  late final _yaca_decrypt_finalize = _yaca_decrypt_finalizePtr.asFunction<
      int Function(
          yaca_context_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Initializes an asymmetric encryption context and generates
  /// symmetric key and Initialization Vector.
  ///
  /// @remarks  Generated symmetric key is encrypted with public key,
  /// so can be only used with yaca_open_initialize(). It can be exported,
  /// but after import it can be only used with yaca_open_initialize() as well.
  ///
  /// @remarks  The @a ctx should be released using yaca_context_destroy().
  ///
  /// @remarks  The @a pub_key must be #YACA_KEY_TYPE_RSA_PUB.
  ///
  /// @remarks  The @a sym_key_bit_len must be at least 88 bits shorter than the @a pub_key bit length.
  ///
  /// @remarks  The @a sym_key should be released using yaca_key_destroy().
  ///
  /// @remarks  The @a iv should be released using yaca_key_destroy().
  ///
  /// @since_tizen 3.0
  ///
  /// @param[out] ctx              Newly created context
  /// @param[in]  pub_key          Public key of the peer that will receive the encrypted data
  /// @param[in]  algo             Symmetric algorithm that will be used
  /// @param[in]  bcm              Block chaining mode for the symmetric algorithm
  /// @param[in]  sym_key_bit_len  Symmetric key length (in bits) that will be generated
  /// @param[out] sym_key          Generated symmetric key that will be used,
  /// it is encrypted with peer's public key
  /// @param[out] iv               Generated Initialization Vector that will be used
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a algo, @a bcm, @a sym_key_bit_len or @a pub_key)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_encrypt_algorithm_e
  /// @see #yaca_block_cipher_mode_e
  /// @see #yaca_key_bit_length_e
  /// @see yaca_seal_update()
  /// @see yaca_seal_finalize()
  /// @see yaca_open_initialize()
  /// @see yaca_key_destroy()
  /// @see yaca_context_destroy()
  int yaca_seal_initialize(
    ffi.Pointer<yaca_context_h> ctx,
    yaca_key_h pub_key,
    int algo,
    int bcm,
    int sym_key_bit_len,
    ffi.Pointer<yaca_key_h> sym_key,
    ffi.Pointer<yaca_key_h> iv,
  ) {
    return _yaca_seal_initialize(
      ctx,
      pub_key,
      algo,
      bcm,
      sym_key_bit_len,
      sym_key,
      iv,
    );
  }

  late final _yaca_seal_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<yaca_context_h>,
              yaca_key_h,
              ffi.Int32,
              ffi.Int32,
              ffi.Size,
              ffi.Pointer<yaca_key_h>,
              ffi.Pointer<yaca_key_h>)>>('yaca_seal_initialize');
  late final _yaca_seal_initialize = _yaca_seal_initializePtr.asFunction<
      int Function(ffi.Pointer<yaca_context_h>, yaca_key_h, int, int, int,
          ffi.Pointer<yaca_key_h>, ffi.Pointer<yaca_key_h>)>();

  /// @brief  Encrypts piece of the data.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx             Context created by yaca_seal_initialize()
  /// @param[in]     plaintext       Plaintext to be encrypted
  /// @param[in]     plaintext_len   Length of the plaintext
  /// @param[out]    ciphertext      Buffer for the encrypted data
  /// (must be allocated by client, see yaca_context_get_output_length())
  /// @param[out]    ciphertext_len  Length of the encrypted data,
  /// actual number of bytes written will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a ctx)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_seal_initialize()
  /// @see yaca_seal_finalize()
  /// @see yaca_context_get_output_length()
  int yaca_seal_update(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> plaintext,
    int plaintext_len,
    ffi.Pointer<ffi.Char> ciphertext,
    ffi.Pointer<ffi.Size> ciphertext_len,
  ) {
    return _yaca_seal_update(
      ctx,
      plaintext,
      plaintext_len,
      ciphertext,
      ciphertext_len,
    );
  }

  late final _yaca_seal_updatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              yaca_context_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Size>)>>('yaca_seal_update');
  late final _yaca_seal_update = _yaca_seal_updatePtr.asFunction<
      int Function(yaca_context_h, ffi.Pointer<ffi.Char>, int,
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Encrypts the final piece of the data.
  ///
  /// @remarks  Skipping yaca_seal_update() and calling only yaca_seal_finalize() will produce an
  /// encryption of an empty message.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx             A valid seal context
  /// @param[out]    ciphertext      Final piece of the encrypted data
  /// (must be allocated by client, see yaca_context_get_output_length())
  /// @param[out]    ciphertext_len  Length of the final piece,
  /// actual number of bytes written will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a ctx)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_seal_initialize()
  /// @see yaca_seal_update()
  /// @see yaca_context_get_output_length()
  int yaca_seal_finalize(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> ciphertext,
    ffi.Pointer<ffi.Size> ciphertext_len,
  ) {
    return _yaca_seal_finalize(
      ctx,
      ciphertext,
      ciphertext_len,
    );
  }

  late final _yaca_seal_finalizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Size>)>>('yaca_seal_finalize');
  late final _yaca_seal_finalize = _yaca_seal_finalizePtr.asFunction<
      int Function(
          yaca_context_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Initializes an asymmetric decryption context.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a ctx should be released using yaca_context_destroy().
  ///
  /// @remarks  The @a prv_key must be #YACA_KEY_TYPE_RSA_PRIV.
  ///
  /// @param[out] ctx              Newly created context
  /// @param[in]  prv_key          Private key, part of the pair that was used for the encryption
  /// @param[in]  algo             Symmetric algorithm that was used for the encryption
  /// @param[in]  bcm              Block chaining mode for the symmetric algorithm
  /// @param[in]  sym_key_bit_len  Symmetric key length (in bits) that was used for the encryption
  /// @param[in]  sym_key          Symmetric key, encrypted with the public key,
  /// that was used to encrypt the data
  /// @param[in]  iv               Initialization Vector that was used for the encryption
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, invalid
  /// @a algo, @a bcm, @a sym_key_bit_len, @a prv_key,
  /// @a sym_key or @a iv)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_encrypt_algorithm_e
  /// @see #yaca_block_cipher_mode_e
  /// @see #yaca_key_bit_length_e
  /// @see yaca_open_update()
  /// @see yaca_open_finalize()
  /// @see yaca_context_destroy()
  int yaca_open_initialize(
    ffi.Pointer<yaca_context_h> ctx,
    yaca_key_h prv_key,
    int algo,
    int bcm,
    int sym_key_bit_len,
    yaca_key_h sym_key,
    yaca_key_h iv,
  ) {
    return _yaca_open_initialize(
      ctx,
      prv_key,
      algo,
      bcm,
      sym_key_bit_len,
      sym_key,
      iv,
    );
  }

  late final _yaca_open_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<yaca_context_h>,
              yaca_key_h,
              ffi.Int32,
              ffi.Int32,
              ffi.Size,
              yaca_key_h,
              yaca_key_h)>>('yaca_open_initialize');
  late final _yaca_open_initialize = _yaca_open_initializePtr.asFunction<
      int Function(ffi.Pointer<yaca_context_h>, yaca_key_h, int, int, int,
          yaca_key_h, yaca_key_h)>();

  /// @brief  Decrypts piece of the data.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx             Context created by yaca_open_initialize()
  /// @param[in]     ciphertext      Ciphertext to be decrypted
  /// @param[in]     ciphertext_len  Length of the ciphertext
  /// @param[out]    plaintext       Buffer for the decrypted data
  /// (must be allocated by client, see yaca_context_get_output_length())
  /// @param[out]    plaintext_len   Length of the decrypted data,
  /// actual number of bytes written will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a ctx), wrong #YACA_PROPERTY_CCM_AAD or
  /// wrong #YACA_PROPERTY_CCM_TAG was used
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_open_initialize()
  /// @see yaca_open_finalize()
  /// @see yaca_context_get_output_length()
  int yaca_open_update(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> ciphertext,
    int ciphertext_len,
    ffi.Pointer<ffi.Char> plaintext,
    ffi.Pointer<ffi.Size> plaintext_len,
  ) {
    return _yaca_open_update(
      ctx,
      ciphertext,
      ciphertext_len,
      plaintext,
      plaintext_len,
    );
  }

  late final _yaca_open_updatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              yaca_context_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Size>)>>('yaca_open_update');
  late final _yaca_open_update = _yaca_open_updatePtr.asFunction<
      int Function(yaca_context_h, ffi.Pointer<ffi.Char>, int,
          ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Decrypts last chunk of sealed message.
  ///
  /// @remarks  Skipping yaca_open_update() and calling only yaca_open_finalize() will produce a
  /// decryption of an empty ciphertext.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx            A valid open context
  /// @param[out]    plaintext      Final piece of the decrypted data
  /// (must be allocated by client, see yaca_context_get_output_length())
  /// @param[out]    plaintext_len  Length of the final piece,
  /// actual number of bytes written will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a ctx), wrong #YACA_PROPERTY_GCM_AAD or
  /// wrong #YACA_PROPERTY_GCM_TAG was used
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_open_initialize()
  /// @see yaca_open_update()
  /// @see yaca_context_get_output_length()
  int yaca_open_finalize(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> plaintext,
    ffi.Pointer<ffi.Size> plaintext_len,
  ) {
    return _yaca_open_finalize(
      ctx,
      plaintext,
      plaintext_len,
    );
  }

  late final _yaca_open_finalizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Size>)>>('yaca_open_finalize');
  late final _yaca_open_finalize = _yaca_open_finalizePtr.asFunction<
      int Function(
          yaca_context_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Initializes a signature context for asymmetric signatures.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  For verification use yaca_verify_initialize(), yaca_verify_update() and
  /// yaca_verify_finalize() functions with matching public key.
  ///
  /// @remarks  For RSA operations the default padding used is #YACA_PADDING_PKCS1. It can be
  /// changed using yaca_context_set_property() with #YACA_PROPERTY_PADDING.
  ///
  /// @remarks  For #YACA_DIGEST_SHA384 and #YACA_DIGEST_SHA512 the RSA key size must be bigger than
  /// #YACA_KEY_LENGTH_512BIT.
  ///
  /// @remarks  Using of #YACA_DIGEST_MD5 algorithm for DSA and ECDSA operations is prohibited.
  ///
  /// @remarks  Using of #YACA_DIGEST_MD5 or #YACA_DIGEST_SHA224 with #YACA_PADDING_X931 is prohibited.
  ///
  /// @remarks  The @a ctx should be released using yaca_context_destroy().
  ///
  /// @param[out] ctx      Newly created context
  /// @param[in]  algo     Digest algorithm that will be used
  /// @param[in]  prv_key  Private key that will be used, algorithm is deduced based
  /// on key type, supported key types:
  /// - #YACA_KEY_TYPE_RSA_PRIV,
  /// - #YACA_KEY_TYPE_DSA_PRIV,
  /// - #YACA_KEY_TYPE_EC_PRIV
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a algo or @a prv_key)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_digest_algorithm_e
  /// @see #yaca_padding_e
  /// @see yaca_context_set_property()
  /// @see yaca_sign_update()
  /// @see yaca_sign_finalize()
  /// @see yaca_verify_initialize()
  /// @see yaca_verify_update()
  /// @see yaca_verify_finalize()
  /// @see yaca_context_destroy()
  int yaca_sign_initialize(
    ffi.Pointer<yaca_context_h> ctx,
    int algo,
    yaca_key_h prv_key,
  ) {
    return _yaca_sign_initialize(
      ctx,
      algo,
      prv_key,
    );
  }

  late final _yaca_sign_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<yaca_context_h>, ffi.Int32,
              yaca_key_h)>>('yaca_sign_initialize');
  late final _yaca_sign_initialize = _yaca_sign_initializePtr
      .asFunction<int Function(ffi.Pointer<yaca_context_h>, int, yaca_key_h)>();

  /// @brief  Initializes a signature context for HMAC.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  For verification, calculate message HMAC and compare with received MAC using
  /// yaca_memcmp().
  ///
  /// @remarks  The @a ctx should be released using yaca_context_destroy().
  ///
  /// @param[out] ctx      Newly created context
  /// @param[in]  algo     Digest algorithm that will be used
  /// @param[in]  sym_key  Symmetric key that will be used, supported key types:
  /// - #YACA_KEY_TYPE_SYMMETRIC,
  /// - #YACA_KEY_TYPE_DES
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a algo or @a sym_key)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_digest_algorithm_e
  /// @see yaca_sign_update()
  /// @see yaca_sign_finalize()
  /// @see yaca_memcmp()
  /// @see yaca_context_destroy()
  int yaca_sign_initialize_hmac(
    ffi.Pointer<yaca_context_h> ctx,
    int algo,
    yaca_key_h sym_key,
  ) {
    return _yaca_sign_initialize_hmac(
      ctx,
      algo,
      sym_key,
    );
  }

  late final _yaca_sign_initialize_hmacPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<yaca_context_h>, ffi.Int32,
              yaca_key_h)>>('yaca_sign_initialize_hmac');
  late final _yaca_sign_initialize_hmac = _yaca_sign_initialize_hmacPtr
      .asFunction<int Function(ffi.Pointer<yaca_context_h>, int, yaca_key_h)>();

  /// @brief  Initializes a signature context for CMAC.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  For verification, calculate message CMAC and compare with received MAC using
  /// yaca_memcmp().
  ///
  /// @remarks  The @a ctx should be released using yaca_context_destroy().
  ///
  /// @param[out] ctx      Newly created context
  /// @param[in]  algo     Encryption algorithm that will be used
  /// @param[in]  sym_key  Symmetric key that will be used, supported key types:
  /// - #YACA_KEY_TYPE_SYMMETRIC,
  /// - #YACA_KEY_TYPE_DES
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a algo or @a sym_key)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_encrypt_algorithm_e
  /// @see yaca_sign_update()
  /// @see yaca_sign_finalize()
  /// @see yaca_memcmp()
  /// @see yaca_context_destroy()
  int yaca_sign_initialize_cmac(
    ffi.Pointer<yaca_context_h> ctx,
    int algo,
    yaca_key_h sym_key,
  ) {
    return _yaca_sign_initialize_cmac(
      ctx,
      algo,
      sym_key,
    );
  }

  late final _yaca_sign_initialize_cmacPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<yaca_context_h>, ffi.Int32,
              yaca_key_h)>>('yaca_sign_initialize_cmac');
  late final _yaca_sign_initialize_cmac = _yaca_sign_initialize_cmacPtr
      .asFunction<int Function(ffi.Pointer<yaca_context_h>, int, yaca_key_h)>();

  /// @brief  Feeds the message into the digital signature or MAC algorithm.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx          Context created by yaca_sign_initialize(),
  /// yaca_sign_initialize_hmac() or yaca_sign_initialize_cmac()
  /// @param[in]     message      Message to be signed
  /// @param[in]     message_len  Length of the message
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a ctx)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_sign_initialize()
  /// @see yaca_sign_finalize()
  /// @see yaca_sign_initialize_hmac()
  /// @see yaca_sign_initialize_cmac()
  int yaca_sign_update(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> message,
    int message_len,
  ) {
    return _yaca_sign_update(
      ctx,
      message,
      message_len,
    );
  }

  late final _yaca_sign_updatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Pointer<ffi.Char>,
              ffi.Size)>>('yaca_sign_update');
  late final _yaca_sign_update = _yaca_sign_updatePtr
      .asFunction<int Function(yaca_context_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief  Calculates the final signature or MAC.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  Skipping yaca_sign_update() and calling only yaca_sign_finalize() will produce a
  /// signature or MAC of an empty message.
  ///
  /// @param[in,out] ctx              A valid sign context
  /// @param[out]    signature        Buffer for the MAC or the message signature
  /// (must be allocated by client, see yaca_context_get_output_length())
  /// @param[out]    signature_len    Length of the MAC or the signature,
  /// actual number of bytes written will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a ctx)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_sign_initialize()
  /// @see yaca_sign_update()
  /// @see yaca_sign_initialize_hmac()
  /// @see yaca_sign_initialize_cmac()
  /// @see yaca_context_get_output_length()
  int yaca_sign_finalize(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> signature,
    ffi.Pointer<ffi.Size> signature_len,
  ) {
    return _yaca_sign_finalize(
      ctx,
      signature,
      signature_len,
    );
  }

  late final _yaca_sign_finalizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Size>)>>('yaca_sign_finalize');
  late final _yaca_sign_finalize = _yaca_sign_finalizePtr.asFunction<
      int Function(
          yaca_context_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Initializes a signature verification context for asymmetric signatures.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  For RSA operations the default padding used is #YACA_PADDING_PKCS1. It can be
  /// changed using yaca_context_set_property() with #YACA_PROPERTY_PADDING.
  /// For verify to succeed it has to be set to the same value it was signed with.
  ///
  /// @remarks  The @a ctx should be released using yaca_context_destroy().
  ///
  /// @param[out] ctx      Newly created context
  /// @param[in]  algo     Digest algorithm that will be used
  /// @param[in]  pub_key  Public key that will be used, algorithm is deduced based on
  /// key type, supported key types:
  /// - #YACA_KEY_TYPE_RSA_PUB,
  /// - #YACA_KEY_TYPE_DSA_PUB,
  /// - #YACA_KEY_TYPE_EC_PUB
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a algo or @a pub_key)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_digest_algorithm_e
  /// @see #yaca_padding_e
  /// @see yaca_context_set_property()
  /// @see yaca_verify_update()
  /// @see yaca_verify_finalize()
  /// @see yaca_context_destroy()
  int yaca_verify_initialize(
    ffi.Pointer<yaca_context_h> ctx,
    int algo,
    yaca_key_h pub_key,
  ) {
    return _yaca_verify_initialize(
      ctx,
      algo,
      pub_key,
    );
  }

  late final _yaca_verify_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<yaca_context_h>, ffi.Int32,
              yaca_key_h)>>('yaca_verify_initialize');
  late final _yaca_verify_initialize = _yaca_verify_initializePtr
      .asFunction<int Function(ffi.Pointer<yaca_context_h>, int, yaca_key_h)>();

  /// @brief  Feeds the message into the digital signature verification algorithm.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx          Context created by yaca_verify_initialize()
  /// @param[in]     message      Message
  /// @param[in]     message_len  Length of the message
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a ctx)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_verify_initialize()
  /// @see yaca_verify_finalize()
  int yaca_verify_update(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> message,
    int message_len,
  ) {
    return _yaca_verify_update(
      ctx,
      message,
      message_len,
    );
  }

  late final _yaca_verify_updatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Pointer<ffi.Char>,
              ffi.Size)>>('yaca_verify_update');
  late final _yaca_verify_update = _yaca_verify_updatePtr
      .asFunction<int Function(yaca_context_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief  Performs the verification.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  Skipping yaca_verify_update() and calling only yaca_verify_finalize() will verify
  /// the signature of an empty message.
  ///
  /// @param[in,out] ctx            A valid verify context
  /// @param[in]     signature      Message signature to be verified
  /// @param[in]     signature_len  Length of the signature
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a ctx)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  /// @retval #YACA_ERROR_DATA_MISMATCH The verification failed
  ///
  /// @see yaca_verify_initialize()
  /// @see yaca_verify_update()
  /// @see yaca_sign_finalize()
  int yaca_verify_finalize(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> signature,
    int signature_len,
  ) {
    return _yaca_verify_finalize(
      ctx,
      signature,
      signature_len,
    );
  }

  late final _yaca_verify_finalizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Pointer<ffi.Char>,
              ffi.Size)>>('yaca_verify_finalize');
  late final _yaca_verify_finalize = _yaca_verify_finalizePtr
      .asFunction<int Function(yaca_context_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief  Initializes a digest context.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a ctx should be released using yaca_context_destroy().
  ///
  /// @param[out] ctx   Newly created context
  /// @param[in]  algo  Digest algorithm that will be used
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a algo)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_digest_algorithm_e
  /// @see yaca_digest_update()
  /// @see yaca_digest_finalize()
  /// @see yaca_context_destroy()
  int yaca_digest_initialize(
    ffi.Pointer<yaca_context_h> ctx,
    int algo,
  ) {
    return _yaca_digest_initialize(
      ctx,
      algo,
    );
  }

  late final _yaca_digest_initializePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<yaca_context_h>,
              ffi.Int32)>>('yaca_digest_initialize');
  late final _yaca_digest_initialize = _yaca_digest_initializePtr
      .asFunction<int Function(ffi.Pointer<yaca_context_h>, int)>();

  /// @brief  Feeds the message into the message digest algorithm.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] ctx          Context created by yaca_digest_initialize()
  /// @param[in]     message      Message from which the digest is to be calculated
  /// @param[in]     message_len  Length of the message
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a ctx)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_digest_initialize()
  /// @see yaca_digest_finalize()
  int yaca_digest_update(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> message,
    int message_len,
  ) {
    return _yaca_digest_update(
      ctx,
      message,
      message_len,
    );
  }

  late final _yaca_digest_updatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Pointer<ffi.Char>,
              ffi.Size)>>('yaca_digest_update');
  late final _yaca_digest_update = _yaca_digest_updatePtr
      .asFunction<int Function(yaca_context_h, ffi.Pointer<ffi.Char>, int)>();

  /// @brief  Calculates the final digest.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  Skipping yaca_digest_update() and calling only yaca_digest_finalize() will produce an
  /// empty message digest.
  ///
  /// @param[in,out] ctx         A valid digest context
  /// @param[out]    digest      Buffer for the message digest
  /// (must be allocated by client, see yaca_context_get_output_length())
  /// @param[out]    digest_len  Length of the digest,
  /// actual number of bytes written will be returned here
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a ctx)
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_digest_initialize()
  /// @see yaca_digest_update()
  /// @see yaca_context_get_output_length()
  int yaca_digest_finalize(
    yaca_context_h ctx,
    ffi.Pointer<ffi.Char> digest,
    ffi.Pointer<ffi.Size> digest_len,
  ) {
    return _yaca_digest_finalize(
      ctx,
      digest,
      digest_len,
    );
  }

  late final _yaca_digest_finalizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_context_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Size>)>>('yaca_digest_finalize');
  late final _yaca_digest_finalize = _yaca_digest_finalizePtr.asFunction<
      int Function(
          yaca_context_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Gets key's type.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in]  key       Key which type we return
  /// @param[out] key_type  Key type
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Either of the params is NULL
  ///
  /// @see #yaca_key_type_e
  int yaca_key_get_type(
    yaca_key_h key,
    ffi.Pointer<ffi.Int32> key_type,
  ) {
    return _yaca_key_get_type(
      key,
      key_type,
    );
  }

  late final _yaca_key_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              yaca_key_h, ffi.Pointer<ffi.Int32>)>>('yaca_key_get_type');
  late final _yaca_key_get_type = _yaca_key_get_typePtr
      .asFunction<int Function(yaca_key_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief  Gets key's length (in bits).
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a key can be any symmetric (including an Initialization Vector) or
  /// asymmetric key (including key generation parameters).
  ///
  /// @remarks  For Diffie-Helmann @a key_bit_len returns prime length in bits. Values
  /// used to generate the key/parameters in yaca_key_generate() are not
  /// restored. Neither generator number nor values from #yaca_key_bit_length_dh_rfc_e.
  ///
  /// @remarks  For Elliptic Curves @a key_bit_len returns values from #yaca_key_bit_length_ec_e.
  ///
  /// @param[in]  key          Key which length we return
  /// @param[out] key_bit_len  Key length in bits
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Either of the params is NULL
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_bit_length_e
  /// @see #yaca_key_bit_length_dh_rfc_e
  /// @see #yaca_key_bit_length_ec_e
  int yaca_key_get_bit_length(
    yaca_key_h key,
    ffi.Pointer<ffi.Size> key_bit_len,
  ) {
    return _yaca_key_get_bit_length(
      key,
      key_bit_len,
    );
  }

  late final _yaca_key_get_bit_lengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              yaca_key_h, ffi.Pointer<ffi.Size>)>>('yaca_key_get_bit_length');
  late final _yaca_key_get_bit_length = _yaca_key_get_bit_lengthPtr
      .asFunction<int Function(yaca_key_h, ffi.Pointer<ffi.Size>)>();

  /// @brief  Imports a key or key generation parameters.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  Everywhere where either a key (of any type) or an asymmetric key is referred
  /// in the documentation of this function key generator parameters are also included.
  ///
  /// @remarks  This function imports a key trying to match it to the @a key_type specified.
  /// It should autodetect both the key format and the file format.
  ///
  /// @remarks  For symmetric, Initialization Vector and DES keys RAW binary format and BASE64 encoded
  /// binary format are supported.
  /// For asymmetric keys PEM and DER file formats are supported.
  ///
  /// @remarks  Asymmetric keys can be in their default ASN1 structure formats (like
  /// PKCS#1, SSleay or PKCS#3). Private asymmetric keys can also be in
  /// PKCS#8 format. Additionally it is possible to import public RSA/DSA/EC
  /// keys from X509 certificate.
  ///
  /// @remarks  If the key is encrypted the algorithm will be autodetected and password
  /// used. If it's not known if the key is encrypted one should pass NULL as
  /// password and check for the #YACA_ERROR_INVALID_PASSWORD return code.
  ///
  /// @remarks  If the imported key will be detected as a format that does not support
  /// encryption and password was passed #YACA_ERROR_INVALID_PARAMETER will
  /// be returned. For a list of keys and formats that do support encryption
  /// see yaca_key_export() documentation.
  ///
  /// @remarks  The @a key should be released using yaca_key_destroy().
  ///
  /// @param[in]  key_type  Type of the key
  /// @param[in]  password  Null-terminated password for the key (can be NULL)
  /// @param[in]  data      Blob containing the key
  /// @param[in]  data_len  Size of the blob
  /// @param[out] key       Returned key
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a key_type or @a data_len too big)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  /// @retval #YACA_ERROR_INVALID_PASSWORD Invalid @a password given or @a password was required
  /// and none was given
  ///
  /// @see #yaca_key_type_e
  /// @see yaca_key_export()
  /// @see yaca_key_destroy()
  int yaca_key_import(
    int key_type,
    ffi.Pointer<ffi.Char> password,
    ffi.Pointer<ffi.Char> data,
    int data_len,
    ffi.Pointer<yaca_key_h> key,
  ) {
    return _yaca_key_import(
      key_type,
      password,
      data,
      data_len,
      key,
    );
  }

  late final _yaca_key_importPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<yaca_key_h>)>>('yaca_key_import');
  late final _yaca_key_import = _yaca_key_importPtr.asFunction<
      int Function(int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, int,
          ffi.Pointer<yaca_key_h>)>();

  /// @brief  Exports a key or key generation parameters to arbitrary format.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  Everywhere where either a key (of any type) or an asymmetric key is referred
  /// in the documentation of this function key generator parameters are also included.
  ///
  /// @remarks  This function exports the key to an arbitrary key format and key file format.
  ///
  /// @remarks  For key formats two values are allowed:
  /// - #YACA_KEY_FORMAT_DEFAULT: this is the only option possible in case of symmetric keys
  /// (or Initialization Vector), for asymmetric keys it will
  /// export to their default ASN1 structure format
  /// (e.g. PKCS#1, SSLeay, PKCS#3).
  /// - #YACA_KEY_FORMAT_PKCS8: this will only work for private asymmetric keys.
  ///
  /// @remarks  The following file formats are supported:
  /// - #YACA_KEY_FILE_FORMAT_RAW:    used only for symmetric, raw binary format
  /// - #YACA_KEY_FILE_FORMAT_BASE64: used only for symmetric, BASE64 encoded binary form
  /// - #YACA_KEY_FILE_FORMAT_PEM:    used only for asymmetric, PEM file format
  /// - #YACA_KEY_FILE_FORMAT_DER:    used only for asymmetric, DER file format
  ///
  /// @remarks  Encryption is supported and optional for RSA/DSA private keys in the
  /// #YACA_KEY_FORMAT_DEFAULT with #YACA_KEY_FILE_FORMAT_PEM format. If no password is
  /// provided the exported key will be unencrypted. The encryption algorithm used
  /// in this case is AES-256-CBC.
  ///
  /// @remarks  Encryption is obligatory for #YACA_KEY_FORMAT_PKCS8 format (for both, PEM and DER
  /// file formats). If no password is provided the #YACA_ERROR_INVALID_PARAMETER will
  /// be returned. The encryption algorithm used in this case is AES-256-CBC. The key is
  /// generated from password using PBKDF2 with HMAC-SHA1 function and 2048 iterations.
  ///
  /// @remarks  Encryption is not supported for the symmetric, public keys and key generation
  /// parameters in all their supported formats. If a password is provided in such
  /// case the #YACA_ERROR_INVALID_PARAMETER will be returned.
  ///
  /// @param[in]  key           Key to be exported
  /// @param[in]  key_fmt       Format of the key
  /// @param[in]  key_file_fmt  Format of the key file
  /// @param[in]  password      Password used for the encryption (can be NULL)
  /// @param[out] data          Data, allocated by the library, containing exported key
  /// (must be freed with yaca_free())
  /// @param[out] data_len      Size of the output data
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a key_fmt, @a key_file_fmt or @a data_len too big)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_format_e
  /// @see #yaca_key_file_format_e
  /// @see yaca_key_import()
  /// @see yaca_key_destroy()
  int yaca_key_export(
    yaca_key_h key,
    int key_fmt,
    int key_file_fmt,
    ffi.Pointer<ffi.Char> password,
    ffi.Pointer<ffi.Pointer<ffi.Char>> data,
    ffi.Pointer<ffi.Size> data_len,
  ) {
    return _yaca_key_export(
      key,
      key_fmt,
      key_file_fmt,
      password,
      data,
      data_len,
    );
  }

  late final _yaca_key_exportPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              yaca_key_h,
              ffi.Int32,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_key_export');
  late final _yaca_key_export = _yaca_key_exportPtr.asFunction<
      int Function(yaca_key_h, int, int, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Generates a secure key or key generation parameters (or an Initialization Vector).
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  This function is used to generate symmetric keys, private asymmetric keys
  /// or key generation parameters for key types that support them (DSA, DH and EC).
  ///
  /// @remarks  Supported key lengths:
  /// - RSA: length >= 512bits
  /// - DSA: length >= 512bits, multiple of 64
  /// - DH: a value taken from #yaca_key_bit_length_dh_rfc_e or
  /// (YACA_KEY_LENGTH_DH_GENERATOR_* | prime_length_in_bits),
  /// where prime_length_in_bits can be any positive number
  /// - EC: a value taken from #yaca_key_bit_length_ec_e
  ///
  /// @remarks  The @a key should be released using yaca_key_destroy().
  ///
  /// @param[in]  key_type     Type of the key to be generated
  /// @param[in]  key_bit_len  Length of the key (in bits) to be generated
  /// @param[out] key          Newly generated key
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER @a key is NULL, incorrect @a key_type or
  /// @a key_bit_len is not dividable by 8
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_key_bit_length_e
  /// @see #yaca_key_bit_length_dh_rfc_e
  /// @see #YACA_KEY_LENGTH_DH_GENERATOR_2
  /// @see #YACA_KEY_LENGTH_DH_GENERATOR_5
  /// @see #yaca_key_bit_length_ec_e
  /// @see yaca_key_destroy()
  int yaca_key_generate(
    int key_type,
    int key_bit_len,
    ffi.Pointer<yaca_key_h> key,
  ) {
    return _yaca_key_generate(
      key_type,
      key_bit_len,
      key,
    );
  }

  late final _yaca_key_generatePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Size,
              ffi.Pointer<yaca_key_h>)>>('yaca_key_generate');
  late final _yaca_key_generate = _yaca_key_generatePtr
      .asFunction<int Function(int, int, ffi.Pointer<yaca_key_h>)>();

  /// @brief  Generates a secure private asymmetric key from parameters.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  This function is used to generate private asymmetric keys
  /// based on pre-generated parameters.
  ///
  /// @remarks  The @a key should be released using yaca_key_destroy().
  ///
  /// @param[in]  params   Pre-generated parameters
  /// @param[out] prv_key  Newly generated private key
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER @a prv_key is NULL or incorrect @a params
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_key_destroy()
  /// @see yaca_key_generate()
  /// @see yaca_key_extract_parameters()
  int yaca_key_generate_from_parameters(
    yaca_key_h params,
    ffi.Pointer<yaca_key_h> prv_key,
  ) {
    return _yaca_key_generate_from_parameters(
      params,
      prv_key,
    );
  }

  late final _yaca_key_generate_from_parametersPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_key_h,
              ffi.Pointer<yaca_key_h>)>>('yaca_key_generate_from_parameters');
  late final _yaca_key_generate_from_parameters =
      _yaca_key_generate_from_parametersPtr
          .asFunction<int Function(yaca_key_h, ffi.Pointer<yaca_key_h>)>();

  /// @brief  Extracts public key from a private one.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a pub_key should be released using yaca_key_destroy().
  ///
  /// @param[in]  prv_key  Private key to extract the public one from
  /// @param[out] pub_key  Extracted public key
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER @a prv_key is of invalid type or @a pub_key is NULL
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_key_generate()
  /// @see yaca_key_import()
  /// @see yaca_key_destroy()
  int yaca_key_extract_public(
    yaca_key_h prv_key,
    ffi.Pointer<yaca_key_h> pub_key,
  ) {
    return _yaca_key_extract_public(
      prv_key,
      pub_key,
    );
  }

  late final _yaca_key_extract_publicPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              yaca_key_h, ffi.Pointer<yaca_key_h>)>>('yaca_key_extract_public');
  late final _yaca_key_extract_public = _yaca_key_extract_publicPtr
      .asFunction<int Function(yaca_key_h, ffi.Pointer<yaca_key_h>)>();

  /// @brief  Extracts parameters from a private or a public key.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a params should be released using yaca_key_destroy().
  ///
  /// @param[in]  key      A key to extract the parameters from
  /// @param[out] params   Extracted parameters
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER @a key is of invalid type or @a params is NULL
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_key_generate()
  /// @see yaca_key_generate_from_parameters()
  /// @see yaca_key_import()
  /// @see yaca_key_destroy()
  int yaca_key_extract_parameters(
    yaca_key_h key,
    ffi.Pointer<yaca_key_h> params,
  ) {
    return _yaca_key_extract_parameters(
      key,
      params,
    );
  }

  late final _yaca_key_extract_parametersPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(yaca_key_h,
              ffi.Pointer<yaca_key_h>)>>('yaca_key_extract_parameters');
  late final _yaca_key_extract_parameters = _yaca_key_extract_parametersPtr
      .asFunction<int Function(yaca_key_h, ffi.Pointer<yaca_key_h>)>();

  /// @brief  Derives a shared secret using Diffie-Helmann or EC Diffie-Helmann key exchange protocol.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a secret should not be used as a symmetric key,
  /// to produce a symmetric key pass the secret to a key derivation function (KDF)
  /// or a message digest function.
  ///
  /// @remarks  The @a secret should be freed with yaca_free().
  ///
  /// @param[in]  prv_key      Our private key
  /// @param[in]  pub_key      Peer public key
  /// @param[out] secret       Generated shared secret
  /// @param[out] secret_len   Size of the shared secret
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values
  /// (invalid @a prv_key or @a pub_key)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see yaca_key_derive_kdf()
  /// @see yaca_simple_calculate_digest()
  /// @see yaca_free()
  int yaca_key_derive_dh(
    yaca_key_h prv_key,
    yaca_key_h pub_key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> secret,
    ffi.Pointer<ffi.Size> secret_len,
  ) {
    return _yaca_key_derive_dh(
      prv_key,
      pub_key,
      secret,
      secret_len,
    );
  }

  late final _yaca_key_derive_dhPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              yaca_key_h,
              yaca_key_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_key_derive_dh');
  late final _yaca_key_derive_dh = _yaca_key_derive_dhPtr.asFunction<
      int Function(yaca_key_h, yaca_key_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
          ffi.Pointer<ffi.Size>)>();

  /// @brief  Derives a key material from shared secret.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a info parameter is ANSI X9.42 OtherInfo or ANSI X9.62 SharedInfo structure,
  /// more information can be found in ANSI X9.42/62 standard specification.
  ///
  /// @remarks  The @a key_material or separate parts of it can be used to import a symmetric key
  /// with yaca_key_import().
  ///
  /// @remarks  The @a key_material should be freed using yaca_free().
  ///
  /// @param[in]  kdf               Key derivation function
  /// @param[in]  algo              Digest algorithm that should be used in key derivation
  /// @param[in]  secret            Shared secret
  /// @param[in]  secret_len        Size of the shared secret
  /// @param[in]  info              Optional additional info, use NULL if not appending extra info
  /// @param[in]  info_len          Length of additional info, use 0 if not using additional info
  /// @param[in]  key_material_len  Length of a key material to be generated
  /// @param[out] key_material      Newly generated key material
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a algo or @a kdf)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_kdf_e
  /// @see #yaca_digest_algorithm_e
  /// @see yaca_key_derive_dh()
  /// @see yaca_key_import()
  /// @see yaca_free()
  int yaca_key_derive_kdf(
    int kdf,
    int algo,
    ffi.Pointer<ffi.Char> secret,
    int secret_len,
    ffi.Pointer<ffi.Char> info,
    int info_len,
    int key_material_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> key_material,
  ) {
    return _yaca_key_derive_kdf(
      kdf,
      algo,
      secret,
      secret_len,
      info,
      info_len,
      key_material_len,
      key_material,
    );
  }

  late final _yaca_key_derive_kdfPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('yaca_key_derive_kdf');
  late final _yaca_key_derive_kdf = _yaca_key_derive_kdfPtr.asFunction<
      int Function(int, int, ffi.Pointer<ffi.Char>, int, ffi.Pointer<ffi.Char>,
          int, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief  Derives a key from user password (PKCS #5 a.k.a. pbkdf2 algorithm).
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a key should be released using yaca_key_destroy().
  ///
  /// @param[in]  password     User password as a null-terminated string
  /// @param[in]  salt         Salt, should be a non-empty string
  /// @param[in]  salt_len     Length of the salt
  /// @param[in]  iterations   Number of iterations
  /// @param[in]  algo         Digest algorithm that should be used in key generation
  /// @param[in]  key_bit_len  Length of a key (in bits) to be generated
  /// @param[out] key          Newly generated key
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0,
  /// invalid @a algo or @a key_bit_len not dividable by 8)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_digest_algorithm_e
  /// @see yaca_key_destroy()
  int yaca_key_derive_pbkdf2(
    ffi.Pointer<ffi.Char> password,
    ffi.Pointer<ffi.Char> salt,
    int salt_len,
    int iterations,
    int algo,
    int key_bit_len,
    ffi.Pointer<yaca_key_h> key,
  ) {
    return _yaca_key_derive_pbkdf2(
      password,
      salt,
      salt_len,
      iterations,
      algo,
      key_bit_len,
      key,
    );
  }

  late final _yaca_key_derive_pbkdf2Ptr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Size,
              ffi.Int32,
              ffi.Size,
              ffi.Pointer<yaca_key_h>)>>('yaca_key_derive_pbkdf2');
  late final _yaca_key_derive_pbkdf2 = _yaca_key_derive_pbkdf2Ptr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, int, int, int,
          int, ffi.Pointer<yaca_key_h>)>();

  /// @brief  Release the key created by the library. Passing YACA_KEY_NULL is allowed.
  ///
  /// @since_tizen 3.0
  ///
  /// @param[in,out] key  Key to be released
  ///
  /// @see yaca_key_import()
  /// @see yaca_key_export()
  /// @see yaca_key_generate()
  void yaca_key_destroy(
    yaca_key_h key,
  ) {
    return _yaca_key_destroy(
      key,
    );
  }

  late final _yaca_key_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function(yaca_key_h)>>(
          'yaca_key_destroy');
  late final _yaca_key_destroy =
      _yaca_key_destroyPtr.asFunction<void Function(yaca_key_h)>();

  /// @brief  Encrypts data using a RSA public key (low-level encrypt equivalent).
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a ciphertext should be freed using yaca_free().
  ///
  /// @remarks  The @a pub_key used has to be of a #YACA_KEY_TYPE_RSA_PUB type.
  ///
  /// @remarks  The maximum length of plaintext depends on the key length and padding method.
  /// See #yaca_padding_e for details.
  ///
  /// @remarks  The @a plaintext can be NULL but then the @a plaintext_len must be 0.
  ///
  /// @param[in]  padding         Padding method
  /// @param[in]  pub_key         Public RSA key (see yaca_key.h for key generation functions)
  /// @param[in]  plaintext       Plaintext to be encrypted
  /// @param[in]  plaintext_len   Length of the plaintext
  /// @param[out] ciphertext      Encrypted data, will be allocated by the library
  /// @param[out] ciphertext_len  Length of the encrypted data (may be larger than decrypted)
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0
  /// invalid @a padding, @a pub_key or @a plaintext_len)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_padding_e
  /// @see yaca_rsa_private_decrypt()
  /// @see yaca_free()
  int yaca_rsa_public_encrypt(
    int padding,
    yaca_key_h pub_key,
    ffi.Pointer<ffi.Char> plaintext,
    int plaintext_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> ciphertext,
    ffi.Pointer<ffi.Size> ciphertext_len,
  ) {
    return _yaca_rsa_public_encrypt(
      padding,
      pub_key,
      plaintext,
      plaintext_len,
      ciphertext,
      ciphertext_len,
    );
  }

  late final _yaca_rsa_public_encryptPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              yaca_key_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_rsa_public_encrypt');
  late final _yaca_rsa_public_encrypt = _yaca_rsa_public_encryptPtr.asFunction<
      int Function(int, yaca_key_h, ffi.Pointer<ffi.Char>, int,
          ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Decrypts data using a RSA private key (low-level decrypt equivalent).
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a plaintext should be freed using yaca_free().
  ///
  /// @remarks  The @a prv_key used has to be of a #YACA_KEY_TYPE_RSA_PRIV type.
  ///
  /// @param[in]  padding         Padding method
  /// @param[in]  prv_key         Private RSA key matching the public one used to encrypt the data
  /// @param[in]  ciphertext      Ciphertext to be decrypted
  /// @param[in]  ciphertext_len  Length of ciphertext
  /// @param[out] plaintext       Decrypted data, will be allocated by the library
  /// @param[out] plaintext_len   Length of the decrypted data
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0
  /// invalid @a padding or @a prv_key), padding check failed
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_padding_e
  /// @see yaca_rsa_public_encrypt()
  /// @see yaca_free()
  int yaca_rsa_private_decrypt(
    int padding,
    yaca_key_h prv_key,
    ffi.Pointer<ffi.Char> ciphertext,
    int ciphertext_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> plaintext,
    ffi.Pointer<ffi.Size> plaintext_len,
  ) {
    return _yaca_rsa_private_decrypt(
      padding,
      prv_key,
      ciphertext,
      ciphertext_len,
      plaintext,
      plaintext_len,
    );
  }

  late final _yaca_rsa_private_decryptPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              yaca_key_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_rsa_private_decrypt');
  late final _yaca_rsa_private_decrypt =
      _yaca_rsa_private_decryptPtr.asFunction<
          int Function(int, yaca_key_h, ffi.Pointer<ffi.Char>, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Encrypts data using a RSA private key (low-level sign equivalent).
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a ciphertext should be freed using yaca_free().
  ///
  /// @remarks  The @a prv_key used has to be of a #YACA_KEY_TYPE_RSA_PRIV type.
  ///
  /// @remarks  The maximum length of plaintext depends on the key length and padding method,
  /// see #yaca_padding_e for details.
  ///
  /// @remarks  The @a plaintext can be NULL but then the @a plaintext_len must be 0.
  ///
  /// @param[in]  padding         Padding method
  /// @param[in]  prv_key         Private RSA key (see yaca_key.h for key generation functions)
  /// @param[in]  plaintext       Plaintext to be encrypted
  /// @param[in]  plaintext_len   Length of the plaintext
  /// @param[out] ciphertext      Encrypted data, will be allocated by the library
  /// @param[out] ciphertext_len  Length of the encrypted data (may be larger than decrypted)
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0
  /// invalid @a padding, @a prv_key or @a plaintext_len)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_padding_e
  /// @see yaca_rsa_public_decrypt()
  /// @see yaca_free()
  int yaca_rsa_private_encrypt(
    int padding,
    yaca_key_h prv_key,
    ffi.Pointer<ffi.Char> plaintext,
    int plaintext_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> ciphertext,
    ffi.Pointer<ffi.Size> ciphertext_len,
  ) {
    return _yaca_rsa_private_encrypt(
      padding,
      prv_key,
      plaintext,
      plaintext_len,
      ciphertext,
      ciphertext_len,
    );
  }

  late final _yaca_rsa_private_encryptPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              yaca_key_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_rsa_private_encrypt');
  late final _yaca_rsa_private_encrypt =
      _yaca_rsa_private_encryptPtr.asFunction<
          int Function(int, yaca_key_h, ffi.Pointer<ffi.Char>, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Decrypts data using a RSA public key (low-level verify equivalent).
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a plaintext should be freed using yaca_free().
  ///
  /// @remarks  The @a pub_key used has to be of a #YACA_KEY_TYPE_RSA_PUB type.
  ///
  /// @param[in]  padding         Padding method
  /// @param[in]  pub_key         Public RSA key matching the private one used to encrypt the data
  /// @param[in]  ciphertext      Ciphertext to be decrypted
  /// @param[in]  ciphertext_len  Length of ciphertext
  /// @param[out] plaintext       Decrypted data, will be allocated by the library
  /// @param[out] plaintext_len   Length of the decrypted data
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0
  /// invalid @a padding or @a pub_key), padding check failed
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_padding_e
  /// @see yaca_rsa_private_encrypt()
  /// @see yaca_free()
  int yaca_rsa_public_decrypt(
    int padding,
    yaca_key_h pub_key,
    ffi.Pointer<ffi.Char> ciphertext,
    int ciphertext_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> plaintext,
    ffi.Pointer<ffi.Size> plaintext_len,
  ) {
    return _yaca_rsa_public_decrypt(
      padding,
      pub_key,
      ciphertext,
      ciphertext_len,
      plaintext,
      plaintext_len,
    );
  }

  late final _yaca_rsa_public_decryptPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              yaca_key_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_rsa_public_decrypt');
  late final _yaca_rsa_public_decrypt = _yaca_rsa_public_decryptPtr.asFunction<
      int Function(int, yaca_key_h, ffi.Pointer<ffi.Char>, int,
          ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Encrypts data using a symmetric cipher.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  yaca_simple_encrypt() doesn't support #YACA_BCM_GCM and #YACA_BCM_CCM.
  ///
  /// @remarks  The @a ciphertext should be freed using yaca_free().
  ///
  /// @remarks  The @a plaintext can be NULL but then @a plaintext_len must be 0.
  ///
  /// @param[in]  algo            Encryption algorithm (select #YACA_ENCRYPT_AES if unsure)
  /// @param[in]  bcm             Chaining mode (select #YACA_BCM_CBC if unsure)
  /// @param[in]  sym_key         Symmetric encryption key (see yaca_key.h for key generation functions)
  /// @param[in]  iv              Initialization Vector
  /// @param[in]  plaintext       Plaintext to be encrypted
  /// @param[in]  plaintext_len   Length of the plaintext
  /// @param[out] ciphertext      Encrypted data, will be allocated by the library
  /// @param[out] ciphertext_len  Length of the encrypted data (may be larger than decrypted)
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0
  /// invalid @a algo, @a bcm, @a sym_key or @a iv)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_encrypt_algorithm_e
  /// @see #yaca_block_cipher_mode_e
  /// @see yaca_simple_decrypt()
  /// @see yaca_free()
  int yaca_simple_encrypt(
    int algo,
    int bcm,
    yaca_key_h sym_key,
    yaca_key_h iv,
    ffi.Pointer<ffi.Char> plaintext,
    int plaintext_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> ciphertext,
    ffi.Pointer<ffi.Size> ciphertext_len,
  ) {
    return _yaca_simple_encrypt(
      algo,
      bcm,
      sym_key,
      iv,
      plaintext,
      plaintext_len,
      ciphertext,
      ciphertext_len,
    );
  }

  late final _yaca_simple_encryptPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              ffi.Int32,
              yaca_key_h,
              yaca_key_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_simple_encrypt');
  late final _yaca_simple_encrypt = _yaca_simple_encryptPtr.asFunction<
      int Function(int, int, yaca_key_h, yaca_key_h, ffi.Pointer<ffi.Char>, int,
          ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Decrypts data using a symmetric cipher.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  yaca_simple_decrypt() doesn't support #YACA_BCM_GCM and #YACA_BCM_CCM.
  ///
  /// @remarks  The @a plaintext should be freed using yaca_free().
  ///
  /// @remarks  The @a ciphertext can be NULL but then @a ciphertext_len must be 0.
  ///
  /// @param[in]  algo            Decryption algorithm that was used to encrypt the data
  /// @param[in]  bcm             Chaining mode that was used to encrypt the data
  /// @param[in]  sym_key         Symmetric encryption key that was used to encrypt the data
  /// @param[in]  iv              Initialization Vector that was used to encrypt the data
  /// @param[in]  ciphertext      Ciphertext to be decrypted
  /// @param[in]  ciphertext_len  Length of ciphertext
  /// @param[out] plaintext       Decrypted data, will be allocated by the library
  /// @param[out] plaintext_len   Length of the decrypted data
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0
  /// invalid @a algo, @a bcm, @a sym_key or @a iv)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_encrypt_algorithm_e
  /// @see #yaca_block_cipher_mode_e
  /// @see yaca_simple_encrypt()
  /// @see yaca_free()
  int yaca_simple_decrypt(
    int algo,
    int bcm,
    yaca_key_h sym_key,
    yaca_key_h iv,
    ffi.Pointer<ffi.Char> ciphertext,
    int ciphertext_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> plaintext,
    ffi.Pointer<ffi.Size> plaintext_len,
  ) {
    return _yaca_simple_decrypt(
      algo,
      bcm,
      sym_key,
      iv,
      ciphertext,
      ciphertext_len,
      plaintext,
      plaintext_len,
    );
  }

  late final _yaca_simple_decryptPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              ffi.Int32,
              yaca_key_h,
              yaca_key_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_simple_decrypt');
  late final _yaca_simple_decrypt = _yaca_simple_decryptPtr.asFunction<
      int Function(int, int, yaca_key_h, yaca_key_h, ffi.Pointer<ffi.Char>, int,
          ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Calculates a digest of a message.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a digest should be freed using yaca_free().
  ///
  /// @remarks  The @a message can be NULL but then @a message_len must be 0.
  ///
  /// @param[in]  algo         Digest algorithm (select #YACA_DIGEST_SHA256 if unsure)
  /// @param[in]  message      Message from which the digest is to be calculated
  /// @param[in]  message_len  Length of the message
  /// @param[out] digest       Message digest, will be allocated by the library
  /// @param[out] digest_len   Length of message digest (depends on algorithm)
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL,
  /// invalid @a algo)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_digest_algorithm_e
  /// @see yaca_free()
  int yaca_simple_calculate_digest(
    int algo,
    ffi.Pointer<ffi.Char> message,
    int message_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> digest,
    ffi.Pointer<ffi.Size> digest_len,
  ) {
    return _yaca_simple_calculate_digest(
      algo,
      message,
      message_len,
      digest,
      digest_len,
    );
  }

  late final _yaca_simple_calculate_digestPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_simple_calculate_digest');
  late final _yaca_simple_calculate_digest =
      _yaca_simple_calculate_digestPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Char>, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Creates a signature using asymmetric private key.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  For #YACA_DIGEST_SHA384 and #YACA_DIGEST_SHA512 the RSA key size must be bigger than
  /// #YACA_KEY_LENGTH_512BIT.
  ///
  /// @remarks  Using of #YACA_DIGEST_MD5 algorithm for DSA and ECDSA operations is prohibited.
  ///
  /// @remarks  The @a signature should be freed using yaca_free().
  ///
  /// @remarks  The @a message can be NULL but then @a message_len must be 0.
  ///
  /// @param[in]  algo           Digest algorithm that will be used
  /// @param[in]  prv_key        Private key that will be used, algorithm is
  /// deduced based on key type, supported key types:
  /// - #YACA_KEY_TYPE_RSA_PRIV,
  /// - #YACA_KEY_TYPE_DSA_PRIV,
  /// - #YACA_KEY_TYPE_EC_PRIV
  /// @param[in]  message        Message to be signed
  /// @param[in]  message_len    Length of the message
  /// @param[out] signature      Message signature, will be allocated by the library
  /// @param[out] signature_len  Length of the signature
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0
  /// invalid @a algo or @a prv_key)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_digest_algorithm_e
  /// @see yaca_simple_verify_signature()
  /// @see yaca_free()
  int yaca_simple_calculate_signature(
    int algo,
    yaca_key_h prv_key,
    ffi.Pointer<ffi.Char> message,
    int message_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> signature,
    ffi.Pointer<ffi.Size> signature_len,
  ) {
    return _yaca_simple_calculate_signature(
      algo,
      prv_key,
      message,
      message_len,
      signature,
      signature_len,
    );
  }

  late final _yaca_simple_calculate_signaturePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              yaca_key_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_simple_calculate_signature');
  late final _yaca_simple_calculate_signature =
      _yaca_simple_calculate_signaturePtr.asFunction<
          int Function(int, yaca_key_h, ffi.Pointer<ffi.Char>, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Verifies a signature using asymmetric public key.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  The @a message can be NULL but then @a message_len must be 0.
  ///
  /// @param[in]  algo           Digest algorithm that will be used
  /// @param[in]  pub_key        Public key that will be used, algorithm is
  /// deduced based on key type, supported key types:
  /// - #YACA_KEY_TYPE_RSA_PUB,
  /// - #YACA_KEY_TYPE_DSA_PUB,
  /// - #YACA_KEY_TYPE_EC_PUB
  /// @param[in]  message        Message
  /// @param[in]  message_len    Length of the message
  /// @param[in]  signature      Message signature to be verified
  /// @param[in]  signature_len  Length of the signature
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0
  /// invalid @a algo or @a pub_key)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  /// @retval #YACA_ERROR_DATA_MISMATCH The verification failed
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_digest_algorithm_e
  /// @see yaca_simple_calculate_signature()
  int yaca_simple_verify_signature(
    int algo,
    yaca_key_h pub_key,
    ffi.Pointer<ffi.Char> message,
    int message_len,
    ffi.Pointer<ffi.Char> signature,
    int signature_len,
  ) {
    return _yaca_simple_verify_signature(
      algo,
      pub_key,
      message,
      message_len,
      signature,
      signature_len,
    );
  }

  late final _yaca_simple_verify_signaturePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              yaca_key_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Char>,
              ffi.Size)>>('yaca_simple_verify_signature');
  late final _yaca_simple_verify_signature =
      _yaca_simple_verify_signaturePtr.asFunction<
          int Function(int, yaca_key_h, ffi.Pointer<ffi.Char>, int,
              ffi.Pointer<ffi.Char>, int)>();

  /// @brief  Calculates a HMAC of given message using symmetric key.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  For verification, calculate message HMAC and compare with received MAC using
  /// yaca_memcmp().
  ///
  /// @remarks  The @a mac should be freed using yaca_free().
  ///
  /// @remarks  The @a message can be NULL but then @a message_len must be 0.
  ///
  /// @param[in]  algo         Digest algorithm that will be used
  /// @param[in]  sym_key      Key that will be used, supported key types:
  /// - #YACA_KEY_TYPE_SYMMETRIC,
  /// - #YACA_KEY_TYPE_DES
  /// @param[in]  message      Message to calculate HMAC from
  /// @param[in]  message_len  Length of the message
  /// @param[out] mac          MAC, will be allocated by the library
  /// @param[out] mac_len      Length of the MAC
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0
  /// invalid @a algo or @a sym_key)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_digest_algorithm_e
  /// @see yaca_memcmp()
  /// @see yaca_free()
  int yaca_simple_calculate_hmac(
    int algo,
    yaca_key_h sym_key,
    ffi.Pointer<ffi.Char> message,
    int message_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mac,
    ffi.Pointer<ffi.Size> mac_len,
  ) {
    return _yaca_simple_calculate_hmac(
      algo,
      sym_key,
      message,
      message_len,
      mac,
      mac_len,
    );
  }

  late final _yaca_simple_calculate_hmacPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              yaca_key_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_simple_calculate_hmac');
  late final _yaca_simple_calculate_hmac =
      _yaca_simple_calculate_hmacPtr.asFunction<
          int Function(int, yaca_key_h, ffi.Pointer<ffi.Char>, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  /// @brief  Calculates a CMAC of given message using symmetric key.
  ///
  /// @since_tizen 3.0
  ///
  /// @remarks  For verification, calculate message CMAC and compare with received MAC using
  /// yaca_memcmp().
  ///
  /// @remarks  The @a mac should be freed using yaca_free().
  ///
  /// @remarks  The @a message can be NULL but then @a message_len must be 0.
  ///
  /// @param[in]  algo         Encryption algorithm that will be used
  /// @param[in]  sym_key      Key that will be used, supported key types:
  /// - #YACA_KEY_TYPE_SYMMETRIC,
  /// - #YACA_KEY_TYPE_DES
  /// @param[in]  message      Message to calculate CMAC from
  /// @param[in]  message_len  Length of the message
  /// @param[out] mac          MAC, will be allocated by the library
  /// @param[out] mac_len      Length of the MAC
  ///
  /// @return #YACA_ERROR_NONE on success, negative on error
  /// @retval #YACA_ERROR_NONE Successful
  /// @retval #YACA_ERROR_INVALID_PARAMETER Required parameters have incorrect values (NULL, 0
  /// invalid @a algo or @a sym_key)
  /// @retval #YACA_ERROR_OUT_OF_MEMORY Out of memory error
  /// @retval #YACA_ERROR_INTERNAL Internal error
  ///
  /// @see #yaca_key_type_e
  /// @see #yaca_encrypt_algorithm_e
  /// @see yaca_memcmp()
  /// @see yaca_free()
  int yaca_simple_calculate_cmac(
    int algo,
    yaca_key_h sym_key,
    ffi.Pointer<ffi.Char> message,
    int message_len,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mac,
    ffi.Pointer<ffi.Size> mac_len,
  ) {
    return _yaca_simple_calculate_cmac(
      algo,
      sym_key,
      message,
      message_len,
      mac,
      mac_len,
    );
  }

  late final _yaca_simple_calculate_cmacPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              yaca_key_h,
              ffi.Pointer<ffi.Char>,
              ffi.Size,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Size>)>>('yaca_simple_calculate_cmac');
  late final _yaca_simple_calculate_cmac =
      _yaca_simple_calculate_cmacPtr.asFunction<
          int Function(int, yaca_key_h, ffi.Pointer<ffi.Char>, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Size>)>();

  late final ffi.Pointer<_calendar_book_property_ids> __calendar_book =
      _lookup<_calendar_book_property_ids>('_calendar_book');

  _calendar_book_property_ids get _calendar_book => __calendar_book.ref;

  late final ffi.Pointer<_calendar_event_property_ids> __calendar_event =
      _lookup<_calendar_event_property_ids>('_calendar_event');

  _calendar_event_property_ids get _calendar_event => __calendar_event.ref;

  late final ffi.Pointer<_calendar_todo_property_ids> __calendar_todo =
      _lookup<_calendar_todo_property_ids>('_calendar_todo');

  _calendar_todo_property_ids get _calendar_todo => __calendar_todo.ref;

  late final ffi.Pointer<_calendar_timezone_property_ids> __calendar_timezone =
      _lookup<_calendar_timezone_property_ids>('_calendar_timezone');

  _calendar_timezone_property_ids get _calendar_timezone =>
      __calendar_timezone.ref;

  late final ffi.Pointer<_calendar_attendee_property_ids> __calendar_attendee =
      _lookup<_calendar_attendee_property_ids>('_calendar_attendee');

  _calendar_attendee_property_ids get _calendar_attendee =>
      __calendar_attendee.ref;

  late final ffi.Pointer<_calendar_alarm_property_ids> __calendar_alarm =
      _lookup<_calendar_alarm_property_ids>('_calendar_alarm');

  _calendar_alarm_property_ids get _calendar_alarm => __calendar_alarm.ref;

  late final ffi.Pointer<_calendar_updated_info_property_ids>
      __calendar_updated_info =
      _lookup<_calendar_updated_info_property_ids>('_calendar_updated_info');

  _calendar_updated_info_property_ids get _calendar_updated_info =>
      __calendar_updated_info.ref;

  late final ffi.Pointer<_calendar_event_calendar_book_property_ids>
      __calendar_event_calendar_book =
      _lookup<_calendar_event_calendar_book_property_ids>(
          '_calendar_event_calendar_book');

  _calendar_event_calendar_book_property_ids
      get _calendar_event_calendar_book => __calendar_event_calendar_book.ref;

  late final ffi.Pointer<_calendar_todo_calendar_book_property_ids>
      __calendar_todo_calendar_book =
      _lookup<_calendar_todo_calendar_book_property_ids>(
          '_calendar_todo_calendar_book');

  _calendar_todo_calendar_book_property_ids get _calendar_todo_calendar_book =>
      __calendar_todo_calendar_book.ref;

  late final ffi.Pointer<_calendar_event_calendar_book_attendee_property_ids>
      __calendar_event_calendar_book_attendee =
      _lookup<_calendar_event_calendar_book_attendee_property_ids>(
          '_calendar_event_calendar_book_attendee');

  _calendar_event_calendar_book_attendee_property_ids
      get _calendar_event_calendar_book_attendee =>
          __calendar_event_calendar_book_attendee.ref;

  late final ffi.Pointer<_calendar_instance_utime_calendar_book_property_ids>
      __calendar_instance_utime_calendar_book =
      _lookup<_calendar_instance_utime_calendar_book_property_ids>(
          '_calendar_instance_utime_calendar_book');

  _calendar_instance_utime_calendar_book_property_ids
      get _calendar_instance_utime_calendar_book =>
          __calendar_instance_utime_calendar_book.ref;

  late final ffi
          .Pointer<_calendar_instance_localtime_calendar_book_property_ids>
      __calendar_instance_localtime_calendar_book =
      _lookup<_calendar_instance_localtime_calendar_book_property_ids>(
          '_calendar_instance_localtime_calendar_book');

  _calendar_instance_localtime_calendar_book_property_ids
      get _calendar_instance_localtime_calendar_book =>
          __calendar_instance_localtime_calendar_book.ref;

  late final ffi
          .Pointer<_calendar_instance_utime_calendar_book_extended_property_ids>
      __calendar_instance_utime_calendar_book_extended =
      _lookup<_calendar_instance_utime_calendar_book_extended_property_ids>(
          '_calendar_instance_utime_calendar_book_extended');

  _calendar_instance_utime_calendar_book_extended_property_ids
      get _calendar_instance_utime_calendar_book_extended =>
          __calendar_instance_utime_calendar_book_extended.ref;

  late final ffi.Pointer<
          _calendar_instance_localtime_calendar_book_extended_property_ids>
      __calendar_instance_localtime_calendar_book_extended =
      _lookup<_calendar_instance_localtime_calendar_book_extended_property_ids>(
          '_calendar_instance_localtime_calendar_book_extended');

  _calendar_instance_localtime_calendar_book_extended_property_ids
      get _calendar_instance_localtime_calendar_book_extended =>
          __calendar_instance_localtime_calendar_book_extended.ref;

  late final ffi.Pointer<_calendar_extended_property_property_ids>
      __calendar_extended_property =
      _lookup<_calendar_extended_property_property_ids>(
          '_calendar_extended_property');

  _calendar_extended_property_property_ids get _calendar_extended_property =>
      __calendar_extended_property.ref;

  /// @brief Inserts a record into the calendar database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] record The record handle
  /// @param[out] record_id The record ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_db_update_record()
  /// @see calendar_db_delete_record()
  /// @see calendar_db_get_record()
  int calendar_db_insert_record(
    calendar_record_h record,
    ffi.Pointer<ffi.Int> record_id,
  ) {
    return _calendar_db_insert_record(
      record,
      record_id,
    );
  }

  late final _calendar_db_insert_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h,
              ffi.Pointer<ffi.Int>)>>('calendar_db_insert_record');
  late final _calendar_db_insert_record = _calendar_db_insert_recordPtr
      .asFunction<int Function(calendar_record_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets a record from the calendar database.
  /// @details This function creates a new record handle from the calendar database by the given @a record_id. \n
  /// @a record will be created and filled with record information.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @remarks You must release @a record using calendar_record_destroy().
  /// @param[in] view_uri The view URI of a record
  /// @param[in] record_id The record ID
  /// @param[out] record The record handle associated with the record ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_DB_RECORD_NOT_FOUND Database not found
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_record_destroy()
  int calendar_db_get_record(
    ffi.Pointer<ffi.Char> view_uri,
    int record_id,
    ffi.Pointer<calendar_record_h> record,
  ) {
    return _calendar_db_get_record(
      view_uri,
      record_id,
      record,
    );
  }

  late final _calendar_db_get_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int,
              ffi.Pointer<calendar_record_h>)>>('calendar_db_get_record');
  late final _calendar_db_get_record = _calendar_db_get_recordPtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>, int, ffi.Pointer<calendar_record_h>)>();

  /// @brief Updates a record in the calendar database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] record The record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_DB_RECORD_NOT_FOUND Database not found
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_db_insert_record()
  /// @see calendar_db_delete_record()
  /// @see calendar_db_get_record()
  int calendar_db_update_record(
    calendar_record_h record,
  ) {
    return _calendar_db_update_record(
      record,
    );
  }

  late final _calendar_db_update_recordPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_record_h)>>(
          'calendar_db_update_record');
  late final _calendar_db_update_record = _calendar_db_update_recordPtr
      .asFunction<int Function(calendar_record_h)>();

  /// @brief Deletes a record from the calendar database with related child records.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] view_uri The view URI of a record
  /// @param[in] record_id The record ID to be deleted
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_DB_RECORD_NOT_FOUND Database not found
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_db_insert_record()
  int calendar_db_delete_record(
    ffi.Pointer<ffi.Char> view_uri,
    int record_id,
  ) {
    return _calendar_db_delete_record(
      view_uri,
      record_id,
    );
  }

  late final _calendar_db_delete_recordPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int)>>(
      'calendar_db_delete_record');
  late final _calendar_db_delete_record = _calendar_db_delete_recordPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @brief Retrieves all records as a list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @remarks You must release @a record_list using calendar_list_destroy().
  /// @param[in] view_uri The view URI to get records from
  /// @param[in] offset The index from which results are received
  /// @param[in] limit The maximum number of results(value 0 is used for all records)
  /// @param[out] record_list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_list_destroy()
  int calendar_db_get_all_records(
    ffi.Pointer<ffi.Char> view_uri,
    int offset,
    int limit,
    ffi.Pointer<calendar_list_h> record_list,
  ) {
    return _calendar_db_get_all_records(
      view_uri,
      offset,
      limit,
      record_list,
    );
  }

  late final _calendar_db_get_all_recordsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int, ffi.Int,
              ffi.Pointer<calendar_list_h>)>>('calendar_db_get_all_records');
  late final _calendar_db_get_all_records =
      _calendar_db_get_all_recordsPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, int, int, ffi.Pointer<calendar_list_h>)>();

  /// @brief Retrieves records using a query handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @remarks You must release @a record_list using calendar_list_destroy().
  /// @param[in] query The query handle used to filter results
  /// @param[in] offset The index from which results are received
  /// @param[in] limit The maximum number of results(value 0 is used for all records)
  /// @param[out] record_list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_list_destroy()
  int calendar_db_get_records_with_query(
    calendar_query_h query,
    int offset,
    int limit,
    ffi.Pointer<calendar_list_h> record_list,
  ) {
    return _calendar_db_get_records_with_query(
      query,
      offset,
      limit,
      record_list,
    );
  }

  late final _calendar_db_get_records_with_queryPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(calendar_query_h, ffi.Int, ffi.Int,
                  ffi.Pointer<calendar_list_h>)>>(
      'calendar_db_get_records_with_query');
  late final _calendar_db_get_records_with_query =
      _calendar_db_get_records_with_queryPtr.asFunction<
          int Function(
              calendar_query_h, int, int, ffi.Pointer<calendar_list_h>)>();

  /// @brief Gets the record count of a specific view.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @param[in] view_uri The view URI to get records from
  /// @param[out] count The number of records
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre This function requires an open connection to the calendar service using calendar_connect2().
  /// @see calendar_connect()
  int calendar_db_get_count(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _calendar_db_get_count(
      view_uri,
      count,
    );
  }

  late final _calendar_db_get_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('calendar_db_get_count');
  late final _calendar_db_get_count = _calendar_db_get_countPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the record count with a query handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @param[in] query The query handle used for filtering the results
  /// @param[out] count The number of records
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre This function requires an open connection to the calendar service using calendar_connect2().
  /// @see calendar_connect2()
  int calendar_db_get_count_with_query(
    calendar_query_h query,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _calendar_db_get_count_with_query(
      query,
      count,
    );
  }

  late final _calendar_db_get_count_with_queryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_query_h,
              ffi.Pointer<ffi.Int>)>>('calendar_db_get_count_with_query');
  late final _calendar_db_get_count_with_query =
      _calendar_db_get_count_with_queryPtr
          .asFunction<int Function(calendar_query_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Inserts multiple records into the calendar database as a batch operation.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] record_list The record list handle
  /// @param[out] record_id_array The array of record IDs
  /// @param[out] count The number of record IDs
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_db_update_records()
  /// @see calendar_db_delete_records()
  int calendar_db_insert_records(
    calendar_list_h record_list,
    ffi.Pointer<ffi.Pointer<ffi.Int>> record_id_array,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _calendar_db_insert_records(
      record_list,
      record_id_array,
      count,
    );
  }

  late final _calendar_db_insert_recordsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_list_h, ffi.Pointer<ffi.Pointer<ffi.Int>>,
              ffi.Pointer<ffi.Int>)>>('calendar_db_insert_records');
  late final _calendar_db_insert_records =
      _calendar_db_insert_recordsPtr.asFunction<
          int Function(calendar_list_h, ffi.Pointer<ffi.Pointer<ffi.Int>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Updates multiple records into the calendar database as a batch operation.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] record_list The record list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_DB_RECORD_NOT_FOUND Database not found
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_db_insert_records()
  /// @see calendar_db_delete_records()
  int calendar_db_update_records(
    calendar_list_h record_list,
  ) {
    return _calendar_db_update_records(
      record_list,
    );
  }

  late final _calendar_db_update_recordsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_list_h)>>(
          'calendar_db_update_records');
  late final _calendar_db_update_records = _calendar_db_update_recordsPtr
      .asFunction<int Function(calendar_list_h)>();

  /// @brief Deletes multiple records with related child records from the calendar database as a batch operation.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] view_uri The view URI of the records to delete
  /// @param[in] record_id_array The record IDs to delete
  /// @param[in] count The number of records
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_DB_RECORD_NOT_FOUND Database not found
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_db_insert_records()
  /// @see calendar_db_delete_records()
  int calendar_db_delete_records(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<ffi.Int> record_id_array,
    int count,
  ) {
    return _calendar_db_delete_records(
      view_uri,
      record_id_array,
      count,
    );
  }

  late final _calendar_db_delete_recordsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>,
              ffi.Int)>>('calendar_db_delete_records');
  late final _calendar_db_delete_records =
      _calendar_db_delete_recordsPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>, int)>();

  /// @brief Gets the current calendar database version.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @param[out] calendar_db_version The calendar database version
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_DB_RECORD_NOT_FOUND Database not found
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre This function requires an open connection to the calendar service using calendar_connect().
  /// @see calendar_connect()
  /// @see calendar_db_get_changes_by_version()
  int calendar_db_get_current_version(
    ffi.Pointer<ffi.Int> calendar_db_version,
  ) {
    return _calendar_db_get_current_version(
      calendar_db_version,
    );
  }

  late final _calendar_db_get_current_versionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'calendar_db_get_current_version');
  late final _calendar_db_get_current_version =
      _calendar_db_get_current_versionPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Registers a callback function to be invoked when a record changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @remarks If successive change notification produced on the view_uri are identical,
  /// then they are coalesced into a single notification if the older notification has not yet been called
  /// because default main loop is doing something.
  /// But it means that a callback function is not called to reliably count of change.
  /// This API supports only @ref CAPI_SOCIAL_CALENDAR_SVC_VIEW_MODULE_calendar_book view, @ref CAPI_SOCIAL_CALENDAR_SVC_VIEW_MODULE_calendar_event view,
  /// @ref CAPI_SOCIAL_CALENDAR_SVC_VIEW_MODULE_calendar_todo view.
  /// @param[in] view_uri The view URI of the record to subscribe for change notifications
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre This function requires an open connection to the calendar service using calendar_connect().
  /// @post calendar_db_changed_cb() will be invoked when the designated view changes.
  /// @see calendar_connect()
  /// @see calendar_db_changed_cb()
  /// @see calendar_db_remove_changed_cb()
  int calendar_db_add_changed_cb(
    ffi.Pointer<ffi.Char> view_uri,
    calendar_db_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _calendar_db_add_changed_cb(
      view_uri,
      callback,
      user_data,
    );
  }

  late final _calendar_db_add_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, calendar_db_changed_cb,
              ffi.Pointer<ffi.Void>)>>('calendar_db_add_changed_cb');
  late final _calendar_db_add_changed_cb =
      _calendar_db_add_changed_cbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, calendar_db_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters a callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @param[in] view_uri The view URI of the record to subscribe for change notifications
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre This function requires an open connection to the calendar service using calendar_connect().
  /// @see calendar_connect()
  /// @see calendar_db_changed_cb()
  /// @see calendar_db_add_changed_cb()
  int calendar_db_remove_changed_cb(
    ffi.Pointer<ffi.Char> view_uri,
    calendar_db_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _calendar_db_remove_changed_cb(
      view_uri,
      callback,
      user_data,
    );
  }

  late final _calendar_db_remove_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, calendar_db_changed_cb,
              ffi.Pointer<ffi.Void>)>>('calendar_db_remove_changed_cb');
  late final _calendar_db_remove_changed_cb =
      _calendar_db_remove_changed_cbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, calendar_db_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves records with the given calendar database version.
  /// @details This function finds all the changed records since the given @a calendar_db_version.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @remarks You must release @a change_record_list using calendar_list_destroy().
  /// @param[in] view_uri The view URI to get records from
  /// @param[in] calendar_book_id The calendar book ID to filter
  /// @param[in] calendar_db_version The calendar database version
  /// @param[out] record_list The record list
  /// @param[out] current_calendar_db_version The current calendar database version
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_DB_RECORD_NOT_FOUND Database not found
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_list_destroy()
  int calendar_db_get_changes_by_version(
    ffi.Pointer<ffi.Char> view_uri,
    int calendar_book_id,
    int calendar_db_version,
    ffi.Pointer<calendar_list_h> record_list,
    ffi.Pointer<ffi.Int> current_calendar_db_version,
  ) {
    return _calendar_db_get_changes_by_version(
      view_uri,
      calendar_book_id,
      calendar_db_version,
      record_list,
      current_calendar_db_version,
    );
  }

  late final _calendar_db_get_changes_by_versionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Int,
              ffi.Pointer<calendar_list_h>,
              ffi.Pointer<ffi.Int>)>>('calendar_db_get_changes_by_version');
  late final _calendar_db_get_changes_by_version =
      _calendar_db_get_changes_by_versionPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, int,
              ffi.Pointer<calendar_list_h>, ffi.Pointer<ffi.Int>)>();

  /// @brief Inserts a vcalendar stream into the calendar database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] vcalendar_stream The vcalendar stream
  /// @param[out] record_id_array The record IDs to delete
  /// @param[out] count The number of record ID arrays
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_db_replace_vcalendars()
  int calendar_db_insert_vcalendars(
    ffi.Pointer<ffi.Char> vcalendar_stream,
    ffi.Pointer<ffi.Pointer<ffi.Int>> record_id_array,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _calendar_db_insert_vcalendars(
      vcalendar_stream,
      record_id_array,
      count,
    );
  }

  late final _calendar_db_insert_vcalendarsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Int>>,
              ffi.Pointer<ffi.Int>)>>('calendar_db_insert_vcalendars');
  late final _calendar_db_insert_vcalendars =
      _calendar_db_insert_vcalendarsPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Int>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Replaces a vcalendar stream in the calendar database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] vcalendar_stream The vcalendar stream
  /// @param[in] record_id_array The record IDs to replace
  /// @param[in] count The number of record ID arrays
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_DB_RECORD_NOT_FOUND Database not found
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre This function requires an open connection to the calendar service by calendar_connect().
  /// @see calendar_connect()
  /// @see calendar_db_replace_vcalendars()
  int calendar_db_replace_vcalendars(
    ffi.Pointer<ffi.Char> vcalendar_stream,
    ffi.Pointer<ffi.Int> record_id_array,
    int count,
  ) {
    return _calendar_db_replace_vcalendars(
      vcalendar_stream,
      record_id_array,
      count,
    );
  }

  late final _calendar_db_replace_vcalendarsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>,
              ffi.Int)>>('calendar_db_replace_vcalendars');
  late final _calendar_db_replace_vcalendars =
      _calendar_db_replace_vcalendarsPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>, int)>();

  /// @brief Replaces a record in the calendar database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] record The record handle
  /// @param[in] record_id The record ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_db_update_record()
  /// @see calendar_db_delete_record()
  /// @see calendar_db_get_record()
  int calendar_db_replace_record(
    calendar_record_h record,
    int record_id,
  ) {
    return _calendar_db_replace_record(
      record,
      record_id,
    );
  }

  late final _calendar_db_replace_recordPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_record_h, ffi.Int)>>(
          'calendar_db_replace_record');
  late final _calendar_db_replace_record = _calendar_db_replace_recordPtr
      .asFunction<int Function(calendar_record_h, int)>();

  /// @brief Replaces multiple records in the calendar database as a batch operation.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] record_list The record list handle
  /// @param[in] record_id_array The record IDs
  /// @param[in] count The number of record ID arrays
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_db_update_records()
  /// @see calendar_db_delete_records()
  /// @see calendar_db_replace_record()
  int calendar_db_replace_records(
    calendar_list_h record_list,
    ffi.Pointer<ffi.Int> record_id_array,
    int count,
  ) {
    return _calendar_db_replace_records(
      record_list,
      record_id_array,
      count,
    );
  }

  late final _calendar_db_replace_recordsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_list_h, ffi.Pointer<ffi.Int>,
              ffi.Int)>>('calendar_db_replace_records');
  late final _calendar_db_replace_records = _calendar_db_replace_recordsPtr
      .asFunction<int Function(calendar_list_h, ffi.Pointer<ffi.Int>, int)>();

  /// @brief Gets the last successful change version of the database on the current connection.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @param[out] last_change_version The calendar database version on the current connection
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre This function requires an open connection to the calendar service using calendar_connect().
  /// @see calendar_connect()
  /// @see calendar_db_get_current_version()
  int calendar_db_get_last_change_version(
    ffi.Pointer<ffi.Int> last_change_version,
  ) {
    return _calendar_db_get_last_change_version(
      last_change_version,
    );
  }

  late final _calendar_db_get_last_change_versionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'calendar_db_get_last_change_version');
  late final _calendar_db_get_last_change_version =
      _calendar_db_get_last_change_versionPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Retrieves changed exception records since the given calendar database version.
  /// Exceptions are the modified or deleted instances in a recurring event.
  /// @details This function finds all the changed records since the given @a calendar_db_version.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @remarks You must release @a change_record_list using calendar_list_destroy().
  /// @param[in] view_uri The view URI to get records from
  /// @param[in] original_event_id The original event ID
  /// @param[in] calendar_db_version The calendar database version starting from which to get records
  /// @param[out] list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  /// @see calendar_list_destroy()
  int calendar_db_get_changes_exception_by_version(
    ffi.Pointer<ffi.Char> view_uri,
    int original_event_id,
    int calendar_db_version,
    ffi.Pointer<calendar_list_h> list,
  ) {
    return _calendar_db_get_changes_exception_by_version(
      view_uri,
      original_event_id,
      calendar_db_version,
      list,
    );
  }

  late final _calendar_db_get_changes_exception_by_versionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int, ffi.Int,
                  ffi.Pointer<calendar_list_h>)>>(
      'calendar_db_get_changes_exception_by_version');
  late final _calendar_db_get_changes_exception_by_version =
      _calendar_db_get_changes_exception_by_versionPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, int, int, ffi.Pointer<calendar_list_h>)>();

  /// @brief Cleans the data after sync.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] calendar_book_id The calendar book ID
  /// @param[in] calendar_db_version The calendar database version
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_NO_DATA Data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  int calendar_db_clean_after_sync(
    int calendar_book_id,
    int calendar_db_version,
  ) {
    return _calendar_db_clean_after_sync(
      calendar_book_id,
      calendar_db_version,
    );
  }

  late final _calendar_db_clean_after_syncPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'calendar_db_clean_after_sync');
  late final _calendar_db_clean_after_sync =
      _calendar_db_clean_after_syncPtr.asFunction<int Function(int, int)>();

  /// @brief Links a record to another record.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] base_id The base record ID
  /// @param[in] record_id The record ID to link to
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  int calendar_db_link_record(
    int base_id,
    int record_id,
  ) {
    return _calendar_db_link_record(
      base_id,
      record_id,
    );
  }

  late final _calendar_db_link_recordPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'calendar_db_link_record');
  late final _calendar_db_link_record =
      _calendar_db_link_recordPtr.asFunction<int Function(int, int)>();

  /// @brief Unlinks a record from base record.
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.write
  /// @param[in] record_id The record ID to unlink
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #CALENDAR_ERROR_FILE_NO_SPACE File system is full
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to open a connection to the calendar service.
  /// @see calendar_connect()
  int calendar_db_unlink_record(
    int record_id,
  ) {
    return _calendar_db_unlink_record(
      record_id,
    );
  }

  late final _calendar_db_unlink_recordPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'calendar_db_unlink_record');
  late final _calendar_db_unlink_record =
      _calendar_db_unlink_recordPtr.asFunction<int Function(int)>();

  /// @brief Creates a filter handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks You must release @a filter using calendar_filter_destroy().
  /// @param[in] view_uri The view URI of a filter
  /// @param[out] filter The filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to initialize.
  /// @see calendar_filter_destroy()
  int calendar_filter_create(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<calendar_filter_h> filter,
  ) {
    return _calendar_filter_create(
      view_uri,
      filter,
    );
  }

  late final _calendar_filter_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<calendar_filter_h>)>>('calendar_filter_create');
  late final _calendar_filter_create = _calendar_filter_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<calendar_filter_h>)>();

  /// @brief Destroys a filter handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] filter The filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_filter_create()
  int calendar_filter_destroy(
    calendar_filter_h filter,
  ) {
    return _calendar_filter_destroy(
      filter,
    );
  }

  late final _calendar_filter_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_filter_h)>>(
          'calendar_filter_destroy');
  late final _calendar_filter_destroy =
      _calendar_filter_destroyPtr.asFunction<int Function(calendar_filter_h)>();

  /// @brief Adds a condition for the string type property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] property_id The property ID to add a condition
  /// @param[in] match The match flag
  /// @param[in] match_value The match value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_filter_add_operator()
  int calendar_filter_add_str(
    calendar_filter_h filter,
    int property_id,
    int match,
    ffi.Pointer<ffi.Char> match_value,
  ) {
    return _calendar_filter_add_str(
      filter,
      property_id,
      match,
      match_value,
    );
  }

  late final _calendar_filter_add_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_filter_h, ffi.UnsignedInt, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('calendar_filter_add_str');
  late final _calendar_filter_add_str = _calendar_filter_add_strPtr.asFunction<
      int Function(calendar_filter_h, int, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Adds a condition for the integer type property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] property_id The property ID to add a condition
  /// @param[in] match The match flag
  /// @param[in] match_value The match value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_filter_add_operator()
  int calendar_filter_add_int(
    calendar_filter_h filter,
    int property_id,
    int match,
    int match_value,
  ) {
    return _calendar_filter_add_int(
      filter,
      property_id,
      match,
      match_value,
    );
  }

  late final _calendar_filter_add_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_filter_h, ffi.UnsignedInt, ffi.Int32,
              ffi.Int)>>('calendar_filter_add_int');
  late final _calendar_filter_add_int = _calendar_filter_add_intPtr
      .asFunction<int Function(calendar_filter_h, int, int, int)>();

  /// @brief Adds a condition for the double type property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] property_id The property ID to add a condition
  /// @param[in] match The match flag
  /// @param[in] match_value The match value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_filter_add_operator()
  int calendar_filter_add_double(
    calendar_filter_h filter,
    int property_id,
    int match,
    double match_value,
  ) {
    return _calendar_filter_add_double(
      filter,
      property_id,
      match,
      match_value,
    );
  }

  late final _calendar_filter_add_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_filter_h, ffi.UnsignedInt, ffi.Int32,
              ffi.Double)>>('calendar_filter_add_double');
  late final _calendar_filter_add_double = _calendar_filter_add_doublePtr
      .asFunction<int Function(calendar_filter_h, int, int, double)>();

  /// @brief Adds a condition for the long long int type property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] property_id The property ID to add a condition
  /// @param[in] match The match flag
  /// @param[in] match_value The match value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_filter_add_operator()
  int calendar_filter_add_lli(
    calendar_filter_h filter,
    int property_id,
    int match,
    int match_value,
  ) {
    return _calendar_filter_add_lli(
      filter,
      property_id,
      match,
      match_value,
    );
  }

  late final _calendar_filter_add_lliPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_filter_h, ffi.UnsignedInt, ffi.Int32,
              ffi.LongLong)>>('calendar_filter_add_lli');
  late final _calendar_filter_add_lli = _calendar_filter_add_lliPtr
      .asFunction<int Function(calendar_filter_h, int, int, int)>();

  /// @brief Adds a condition for the calendar_time_s type property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] property_id The property ID to add a condition
  /// @param[in] match The match flag
  /// @param[in] match_value The match value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_filter_add_operator()
  int calendar_filter_add_caltime(
    calendar_filter_h filter,
    int property_id,
    int match,
    calendar_time_s match_value,
  ) {
    return _calendar_filter_add_caltime(
      filter,
      property_id,
      match,
      match_value,
    );
  }

  late final _calendar_filter_add_caltimePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_filter_h, ffi.UnsignedInt, ffi.Int32,
              calendar_time_s)>>('calendar_filter_add_caltime');
  late final _calendar_filter_add_caltime = _calendar_filter_add_caltimePtr
      .asFunction<int Function(calendar_filter_h, int, int, calendar_time_s)>();

  /// @brief Adds a child filter to a parent filter.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] parent_filter The parent filter handle
  /// @param[in] child_filter The child filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_filter_add_operator()
  int calendar_filter_add_filter(
    calendar_filter_h parent_filter,
    calendar_filter_h child_filter,
  ) {
    return _calendar_filter_add_filter(
      parent_filter,
      child_filter,
    );
  }

  late final _calendar_filter_add_filterPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_filter_h,
              calendar_filter_h)>>('calendar_filter_add_filter');
  late final _calendar_filter_add_filter = _calendar_filter_add_filterPtr
      .asFunction<int Function(calendar_filter_h, calendar_filter_h)>();

  /// @brief Adds an operator between conditions.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] operator_type The operator type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_filter_add_str()
  /// @see calendar_filter_add_int()
  /// @see calendar_filter_add_double()
  /// @see calendar_filter_add_caltime()
  /// @see calendar_filter_add_filter()
  int calendar_filter_add_operator(
    calendar_filter_h filter,
    int operator_type,
  ) {
    return _calendar_filter_add_operator(
      filter,
      operator_type,
    );
  }

  late final _calendar_filter_add_operatorPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(calendar_filter_h, ffi.Int32)>>(
      'calendar_filter_add_operator');
  late final _calendar_filter_add_operator = _calendar_filter_add_operatorPtr
      .asFunction<int Function(calendar_filter_h, int)>();

  /// @brief Creates a calendar list handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks You must release @a calendar_list using calendar_list_destroy().
  /// @param[out] out_list The calendar list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_list_destroy()
  int calendar_list_create(
    ffi.Pointer<calendar_list_h> out_list,
  ) {
    return _calendar_list_create(
      out_list,
    );
  }

  late final _calendar_list_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<calendar_list_h>)>>(
      'calendar_list_create');
  late final _calendar_list_create = _calendar_list_createPtr
      .asFunction<int Function(ffi.Pointer<calendar_list_h>)>();

  /// @brief Destroys a calendar list handle and releases all its resources.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] list The calendar list handle
  /// @param[in] delete_record If @c true, child records are destroyed automatically,
  /// otherwise @c false
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_list_create()
  int calendar_list_destroy(
    calendar_list_h list,
    bool delete_record,
  ) {
    return _calendar_list_destroy(
      list,
      delete_record,
    );
  }

  late final _calendar_list_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_list_h, ffi.Bool)>>(
          'calendar_list_destroy');
  late final _calendar_list_destroy = _calendar_list_destroyPtr
      .asFunction<int Function(calendar_list_h, bool)>();

  /// @brief Retrieves the number of calendar entities in a calendar list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] list The calendar list handle
  /// @param[out] count The count of the calendar entity
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_list_add()
  int calendar_list_get_count(
    calendar_list_h list,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _calendar_list_get_count(
      list,
      count,
    );
  }

  late final _calendar_list_get_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_list_h,
              ffi.Pointer<ffi.Int>)>>('calendar_list_get_count');
  late final _calendar_list_get_count = _calendar_list_get_countPtr
      .asFunction<int Function(calendar_list_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Adds a record to the calendar list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] list The calendar list handle
  /// @param[in] record The record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_list_remove()
  int calendar_list_add(
    calendar_list_h list,
    calendar_record_h record,
  ) {
    return _calendar_list_add(
      list,
      record,
    );
  }

  late final _calendar_list_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              calendar_list_h, calendar_record_h)>>('calendar_list_add');
  late final _calendar_list_add = _calendar_list_addPtr
      .asFunction<int Function(calendar_list_h, calendar_record_h)>();

  /// @brief Removes a record from the calendar list.
  /// @details If the record is the current record, then the current record is changed to the next record.\n
  /// If the record is the last record then the current record will be @c NULL.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] list The calendar list handle
  /// @param[in] record The record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NO_DATA Requested data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_list_add()
  int calendar_list_remove(
    calendar_list_h list,
    calendar_record_h record,
  ) {
    return _calendar_list_remove(
      list,
      record,
    );
  }

  late final _calendar_list_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              calendar_list_h, calendar_record_h)>>('calendar_list_remove');
  late final _calendar_list_remove = _calendar_list_removePtr
      .asFunction<int Function(calendar_list_h, calendar_record_h)>();

  /// @brief Retrieves a record from the calendar list.
  /// @details The default current record is the first record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks You MUST NOT destroy the @a record handle.
  /// It is destroyed automatically when the @a list is destroyed.
  /// @param[in] list The calendar list handle
  /// @param[out] record The record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NO_DATA Requested data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  int calendar_list_get_current_record_p(
    calendar_list_h list,
    ffi.Pointer<calendar_record_h> record,
  ) {
    return _calendar_list_get_current_record_p(
      list,
      record,
    );
  }

  late final _calendar_list_get_current_record_pPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  calendar_list_h, ffi.Pointer<calendar_record_h>)>>(
      'calendar_list_get_current_record_p');
  late final _calendar_list_get_current_record_p =
      _calendar_list_get_current_record_pPtr.asFunction<
          int Function(calendar_list_h, ffi.Pointer<calendar_record_h>)>();

  /// @brief Moves a calendar list to the previous position.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] list The calendar list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NO_DATA Requested data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_list_next()
  int calendar_list_prev(
    calendar_list_h list,
  ) {
    return _calendar_list_prev(
      list,
    );
  }

  late final _calendar_list_prevPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_list_h)>>(
          'calendar_list_prev');
  late final _calendar_list_prev =
      _calendar_list_prevPtr.asFunction<int Function(calendar_list_h)>();

  /// @brief Moves a calendar list to the next position.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] list The calendar list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NO_DATA Requested data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_list_prev()
  int calendar_list_next(
    calendar_list_h list,
  ) {
    return _calendar_list_next(
      list,
    );
  }

  late final _calendar_list_nextPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_list_h)>>(
          'calendar_list_next');
  late final _calendar_list_next =
      _calendar_list_nextPtr.asFunction<int Function(calendar_list_h)>();

  /// @brief Moves a calendar list to the first position.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] list The calendar list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_list_last()
  int calendar_list_first(
    calendar_list_h list,
  ) {
    return _calendar_list_first(
      list,
    );
  }

  late final _calendar_list_firstPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_list_h)>>(
          'calendar_list_first');
  late final _calendar_list_first =
      _calendar_list_firstPtr.asFunction<int Function(calendar_list_h)>();

  /// @brief Moves a calendar list to the last position.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] list The calendar list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_list_first()
  int calendar_list_last(
    calendar_list_h list,
  ) {
    return _calendar_list_last(
      list,
    );
  }

  late final _calendar_list_lastPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_list_h)>>(
          'calendar_list_last');
  late final _calendar_list_last =
      _calendar_list_lastPtr.asFunction<int Function(calendar_list_h)>();

  /// @brief Creates a query handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks You must release @a query using calendar_query_destroy().
  /// @param[in] view_uri The view URI of a query
  /// @param[out] query The filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to initialize.
  /// @see calendar_query_destroy()
  int calendar_query_create(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<calendar_query_h> query,
  ) {
    return _calendar_query_create(
      view_uri,
      query,
    );
  }

  late final _calendar_query_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<calendar_query_h>)>>('calendar_query_create');
  late final _calendar_query_create = _calendar_query_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<calendar_query_h>)>();

  /// @brief Destroys a query handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] query The query handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_query_create()
  int calendar_query_destroy(
    calendar_query_h query,
  ) {
    return _calendar_query_destroy(
      query,
    );
  }

  late final _calendar_query_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_query_h)>>(
          'calendar_query_destroy');
  late final _calendar_query_destroy =
      _calendar_query_destroyPtr.asFunction<int Function(calendar_query_h)>();

  /// @brief Adds property IDs for projection.
  /// @details Property IDs can be of one of the properties of view_uri which is used in calendar_query_create().
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] query The query handle
  /// @param[in] property_id_array The property ID array
  /// @param[in] count The number of property IDs
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  int calendar_query_set_projection(
    calendar_query_h query,
    ffi.Pointer<ffi.UnsignedInt> property_id_array,
    int count,
  ) {
    return _calendar_query_set_projection(
      query,
      property_id_array,
      count,
    );
  }

  late final _calendar_query_set_projectionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_query_h, ffi.Pointer<ffi.UnsignedInt>,
              ffi.Int)>>('calendar_query_set_projection');
  late final _calendar_query_set_projection =
      _calendar_query_set_projectionPtr.asFunction<
          int Function(calendar_query_h, ffi.Pointer<ffi.UnsignedInt>, int)>();

  /// @brief Sets the "distinct" option for projection.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] query The query handle
  /// @param[in] set If @c true it is set,
  /// otherwise if @c false it is unset
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  int calendar_query_set_distinct(
    calendar_query_h query,
    bool set1,
  ) {
    return _calendar_query_set_distinct(
      query,
      set1,
    );
  }

  late final _calendar_query_set_distinctPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(calendar_query_h, ffi.Bool)>>(
          'calendar_query_set_distinct');
  late final _calendar_query_set_distinct = _calendar_query_set_distinctPtr
      .asFunction<int Function(calendar_query_h, bool)>();

  /// @brief Sets the filter for a query.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] query The query handle
  /// @param[in] filter The filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NO_DATA Requested data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_query_add_operator()
  int calendar_query_set_filter(
    calendar_query_h query,
    calendar_filter_h filter,
  ) {
    return _calendar_query_set_filter(
      query,
      filter,
    );
  }

  late final _calendar_query_set_filterPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_query_h,
              calendar_filter_h)>>('calendar_query_set_filter');
  late final _calendar_query_set_filter = _calendar_query_set_filterPtr
      .asFunction<int Function(calendar_query_h, calendar_filter_h)>();

  /// @brief Sets the sort mode for a query.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] query The query handle
  /// @param[in] property_id The property ID to sort
  /// @param[in] is_ascending If @c true it sorts in the ascending order,
  /// otherwise if @c false it sorts in the descending order
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  int calendar_query_set_sort(
    calendar_query_h query,
    int property_id,
    bool is_ascending,
  ) {
    return _calendar_query_set_sort(
      query,
      property_id,
      is_ascending,
    );
  }

  late final _calendar_query_set_sortPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_query_h, ffi.UnsignedInt,
              ffi.Bool)>>('calendar_query_set_sort');
  late final _calendar_query_set_sort = _calendar_query_set_sortPtr
      .asFunction<int Function(calendar_query_h, int, bool)>();

  /// @brief Creates a record handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks You must release @a record using calendar_record_destroy().
  /// @param[in] view_uri The view URI
  /// @param[out] out_record The record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to initialize.
  /// @see calendar_record_destroy()
  int calendar_record_create(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<calendar_record_h> out_record,
  ) {
    return _calendar_record_create(
      view_uri,
      out_record,
    );
  }

  late final _calendar_record_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<calendar_record_h>)>>('calendar_record_create');
  late final _calendar_record_create = _calendar_record_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<calendar_record_h>)>();

  /// @brief Destroys a record handle and releases all its resources.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[in] delete_child If @c true, child records are destroyed automatically,
  /// otherwise @c false
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_create()
  int calendar_record_destroy(
    calendar_record_h record,
    bool delete_child,
  ) {
    return _calendar_record_destroy(
      record,
      delete_child,
    );
  }

  late final _calendar_record_destroyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(calendar_record_h, ffi.Bool)>>(
      'calendar_record_destroy');
  late final _calendar_record_destroy = _calendar_record_destroyPtr
      .asFunction<int Function(calendar_record_h, bool)>();

  /// @brief Makes a clone of a record handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks You must release @a cloned_record using calendar_record_destroy().
  /// @param[in] record The record handle
  /// @param[out] out_record The cloned record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_destroy()
  int calendar_record_clone(
    calendar_record_h record,
    ffi.Pointer<calendar_record_h> out_record,
  ) {
    return _calendar_record_clone(
      record,
      out_record,
    );
  }

  late final _calendar_record_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h,
              ffi.Pointer<calendar_record_h>)>>('calendar_record_clone');
  late final _calendar_record_clone = _calendar_record_clonePtr.asFunction<
      int Function(calendar_record_h, ffi.Pointer<calendar_record_h>)>();

  /// @brief Gets a URI string from a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[out] uri The URI of the record
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  int calendar_record_get_uri_p(
    calendar_record_h record,
    ffi.Pointer<ffi.Pointer<ffi.Char>> uri,
  ) {
    return _calendar_record_get_uri_p(
      record,
      uri,
    );
  }

  late final _calendar_record_get_uri_pPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  calendar_record_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'calendar_record_get_uri_p');
  late final _calendar_record_get_uri_p =
      _calendar_record_get_uri_pPtr.asFunction<
          int Function(
              calendar_record_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets a string from a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks You must release @a value using free().
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] out_str The result value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_get_str_p()
  /// @see calendar_record_set_str()
  int calendar_record_get_str(
    calendar_record_h record,
    int property_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> out_str,
  ) {
    return _calendar_record_get_str(
      record,
      property_id,
      out_str,
    );
  }

  late final _calendar_record_get_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('calendar_record_get_str');
  late final _calendar_record_get_str = _calendar_record_get_strPtr.asFunction<
      int Function(
          calendar_record_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets a string pointer from a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks You MUST NOT release @a value.
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] out_str The result value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_get_str()
  /// @see calendar_record_set_str()
  int calendar_record_get_str_p(
    calendar_record_h record,
    int property_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> out_str,
  ) {
    return _calendar_record_get_str_p(
      record,
      property_id,
      out_str,
    );
  }

  late final _calendar_record_get_str_pPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'calendar_record_get_str_p');
  late final _calendar_record_get_str_p =
      _calendar_record_get_str_pPtr.asFunction<
          int Function(
              calendar_record_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets an integer value from a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] out_value The result value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_set_int()
  int calendar_record_get_int(
    calendar_record_h record,
    int property_id,
    ffi.Pointer<ffi.Int> out_value,
  ) {
    return _calendar_record_get_int(
      record,
      property_id,
      out_value,
    );
  }

  late final _calendar_record_get_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Int>)>>('calendar_record_get_int');
  late final _calendar_record_get_int = _calendar_record_get_intPtr
      .asFunction<int Function(calendar_record_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets a double value from a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] out_value The result value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_set_double()
  int calendar_record_get_double(
    calendar_record_h record,
    int property_id,
    ffi.Pointer<ffi.Double> out_value,
  ) {
    return _calendar_record_get_double(
      record,
      property_id,
      out_value,
    );
  }

  late final _calendar_record_get_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Double>)>>('calendar_record_get_double');
  late final _calendar_record_get_double =
      _calendar_record_get_doublePtr.asFunction<
          int Function(calendar_record_h, int, ffi.Pointer<ffi.Double>)>();

  /// @brief Gets a long long integer value from a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] out_value The result value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_set_lli()
  int calendar_record_get_lli(
    calendar_record_h record,
    int property_id,
    ffi.Pointer<ffi.LongLong> out_value,
  ) {
    return _calendar_record_get_lli(
      record,
      property_id,
      out_value,
    );
  }

  late final _calendar_record_get_lliPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.LongLong>)>>('calendar_record_get_lli');
  late final _calendar_record_get_lli = _calendar_record_get_lliPtr.asFunction<
      int Function(calendar_record_h, int, ffi.Pointer<ffi.LongLong>)>();

  /// @brief Gets a calendar_caltime_s value from a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] out_value The result value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_set_caltime()
  int calendar_record_get_caltime(
    calendar_record_h record,
    int property_id,
    ffi.Pointer<calendar_time_s> out_value,
  ) {
    return _calendar_record_get_caltime(
      record,
      property_id,
      out_value,
    );
  }

  late final _calendar_record_get_caltimePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              ffi.Pointer<calendar_time_s>)>>('calendar_record_get_caltime');
  late final _calendar_record_get_caltime =
      _calendar_record_get_caltimePtr.asFunction<
          int Function(calendar_record_h, int, ffi.Pointer<calendar_time_s>)>();

  /// @brief Sets a string to a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] value The value to be set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_get_str()
  /// @see calendar_record_get_str_p()
  int calendar_record_set_str(
    calendar_record_h record,
    int property_id,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _calendar_record_set_str(
      record,
      property_id,
      value,
    );
  }

  late final _calendar_record_set_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Char>)>>('calendar_record_set_str');
  late final _calendar_record_set_str = _calendar_record_set_strPtr.asFunction<
      int Function(calendar_record_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets an integer value to a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] value The value to be set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_get_int()
  int calendar_record_set_int(
    calendar_record_h record,
    int property_id,
    int value,
  ) {
    return _calendar_record_set_int(
      record,
      property_id,
      value,
    );
  }

  late final _calendar_record_set_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              ffi.Int)>>('calendar_record_set_int');
  late final _calendar_record_set_int = _calendar_record_set_intPtr
      .asFunction<int Function(calendar_record_h, int, int)>();

  /// @brief Sets a double value to a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] value The value to be set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_get_double()
  int calendar_record_set_double(
    calendar_record_h record,
    int property_id,
    double value,
  ) {
    return _calendar_record_set_double(
      record,
      property_id,
      value,
    );
  }

  late final _calendar_record_set_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              ffi.Double)>>('calendar_record_set_double');
  late final _calendar_record_set_double = _calendar_record_set_doublePtr
      .asFunction<int Function(calendar_record_h, int, double)>();

  /// @brief Sets a long long integer value to a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] value The value to be set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_get_lli()
  int calendar_record_set_lli(
    calendar_record_h record,
    int property_id,
    int value,
  ) {
    return _calendar_record_set_lli(
      record,
      property_id,
      value,
    );
  }

  late final _calendar_record_set_lliPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              ffi.LongLong)>>('calendar_record_set_lli');
  late final _calendar_record_set_lli = _calendar_record_set_lliPtr
      .asFunction<int Function(calendar_record_h, int, int)>();

  /// @brief Sets a calendar_time_s value to a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] value The value to be set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_get_caltime()
  int calendar_record_set_caltime(
    calendar_record_h record,
    int property_id,
    calendar_time_s value,
  ) {
    return _calendar_record_set_caltime(
      record,
      property_id,
      value,
    );
  }

  late final _calendar_record_set_caltimePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              calendar_time_s)>>('calendar_record_set_caltime');
  late final _calendar_record_set_caltime = _calendar_record_set_caltimePtr
      .asFunction<int Function(calendar_record_h, int, calendar_time_s)>();

  /// @brief Adds a child record to the parent record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The parent record handle
  /// @param[in] property_id The property ID
  /// @param[in] child_record The handle of the child record to be added to the parent record
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_remove_child_record()
  int calendar_record_add_child_record(
    calendar_record_h record,
    int property_id,
    calendar_record_h child_record,
  ) {
    return _calendar_record_add_child_record(
      record,
      property_id,
      child_record,
    );
  }

  late final _calendar_record_add_child_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              calendar_record_h)>>('calendar_record_add_child_record');
  late final _calendar_record_add_child_record =
      _calendar_record_add_child_recordPtr.asFunction<
          int Function(calendar_record_h, int, calendar_record_h)>();

  /// @brief Removes a child record from the parent record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The parent record handle
  /// @param[in] property_id The property ID
  /// @param[in] child_record The handle of the child record to be removed from the parent record
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_add_child_record()
  int calendar_record_remove_child_record(
    calendar_record_h record,
    int property_id,
    calendar_record_h child_record,
  ) {
    return _calendar_record_remove_child_record(
      record,
      property_id,
      child_record,
    );
  }

  late final _calendar_record_remove_child_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
              calendar_record_h)>>('calendar_record_remove_child_record');
  late final _calendar_record_remove_child_record =
      _calendar_record_remove_child_recordPtr.asFunction<
          int Function(calendar_record_h, int, calendar_record_h)>();

  /// @brief Gets the number of child records in a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] record The parent record handle
  /// @param[in] property_id The property ID
  /// @param[out] count The child record count
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_add_child_record()
  /// @see calendar_record_remove_child_record()
  int calendar_record_get_child_record_count(
    calendar_record_h record,
    int property_id,
    ffi.Pointer<ffi.UnsignedInt> count,
  ) {
    return _calendar_record_get_child_record_count(
      record,
      property_id,
      count,
    );
  }

  late final _calendar_record_get_child_record_countPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
                  ffi.Pointer<ffi.UnsignedInt>)>>(
      'calendar_record_get_child_record_count');
  late final _calendar_record_get_child_record_count =
      _calendar_record_get_child_record_countPtr.asFunction<
          int Function(calendar_record_h, int, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets a child record handle pointer from the parent record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks You MUST NOT release @a child_record. \n
  /// It is released when the parent record handle is destroyed.
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] index The index of the child record
  /// @param[out] child_record The child record handle pointer
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_record_add_child_record()
  /// @see calendar_record_remove_child_record()
  /// @see calendar_record_get_child_record_count()
  int calendar_record_get_child_record_at_p(
    calendar_record_h record,
    int property_id,
    int index,
    ffi.Pointer<calendar_record_h> child_record,
  ) {
    return _calendar_record_get_child_record_at_p(
      record,
      property_id,
      index,
      child_record,
    );
  }

  late final _calendar_record_get_child_record_at_pPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(calendar_record_h, ffi.UnsignedInt, ffi.Int,
                  ffi.Pointer<calendar_record_h>)>>(
      'calendar_record_get_child_record_at_p');
  late final _calendar_record_get_child_record_at_p =
      _calendar_record_get_child_record_at_pPtr.asFunction<
          int Function(
              calendar_record_h, int, int, ffi.Pointer<calendar_record_h>)>();

  /// @brief Makes a clone of a given record's child record list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks You must release @a cloned_list using calendar_list_destroy().
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] out_list The cloned list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_list_destroy()
  int calendar_record_clone_child_record_list(
    calendar_record_h record,
    int property_id,
    ffi.Pointer<calendar_list_h> out_list,
  ) {
    return _calendar_record_clone_child_record_list(
      record,
      property_id,
      out_list,
    );
  }

  late final _calendar_record_clone_child_record_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(calendar_record_h, ffi.UnsignedInt,
                  ffi.Pointer<calendar_list_h>)>>(
      'calendar_record_clone_child_record_list');
  late final _calendar_record_clone_child_record_list =
      _calendar_record_clone_child_record_listPtr.asFunction<
          int Function(calendar_record_h, int, ffi.Pointer<calendar_list_h>)>();

  /// @brief Connects to the calendar service.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks Opening the connection is necessary to access the calendar database and perform operations such as fetching, inserting, or updating records.\n
  /// The execution of calendar_connect() and calendar_disconnect() could slow down your application, so you are recommended not to call them frequently.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see  calendar_disconnect()
  int calendar_connect() {
    return _calendar_connect();
  }

  late final _calendar_connectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('calendar_connect');
  late final _calendar_connect =
      _calendar_connectPtr.asFunction<int Function()>();

  /// @brief Disconnects from the calendar service.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks If there is no open connection, this function returns #CALENDAR_ERROR_DB_FAILED.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_connect()
  int calendar_disconnect() {
    return _calendar_disconnect();
  }

  late final _calendar_disconnectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('calendar_disconnect');
  late final _calendar_disconnect =
      _calendar_disconnectPtr.asFunction<int Function()>();

  /// @brief Connects to the calendar service on a thread.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks Opening a connection is necessary to access the calendar database and perform operations such as fetching, inserting, or updating records.\n
  /// On a thread environment with calendar_connect(), request in one thread could fail, while another request connection is working in the other thread.
  /// To prevent request failure, calendar_connect_on_thread() is recommended.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see  calendar_disconnect_on_thread()
  int calendar_connect_on_thread() {
    return _calendar_connect_on_thread();
  }

  late final _calendar_connect_on_threadPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'calendar_connect_on_thread');
  late final _calendar_connect_on_thread =
      _calendar_connect_on_threadPtr.asFunction<int Function()>();

  /// @brief Disconnects from the calendar service on a thread.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks If there is no open connection, this function returns #CALENDAR_ERROR_DB_FAILED.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_connect_on_thread()
  int calendar_disconnect_on_thread() {
    return _calendar_disconnect_on_thread();
  }

  late final _calendar_disconnect_on_threadPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'calendar_disconnect_on_thread');
  late final _calendar_disconnect_on_thread =
      _calendar_disconnect_on_threadPtr.asFunction<int Function()>();

  /// @brief Connects to the calendar service.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @remarks Opening a connection is necessary to access the calendar database and perform operations such as fetching, inserting, or updating records.\n
  /// Before the calendar-service daemon is ready, if you call calendar_connect(), it could fail.
  /// It is recommended to call this API with #CALENDAR_CONNECT_FLAG_RETRY flags in such a situation.
  /// @param[in] flags calendar_connect_flag
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see  calendar_disconnect(), CALENDAR_CONNECT_FLAG_RETRY
  int calendar_connect_with_flags(
    int flags,
  ) {
    return _calendar_connect_with_flags(
      flags,
    );
  }

  late final _calendar_connect_with_flagsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.UnsignedInt)>>(
          'calendar_connect_with_flags');
  late final _calendar_connect_with_flags =
      _calendar_connect_with_flagsPtr.asFunction<int Function(int)>();

  /// @brief Retrieves a vcalendar stream from a calendar list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] calendar_list The calendar list handle
  /// @param[out] vcalendar_stream The vcalendar stream
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NO_DATA Requested data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  int calendar_vcalendar_make_from_records(
    calendar_list_h calendar_list,
    ffi.Pointer<ffi.Pointer<ffi.Char>> vcalendar_stream,
  ) {
    return _calendar_vcalendar_make_from_records(
      calendar_list,
      vcalendar_stream,
    );
  }

  late final _calendar_vcalendar_make_from_recordsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  calendar_list_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'calendar_vcalendar_make_from_records');
  late final _calendar_vcalendar_make_from_records =
      _calendar_vcalendar_make_from_recordsPtr.asFunction<
          int Function(calendar_list_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Retrieves all calendars from a vcalendar stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] vcalendar_stream The vcalendar stream
  /// @param[out] calendar_list The calendar list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_NO_DATA Requested data does not exist
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to initialize.
  int calendar_vcalendar_parse_to_calendar(
    ffi.Pointer<ffi.Char> vcalendar_stream,
    ffi.Pointer<calendar_list_h> calendar_list,
  ) {
    return _calendar_vcalendar_parse_to_calendar(
      vcalendar_stream,
      calendar_list,
    );
  }

  late final _calendar_vcalendar_parse_to_calendarPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<calendar_list_h>)>>(
      'calendar_vcalendar_parse_to_calendar');
  late final _calendar_vcalendar_parse_to_calendar =
      _calendar_vcalendar_parse_to_calendarPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<calendar_list_h>)>();

  /// @brief Retrieves all events or to-dos
  /// (\ref CAPI_SOCIAL_CALENDAR_SVC_VIEW_MODULE_calendar_event or \ref CAPI_SOCIAL_CALENDAR_SVC_VIEW_MODULE_calendar_todo) from a vCalendar file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] vcalendar_file_path The file path of the vCalendar stream file
  /// @param[in] callback The callback function to be invoked
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @pre calendar_connect() should be called to initialize.
  /// @post This function invokes calendar_vcalendar_parse_cb().
  /// @see  calendar_vcalendar_parse_cb()
  /// @see  calendar_record_get_uri_p()
  int calendar_vcalendar_parse_to_calendar_foreach(
    ffi.Pointer<ffi.Char> vcalendar_file_path,
    calendar_vcalendar_parse_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _calendar_vcalendar_parse_to_calendar_foreach(
      vcalendar_file_path,
      callback,
      user_data,
    );
  }

  late final _calendar_vcalendar_parse_to_calendar_foreachPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>,
                  calendar_vcalendar_parse_cb, ffi.Pointer<ffi.Void>)>>(
      'calendar_vcalendar_parse_to_calendar_foreach');
  late final _calendar_vcalendar_parse_to_calendar_foreach =
      _calendar_vcalendar_parse_to_calendar_foreachPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, calendar_vcalendar_parse_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Adds a callback to get a notification when an alarm gives an alert.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/calendar.read
  /// @param[in] callback The callback to be added
  /// @param[in] user_data The user data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CALENDAR_ERROR_NOT_PERMITTED Operation not permitted
  /// @retval #CALENDAR_ERROR_IPC Unknown IPC error
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_reminder_remove_cb()
  int calendar_reminder_add_cb(
    calendar_reminder_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _calendar_reminder_add_cb(
      callback,
      user_data,
    );
  }

  late final _calendar_reminder_add_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_reminder_cb,
              ffi.Pointer<ffi.Void>)>>('calendar_reminder_add_cb');
  late final _calendar_reminder_add_cb = _calendar_reminder_add_cbPtr
      .asFunction<int Function(calendar_reminder_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Removes a callback to get a notification when an alarm gives an alert.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
  /// @param[in] callback The callback to be removed
  /// @param[in] user_data The user data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CALENDAR_ERROR_NONE Successful
  /// @retval #CALENDAR_ERROR_DB_FAILED Database operation failure
  /// @retval #CALENDAR_ERROR_SYSTEM Internal system module error
  /// @retval #CALENDAR_ERROR_NOT_SUPPORTED Not supported
  /// @see calendar_reminder_add_cb()
  int calendar_reminder_remove_cb(
    calendar_reminder_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _calendar_reminder_remove_cb(
      callback,
      user_data,
    );
  }

  late final _calendar_reminder_remove_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(calendar_reminder_cb,
              ffi.Pointer<ffi.Void>)>>('calendar_reminder_remove_cb');
  late final _calendar_reminder_remove_cb = _calendar_reminder_remove_cbPtr
      .asFunction<int Function(calendar_reminder_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Connects to the contacts service.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks Connection opening is necessary to access the contacts server such as fetching, inserting, or updating records.\n
  /// The execution of contacts_connect() and contacts_disconnect() could slow down your application. So it is not recommended to call them frequently.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM System error
  /// @retval #CONTACTS_ERROR_INTERNAL Internal error
  /// @see contacts_disconnect()
  int contacts_connect() {
    return _contacts_connect();
  }

  late final _contacts_connectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('contacts_connect');
  late final _contacts_connect =
      _contacts_connectPtr.asFunction<int Function()>();

  /// @brief Disconnects from the contacts service.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks If there is no opened connection, this function returns #CONTACTS_ERROR_DB.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM System error
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @see contacts_connect()
  int contacts_disconnect() {
    return _contacts_disconnect();
  }

  late final _contacts_disconnectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('contacts_disconnect');
  late final _contacts_disconnect =
      _contacts_disconnectPtr.asFunction<int Function()>();

  /// @brief Connects to the contacts service with a connection on another thread.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks Opening connection is necessary to access the contact server and to perform operations such as fetching, inserting, or updating records.\n
  /// On multiple thread environment with contacts_connect(), request can be failed in one thread, while another request is working by the connection in the other thread.
  /// To prevent request fail, contacts_connect_on_thread() is recommended. Then new connection is set for the thread.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM System error
  /// @retval #CONTACTS_ERROR_INTERNAL Internal error
  /// @see contacts_disconnect_on_thread()
  int contacts_connect_on_thread() {
    return _contacts_connect_on_thread();
  }

  late final _contacts_connect_on_threadPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'contacts_connect_on_thread');
  late final _contacts_connect_on_thread =
      _contacts_connect_on_threadPtr.asFunction<int Function()>();

  /// @brief Disconnects from the contacts service.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks If there is no opened connection, this function returns #CONTACTS_ERROR_DB.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM System error
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @see contacts_connect_on_thread()
  int contacts_disconnect_on_thread() {
    return _contacts_disconnect_on_thread();
  }

  late final _contacts_disconnect_on_threadPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'contacts_disconnect_on_thread');
  late final _contacts_disconnect_on_thread =
      _contacts_disconnect_on_threadPtr.asFunction<int Function()>();

  /// @brief Connects to the contacts service.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] flags	Connection flag
  /// @remarks Connection opening is necessary to access the contacts server such as fetching, inserting, or updating records.\n
  /// Before contacts-service daemon is ready, if you call contacts_connect(), it will fail.
  /// To prevent it, if you call this API with @ref CONTACTS_CONNECT_FLAG_RETRY flags, it will retry several time.\n
  /// To close the connection, contacts_disconnect() should be called.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM System error
  /// @retval #CONTACTS_ERROR_INTERNAL Internal error
  /// @see contacts_disconnect()
  int contacts_connect_with_flags(
    int flags,
  ) {
    return _contacts_connect_with_flags(
      flags,
    );
  }

  late final _contacts_connect_with_flagsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.UnsignedInt)>>(
          'contacts_connect_with_flags');
  late final _contacts_connect_with_flags =
      _contacts_connect_with_flagsPtr.asFunction<int Function(int)>();

  late final ffi.Pointer<_contacts_address_book_property_ids>
      __contacts_address_book =
      _lookup<_contacts_address_book_property_ids>('_contacts_address_book');

  _contacts_address_book_property_ids get _contacts_address_book =>
      __contacts_address_book.ref;

  late final ffi.Pointer<_contacts_group_property_ids> __contacts_group =
      _lookup<_contacts_group_property_ids>('_contacts_group');

  _contacts_group_property_ids get _contacts_group => __contacts_group.ref;

  late final ffi.Pointer<_contacts_person_property_ids> __contacts_person =
      _lookup<_contacts_person_property_ids>('_contacts_person');

  _contacts_person_property_ids get _contacts_person => __contacts_person.ref;

  late final ffi.Pointer<_contacts_simple_contact_property_ids>
      __contacts_simple_contact =
      _lookup<_contacts_simple_contact_property_ids>(
          '_contacts_simple_contact');

  _contacts_simple_contact_property_ids get _contacts_simple_contact =>
      __contacts_simple_contact.ref;

  late final ffi.Pointer<_contacts_contact_property_ids> __contacts_contact =
      _lookup<_contacts_contact_property_ids>('_contacts_contact');

  _contacts_contact_property_ids get _contacts_contact =>
      __contacts_contact.ref;

  late final ffi.Pointer<_contacts_my_profile_property_ids>
      __contacts_my_profile =
      _lookup<_contacts_my_profile_property_ids>('_contacts_my_profile');

  _contacts_my_profile_property_ids get _contacts_my_profile =>
      __contacts_my_profile.ref;

  late final ffi.Pointer<_contacts_name_property_ids> __contacts_name =
      _lookup<_contacts_name_property_ids>('_contacts_name');

  _contacts_name_property_ids get _contacts_name => __contacts_name.ref;

  late final ffi.Pointer<_contacts_number_property_ids> __contacts_number =
      _lookup<_contacts_number_property_ids>('_contacts_number');

  _contacts_number_property_ids get _contacts_number => __contacts_number.ref;

  late final ffi.Pointer<_contacts_email_property_ids> __contacts_email =
      _lookup<_contacts_email_property_ids>('_contacts_email');

  _contacts_email_property_ids get _contacts_email => __contacts_email.ref;

  late final ffi.Pointer<_contacts_address_property_ids> __contacts_address =
      _lookup<_contacts_address_property_ids>('_contacts_address');

  _contacts_address_property_ids get _contacts_address =>
      __contacts_address.ref;

  late final ffi.Pointer<_contacts_note_property_ids> __contacts_note =
      _lookup<_contacts_note_property_ids>('_contacts_note');

  _contacts_note_property_ids get _contacts_note => __contacts_note.ref;

  late final ffi.Pointer<_contacts_url_property_ids> __contacts_url =
      _lookup<_contacts_url_property_ids>('_contacts_url');

  _contacts_url_property_ids get _contacts_url => __contacts_url.ref;

  late final ffi.Pointer<_contacts_event_property_ids> __contacts_event =
      _lookup<_contacts_event_property_ids>('_contacts_event');

  _contacts_event_property_ids get _contacts_event => __contacts_event.ref;

  late final ffi.Pointer<_contacts_group_relation_property_ids>
      __contacts_group_relation =
      _lookup<_contacts_group_relation_property_ids>(
          '_contacts_group_relation');

  _contacts_group_relation_property_ids get _contacts_group_relation =>
      __contacts_group_relation.ref;

  late final ffi.Pointer<_contacts_relationship_property_ids>
      __contacts_relationship =
      _lookup<_contacts_relationship_property_ids>('_contacts_relationship');

  _contacts_relationship_property_ids get _contacts_relationship =>
      __contacts_relationship.ref;

  late final ffi.Pointer<_contacts_image_property_ids> __contacts_image =
      _lookup<_contacts_image_property_ids>('_contacts_image');

  _contacts_image_property_ids get _contacts_image => __contacts_image.ref;

  late final ffi.Pointer<_contacts_company_property_ids> __contacts_company =
      _lookup<_contacts_company_property_ids>('_contacts_company');

  _contacts_company_property_ids get _contacts_company =>
      __contacts_company.ref;

  late final ffi.Pointer<_contacts_nickname_property_ids> __contacts_nickname =
      _lookup<_contacts_nickname_property_ids>('_contacts_nickname');

  _contacts_nickname_property_ids get _contacts_nickname =>
      __contacts_nickname.ref;

  late final ffi.Pointer<_contacts_messenger_property_ids>
      __contacts_messenger =
      _lookup<_contacts_messenger_property_ids>('_contacts_messenger');

  _contacts_messenger_property_ids get _contacts_messenger =>
      __contacts_messenger.ref;

  late final ffi.Pointer<_contacts_extension_property_ids>
      __contacts_extension =
      _lookup<_contacts_extension_property_ids>('_contacts_extension');

  _contacts_extension_property_ids get _contacts_extension =>
      __contacts_extension.ref;

  late final ffi.Pointer<_contacts_sdn_property_ids> __contacts_sdn =
      _lookup<_contacts_sdn_property_ids>('_contacts_sdn');

  _contacts_sdn_property_ids get _contacts_sdn => __contacts_sdn.ref;

  late final ffi.Pointer<_contacts_profile_property_ids> __contacts_profile =
      _lookup<_contacts_profile_property_ids>('_contacts_profile');

  _contacts_profile_property_ids get _contacts_profile =>
      __contacts_profile.ref;

  late final ffi.Pointer<_contacts_activity_photo_property_ids>
      __contacts_activity_photo =
      _lookup<_contacts_activity_photo_property_ids>(
          '_contacts_activity_photo');

  _contacts_activity_photo_property_ids get _contacts_activity_photo =>
      __contacts_activity_photo.ref;

  late final ffi.Pointer<_contacts_activity_property_ids> __contacts_activity =
      _lookup<_contacts_activity_property_ids>('_contacts_activity');

  _contacts_activity_property_ids get _contacts_activity =>
      __contacts_activity.ref;

  late final ffi.Pointer<_contacts_speeddial_property_ids>
      __contacts_speeddial =
      _lookup<_contacts_speeddial_property_ids>('_contacts_speeddial');

  _contacts_speeddial_property_ids get _contacts_speeddial =>
      __contacts_speeddial.ref;

  late final ffi.Pointer<_contacts_phone_log_property_ids>
      __contacts_phone_log =
      _lookup<_contacts_phone_log_property_ids>('_contacts_phone_log');

  _contacts_phone_log_property_ids get _contacts_phone_log =>
      __contacts_phone_log.ref;

  late final ffi.Pointer<_contacts_contact_updated_info_property_ids>
      __contacts_contact_updated_info =
      _lookup<_contacts_contact_updated_info_property_ids>(
          '_contacts_contact_updated_info');

  _contacts_contact_updated_info_property_ids
      get _contacts_contact_updated_info => __contacts_contact_updated_info.ref;

  late final ffi.Pointer<_contacts_my_profile_updated_info_property_ids>
      __contacts_my_profile_updated_info =
      _lookup<_contacts_my_profile_updated_info_property_ids>(
          '_contacts_my_profile_updated_info');

  _contacts_my_profile_updated_info_property_ids
      get _contacts_my_profile_updated_info =>
          __contacts_my_profile_updated_info.ref;

  late final ffi.Pointer<_contacts_group_updated_info_property_ids>
      __contacts_group_updated_info =
      _lookup<_contacts_group_updated_info_property_ids>(
          '_contacts_group_updated_info');

  _contacts_group_updated_info_property_ids get _contacts_group_updated_info =>
      __contacts_group_updated_info.ref;

  late final ffi.Pointer<_contacts_group_member_updated_info_property_ids>
      __contacts_group_member_updated_info =
      _lookup<_contacts_group_member_updated_info_property_ids>(
          '_contacts_group_member_updated_info');

  _contacts_group_member_updated_info_property_ids
      get _contacts_group_member_updated_info =>
          __contacts_group_member_updated_info.ref;

  late final ffi.Pointer<_contacts_grouprel_updated_info_property_ids>
      __contacts_grouprel_updated_info =
      _lookup<_contacts_grouprel_updated_info_property_ids>(
          '_contacts_grouprel_updated_info');

  _contacts_grouprel_updated_info_property_ids
      get _contacts_grouprel_updated_info =>
          __contacts_grouprel_updated_info.ref;

  late final ffi.Pointer<_contacts_person_contact_property_ids>
      __contacts_person_contact =
      _lookup<_contacts_person_contact_property_ids>(
          '_contacts_person_contact');

  _contacts_person_contact_property_ids get _contacts_person_contact =>
      __contacts_person_contact.ref;

  late final ffi.Pointer<_contacts_person_number_property_ids>
      __contacts_person_number =
      _lookup<_contacts_person_number_property_ids>('_contacts_person_number');

  _contacts_person_number_property_ids get _contacts_person_number =>
      __contacts_person_number.ref;

  late final ffi.Pointer<_contacts_person_email_property_ids>
      __contacts_person_email =
      _lookup<_contacts_person_email_property_ids>('_contacts_person_email');

  _contacts_person_email_property_ids get _contacts_person_email =>
      __contacts_person_email.ref;

  late final ffi.Pointer<_contacts_person_grouprel_property_ids>
      __contacts_person_grouprel =
      _lookup<_contacts_person_grouprel_property_ids>(
          '_contacts_person_grouprel');

  _contacts_person_grouprel_property_ids get _contacts_person_grouprel =>
      __contacts_person_grouprel.ref;

  late final ffi.Pointer<_contacts_person_group_assigned_property_ids>
      __contacts_person_group_assigned =
      _lookup<_contacts_person_group_assigned_property_ids>(
          '_contacts_person_group_assigned');

  _contacts_person_group_assigned_property_ids
      get _contacts_person_group_assigned =>
          __contacts_person_group_assigned.ref;

  late final ffi.Pointer<_contacts_person_group_not_assigned_property_ids>
      __contacts_person_group_not_assigned =
      _lookup<_contacts_person_group_not_assigned_property_ids>(
          '_contacts_person_group_not_assigned');

  _contacts_person_group_not_assigned_property_ids
      get _contacts_person_group_not_assigned =>
          __contacts_person_group_not_assigned.ref;

  late final ffi.Pointer<_contacts_person_phone_log_property_ids>
      __contacts_person_phone_log =
      _lookup<_contacts_person_phone_log_property_ids>(
          '_contacts_person_phone_log');

  _contacts_person_phone_log_property_ids get _contacts_person_phone_log =>
      __contacts_person_phone_log.ref;

  late final ffi.Pointer<_contacts_person_usage_property_ids>
      __contacts_person_usage =
      _lookup<_contacts_person_usage_property_ids>('_contacts_person_usage');

  _contacts_person_usage_property_ids get _contacts_person_usage =>
      __contacts_person_usage.ref;

  late final ffi.Pointer<_contacts_contact_number_property_ids>
      __contacts_contact_number =
      _lookup<_contacts_contact_number_property_ids>(
          '_contacts_contact_number');

  _contacts_contact_number_property_ids get _contacts_contact_number =>
      __contacts_contact_number.ref;

  late final ffi.Pointer<_contacts_contact_email_property_ids>
      __contacts_contact_email =
      _lookup<_contacts_contact_email_property_ids>('_contacts_contact_email');

  _contacts_contact_email_property_ids get _contacts_contact_email =>
      __contacts_contact_email.ref;

  late final ffi.Pointer<_contacts_contact_grouprel_property_ids>
      __contacts_contact_grouprel =
      _lookup<_contacts_contact_grouprel_property_ids>(
          '_contacts_contact_grouprel');

  _contacts_contact_grouprel_property_ids get _contacts_contact_grouprel =>
      __contacts_contact_grouprel.ref;

  late final ffi.Pointer<_contacts_contact_activity_property_ids>
      __contacts_contact_activity =
      _lookup<_contacts_contact_activity_property_ids>(
          '_contacts_contact_activity');

  _contacts_contact_activity_property_ids get _contacts_contact_activity =>
      __contacts_contact_activity.ref;

  late final ffi.Pointer<_contacts_phone_log_stat_property_ids>
      __contacts_phone_log_stat =
      _lookup<_contacts_phone_log_stat_property_ids>(
          '_contacts_phone_log_stat');

  _contacts_phone_log_stat_property_ids get _contacts_phone_log_stat =>
      __contacts_phone_log_stat.ref;

  late final ffi.Pointer<_contacts_sip_property_ids> __contacts_sip =
      _lookup<_contacts_sip_property_ids>('_contacts_sip');

  _contacts_sip_property_ids get _contacts_sip => __contacts_sip.ref;

  /// @brief Creates a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a record using contacts_record_destroy().
  /// @param[in] view_uri The view URI
  /// @param[out] record The record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to initialize.
  /// @see contacts_record_destroy()
  int contacts_record_create(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<contacts_record_h> record,
  ) {
    return _contacts_record_create(
      view_uri,
      record,
    );
  }

  late final _contacts_record_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<contacts_record_h>)>>('contacts_record_create');
  late final _contacts_record_create = _contacts_record_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<contacts_record_h>)>();

  /// @brief Destroys a record and releases its all resources.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[in] delete_child Set @c true to destroy child records automatically,
  /// otherwise set @c false to not destroy child records automatically
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_create()
  int contacts_record_destroy(
    contacts_record_h record,
    bool delete_child,
  ) {
    return _contacts_record_destroy(
      record,
      delete_child,
    );
  }

  late final _contacts_record_destroyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(contacts_record_h, ffi.Bool)>>(
      'contacts_record_destroy');
  late final _contacts_record_destroy = _contacts_record_destroyPtr
      .asFunction<int Function(contacts_record_h, bool)>();

  /// @brief Makes a clone of a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a cloned_record using contacts_record_destroy().
  /// @param[in] record The record handle
  /// @param[out] cloned_record The cloned record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_destroy()
  int contacts_record_clone(
    contacts_record_h record,
    ffi.Pointer<contacts_record_h> cloned_record,
  ) {
    return _contacts_record_clone(
      record,
      cloned_record,
    );
  }

  late final _contacts_record_clonePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h,
              ffi.Pointer<contacts_record_h>)>>('contacts_record_clone');
  late final _contacts_record_clone = _contacts_record_clonePtr.asFunction<
      int Function(contacts_record_h, ffi.Pointer<contacts_record_h>)>();

  /// @brief Gets a string from the record handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a value using free().
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] value The value to be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_get_str_p()
  /// @see contacts_record_set_str()
  int contacts_record_get_str(
    contacts_record_h record,
    int property_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _contacts_record_get_str(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_get_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('contacts_record_get_str');
  late final _contacts_record_get_str = _contacts_record_get_strPtr.asFunction<
      int Function(
          contacts_record_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets a string pointer from the record handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks You MUST NOT release @a value.
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] value The value to be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_get_str()
  /// @see contacts_record_set_str()
  int contacts_record_get_str_p(
    contacts_record_h record,
    int property_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _contacts_record_get_str_p(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_get_str_pPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'contacts_record_get_str_p');
  late final _contacts_record_get_str_p =
      _contacts_record_get_str_pPtr.asFunction<
          int Function(
              contacts_record_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets a string to a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] value The value to set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_get_str()
  /// @see contacts_record_get_str_p()
  int contacts_record_set_str(
    contacts_record_h record,
    int property_id,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _contacts_record_set_str(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_set_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Char>)>>('contacts_record_set_str');
  late final _contacts_record_set_str = _contacts_record_set_strPtr.asFunction<
      int Function(contacts_record_h, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets a record's integer value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] value The value to be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_set_int()
  int contacts_record_get_int(
    contacts_record_h record,
    int property_id,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _contacts_record_get_int(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_get_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Int>)>>('contacts_record_get_int');
  late final _contacts_record_get_int = _contacts_record_get_intPtr
      .asFunction<int Function(contacts_record_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets an integer value to a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] value The value to set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_get_int()
  int contacts_record_set_int(
    contacts_record_h record,
    int property_id,
    int value,
  ) {
    return _contacts_record_set_int(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_set_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.Int)>>('contacts_record_set_int');
  late final _contacts_record_set_int = _contacts_record_set_intPtr
      .asFunction<int Function(contacts_record_h, int, int)>();

  /// @brief Gets a record's long integer value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] value The value to be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_set_lli()
  int contacts_record_get_lli(
    contacts_record_h record,
    int property_id,
    ffi.Pointer<ffi.LongLong> value,
  ) {
    return _contacts_record_get_lli(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_get_lliPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.LongLong>)>>('contacts_record_get_lli');
  late final _contacts_record_get_lli = _contacts_record_get_lliPtr.asFunction<
      int Function(contacts_record_h, int, ffi.Pointer<ffi.LongLong>)>();

  /// @brief Sets a long long integer value to a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] value The value to set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_get_lli()
  int contacts_record_set_lli(
    contacts_record_h record,
    int property_id,
    int value,
  ) {
    return _contacts_record_set_lli(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_set_lliPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.LongLong)>>('contacts_record_set_lli');
  late final _contacts_record_set_lli = _contacts_record_set_lliPtr
      .asFunction<int Function(contacts_record_h, int, int)>();

  /// @brief Gets a record's boolean value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] value The value to be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_set_bool()
  int contacts_record_get_bool(
    contacts_record_h record,
    int property_id,
    ffi.Pointer<ffi.Bool> value,
  ) {
    return _contacts_record_get_bool(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_get_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Bool>)>>('contacts_record_get_bool');
  late final _contacts_record_get_bool =
      _contacts_record_get_boolPtr.asFunction<
          int Function(contacts_record_h, int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets a boolean value to a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] value The value to set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_get_bool()
  int contacts_record_set_bool(
    contacts_record_h record,
    int property_id,
    bool value,
  ) {
    return _contacts_record_set_bool(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_set_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.Bool)>>('contacts_record_set_bool');
  late final _contacts_record_set_bool = _contacts_record_set_boolPtr
      .asFunction<int Function(contacts_record_h, int, bool)>();

  /// @brief Gets a record's double value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] value The value to be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_set_double()
  int contacts_record_get_double(
    contacts_record_h record,
    int property_id,
    ffi.Pointer<ffi.Double> value,
  ) {
    return _contacts_record_get_double(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_get_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Double>)>>('contacts_record_get_double');
  late final _contacts_record_get_double =
      _contacts_record_get_doublePtr.asFunction<
          int Function(contacts_record_h, int, ffi.Pointer<ffi.Double>)>();

  /// @brief Sets a double value to a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] value The value to set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_get_double()
  int contacts_record_set_double(
    contacts_record_h record,
    int property_id,
    double value,
  ) {
    return _contacts_record_set_double(
      record,
      property_id,
      value,
    );
  }

  late final _contacts_record_set_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.Double)>>('contacts_record_set_double');
  late final _contacts_record_set_double = _contacts_record_set_doublePtr
      .asFunction<int Function(contacts_record_h, int, double)>();

  /// @brief Adds a child record to the parent record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The parent record handle
  /// @param[in] property_id The property ID
  /// @param[in] child_record The child record handle to be added to parent record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_remove_child_record()
  int contacts_record_add_child_record(
    contacts_record_h record,
    int property_id,
    contacts_record_h child_record,
  ) {
    return _contacts_record_add_child_record(
      record,
      property_id,
      child_record,
    );
  }

  late final _contacts_record_add_child_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              contacts_record_h)>>('contacts_record_add_child_record');
  late final _contacts_record_add_child_record =
      _contacts_record_add_child_recordPtr.asFunction<
          int Function(contacts_record_h, int, contacts_record_h)>();

  /// @brief Removes a child record from the parent record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The parent record handle
  /// @param[in] property_id The property ID
  /// @param[in] child_record The child record handle to be removed from parent record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_add_child_record()
  int contacts_record_remove_child_record(
    contacts_record_h record,
    int property_id,
    contacts_record_h child_record,
  ) {
    return _contacts_record_remove_child_record(
      record,
      property_id,
      child_record,
    );
  }

  late final _contacts_record_remove_child_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              contacts_record_h)>>('contacts_record_remove_child_record');
  late final _contacts_record_remove_child_record =
      _contacts_record_remove_child_recordPtr.asFunction<
          int Function(contacts_record_h, int, contacts_record_h)>();

  /// @brief Gets the number of child records of a parent record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The parent record handle
  /// @param[in] property_id The property ID
  /// @param[out] count The child record count
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_add_child_record()
  /// @see contacts_record_remove_child_record()
  int contacts_record_get_child_record_count(
    contacts_record_h record,
    int property_id,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _contacts_record_get_child_record_count(
      record,
      property_id,
      count,
    );
  }

  late final _contacts_record_get_child_record_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
              ffi.Pointer<ffi.Int>)>>('contacts_record_get_child_record_count');
  late final _contacts_record_get_child_record_count =
      _contacts_record_get_child_record_countPtr.asFunction<
          int Function(contacts_record_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets a child record handle pointer from the parent record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks You MUST NOT release @a child_record. It is released when the parent record is destroyed.
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[in] index The index of child record
  /// @param[out] child_record The child record handle pointer
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_record_add_child_record()
  /// @see contacts_record_remove_child_record()
  /// @see contacts_record_get_child_record_count()
  int contacts_record_get_child_record_at_p(
    contacts_record_h record,
    int property_id,
    int index,
    ffi.Pointer<contacts_record_h> child_record,
  ) {
    return _contacts_record_get_child_record_at_p(
      record,
      property_id,
      index,
      child_record,
    );
  }

  late final _contacts_record_get_child_record_at_pPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(contacts_record_h, ffi.UnsignedInt, ffi.Int,
                  ffi.Pointer<contacts_record_h>)>>(
      'contacts_record_get_child_record_at_p');
  late final _contacts_record_get_child_record_at_p =
      _contacts_record_get_child_record_at_pPtr.asFunction<
          int Function(
              contacts_record_h, int, int, ffi.Pointer<contacts_record_h>)>();

  /// @brief Clones a child record list of the given parent record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a cloned_list using contacts_list_destroy().
  /// @param[in] record The record handle
  /// @param[in] property_id The property ID
  /// @param[out] cloned_list The cloned list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_list_destroy()
  int contacts_record_clone_child_record_list(
    contacts_record_h record,
    int property_id,
    ffi.Pointer<contacts_list_h> cloned_list,
  ) {
    return _contacts_record_clone_child_record_list(
      record,
      property_id,
      cloned_list,
    );
  }

  late final _contacts_record_clone_child_record_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(contacts_record_h, ffi.UnsignedInt,
                  ffi.Pointer<contacts_list_h>)>>(
      'contacts_record_clone_child_record_list');
  late final _contacts_record_clone_child_record_list =
      _contacts_record_clone_child_record_listPtr.asFunction<
          int Function(contacts_record_h, int, ffi.Pointer<contacts_list_h>)>();

  /// @brief Gets URI string from a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] record The record handle
  /// @param[out] view_uri The URI of record
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  int contacts_record_get_uri_p(
    contacts_record_h record,
    ffi.Pointer<ffi.Pointer<ffi.Char>> view_uri,
  ) {
    return _contacts_record_get_uri_p(
      record,
      view_uri,
    );
  }

  late final _contacts_record_get_uri_pPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  contacts_record_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'contacts_record_get_uri_p');
  late final _contacts_record_get_uri_p =
      _contacts_record_get_uri_pPtr.asFunction<
          int Function(
              contacts_record_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Creates a contacts list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a contacts_list using contacts_list_destroy().
  /// @param[out] contacts_list The contacts list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_list_destroy()
  int contacts_list_create(
    ffi.Pointer<contacts_list_h> contacts_list,
  ) {
    return _contacts_list_create(
      contacts_list,
    );
  }

  late final _contacts_list_createPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<contacts_list_h>)>>(
      'contacts_list_create');
  late final _contacts_list_create = _contacts_list_createPtr
      .asFunction<int Function(ffi.Pointer<contacts_list_h>)>();

  /// @brief Destroys a contacts list and releases its all resources.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] contacts_list The contacts list handle
  /// @param[in] delete_child Set @c true to destroy child records automatically,
  /// otherwise set @c false to not destroy child records automatically
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_list_create()
  int contacts_list_destroy(
    contacts_list_h contacts_list,
    bool delete_child,
  ) {
    return _contacts_list_destroy(
      contacts_list,
      delete_child,
    );
  }

  late final _contacts_list_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_list_h, ffi.Bool)>>(
          'contacts_list_destroy');
  late final _contacts_list_destroy = _contacts_list_destroyPtr
      .asFunction<int Function(contacts_list_h, bool)>();

  /// @brief Retrieves the number of contact entities from a contacts list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] contacts_list The contacts list handle
  /// @param[out] count The count of contact entity
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_list_add()
  int contacts_list_get_count(
    contacts_list_h contacts_list,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _contacts_list_get_count(
      contacts_list,
      count,
    );
  }

  late final _contacts_list_get_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_list_h,
              ffi.Pointer<ffi.Int>)>>('contacts_list_get_count');
  late final _contacts_list_get_count = _contacts_list_get_countPtr
      .asFunction<int Function(contacts_list_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Adds a record to a contacts list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks Same kind of record can be added.
  /// @param[in] contacts_list The contacts list handle
  /// @param[in] record The record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_list_remove()
  int contacts_list_add(
    contacts_list_h contacts_list,
    contacts_record_h record,
  ) {
    return _contacts_list_add(
      contacts_list,
      record,
    );
  }

  late final _contacts_list_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              contacts_list_h, contacts_record_h)>>('contacts_list_add');
  late final _contacts_list_add = _contacts_list_addPtr
      .asFunction<int Function(contacts_list_h, contacts_record_h)>();

  /// @brief Removes a record from the contacts list.
  /// @details If the record is current record, then current record is changed the next record. \n
  /// If the record is the last record, then current record will be @c NULL.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] contacts_list The contacts list handle
  /// @param[in] record The record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_list_add()
  int contacts_list_remove(
    contacts_list_h contacts_list,
    contacts_record_h record,
  ) {
    return _contacts_list_remove(
      contacts_list,
      record,
    );
  }

  late final _contacts_list_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              contacts_list_h, contacts_record_h)>>('contacts_list_remove');
  late final _contacts_list_remove = _contacts_list_removePtr
      .asFunction<int Function(contacts_list_h, contacts_record_h)>();

  /// @brief Retrieves a record from the contacts list.
  /// @details The default current record is the first record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks You MUST NOT destroy the @a record.
  /// It is destroyed automatically when the @a contacts_list is destroyed.
  /// @param[in] contacts_list The contacts list handle
  /// @param[out] record The record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  int contacts_list_get_current_record_p(
    contacts_list_h contacts_list,
    ffi.Pointer<contacts_record_h> record,
  ) {
    return _contacts_list_get_current_record_p(
      contacts_list,
      record,
    );
  }

  late final _contacts_list_get_current_record_pPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  contacts_list_h, ffi.Pointer<contacts_record_h>)>>(
      'contacts_list_get_current_record_p');
  late final _contacts_list_get_current_record_p =
      _contacts_list_get_current_record_pPtr.asFunction<
          int Function(contacts_list_h, ffi.Pointer<contacts_record_h>)>();

  /// @brief Moves a contacts list to the previous position.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] contacts_list The contacts list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_list_next()
  int contacts_list_prev(
    contacts_list_h contacts_list,
  ) {
    return _contacts_list_prev(
      contacts_list,
    );
  }

  late final _contacts_list_prevPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_list_h)>>(
          'contacts_list_prev');
  late final _contacts_list_prev =
      _contacts_list_prevPtr.asFunction<int Function(contacts_list_h)>();

  /// @brief Moves a contacts list to the next position.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] contacts_list The contacts list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_list_prev()
  int contacts_list_next(
    contacts_list_h contacts_list,
  ) {
    return _contacts_list_next(
      contacts_list,
    );
  }

  late final _contacts_list_nextPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_list_h)>>(
          'contacts_list_next');
  late final _contacts_list_next =
      _contacts_list_nextPtr.asFunction<int Function(contacts_list_h)>();

  /// @brief Moves a contacts list to the first position.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] contacts_list The contacts list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_list_last()
  int contacts_list_first(
    contacts_list_h contacts_list,
  ) {
    return _contacts_list_first(
      contacts_list,
    );
  }

  late final _contacts_list_firstPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_list_h)>>(
          'contacts_list_first');
  late final _contacts_list_first =
      _contacts_list_firstPtr.asFunction<int Function(contacts_list_h)>();

  /// @brief Moves a contacts list to the last position.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] contacts_list The contacts list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_list_first()
  int contacts_list_last(
    contacts_list_h contacts_list,
  ) {
    return _contacts_list_last(
      contacts_list,
    );
  }

  late final _contacts_list_lastPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_list_h)>>(
          'contacts_list_last');
  late final _contacts_list_last =
      _contacts_list_lastPtr.asFunction<int Function(contacts_list_h)>();

  /// @brief Creates a filter.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a filter using contacts_filter_destroy().
  /// @param[in] view_uri The view URI of a filter
  /// @param[out] filter The filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to initialize
  /// @see contacts_filter_destroy()
  int contacts_filter_create(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<contacts_filter_h> filter,
  ) {
    return _contacts_filter_create(
      view_uri,
      filter,
    );
  }

  late final _contacts_filter_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<contacts_filter_h>)>>('contacts_filter_create');
  late final _contacts_filter_create = _contacts_filter_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<contacts_filter_h>)>();

  /// @brief Destroys a filter.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] filter The filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_filter_create()
  int contacts_filter_destroy(
    contacts_filter_h filter,
  ) {
    return _contacts_filter_destroy(
      filter,
    );
  }

  late final _contacts_filter_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_filter_h)>>(
          'contacts_filter_destroy');
  late final _contacts_filter_destroy =
      _contacts_filter_destroyPtr.asFunction<int Function(contacts_filter_h)>();

  /// @brief Adds a condition for a string type property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] property_id The property ID to add a condition
  /// @param[in] match The match flag
  /// @param[in] match_value The match value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_filter_add_operator()
  int contacts_filter_add_str(
    contacts_filter_h filter,
    int property_id,
    int match,
    ffi.Pointer<ffi.Char> match_value,
  ) {
    return _contacts_filter_add_str(
      filter,
      property_id,
      match,
      match_value,
    );
  }

  late final _contacts_filter_add_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_filter_h, ffi.UnsignedInt, ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('contacts_filter_add_str');
  late final _contacts_filter_add_str = _contacts_filter_add_strPtr.asFunction<
      int Function(contacts_filter_h, int, int, ffi.Pointer<ffi.Char>)>();

  /// @brief Adds a condition for an integer type property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] property_id The property ID to add a condition
  /// @param[in] match The match flag
  /// @param[in] match_value The match value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_filter_add_operator()
  int contacts_filter_add_int(
    contacts_filter_h filter,
    int property_id,
    int match,
    int match_value,
  ) {
    return _contacts_filter_add_int(
      filter,
      property_id,
      match,
      match_value,
    );
  }

  late final _contacts_filter_add_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_filter_h, ffi.UnsignedInt, ffi.Int32,
              ffi.Int)>>('contacts_filter_add_int');
  late final _contacts_filter_add_int = _contacts_filter_add_intPtr
      .asFunction<int Function(contacts_filter_h, int, int, int)>();

  /// @brief Adds a condition for a long int type property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] property_id The property ID to add a condition
  /// @param[in] match The match flag
  /// @param[in] match_value The match value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_filter_add_operator()
  int contacts_filter_add_lli(
    contacts_filter_h filter,
    int property_id,
    int match,
    int match_value,
  ) {
    return _contacts_filter_add_lli(
      filter,
      property_id,
      match,
      match_value,
    );
  }

  late final _contacts_filter_add_lliPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_filter_h, ffi.UnsignedInt, ffi.Int32,
              ffi.LongLong)>>('contacts_filter_add_lli');
  late final _contacts_filter_add_lli = _contacts_filter_add_lliPtr
      .asFunction<int Function(contacts_filter_h, int, int, int)>();

  /// @brief Adds a condition for a double type property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] property_id The property ID to add a condition
  /// @param[in] match The match flag
  /// @param[in] match_value The match value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_filter_add_operator()
  int contacts_filter_add_double(
    contacts_filter_h filter,
    int property_id,
    int match,
    double match_value,
  ) {
    return _contacts_filter_add_double(
      filter,
      property_id,
      match,
      match_value,
    );
  }

  late final _contacts_filter_add_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_filter_h, ffi.UnsignedInt, ffi.Int32,
              ffi.Double)>>('contacts_filter_add_double');
  late final _contacts_filter_add_double = _contacts_filter_add_doublePtr
      .asFunction<int Function(contacts_filter_h, int, int, double)>();

  /// @brief Adds a condition for a boolean type property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] property_id The property ID to add a condition
  /// @param[in] match_value The match value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_filter_add_operator()
  int contacts_filter_add_bool(
    contacts_filter_h filter,
    int property_id,
    bool match_value,
  ) {
    return _contacts_filter_add_bool(
      filter,
      property_id,
      match_value,
    );
  }

  late final _contacts_filter_add_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_filter_h, ffi.UnsignedInt,
              ffi.Bool)>>('contacts_filter_add_bool');
  late final _contacts_filter_add_bool = _contacts_filter_add_boolPtr
      .asFunction<int Function(contacts_filter_h, int, bool)>();

  /// @brief Adds an operator between conditions.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] filter The filter handle
  /// @param[in] operator_type The operator type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_filter_add_str()
  /// @see contacts_filter_add_int()
  /// @see contacts_filter_add_bool()
  int contacts_filter_add_operator(
    contacts_filter_h filter,
    int operator_type,
  ) {
    return _contacts_filter_add_operator(
      filter,
      operator_type,
    );
  }

  late final _contacts_filter_add_operatorPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(contacts_filter_h, ffi.Int32)>>(
      'contacts_filter_add_operator');
  late final _contacts_filter_add_operator = _contacts_filter_add_operatorPtr
      .asFunction<int Function(contacts_filter_h, int)>();

  /// @brief Adds a filter to a given filter.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] parent_filter The parent filter handle
  /// @param[in] child_filter The child filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_filter_add_operator()
  int contacts_filter_add_filter(
    contacts_filter_h parent_filter,
    contacts_filter_h child_filter,
  ) {
    return _contacts_filter_add_filter(
      parent_filter,
      child_filter,
    );
  }

  late final _contacts_filter_add_filterPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_filter_h,
              contacts_filter_h)>>('contacts_filter_add_filter');
  late final _contacts_filter_add_filter = _contacts_filter_add_filterPtr
      .asFunction<int Function(contacts_filter_h, contacts_filter_h)>();

  /// @brief Creates a query.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a query using contacts_query_destroy().
  /// @param[in] view_uri The view URI of a query
  /// @param[out] query The filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to initialize
  /// @see contacts_query_destroy()
  int contacts_query_create(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<contacts_query_h> query,
  ) {
    return _contacts_query_create(
      view_uri,
      query,
    );
  }

  late final _contacts_query_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<contacts_query_h>)>>('contacts_query_create');
  late final _contacts_query_create = _contacts_query_createPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<contacts_query_h>)>();

  /// @brief Destroys a query.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] query The query handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_query_create()
  int contacts_query_destroy(
    contacts_query_h query,
  ) {
    return _contacts_query_destroy(
      query,
    );
  }

  late final _contacts_query_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_query_h)>>(
          'contacts_query_destroy');
  late final _contacts_query_destroy =
      _contacts_query_destroyPtr.asFunction<int Function(contacts_query_h)>();

  /// @brief Adds property IDs for projection.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] query The query handle
  /// @param[in] property_id_array The property ID array
  /// @param[in] count The number of property IDs
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  int contacts_query_set_projection(
    contacts_query_h query,
    ffi.Pointer<ffi.UnsignedInt> property_id_array,
    int count,
  ) {
    return _contacts_query_set_projection(
      query,
      property_id_array,
      count,
    );
  }

  late final _contacts_query_set_projectionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_query_h, ffi.Pointer<ffi.UnsignedInt>,
              ffi.Int)>>('contacts_query_set_projection');
  late final _contacts_query_set_projection =
      _contacts_query_set_projectionPtr.asFunction<
          int Function(contacts_query_h, ffi.Pointer<ffi.UnsignedInt>, int)>();

  /// @brief Sets the "distinct" option for projection.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] query The query handle
  /// @param[in] set Set @c true to set the distinct option for projection,
  /// otherwise @c false to unset the distinct option
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  int contacts_query_set_distinct(
    contacts_query_h query,
    bool set1,
  ) {
    return _contacts_query_set_distinct(
      query,
      set1,
    );
  }

  late final _contacts_query_set_distinctPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_query_h, ffi.Bool)>>(
          'contacts_query_set_distinct');
  late final _contacts_query_set_distinct = _contacts_query_set_distinctPtr
      .asFunction<int Function(contacts_query_h, bool)>();

  /// @brief Sets a filter for query.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] query The query handle
  /// @param[in] filter The filter handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @see contacts_filter_create()
  int contacts_query_set_filter(
    contacts_query_h query,
    contacts_filter_h filter,
  ) {
    return _contacts_query_set_filter(
      query,
      filter,
    );
  }

  late final _contacts_query_set_filterPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_query_h,
              contacts_filter_h)>>('contacts_query_set_filter');
  late final _contacts_query_set_filter = _contacts_query_set_filterPtr
      .asFunction<int Function(contacts_query_h, contacts_filter_h)>();

  /// @brief Sets a sort mode for query.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] query The query handle
  /// @param[in] property_id The property ID to sort
  /// @param[in] is_ascending Set @c true for ascending sort mode,
  /// otherwise @c false for descending sort mode
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  int contacts_query_set_sort(
    contacts_query_h query,
    int property_id,
    bool is_ascending,
  ) {
    return _contacts_query_set_sort(
      query,
      property_id,
      is_ascending,
    );
  }

  late final _contacts_query_set_sortPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_query_h, ffi.UnsignedInt,
              ffi.Bool)>>('contacts_query_set_sort');
  late final _contacts_query_set_sort = _contacts_query_set_sortPtr
      .asFunction<int Function(contacts_query_h, int, bool)>();

  /// @brief Inserts a record to the contacts database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @privilege %http://tizen.org/privilege/callhistory.write
  /// @remarks %http://tizen.org/privilege/contact.write is needed for record which is created with @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, \n @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile,
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial. \n
  /// %http://tizen.org/privilege/callhistory.write is needed for record which is created with @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log.
  /// @param[in] record The record handle
  /// @param[out] id The ID of inserted record
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_db_changed_cb() callback wil be called upon success.
  /// @see contacts_connect()
  /// @see contacts_db_update_record()
  /// @see contacts_db_delete_record()
  /// @see contacts_db_get_record()
  int contacts_db_insert_record(
    contacts_record_h record,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _contacts_db_insert_record(
      record,
      id,
    );
  }

  late final _contacts_db_insert_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_record_h,
              ffi.Pointer<ffi.Int>)>>('contacts_db_insert_record');
  late final _contacts_db_insert_record = _contacts_db_insert_recordPtr
      .asFunction<int Function(contacts_record_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets a record from the contacts database.
  /// @details This function creates a new contact handle from the contacts database by the given @a record_id. \n
  /// @a record will be created, which is filled with contact information.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @privilege %http://tizen.org/privilege/callhistory.read
  /// @remarks %http://tizen.org/privilege/contact.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_simple_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_sdn. \n
  /// %http://tizen.org/privilege/callhistory.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log.
  /// @remarks You must release @a record using contacts_record_destroy().
  /// @param[in] view_uri The view URI of a record
  /// @param[in] record_id The record ID to get from database
  /// @param[out] record The record handle associated with the record ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_record_destroy()
  int contacts_db_get_record(
    ffi.Pointer<ffi.Char> view_uri,
    int record_id,
    ffi.Pointer<contacts_record_h> record,
  ) {
    return _contacts_db_get_record(
      view_uri,
      record_id,
      record,
    );
  }

  late final _contacts_db_get_recordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int,
              ffi.Pointer<contacts_record_h>)>>('contacts_db_get_record');
  late final _contacts_db_get_record = _contacts_db_get_recordPtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Char>, int, ffi.Pointer<contacts_record_h>)>();

  /// @brief Updates a record in the contacts database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @privilege %http://tizen.org/privilege/callhistory.write
  /// @remarks %http://tizen.org/privilege/contact.write is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, \n @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile,
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial. \n
  /// %http://tizen.org/privilege/callhistory.write is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log.
  /// @param[in] record The record handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_db_changed_cb() callback wil be called upon success.
  /// @see contacts_connect()
  /// @see contacts_db_insert_record()
  /// @see contacts_db_delete_record()
  /// @see contacts_db_get_record()
  int contacts_db_update_record(
    contacts_record_h record,
  ) {
    return _contacts_db_update_record(
      record,
    );
  }

  late final _contacts_db_update_recordPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_record_h)>>(
          'contacts_db_update_record');
  late final _contacts_db_update_record = _contacts_db_update_recordPtr
      .asFunction<int Function(contacts_record_h)>();

  /// @brief Deletes a record from the contacts database with related child records.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @privilege %http://tizen.org/privilege/callhistory.write
  /// @remarks %http://tizen.org/privilege/contact.write is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, \n @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile,
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial. \n
  /// %http://tizen.org/privilege/callhistory.write is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log.
  /// @param[in] view_uri The view URI of a record
  /// @param[in] record_id The record ID to delete
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_db_changed_cb() callback wil be called upon success.
  /// @see contacts_connect()
  /// @see contacts_db_insert_record()
  int contacts_db_delete_record(
    ffi.Pointer<ffi.Char> view_uri,
    int record_id,
  ) {
    return _contacts_db_delete_record(
      view_uri,
      record_id,
    );
  }

  late final _contacts_db_delete_recordPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int)>>(
      'contacts_db_delete_record');
  late final _contacts_db_delete_record = _contacts_db_delete_recordPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, int)>();

  /// @brief Replaces an id-identified record with the given record.
  /// @details Now, this API supports only _contacts_contact view_uri.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @remarks The write-once value of @a record is not replaced. \n
  /// This API works only for @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact.
  /// @param[in] record The new record handle to replace
  /// @param[in] id The DB record ID to be replaced
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_db_changed_cb() callback wil be called upon success.
  /// @see contacts_connect()
  /// @see contacts_db_update_record()
  /// @see contacts_db_delete_record()
  /// @see contacts_db_get_record()
  int contacts_db_replace_record(
    contacts_record_h record,
    int id,
  ) {
    return _contacts_db_replace_record(
      record,
      id,
    );
  }

  late final _contacts_db_replace_recordPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_record_h, ffi.Int)>>(
          'contacts_db_replace_record');
  late final _contacts_db_replace_record = _contacts_db_replace_recordPtr
      .asFunction<int Function(contacts_record_h, int)>();

  /// @brief Retrieves all records and returns the results list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @privilege %http://tizen.org/privilege/callhistory.read
  /// @remarks You must release @a record_list using contacts_list_destroy(). \n
  /// %http://tizen.org/privilege/contact.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_simple_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_sdn and all read-only views except views which are related to phone log. \n
  /// %http://tizen.org/privilege/callhistory.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log_stat. \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_phone_log view is needed both privileges.
  /// @param[in] view_uri The view URI to get records
  /// @param[in] offset The index from which to get results
  /// @param[in] limit The number to limit results(value 0 is used for all records)
  /// @param[out] record_list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_list_destroy()
  int contacts_db_get_all_records(
    ffi.Pointer<ffi.Char> view_uri,
    int offset,
    int limit,
    ffi.Pointer<contacts_list_h> record_list,
  ) {
    return _contacts_db_get_all_records(
      view_uri,
      offset,
      limit,
      record_list,
    );
  }

  late final _contacts_db_get_all_recordsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int, ffi.Int,
              ffi.Pointer<contacts_list_h>)>>('contacts_db_get_all_records');
  late final _contacts_db_get_all_records =
      _contacts_db_get_all_recordsPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, int, int, ffi.Pointer<contacts_list_h>)>();

  /// @brief Uses a query to find records.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @privilege %http://tizen.org/privilege/callhistory.read
  /// @remarks You must release @a record_list using contacts_list_destroy(). \n
  /// %http://tizen.org/privilege/contact.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_simple_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_sdn and all read-only views except views which are related to phone log. \n
  /// %http://tizen.org/privilege/callhistory.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log_stat. \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_phone_log view is needed both privileges.
  /// @param[in] query The query to filter the results
  /// @param[in] offset The index from which to get results
  /// @param[in] limit The number to limit results(value 0 is used for get all records)
  /// @param[out] record_list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_list_destroy()
  int contacts_db_get_records_with_query(
    contacts_query_h query,
    int offset,
    int limit,
    ffi.Pointer<contacts_list_h> record_list,
  ) {
    return _contacts_db_get_records_with_query(
      query,
      offset,
      limit,
      record_list,
    );
  }

  late final _contacts_db_get_records_with_queryPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(contacts_query_h, ffi.Int, ffi.Int,
                  ffi.Pointer<contacts_list_h>)>>(
      'contacts_db_get_records_with_query');
  late final _contacts_db_get_records_with_query =
      _contacts_db_get_records_with_queryPtr.asFunction<
          int Function(
              contacts_query_h, int, int, ffi.Pointer<contacts_list_h>)>();

  /// @brief Inserts multiple records to the contacts database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @privilege %http://tizen.org/privilege/callhistory.write
  /// @remarks %http://tizen.org/privilege/contact.write is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, \n @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile,
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial. \n
  /// %http://tizen.org/privilege/callhistory.write is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log.
  /// @param[in] record_list The record list handle
  /// @param[out] ids The IDs of inserted records
  /// @param[out] count The number of IDs
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_db_changed_cb() callback wil be called upon success.
  /// @see contacts_connect()
  /// @see contacts_db_update_records()
  /// @see contacts_db_delete_records()
  int contacts_db_insert_records(
    contacts_list_h record_list,
    ffi.Pointer<ffi.Pointer<ffi.Int>> ids,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _contacts_db_insert_records(
      record_list,
      ids,
      count,
    );
  }

  late final _contacts_db_insert_recordsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_list_h, ffi.Pointer<ffi.Pointer<ffi.Int>>,
              ffi.Pointer<ffi.Int>)>>('contacts_db_insert_records');
  late final _contacts_db_insert_records =
      _contacts_db_insert_recordsPtr.asFunction<
          int Function(contacts_list_h, ffi.Pointer<ffi.Pointer<ffi.Int>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Updates multiple records in the contacts database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @privilege %http://tizen.org/privilege/callhistory.write
  /// @remarks %http://tizen.org/privilege/contact.write is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, \n @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile,
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial. \n
  /// %http://tizen.org/privilege/callhistory.write is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log.
  /// @param[in] record_list The record list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_db_changed_cb() callback wil be called upon success.
  /// @see contacts_connect()
  /// @see contacts_db_insert_records()
  /// @see contacts_db_delete_records()
  int contacts_db_update_records(
    contacts_list_h record_list,
  ) {
    return _contacts_db_update_records(
      record_list,
    );
  }

  late final _contacts_db_update_recordsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(contacts_list_h)>>(
          'contacts_db_update_records');
  late final _contacts_db_update_records = _contacts_db_update_recordsPtr
      .asFunction<int Function(contacts_list_h)>();

  /// @brief Deletes multiple records in the contacts database with related child records.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @privilege %http://tizen.org/privilege/callhistory.write
  /// @remarks %http://tizen.org/privilege/contact.write is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, \n @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile,
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial. \n
  /// %http://tizen.org/privilege/callhistory.write is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log.
  /// @param[in] view_uri The view URI of records
  /// @param[in] record_id_array The record IDs to delete
  /// @param[in] count The size of record ID array
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_db_changed_cb() callback wil be called upon success.
  /// @see contacts_connect()
  /// @see contacts_db_insert_records()
  /// @see contacts_db_update_records()
  int contacts_db_delete_records(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<ffi.Int> record_id_array,
    int count,
  ) {
    return _contacts_db_delete_records(
      view_uri,
      record_id_array,
      count,
    );
  }

  late final _contacts_db_delete_recordsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>,
              ffi.Int)>>('contacts_db_delete_records');
  late final _contacts_db_delete_records =
      _contacts_db_delete_recordsPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>, int)>();

  /// @brief Replaces database records identified by given ids with a given record list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @remarks The write-once value of record is not replaced. \n
  /// This API works only for @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact.
  /// @param[in] list The new record list handle to replace
  /// @param[in] record_id_array The record IDs to replace
  /// @param[in] count The size of record ID array
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_db_changed_cb() callback wil be called upon success.
  /// @see contacts_connect()
  /// @see contacts_db_update_record()
  /// @see contacts_db_delete_record()
  /// @see contacts_db_get_record()
  int contacts_db_replace_records(
    contacts_list_h list,
    ffi.Pointer<ffi.Int> record_id_array,
    int count,
  ) {
    return _contacts_db_replace_records(
      list,
      record_id_array,
      count,
    );
  }

  late final _contacts_db_replace_recordsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_list_h, ffi.Pointer<ffi.Int>,
              ffi.Int)>>('contacts_db_replace_records');
  late final _contacts_db_replace_records = _contacts_db_replace_recordsPtr
      .asFunction<int Function(contacts_list_h, ffi.Pointer<ffi.Int>, int)>();

  /// @brief Gets the current contacts database version.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @privilege %http://tizen.org/privilege/callhistory.read
  /// @param[out] contacts_db_version The contacts database version
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_db_get_changes_by_version()
  int contacts_db_get_current_version(
    ffi.Pointer<ffi.Int> contacts_db_version,
  ) {
    return _contacts_db_get_current_version(
      contacts_db_version,
    );
  }

  late final _contacts_db_get_current_versionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'contacts_db_get_current_version');
  late final _contacts_db_get_current_version =
      _contacts_db_get_current_versionPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Registers a callback function to be invoked when a record changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @privilege %http://tizen.org/privilege/callhistory.read
  /// @remarks %http://tizen.org/privilege/contact.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_simple_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_sdn, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group_relation.\n
  /// %http://tizen.org/privilege/callhistory.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log.
  /// If successive change notification produced on the view_uri are identical,
  /// then they are coalesced into a single notification if the older notification has not yet been called
  /// because default main loop is doing something.
  /// But, it means that a callback function is not called to reliably count of change.
  /// @param[in] view_uri The view URI of records whose changes are monitored
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM System error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_db_changed_cb() will be invoked when the designated view changes.
  /// @see contacts_connect()
  /// @see contacts_db_changed_cb()
  /// @see contacts_db_remove_changed_cb()
  int contacts_db_add_changed_cb(
    ffi.Pointer<ffi.Char> view_uri,
    contacts_db_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _contacts_db_add_changed_cb(
      view_uri,
      callback,
      user_data,
    );
  }

  late final _contacts_db_add_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, contacts_db_changed_cb,
              ffi.Pointer<ffi.Void>)>>('contacts_db_add_changed_cb');
  late final _contacts_db_add_changed_cb =
      _contacts_db_add_changed_cbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, contacts_db_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters a callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] view_uri The view URI of records whose changes are monitored
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM System error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_db_changed_cb()
  /// @see contacts_db_add_changed_cb()
  int contacts_db_remove_changed_cb(
    ffi.Pointer<ffi.Char> view_uri,
    contacts_db_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _contacts_db_remove_changed_cb(
      view_uri,
      callback,
      user_data,
    );
  }

  late final _contacts_db_remove_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, contacts_db_changed_cb,
              ffi.Pointer<ffi.Void>)>>('contacts_db_remove_changed_cb');
  late final _contacts_db_remove_changed_cb =
      _contacts_db_remove_changed_cbPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, contacts_db_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves records changes since the given database version.
  /// @details This function will find all changed records since the given @a contacts_db_version. \n
  /// Now, support @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact_updated_info, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group_updated_info \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile_updated_info and @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_grouprel_updated_info.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @remarks You must release @a record_list using contacts_list_destroy().
  /// @param[in] view_uri The view URI to get records
  /// @param[in] address_book_id The address book ID to filter
  /// @param[in] contacts_db_version The contacts database version
  /// @param[out] change_record_list The record list
  /// @param[out] current_contacts_db_version The current contacts database version
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_list_destroy()
  int contacts_db_get_changes_by_version(
    ffi.Pointer<ffi.Char> view_uri,
    int address_book_id,
    int contacts_db_version,
    ffi.Pointer<contacts_list_h> change_record_list,
    ffi.Pointer<ffi.Int> current_contacts_db_version,
  ) {
    return _contacts_db_get_changes_by_version(
      view_uri,
      address_book_id,
      contacts_db_version,
      change_record_list,
      current_contacts_db_version,
    );
  }

  late final _contacts_db_get_changes_by_versionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Int,
              ffi.Pointer<contacts_list_h>,
              ffi.Pointer<ffi.Int>)>>('contacts_db_get_changes_by_version');
  late final _contacts_db_get_changes_by_version =
      _contacts_db_get_changes_by_versionPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, int,
              ffi.Pointer<contacts_list_h>, ffi.Pointer<ffi.Int>)>();

  /// @brief Finds records based on a given keyword.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @remarks You must release @a record_list using contacts_list_destroy(). \n
  /// This API works only for @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_contact, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_grouprel, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_assigned \n
  /// and @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_not_assigned.
  /// @param[in] view_uri The view URI to get records
  /// @param[in] keyword The keyword
  /// @param[in] offset The index from which to get results
  /// @param[in] limit The number to limit results(value 0 is used for get all records)
  /// @param[out] record_list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_list_destroy()
  int contacts_db_search_records(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<ffi.Char> keyword,
    int offset,
    int limit,
    ffi.Pointer<contacts_list_h> record_list,
  ) {
    return _contacts_db_search_records(
      view_uri,
      keyword,
      offset,
      limit,
      record_list,
    );
  }

  late final _contacts_db_search_recordsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              ffi.Int,
              ffi.Int,
              ffi.Pointer<contacts_list_h>)>>('contacts_db_search_records');
  late final _contacts_db_search_records =
      _contacts_db_search_recordsPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, int, int,
              ffi.Pointer<contacts_list_h>)>();

  /// @brief Finds records based on given query and keyword.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @remarks You must release @a record_list using contacts_list_destroy(). \n
  /// This API works only for @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_contact, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_grouprel, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_assigned \n
  /// and @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_not_assigned.
  /// @param[in] query The query handle to filter
  /// @param[in] keyword The keyword
  /// @param[in] offset The index from which to get results
  /// @param[in] limit The number to limit results(value 0 used for get all records)
  /// @param[out] record_list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_list_destroy()
  int contacts_db_search_records_with_query(
    contacts_query_h query,
    ffi.Pointer<ffi.Char> keyword,
    int offset,
    int limit,
    ffi.Pointer<contacts_list_h> record_list,
  ) {
    return _contacts_db_search_records_with_query(
      query,
      keyword,
      offset,
      limit,
      record_list,
    );
  }

  late final _contacts_db_search_records_with_queryPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(contacts_query_h, ffi.Pointer<ffi.Char>, ffi.Int,
                  ffi.Int, ffi.Pointer<contacts_list_h>)>>(
      'contacts_db_search_records_with_query');
  late final _contacts_db_search_records_with_query =
      _contacts_db_search_records_with_queryPtr.asFunction<
          int Function(contacts_query_h, ffi.Pointer<ffi.Char>, int, int,
              ffi.Pointer<contacts_list_h>)>();

  /// @brief Finds records based on a keyword and range.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @remarks You must release @a record_list using contacts_list_destroy(). \n
  /// This API works only for @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_contact, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_grouprel, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_assigned, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_not_assigned. These views can search records with range @ref CONTACTS_SEARCH_RANGE_NAME, @ref CONTACTS_SEARCH_RANGE_NUMBER, @ref CONTACTS_SEARCH_RANGE_DATA. \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_number can search records with @ref CONTACTS_SEARCH_RANGE_NAME and @ref CONTACTS_SEARCH_RANGE_NUMBER.\n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_email can search records with @ref CONTACTS_SEARCH_RANGE_NAME and @ref CONTACTS_SEARCH_RANGE_EMAIL.
  /// @param[in] view_uri The view URI
  /// @param[in] keyword The keyword
  /// @param[in] offset The index from which to get results
  /// @param[in] limit The number to limit results(value 0 is used for get all records)
  /// @param[in] range The search range
  /// @param[out] record_list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_list_destroy()
  int contacts_db_search_records_with_range(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<ffi.Char> keyword,
    int offset,
    int limit,
    int range,
    ffi.Pointer<contacts_list_h> record_list,
  ) {
    return _contacts_db_search_records_with_range(
      view_uri,
      keyword,
      offset,
      limit,
      range,
      record_list,
    );
  }

  late final _contacts_db_search_records_with_rangePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
                  ffi.Int, ffi.Int, ffi.Int, ffi.Pointer<contacts_list_h>)>>(
      'contacts_db_search_records_with_range');
  late final _contacts_db_search_records_with_range =
      _contacts_db_search_records_with_rangePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, int, int,
              int, ffi.Pointer<contacts_list_h>)>();

  /// @brief Finds records based on a given keyword for snippet.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @remarks You must release @a record_list using contacts_list_destroy(). \n
  /// This API works only for @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_contact, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_grouprel, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_assigned \n
  /// and @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_not_assigned. \n
  /// Because start match and end match is needed to be composed with keyword, this API performance is lower than contacts_db_search_records().
  /// @param[in] view_uri The view URI to get records
  /// @param[in] keyword The keyword
  /// @param[in] offset The index from which to get results
  /// @param[in] limit The number to limit results(value 0 used for get all records)
  /// @param[in] start_match The text which is inserted into the fragment before the keyword(If NULL, default is "[")
  /// @param[in] end_match The text which is inserted into the fragment after the keyword(If NULL, default is "]")
  /// @param[in] token_number The one side extra number of tokens near keyword(If negative value, full sentence is printed. e.g. if token number is 3 with 'abc' keyword, "my name is [abc]de and my home")
  /// @param[out] record_list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_list_destroy()
  int contacts_db_search_records_for_snippet(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<ffi.Char> keyword,
    int offset,
    int limit,
    ffi.Pointer<ffi.Char> start_match,
    ffi.Pointer<ffi.Char> end_match,
    int token_number,
    ffi.Pointer<contacts_list_h> record_list,
  ) {
    return _contacts_db_search_records_for_snippet(
      view_uri,
      keyword,
      offset,
      limit,
      start_match,
      end_match,
      token_number,
      record_list,
    );
  }

  late final _contacts_db_search_records_for_snippetPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ffi.Int,
                  ffi.Int,
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ffi.Int,
                  ffi.Pointer<contacts_list_h>)>>(
      'contacts_db_search_records_for_snippet');
  late final _contacts_db_search_records_for_snippet =
      _contacts_db_search_records_for_snippetPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              int,
              int,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              int,
              ffi.Pointer<contacts_list_h>)>();

  /// @brief Finds records based on given query and keyword for snippet.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @remarks You must release @a record_list using contacts_list_destroy(). \n
  /// This API works only for @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_contact, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_grouprel, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_assigned \n
  /// and @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_not_assigned. \n
  /// Because start match and end match is needed to be composed with keyword, this API performance is lower than contacts_db_search_records_with_query().
  /// @param[in] query The query handle to filter
  /// @param[in] keyword The keyword
  /// @param[in] offset The index from which to get results
  /// @param[in] limit The number to limit results(value 0 used for get all records)
  /// @param[in] start_match The text which is inserted into the fragment before the keyword(If NULL, default is "[")
  /// @param[in] end_match The text which is inserted into the fragment after the keyword(If NULL, default is "]")
  /// @param[in] token_number The one side extra number of tokens near keyword(If negative value, full sentence is printed. e.g. if token number is 3 with 'abc' keyword, "my name is [abc]de and my home")
  /// @param[out] record_list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_list_destroy()
  int contacts_db_search_records_with_query_for_snippet(
    contacts_query_h query,
    ffi.Pointer<ffi.Char> keyword,
    int offset,
    int limit,
    ffi.Pointer<ffi.Char> start_match,
    ffi.Pointer<ffi.Char> end_match,
    int token_number,
    ffi.Pointer<contacts_list_h> record_list,
  ) {
    return _contacts_db_search_records_with_query_for_snippet(
      query,
      keyword,
      offset,
      limit,
      start_match,
      end_match,
      token_number,
      record_list,
    );
  }

  late final _contacts_db_search_records_with_query_for_snippetPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  contacts_query_h,
                  ffi.Pointer<ffi.Char>,
                  ffi.Int,
                  ffi.Int,
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ffi.Int,
                  ffi.Pointer<contacts_list_h>)>>(
      'contacts_db_search_records_with_query_for_snippet');
  late final _contacts_db_search_records_with_query_for_snippet =
      _contacts_db_search_records_with_query_for_snippetPtr.asFunction<
          int Function(
              contacts_query_h,
              ffi.Pointer<ffi.Char>,
              int,
              int,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              int,
              ffi.Pointer<contacts_list_h>)>();

  /// @brief Finds records based on a keyword and range for snippet.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @remarks You must release @a record_list using contacts_list_destroy(). \n
  /// This API works only for @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_contact, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_grouprel, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_assigned, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_group_not_assigned. These views can search records with range @ref CONTACTS_SEARCH_RANGE_NAME, @ref CONTACTS_SEARCH_RANGE_NUMBER, @ref CONTACTS_SEARCH_RANGE_DATA. \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_number can search records with @ref CONTACTS_SEARCH_RANGE_NAME and @ref CONTACTS_SEARCH_RANGE_NUMBER.\n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_email can search records with @ref CONTACTS_SEARCH_RANGE_NAME and @ref CONTACTS_SEARCH_RANGE_EMAIL. \n
  /// Because start match and end match is needed to be composed with keyword, this API performance is lower than contacts_db_search_records_with_range().
  /// @param[in] view_uri The view URI
  /// @param[in] keyword The keyword
  /// @param[in] offset The index from which to get results
  /// @param[in] limit The number to limit results(value 0 is used for get all records)
  /// @param[in] range The search range
  /// @param[in] start_match The text which is inserted into the fragment before the keyword(If NULL, default is "[")
  /// @param[in] end_match The text which is inserted into the fragment after the keyword(If NULL, default is "]")
  /// @param[in] token_number The one side extra number of tokens near keyword(If negative value, full sentence is printed. e.g. if token number is 3 with 'abc' keyword, "my name is [abc]de and my home")
  /// @param[out] record_list The record list
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_list_destroy()
  int contacts_db_search_records_with_range_for_snippet(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<ffi.Char> keyword,
    int offset,
    int limit,
    int range,
    ffi.Pointer<ffi.Char> start_match,
    ffi.Pointer<ffi.Char> end_match,
    int token_number,
    ffi.Pointer<contacts_list_h> record_list,
  ) {
    return _contacts_db_search_records_with_range_for_snippet(
      view_uri,
      keyword,
      offset,
      limit,
      range,
      start_match,
      end_match,
      token_number,
      record_list,
    );
  }

  late final _contacts_db_search_records_with_range_for_snippetPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ffi.Int,
                  ffi.Int,
                  ffi.Int,
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Char>,
                  ffi.Int,
                  ffi.Pointer<contacts_list_h>)>>(
      'contacts_db_search_records_with_range_for_snippet');
  late final _contacts_db_search_records_with_range_for_snippet =
      _contacts_db_search_records_with_range_for_snippetPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              int,
              int,
              int,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>,
              int,
              ffi.Pointer<contacts_list_h>)>();

  /// @brief Gets the number of records in a specific view.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @privilege %http://tizen.org/privilege/callhistory.read
  /// @remarks %http://tizen.org/privilege/contact.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_simple_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_sdn and all read-only views except views which is related to phone log. \n
  /// %http://tizen.org/privilege/callhistory.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log_stat. \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_phone_log view is needed both privilege.
  /// @param[in] view_uri The view URI
  /// @param[out] count The count of records
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_db_get_count(
    ffi.Pointer<ffi.Char> view_uri,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _contacts_db_get_count(
      view_uri,
      count,
    );
  }

  late final _contacts_db_get_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('contacts_db_get_count');
  late final _contacts_db_get_count = _contacts_db_get_countPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the number of records matching a query.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @privilege %http://tizen.org/privilege/callhistory.read
  /// @remarks %http://tizen.org/privilege/contact.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address_book, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_simple_contact, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_group, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_my_profile, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_name, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_number, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_email, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_address, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_note, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_url, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_event, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_image, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_company, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_nickname, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_messenger, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_extension, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_profile, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_relationship, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_activity_photo, \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_speeddial, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_sdn and all read-only views except views which is related to phone log. \n
  /// %http://tizen.org/privilege/callhistory.read is needed for record which is related to @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log, @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_phone_log_stat. \n
  /// @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_person_phone_log view is needed both privilege.
  /// @param[in] query The query handle
  /// @param[out] count The count of records
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_db_get_count_with_query(
    contacts_query_h query,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _contacts_db_get_count_with_query(
      query,
      count,
    );
  }

  late final _contacts_db_get_count_with_queryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_query_h,
              ffi.Pointer<ffi.Int>)>>('contacts_db_get_count_with_query');
  late final _contacts_db_get_count_with_query =
      _contacts_db_get_count_with_queryPtr
          .asFunction<int Function(contacts_query_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the last successful changed contacts database version on the current connection.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @privilege %http://tizen.org/privilege/callhistory.read
  /// @param[out] last_change_version The database version
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_db_get_current_version()
  int contacts_db_get_last_change_version(
    ffi.Pointer<ffi.Int> last_change_version,
  ) {
    return _contacts_db_get_last_change_version(
      last_change_version,
    );
  }

  late final _contacts_db_get_last_change_versionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'contacts_db_get_last_change_version');
  late final _contacts_db_get_last_change_version =
      _contacts_db_get_last_change_versionPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the contacts name display order.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @param[out] name_display_order The name display order
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_IPC Unknown IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_setting_get_name_display_order(
    ffi.Pointer<ffi.Int32> name_display_order,
  ) {
    return _contacts_setting_get_name_display_order(
      name_display_order,
    );
  }

  late final _contacts_setting_get_name_display_orderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'contacts_setting_get_name_display_order');
  late final _contacts_setting_get_name_display_order =
      _contacts_setting_get_name_display_orderPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the contacts name display order.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] name_display_order The name display order
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_IPC Unknown IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_setting_name_display_order_changed_cb() callback will be called upon success.
  /// @see contacts_connect()
  int contacts_setting_set_name_display_order(
    int name_display_order,
  ) {
    return _contacts_setting_set_name_display_order(
      name_display_order,
    );
  }

  late final _contacts_setting_set_name_display_orderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'contacts_setting_set_name_display_order');
  late final _contacts_setting_set_name_display_order =
      _contacts_setting_set_name_display_orderPtr
          .asFunction<int Function(int)>();

  /// @brief Gets the contacts name sorting order in which contacts are returned.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @param[out] name_sorting_order The name sorting order
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_IPC Unknown IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_setting_get_name_sorting_order(
    ffi.Pointer<ffi.Int32> name_sorting_order,
  ) {
    return _contacts_setting_get_name_sorting_order(
      name_sorting_order,
    );
  }

  late final _contacts_setting_get_name_sorting_orderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'contacts_setting_get_name_sorting_order');
  late final _contacts_setting_get_name_sorting_order =
      _contacts_setting_get_name_sorting_orderPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the contacts name sorting order in which contacts are returned.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] name_sorting_order The name sorting order
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_IPC Unknown IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_setting_name_sorting_order_changed_cb() callback will be called upon success.
  /// @see contacts_connect()
  int contacts_setting_set_name_sorting_order(
    int name_sorting_order,
  ) {
    return _contacts_setting_set_name_sorting_order(
      name_sorting_order,
    );
  }

  late final _contacts_setting_set_name_sorting_orderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'contacts_setting_set_name_sorting_order');
  late final _contacts_setting_set_name_sorting_order =
      _contacts_setting_set_name_sorting_orderPtr
          .asFunction<int Function(int)>();

  /// @brief Registers a callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_IPC Unknown IPC error
  /// @retval #CONTACTS_ERROR_INTERNAL Implementation Error, Temporary Use
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_setting_name_display_order_changed_cb() will be called under certain conditions, after calling contacts_setting_set_name_display_order().
  /// @see contacts_connect()
  /// @see contacts_setting_remove_name_display_order_changed_cb()
  int contacts_setting_add_name_display_order_changed_cb(
    contacts_setting_name_display_order_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _contacts_setting_add_name_display_order_changed_cb(
      callback,
      user_data,
    );
  }

  late final _contacts_setting_add_name_display_order_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(contacts_setting_name_display_order_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'contacts_setting_add_name_display_order_changed_cb');
  late final _contacts_setting_add_name_display_order_changed_cb =
      _contacts_setting_add_name_display_order_changed_cbPtr.asFunction<
          int Function(contacts_setting_name_display_order_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters a callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_INTERNAL Implementation Error, Temporary Use
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_setting_add_name_display_order_changed_cb()
  int contacts_setting_remove_name_display_order_changed_cb(
    contacts_setting_name_display_order_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _contacts_setting_remove_name_display_order_changed_cb(
      callback,
      user_data,
    );
  }

  late final _contacts_setting_remove_name_display_order_changed_cbPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      contacts_setting_name_display_order_changed_cb,
                      ffi.Pointer<ffi.Void>)>>(
          'contacts_setting_remove_name_display_order_changed_cb');
  late final _contacts_setting_remove_name_display_order_changed_cb =
      _contacts_setting_remove_name_display_order_changed_cbPtr.asFunction<
          int Function(contacts_setting_name_display_order_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Registers a callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_IPC Unknown IPC error
  /// @retval #CONTACTS_ERROR_INTERNAL Implementation Error, Temporary Use
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @post contacts_setting_name_sorting_order_changed_cb() will be called under certain conditions, after calling contacts_setting_set_name_sorting_order().
  /// @see contacts_connect()
  /// @see contacts_setting_remove_name_sorting_order_changed_cb()
  int contacts_setting_add_name_sorting_order_changed_cb(
    contacts_setting_name_sorting_order_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _contacts_setting_add_name_sorting_order_changed_cb(
      callback,
      user_data,
    );
  }

  late final _contacts_setting_add_name_sorting_order_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(contacts_setting_name_sorting_order_changed_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'contacts_setting_add_name_sorting_order_changed_cb');
  late final _contacts_setting_add_name_sorting_order_changed_cb =
      _contacts_setting_add_name_sorting_order_changed_cbPtr.asFunction<
          int Function(contacts_setting_name_sorting_order_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters a callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_INTERNAL Implementation Error, Temporary Use
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_setting_add_name_sorting_order_changed_cb()
  int contacts_setting_remove_name_sorting_order_changed_cb(
    contacts_setting_name_sorting_order_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _contacts_setting_remove_name_sorting_order_changed_cb(
      callback,
      user_data,
    );
  }

  late final _contacts_setting_remove_name_sorting_order_changed_cbPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(
                      contacts_setting_name_sorting_order_changed_cb,
                      ffi.Pointer<ffi.Void>)>>(
          'contacts_setting_remove_name_sorting_order_changed_cb');
  late final _contacts_setting_remove_name_sorting_order_changed_cb =
      _contacts_setting_remove_name_sorting_order_changed_cbPtr.asFunction<
          int Function(contacts_setting_name_sorting_order_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Links a person to another person.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] base_person_id The base person ID
  /// @param[in] person_id The person ID to link to
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_person_link_person(
    int base_person_id,
    int person_id,
  ) {
    return _contacts_person_link_person(
      base_person_id,
      person_id,
    );
  }

  late final _contacts_person_link_personPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'contacts_person_link_person');
  late final _contacts_person_link_person =
      _contacts_person_link_personPtr.asFunction<int Function(int, int)>();

  /// @brief Unlinks a contact from a person.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] person_id The person ID
  /// @param[in] contact_id The contact ID to unlink
  /// @param[out] unlinked_person_id The person ID generated
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_person_unlink_contact(
    int person_id,
    int contact_id,
    ffi.Pointer<ffi.Int> unlinked_person_id,
  ) {
    return _contacts_person_unlink_contact(
      person_id,
      contact_id,
      unlinked_person_id,
    );
  }

  late final _contacts_person_unlink_contactPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('contacts_person_unlink_contact');
  late final _contacts_person_unlink_contact =
      _contacts_person_unlink_contactPtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Resets a person's usage count.
  /// @details The person is no longer in the most frequently contacted person list.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] person_id The person ID
  /// @param[in] type The type to reset
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_person_reset_usage(
    int person_id,
    int type,
  ) {
    return _contacts_person_reset_usage(
      person_id,
      type,
    );
  }

  late final _contacts_person_reset_usagePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int32)>>(
          'contacts_person_reset_usage');
  late final _contacts_person_reset_usage =
      _contacts_person_reset_usagePtr.asFunction<int Function(int, int)>();

  /// @brief Sets the order of a (favorite) contact.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] person_id The person ID to move
  /// @param[in] previous_person_id The previous person ID
  /// @param[in] next_person_id The back person ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_person_set_favorite_order(
    int person_id,
    int previous_person_id,
    int next_person_id,
  ) {
    return _contacts_person_set_favorite_order(
      person_id,
      previous_person_id,
      next_person_id,
    );
  }

  late final _contacts_person_set_favorite_orderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int, ffi.Int)>>(
          'contacts_person_set_favorite_order');
  late final _contacts_person_set_favorite_order =
      _contacts_person_set_favorite_orderPtr
          .asFunction<int Function(int, int, int)>();

  /// @brief Sets a record's default property.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @remarks @a id can be contact_id, number_id, email_id, image_id.
  /// @param[in] property #contacts_person_property_e
  /// @param[in] person_id The person ID
  /// @param[in] id The record ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_person_set_default_property(
    int property,
    int person_id,
    int id,
  ) {
    return _contacts_person_set_default_property(
      property,
      person_id,
      id,
    );
  }

  late final _contacts_person_set_default_propertyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int32, ffi.Int, ffi.Int)>>(
      'contacts_person_set_default_property');
  late final _contacts_person_set_default_property =
      _contacts_person_set_default_propertyPtr
          .asFunction<int Function(int, int, int)>();

  /// @brief Gets a default property for a record.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @remarks @a id can be contact_id, number_id, email_id, image_id.
  /// @param[in] property #contacts_person_property_e
  /// @param[in] person_id The person ID
  /// @param[out] id The record ID of the property to be set as default
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_person_get_default_property(
    int property,
    int person_id,
    ffi.Pointer<ffi.Int> id,
  ) {
    return _contacts_person_get_default_property(
      property,
      person_id,
      id,
    );
  }

  late final _contacts_person_get_default_propertyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('contacts_person_get_default_property');
  late final _contacts_person_get_default_property =
      _contacts_person_get_default_propertyPtr
          .asFunction<int Function(int, int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets aggregation suggestions.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @remarks You must release @a record_list using contacts_list_destroy().
  /// @remarks This may take a long time. If you need to use it in bulk, make sure the user experience is acceptable while running it.
  /// @param[in] person_id The person ID
  /// @param[in] limit The number to limit results(value 0 is used for get all records)
  /// @param[out] record_list The list of person records
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_person_get_aggregation_suggestions(
    int person_id,
    int limit,
    ffi.Pointer<contacts_list_h> record_list,
  ) {
    return _contacts_person_get_aggregation_suggestions(
      person_id,
      limit,
      record_list,
    );
  }

  late final _contacts_person_get_aggregation_suggestionsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Int, ffi.Int, ffi.Pointer<contacts_list_h>)>>(
      'contacts_person_get_aggregation_suggestions');
  late final _contacts_person_get_aggregation_suggestions =
      _contacts_person_get_aggregation_suggestionsPtr
          .asFunction<int Function(int, int, ffi.Pointer<contacts_list_h>)>();

  /// @brief Adds a contact and a group relationship to the contacts database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] group_id The group ID
  /// @param[in] contact_id The contact ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_group_remove_contact()
  int contacts_group_add_contact(
    int group_id,
    int contact_id,
  ) {
    return _contacts_group_add_contact(
      group_id,
      contact_id,
    );
  }

  late final _contacts_group_add_contactPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'contacts_group_add_contact');
  late final _contacts_group_add_contact =
      _contacts_group_add_contactPtr.asFunction<int Function(int, int)>();

  /// @brief Removes a contact and a group relationship from the contacts database.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] group_id The group ID
  /// @param[in] contact_id The contact ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_group_add_contact()
  int contacts_group_remove_contact(
    int group_id,
    int contact_id,
  ) {
    return _contacts_group_remove_contact(
      group_id,
      contact_id,
    );
  }

  late final _contacts_group_remove_contactPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'contacts_group_remove_contact');
  late final _contacts_group_remove_contact =
      _contacts_group_remove_contactPtr.asFunction<int Function(int, int)>();

  /// @brief Sets a group between the previous group and the next group.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] group_id The group ID to move
  /// @param[in] previous_group_id The previous group ID
  /// @param[in] next_group_id The back group ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_group_set_group_order(
    int group_id,
    int previous_group_id,
    int next_group_id,
  ) {
    return _contacts_group_set_group_order(
      group_id,
      previous_group_id,
      next_group_id,
    );
  }

  late final _contacts_group_set_group_orderPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int, ffi.Int)>>(
          'contacts_group_set_group_order');
  late final _contacts_group_set_group_order =
      _contacts_group_set_group_orderPtr
          .asFunction<int Function(int, int, int)>();

  /// @deprecated Deprecated since 3.0. Use contacts_sim_import_all_contacts_by_sim_slot_no() instead.
  /// @brief Imports all contacts from first SIM to Contacts Database.
  /// @since_tizen @if MOBILE 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_IPC Unknown IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @retval #CONTACTS_ERROR_INTERNAL Implementation Error, Temporary Use
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_sim_import_all_contacts() {
    return _contacts_sim_import_all_contacts();
  }

  late final _contacts_sim_import_all_contactsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'contacts_sim_import_all_contacts');
  late final _contacts_sim_import_all_contacts =
      _contacts_sim_import_all_contactsPtr.asFunction<int Function()>();

  /// @deprecated Deprecated since 3.0. Use contacts_sim_get_initialization_status_by_sim_slot_no() instead.
  /// @brief Checks whether first SIM initialization is completed.
  /// @since_tizen @if MOBILE 2.3 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @param[out] completed @c true if SIM is initialized,
  /// otherwise @c false if SIM is not initialized
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method.
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_IPC Unknown IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_sim_get_initialization_status(
    ffi.Pointer<ffi.Bool> completed,
  ) {
    return _contacts_sim_get_initialization_status(
      completed,
    );
  }

  late final _contacts_sim_get_initialization_statusPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Bool>)>>(
          'contacts_sim_get_initialization_status');
  late final _contacts_sim_get_initialization_status =
      _contacts_sim_get_initialization_statusPtr
          .asFunction<int Function(ffi.Pointer<ffi.Bool>)>();

  /// @brief Imports all contacts from SIM of the given SIM slot number to the Contacts Database.
  /// @details This function invokes contacts_sim_import_progress_cb() to indicate the progress of imports whenever a contact is imported.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] sim_slot_no The SIM slot number; 0 means first SIM, 1 means second SIM
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_IPC Unknown IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  /// @see contacts_sim_import_progress_cb()
  int contacts_sim_import_all_contacts_by_sim_slot_no(
    int sim_slot_no,
    contacts_sim_import_progress_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _contacts_sim_import_all_contacts_by_sim_slot_no(
      sim_slot_no,
      callback,
      user_data,
    );
  }

  late final _contacts_sim_import_all_contacts_by_sim_slot_noPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, contacts_sim_import_progress_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'contacts_sim_import_all_contacts_by_sim_slot_no');
  late final _contacts_sim_import_all_contacts_by_sim_slot_no =
      _contacts_sim_import_all_contacts_by_sim_slot_noPtr.asFunction<
          int Function(
              int, contacts_sim_import_progress_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Checks whether SIM of the given SIM slot number is initialized.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @param[in] sim_slot_no The SIM slot number; 0 means first SIM, 1 means second SIM
  /// @param[out] completed @c true if SIM is initialized,
  /// otherwise @c false if SIM is not initialized
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_IPC Unknown IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_sim_get_initialization_status_by_sim_slot_no(
    int sim_slot_no,
    ffi.Pointer<ffi.Bool> completed,
  ) {
    return _contacts_sim_get_initialization_status_by_sim_slot_no(
      sim_slot_no,
      completed,
    );
  }

  late final _contacts_sim_get_initialization_status_by_sim_slot_noPtr =
      _lookup<
              ffi.NativeFunction<
                  ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Bool>)>>(
          'contacts_sim_get_initialization_status_by_sim_slot_no');
  late final _contacts_sim_get_initialization_status_by_sim_slot_no =
      _contacts_sim_get_initialization_status_by_sim_slot_noPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Retrieves all contacts with a record handle (_contacts_contact) from a vCard file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] vcard_file_path The file path of vCard stream file
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_NO_DATA Requested data does not exist
  /// @retval #CONTACTS_ERROR_SYSTEM System error
  /// @pre contacts_connect() should be called to initialize.
  /// @post This function invokes contacts_vcard_parse_cb().
  /// @see contacts_vcard_parse_cb()
  int contacts_vcard_parse_to_contact_foreach(
    ffi.Pointer<ffi.Char> vcard_file_path,
    contacts_vcard_parse_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _contacts_vcard_parse_to_contact_foreach(
      vcard_file_path,
      callback,
      user_data,
    );
  }

  late final _contacts_vcard_parse_to_contact_foreachPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, contacts_vcard_parse_cb,
                  ffi.Pointer<ffi.Void>)>>(
      'contacts_vcard_parse_to_contact_foreach');
  late final _contacts_vcard_parse_to_contact_foreach =
      _contacts_vcard_parse_to_contact_foreachPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, contacts_vcard_parse_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief Retrieves all contacts with a contacts list from a vCard stream.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] vcard_stream The vCard stream
  /// @param[out] contacts_list The contacts list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to initialize.
  int contacts_vcard_parse_to_contacts(
    ffi.Pointer<ffi.Char> vcard_stream,
    ffi.Pointer<contacts_list_h> contacts_list,
  ) {
    return _contacts_vcard_parse_to_contacts(
      vcard_stream,
      contacts_list,
    );
  }

  late final _contacts_vcard_parse_to_contactsPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<contacts_list_h>)>>(
      'contacts_vcard_parse_to_contacts');
  late final _contacts_vcard_parse_to_contacts =
      _contacts_vcard_parse_to_contactsPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<contacts_list_h>)>();

  /// @brief Retrieves the vCard stream from a contact.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] contact The contact record handle
  /// @param[out] vcard_stream The vCard stream
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  int contacts_vcard_make_from_contact(
    contacts_record_h contact,
    ffi.Pointer<ffi.Pointer<ffi.Char>> vcard_stream,
  ) {
    return _contacts_vcard_make_from_contact(
      contact,
      vcard_stream,
    );
  }

  late final _contacts_vcard_make_from_contactPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  contacts_record_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'contacts_vcard_make_from_contact');
  late final _contacts_vcard_make_from_contact =
      _contacts_vcard_make_from_contactPtr.asFunction<
          int Function(
              contacts_record_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Retrieves the vCard stream from a contact.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] my_profile The my_profile record handle
  /// @param[out] vcard_stream The vCard stream
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  int contacts_vcard_make_from_my_profile(
    contacts_record_h my_profile,
    ffi.Pointer<ffi.Pointer<ffi.Char>> vcard_stream,
  ) {
    return _contacts_vcard_make_from_my_profile(
      my_profile,
      vcard_stream,
    );
  }

  late final _contacts_vcard_make_from_my_profilePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  contacts_record_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'contacts_vcard_make_from_my_profile');
  late final _contacts_vcard_make_from_my_profile =
      _contacts_vcard_make_from_my_profilePtr.asFunction<
          int Function(
              contacts_record_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Retrieves the vCard stream from a person.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @param[in] person The person record handle
  /// @param[out] vcard_stream The vCard stream
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB DB error
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to initialize.
  int contacts_vcard_make_from_person(
    contacts_record_h person,
    ffi.Pointer<ffi.Pointer<ffi.Char>> vcard_stream,
  ) {
    return _contacts_vcard_make_from_person(
      person,
      vcard_stream,
    );
  }

  late final _contacts_vcard_make_from_personPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  contacts_record_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'contacts_vcard_make_from_person');
  late final _contacts_vcard_make_from_person =
      _contacts_vcard_make_from_personPtr.asFunction<
          int Function(
              contacts_record_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Retrieves the count of contact entities from a vCard file.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] vcard_file_path The person record handle
  /// @param[out] count The count of contact entity
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM System error
  int contacts_vcard_get_entity_count(
    ffi.Pointer<ffi.Char> vcard_file_path,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _contacts_vcard_get_entity_count(
      vcard_file_path,
      count,
    );
  }

  late final _contacts_vcard_get_entity_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('contacts_vcard_get_entity_count');
  late final _contacts_vcard_get_entity_count =
      _contacts_vcard_get_entity_countPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the limit size of width and height of photos to append in vCard streams.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.read
  /// @param[out] limit_size The limit size of width and height of photos to append in vCard streams. It's in pixels
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  int contacts_vcard_get_limit_size_of_photo(
    ffi.Pointer<ffi.UnsignedInt> limit_size,
  ) {
    return _contacts_vcard_get_limit_size_of_photo(
      limit_size,
    );
  }

  late final _contacts_vcard_get_limit_size_of_photoPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.UnsignedInt>)>>(
      'contacts_vcard_get_limit_size_of_photo');
  late final _contacts_vcard_get_limit_size_of_photo =
      _contacts_vcard_get_limit_size_of_photoPtr
          .asFunction<int Function(ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Sets the limit size of width and height of photos to append to vCard streams.
  /// @details This function can be used for getting reduced vCard stream. \n
  /// When making vCard stream by using contacts_vcard_make_from_person(), contacts_vcard_make_from_my_profile(), contacts_vcard_make_from_contact(), \n
  /// if width or height of the photo to append is bigger than the limit size, it is reduced to the limit size while maintaining original aspect ratio, \n
  /// so that vCard stream size can be reduced.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @remarks The limit_size should be bigger than or equal to 8 and smaller than 1080.
  /// @param[in] limit_size The limit size of width and height of photos to append in vCard streams. It's in pixels
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  int contacts_vcard_set_limit_size_of_photo(
    int limit_size,
  ) {
    return _contacts_vcard_set_limit_size_of_photo(
      limit_size,
    );
  }

  late final _contacts_vcard_set_limit_size_of_photoPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.UnsignedInt)>>(
          'contacts_vcard_set_limit_size_of_photo');
  late final _contacts_vcard_set_limit_size_of_photo =
      _contacts_vcard_set_limit_size_of_photoPtr
          .asFunction<int Function(int)>();

  /// @brief Deletes an activity record from the contacts database by contact ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] contact_id The contact ID to delete
  /// @return @c 0 on success,
  /// otherwise a negative error value (#contacts_error_e)
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_activity_delete_by_contact_id(
    int contact_id,
  ) {
    return _contacts_activity_delete_by_contact_id(
      contact_id,
    );
  }

  late final _contacts_activity_delete_by_contact_idPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'contacts_activity_delete_by_contact_id');
  late final _contacts_activity_delete_by_contact_id =
      _contacts_activity_delete_by_contact_idPtr
          .asFunction<int Function(int)>();

  /// @brief Deletes an activity record from the contacts database by account ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/contact.write
  /// @param[in] account_id The account ID to delete
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_activity_delete_by_account_id(
    int account_id,
  ) {
    return _contacts_activity_delete_by_account_id(
      account_id,
    );
  }

  late final _contacts_activity_delete_by_account_idPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'contacts_activity_delete_by_account_id');
  late final _contacts_activity_delete_by_account_id =
      _contacts_activity_delete_by_account_idPtr
          .asFunction<int Function(int)>();

  /// @brief Resets the phone log's count.
  /// @details The number of all types in the phone log will be @c 0.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/callhistory.write
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_phone_log_reset_statistics() {
    return _contacts_phone_log_reset_statistics();
  }

  late final _contacts_phone_log_reset_statisticsPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'contacts_phone_log_reset_statistics');
  late final _contacts_phone_log_reset_statistics =
      _contacts_phone_log_reset_statisticsPtr.asFunction<int Function()>();

  /// @brief Resets the phone log's count by sim slot no.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/callhistory.write
  /// @param[in] sim_slot_no It is related to the SIM slot number. sim_slot_no 0 means first SIM, sim_slot_no 1 means second SIM
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #CONTACTS_ERROR_FILE_NO_SPACE FS Full
  /// @retval #CONTACTS_ERROR_PERMISSION_DENIED Permission denied. This application does not have the privilege to call this method
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED Not supported
  /// @retval #CONTACTS_ERROR_DB Database operation failure
  /// @retval #CONTACTS_ERROR_IPC IPC error
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre contacts_connect() should be called to open a connection to the contacts service.
  /// @see contacts_connect()
  int contacts_phone_log_reset_statistics_by_sim(
    int sim_slot_no,
  ) {
    return _contacts_phone_log_reset_statistics_by_sim(
      sim_slot_no,
    );
  }

  late final _contacts_phone_log_reset_statistics_by_simPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'contacts_phone_log_reset_statistics_by_sim');
  late final _contacts_phone_log_reset_statistics_by_sim =
      _contacts_phone_log_reset_statistics_by_simPtr
          .asFunction<int Function(int)>();

  /// @brief Gets the current status of server.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] status The current status of server
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED       Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre This function requires an open connection to the contacts service by contacts_connect().
  /// @see contacts_connect()
  int contacts_db_get_status(
    ffi.Pointer<ffi.Int32> status,
  ) {
    return _contacts_db_get_status(
      status,
    );
  }

  late final _contacts_db_get_statusPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'contacts_db_get_status');
  late final _contacts_db_get_status = _contacts_db_get_statusPtr
      .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Registers a callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED       Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre This function requires an open connection to the contacts service by contacts_connect().
  /// @see contacts_connect()
  /// @see contacts_db_remove_status_changed_cb()
  int contacts_db_add_status_changed_cb(
    contacts_db_status_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _contacts_db_add_status_changed_cb(
      callback,
      user_data,
    );
  }

  late final _contacts_db_add_status_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_db_status_changed_cb,
              ffi.Pointer<ffi.Void>)>>('contacts_db_add_status_changed_cb');
  late final _contacts_db_add_status_changed_cb =
      _contacts_db_add_status_changed_cbPtr.asFunction<
          int Function(contacts_db_status_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters a callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CONTACTS_ERROR_NONE Successful
  /// @retval #CONTACTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #CONTACTS_ERROR_NOT_SUPPORTED       Not supported
  /// @retval #CONTACTS_ERROR_SYSTEM Internal system module error
  /// @pre This function requires an open connection to the contacts service by contacts_connect().
  /// @see contacts_connect()
  /// @see contacts_db_add_status_changed_cb()
  int contacts_db_remove_status_changed_cb(
    contacts_db_status_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _contacts_db_remove_status_changed_cb(
      callback,
      user_data,
    );
  }

  late final _contacts_db_remove_status_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(contacts_db_status_changed_cb,
              ffi.Pointer<ffi.Void>)>>('contacts_db_remove_status_changed_cb');
  late final _contacts_db_remove_status_changed_cb =
      _contacts_db_remove_status_changed_cbPtr.asFunction<
          int Function(contacts_db_status_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Creates a blocking rule.
  ///
  /// @since_tizen 4.0
  ///
  /// @remarks You must release @a rule using phone_number_blocking_rule_destroy().
  ///
  /// @param[out] rule      The blocking rule handle
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                Successful
  /// @retval #PHONE_NUMBER_ERROR_OUT_OF_MEMORY       Out of memory
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  ///
  /// @pre     phone_number_connect() should be called to initialize.
  ///
  /// @see phone_number_blocking_rule_destroy()
  int phone_number_blocking_rule_create(
    ffi.Pointer<phone_number_blocking_rule_h> rule,
  ) {
    return _phone_number_blocking_rule_create(
      rule,
    );
  }

  late final _phone_number_blocking_rule_createPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<phone_number_blocking_rule_h>)>>(
      'phone_number_blocking_rule_create');
  late final _phone_number_blocking_rule_create =
      _phone_number_blocking_rule_createPtr.asFunction<
          int Function(ffi.Pointer<phone_number_blocking_rule_h>)>();

  /// @brief Destroys a blocking rule and releases all its resources.
  ///
  /// @since_tizen 4.0
  ///
  /// @param[in] rule          The blocking rule handle
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                 Successful
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  ///
  /// @see phone_number_blocking_rule_create()
  int phone_number_blocking_rule_destroy(
    phone_number_blocking_rule_h rule,
  ) {
    return _phone_number_blocking_rule_destroy(
      rule,
    );
  }

  late final _phone_number_blocking_rule_destroyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(phone_number_blocking_rule_h)>>(
      'phone_number_blocking_rule_destroy');
  late final _phone_number_blocking_rule_destroy =
      _phone_number_blocking_rule_destroyPtr
          .asFunction<int Function(phone_number_blocking_rule_h)>();

  /// @brief Gets a blocked number from a rule.
  ///
  /// @since_tizen 4.0
  ///
  /// @remarks You must release @a number using free().
  ///
  /// @param[in]   rule        The blocking rule handle
  /// @param[out]  number       The blocked number
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                Successful
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  ///
  /// @see phone_number_blocking_rule_set_number()
  int phone_number_blocking_rule_get_number(
    phone_number_blocking_rule_h rule,
    ffi.Pointer<ffi.Pointer<ffi.Char>> number,
  ) {
    return _phone_number_blocking_rule_get_number(
      rule,
      number,
    );
  }

  late final _phone_number_blocking_rule_get_numberPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(phone_number_blocking_rule_h,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'phone_number_blocking_rule_get_number');
  late final _phone_number_blocking_rule_get_number =
      _phone_number_blocking_rule_get_numberPtr.asFunction<
          int Function(phone_number_blocking_rule_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets a rule's match type.
  ///
  /// @since_tizen 4.0
  ///
  /// @param[in]   rule         The blocking rule handle
  /// @param[out]  match_type        The match type of blocked number
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                Successful
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  ///
  /// @see phone_number_blocking_rule_set_match_type()
  int phone_number_blocking_rule_get_match_type(
    phone_number_blocking_rule_h rule,
    ffi.Pointer<ffi.Int32> match_type,
  ) {
    return _phone_number_blocking_rule_get_match_type(
      rule,
      match_type,
    );
  }

  late final _phone_number_blocking_rule_get_match_typePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  phone_number_blocking_rule_h, ffi.Pointer<ffi.Int32>)>>(
      'phone_number_blocking_rule_get_match_type');
  late final _phone_number_blocking_rule_get_match_type =
      _phone_number_blocking_rule_get_match_typePtr.asFunction<
          int Function(phone_number_blocking_rule_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets a blocked number to a rule.
  ///
  /// @since_tizen 4.0
  ///
  /// @param[in]   rule          The blocking rule handle
  /// @param[in]  number       The blocked number
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                Successful
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  ///
  /// @see phone_number_blocking_rule_get_number()
  int phone_number_blocking_rule_set_number(
    phone_number_blocking_rule_h rule,
    ffi.Pointer<ffi.Char> number,
  ) {
    return _phone_number_blocking_rule_set_number(
      rule,
      number,
    );
  }

  late final _phone_number_blocking_rule_set_numberPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(phone_number_blocking_rule_h,
              ffi.Pointer<ffi.Char>)>>('phone_number_blocking_rule_set_number');
  late final _phone_number_blocking_rule_set_number =
      _phone_number_blocking_rule_set_numberPtr.asFunction<
          int Function(phone_number_blocking_rule_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets a rule's match type.
  ///
  /// @since_tizen 4.0
  ///
  /// @param[in] rule          The blocking rule handle
  /// @param[in] match_type        The match type of blocked number
  ///
  /// @return      @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                  Successful
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER     Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  ///
  /// @see phone_number_blocking_rule_get_match_type()
  int phone_number_blocking_rule_set_match_type(
    phone_number_blocking_rule_h rule,
    int match_type,
  ) {
    return _phone_number_blocking_rule_set_match_type(
      rule,
      match_type,
    );
  }

  late final _phone_number_blocking_rule_set_match_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(phone_number_blocking_rule_h,
              ffi.Int32)>>('phone_number_blocking_rule_set_match_type');
  late final _phone_number_blocking_rule_set_match_type =
      _phone_number_blocking_rule_set_match_typePtr
          .asFunction<int Function(phone_number_blocking_rule_h, int)>();

  /// @brief Connects to the phonenumber-utils service.
  /// @since_tizen 3.0
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE Successful
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  /// @see phone_number_disconnect()
  int phone_number_connect() {
    return _phone_number_connect();
  }

  late final _phone_number_connectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('phone_number_connect');
  late final _phone_number_connect =
      _phone_number_connectPtr.asFunction<int Function()>();

  /// @brief Disconnects from the phonenumber-utils service.
  /// @since_tizen 3.0
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE Successful
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  /// @see phone_number_connect()
  int phone_number_disconnect() {
    return _phone_number_disconnect();
  }

  late final _phone_number_disconnectPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'phone_number_disconnect');
  late final _phone_number_disconnect =
      _phone_number_disconnectPtr.asFunction<int Function()>();

  /// @brief Gets the location string from number, region, and language.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a location using free().
  /// @remarks The phonenumber-utils is changed to client/server architecture for performance improvement since 3.0.
  /// phone_number_connect()/phone_number_disconnect() should be called.
  /// @param[in]  number    The number
  /// @param[in]  region    The region of number
  /// @param[in]  language  The language of location
  /// @param[out] location  The location string to be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE Successful
  /// @retval #PHONE_NUMBER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_FILE_NO_SPACE_ON_DEVICE FS Full
  /// @retval #PHONE_NUMBER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_NO_DATA Requested data does not exist
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  /// @pre phone_number_connect() should be called to open a connection to the phonenumber-utils service. (Since 3.0)
  /// @post phone_number_disconnect() should be called to close a connection to the phonenumber-utils service. (Since 3.0)
  int phone_number_get_location_from_number(
    ffi.Pointer<ffi.Char> number,
    int region,
    int language,
    ffi.Pointer<ffi.Pointer<ffi.Char>> location,
  ) {
    return _phone_number_get_location_from_number(
      number,
      region,
      language,
      location,
    );
  }

  late final _phone_number_get_location_from_numberPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int32, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'phone_number_get_location_from_number');
  late final _phone_number_get_location_from_number =
      _phone_number_get_location_from_numberPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the formatted number.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks You must release @a formatted_number using free().
  /// @remarks The phonenumber-utils is changed to client/server architecture for performance improvement since 3.0.
  /// phone_number_connect()/phone_number_disconnect() should be called.
  /// @param[in]  number           The number
  /// @param[in]  region           The region of number
  /// @param[out] formatted_number The formatted number string to be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE Successful
  /// @retval #PHONE_NUMBER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_FILE_NO_SPACE_ON_DEVICE FS Full
  /// @retval #PHONE_NUMBER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_NO_DATA Requested data does not exist
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  /// @pre phone_number_connect() should be called to open a connection to the phonenumber-utils service. (Since 3.0)
  /// @post phone_number_disconnect() should be called to close a connection to the phonenumber-utils service. (Since 3.0)
  int phone_number_get_formatted_number(
    ffi.Pointer<ffi.Char> number,
    int region,
    ffi.Pointer<ffi.Pointer<ffi.Char>> formatted_number,
  ) {
    return _phone_number_get_formatted_number(
      number,
      region,
      formatted_number,
    );
  }

  late final _phone_number_get_formatted_numberPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int32,
                  ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'phone_number_get_formatted_number');
  late final _phone_number_get_formatted_number =
      _phone_number_get_formatted_numberPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, int,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the normalized number.
  /// @details Normalized number starts with plus('+') and country code, and excludes the separators such
  /// as dash or space. It is a format of E.164 standard including the country code based on current network.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  /// @remarks You must release @a normalized_number using free().
  /// @remarks The phonenumber-utils is changed to client/server architecture for performance improvement since 3.0.
  /// phone_number_connect()/phone_number_disconnect() should be called.
  /// @param[in]  number            The number
  /// @param[out] normalized_number The normalized number string to be returned
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE Successful
  /// @retval #PHONE_NUMBER_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_NO_DATA Requested data does not exist
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  /// @pre phone_number_connect() should be called to open a connection to the phonenumber-utils service. (Since 3.0)
  /// @post phone_number_disconnect() should be called to close a connection to the phonenumber-utils service. (Since 3.0)
  int phone_number_get_normalized_number(
    ffi.Pointer<ffi.Char> number,
    ffi.Pointer<ffi.Pointer<ffi.Char>> normalized_number,
  ) {
    return _phone_number_get_normalized_number(
      number,
      normalized_number,
    );
  }

  late final _phone_number_get_normalized_numberPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'phone_number_get_normalized_number');
  late final _phone_number_get_normalized_number =
      _phone_number_get_normalized_numberPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Adds a blocking rule to the phone number database.
  ///
  /// @since_tizen 4.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/blocknumber.write
  ///
  /// @param[in] rule     The blocking rule handle
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                Successful
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_DB_FAILED           Database operation failure
  /// @retval #PHONE_NUMBER_ERROR_PERMISSION_DENIED   Permission denied. This application does not have the privilege to call this method.
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_IPC                 Unknown IPC error
  /// @retval #PHONE_NUMBER_ERROR_OUT_OF_MEMORY       Out of memory
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  /// @pre phone_number_connect() should be called to open a connection to the phonenumber-utils service.
  /// @post phone_number_disconnect() should be called to close a connection to the phonenumber-utils service.
  /// @see phone_number_remove_blocking_rule()
  int phone_number_add_blocking_rule(
    phone_number_blocking_rule_h rule,
  ) {
    return _phone_number_add_blocking_rule(
      rule,
    );
  }

  late final _phone_number_add_blocking_rulePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(phone_number_blocking_rule_h)>>(
      'phone_number_add_blocking_rule');
  late final _phone_number_add_blocking_rule =
      _phone_number_add_blocking_rulePtr
          .asFunction<int Function(phone_number_blocking_rule_h)>();

  /// @brief Removes a blocking rule from the phone number database.
  ///
  /// @since_tizen 4.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/blocknumber.write
  ///
  /// @remarks The blocking rule to remove should have been gotten from the phone number database using phone_number_get_blocking_rules().
  ///
  /// @param[in] rule     The blocking rule handle
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                Successful
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_DB_FAILED           Database operation failure
  /// @retval #PHONE_NUMBER_ERROR_PERMISSION_DENIED   Permission denied. This application does not have the privilege to call this method.
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_IPC                 Unknown IPC error
  /// @retval #PHONE_NUMBER_ERROR_OUT_OF_MEMORY       Out of memory
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  /// @pre phone_number_connect() should be called to open a connection to the phonenumber-utils service.
  /// @post phone_number_disconnect() should be called to close a connection to the phonenumber-utils service.
  /// @see phone_number_add_blocking_rule()
  int phone_number_remove_blocking_rule(
    phone_number_blocking_rule_h rule,
  ) {
    return _phone_number_remove_blocking_rule(
      rule,
    );
  }

  late final _phone_number_remove_blocking_rulePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(phone_number_blocking_rule_h)>>(
      'phone_number_remove_blocking_rule');
  late final _phone_number_remove_blocking_rule =
      _phone_number_remove_blocking_rulePtr
          .asFunction<int Function(phone_number_blocking_rule_h)>();

  /// @brief Retrieves blocking rules as an array.
  ///
  /// @since_tizen 4.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/blocknumber.read
  ///
  /// @remarks You must release each blocking rule in the array with phone_number_blocking_rule_destroy() and @a rules using free().
  ///
  /// @param[in]  offset     The index from which to get results
  /// @param[in]  limit      The number to limit results (value 0 is used for all blocking rules)
  /// @param[out] rules      The array of blocking rule handles
  /// @param[out] length     The number of blocking rule handles in the array
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                Successful
  /// @retval #PHONE_NUMBER_ERROR_OUT_OF_MEMORY       Out of memory
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_DB_FAILED           Database operation failure
  /// @retval #PHONE_NUMBER_ERROR_PERMISSION_DENIED   Permission denied. This application does not have the privilege to call this method.
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_IPC                 Unknown IPC error
  /// @retval #PHONE_NUMBER_ERROR_NO_DATA             Data does not exist
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  /// @pre phone_number_connect() should be called to open a connection to the phonenumber-utils service.
  /// @post phone_number_disconnect() should be called to close a connection to the phonenumber-utils service.
  int phone_number_get_blocking_rules(
    int offset,
    int limit,
    ffi.Pointer<ffi.Pointer<phone_number_blocking_rule_h>> rules,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _phone_number_get_blocking_rules(
      offset,
      limit,
      rules,
      length,
    );
  }

  late final _phone_number_get_blocking_rulesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int,
              ffi.Int,
              ffi.Pointer<ffi.Pointer<phone_number_blocking_rule_h>>,
              ffi.Pointer<ffi.Int>)>>('phone_number_get_blocking_rules');
  late final _phone_number_get_blocking_rules =
      _phone_number_get_blocking_rulesPtr.asFunction<
          int Function(
              int,
              int,
              ffi.Pointer<ffi.Pointer<phone_number_blocking_rule_h>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Retrieves blocking rules that block a specific number.
  ///
  /// @since_tizen 4.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/blocknumber.read
  ///
  /// @remarks You must release each blocking rule in the array with phone_number_blocking_rule_destroy() and @a rules using free().
  ///
  /// @param[in]  number     The number to get blocking rules related with
  /// @param[out] rules      The array of blocking rule handles
  /// @param[out] length     The number of blocking rule handles in the array
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                Successful
  /// @retval #PHONE_NUMBER_ERROR_OUT_OF_MEMORY       Out of memory
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_DB_FAILED           Database operation failure
  /// @retval #PHONE_NUMBER_ERROR_PERMISSION_DENIED   Permission denied. This application does not have the privilege to call this method.
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_IPC                 Unknown IPC error
  /// @retval #PHONE_NUMBER_ERROR_NO_DATA             Data does not exist
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  /// @pre phone_number_connect() should be called to open a connection to the phonenumber-utils service.
  /// @post phone_number_disconnect() should be called to close a connection to the phonenumber-utils service.
  int phone_number_get_blocking_rules_related(
    ffi.Pointer<ffi.Char> number,
    ffi.Pointer<ffi.Pointer<phone_number_blocking_rule_h>> rules,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _phone_number_get_blocking_rules_related(
      number,
      rules,
      length,
    );
  }

  late final _phone_number_get_blocking_rules_relatedPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>,
                  ffi.Pointer<ffi.Pointer<phone_number_blocking_rule_h>>,
                  ffi.Pointer<ffi.Int>)>>(
      'phone_number_get_blocking_rules_related');
  late final _phone_number_get_blocking_rules_related =
      _phone_number_get_blocking_rules_relatedPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<phone_number_blocking_rule_h>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Checks if a specific number is blocked or not.
  ///
  /// @since_tizen 4.0
  /// @privlevel partner
  /// @privilege %http://tizen.org/privilege/blocknumber.read
  ///
  /// @param[in]  number     The number to check blocking
  /// @param[out] is_blocked The blocking result
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #PHONE_NUMBER_ERROR_NONE                Successful
  /// @retval #PHONE_NUMBER_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval #PHONE_NUMBER_ERROR_DB_FAILED           Database operation failure
  /// @retval #PHONE_NUMBER_ERROR_PERMISSION_DENIED   Permission denied. This application does not have the privilege to call this method.
  /// @retval #PHONE_NUMBER_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PHONE_NUMBER_ERROR_IPC                 Unknown IPC error
  /// @retval #PHONE_NUMBER_ERROR_SYSTEM Internal error
  /// @pre phone_number_connect() should be called to open a connection to the phonenumber-utils service.
  /// @post phone_number_disconnect() should be called to close a connection to the phonenumber-utils service.
  int phone_number_check_blocking(
    ffi.Pointer<ffi.Char> number,
    ffi.Pointer<ffi.Bool> is_blocked,
  ) {
    return _phone_number_check_blocking(
      number,
      is_blocked,
    );
  }

  late final _phone_number_check_blockingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('phone_number_check_blocking');
  late final _phone_number_check_blocking = _phone_number_check_blockingPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the battery charge percentage.
  /// @details It returns an integer value from @c 0 to @c 100 that indicates remaining battery charge
  /// as a percentage of the maximum level.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks In order to be notified when the battery state changes, use system_info_set_changed_cb().
  /// @param[out] percent The remaining battery charge percentage (@c 0 ~ @c 100)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  int device_battery_get_percent(
    ffi.Pointer<ffi.Int> percent,
  ) {
    return _device_battery_get_percent(
      percent,
    );
  }

  late final _device_battery_get_percentPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'device_battery_get_percent');
  late final _device_battery_get_percent = _device_battery_get_percentPtr
      .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the charging state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out] charging The battery charging state
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @see device_add_callback
  /// @see device_remove_callback
  /// @see #DEVICE_CALLBACK_BATTERY_CHARGING
  int device_battery_is_charging(
    ffi.Pointer<ffi.Bool> charging,
  ) {
    return _device_battery_is_charging(
      charging,
    );
  }

  late final _device_battery_is_chargingPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Bool>)>>(
          'device_battery_is_charging');
  late final _device_battery_is_charging = _device_battery_is_chargingPtr
      .asFunction<int Function(ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the battery level status.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out] status The battery level status
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @see device_battery_level_e
  /// @see device_add_callback
  /// @see device_remove_callback
  /// @see #DEVICE_CALLBACK_BATTERY_LEVEL
  int device_battery_get_level_status(
    ffi.Pointer<ffi.Int32> status,
  ) {
    return _device_battery_get_level_status(
      status,
    );
  }

  late final _device_battery_get_level_statusPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'device_battery_get_level_status');
  late final _device_battery_get_level_status =
      _device_battery_get_level_statusPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the battery health information.
  /// @since_tizen 3.0
  /// @param[out] health The battery health information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  int device_battery_get_health(
    ffi.Pointer<ffi.Int32> health,
  ) {
    return _device_battery_get_health(
      health,
    );
  }

  late final _device_battery_get_healthPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'device_battery_get_health');
  late final _device_battery_get_health = _device_battery_get_healthPtr
      .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the battery power source information.
  /// @since_tizen 3.0
  /// @param[out] source The battery power source information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  int device_battery_get_power_source(
    ffi.Pointer<ffi.Int32> source,
  ) {
    return _device_battery_get_power_source(
      source,
    );
  }

  late final _device_battery_get_power_sourcePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'device_battery_get_power_source');
  late final _device_battery_get_power_source =
      _device_battery_get_power_sourcePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the battery properties.
  /// @since_tizen 3.0
  /// @param[in] property The property type
  /// @param[out] value The battery information for the property given
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  int device_battery_get_property(
    int property,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _device_battery_get_property(
      property,
      value,
    );
  }

  late final _device_battery_get_propertyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Int>)>>('device_battery_get_property');
  late final _device_battery_get_property = _device_battery_get_propertyPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the battery status information.
  /// @since_tizen 3.0
  /// @param[out] status The battery status information
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  int device_battery_get_status(
    ffi.Pointer<ffi.Int32> status,
  ) {
    return _device_battery_get_status(
      status,
    );
  }

  late final _device_battery_get_statusPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'device_battery_get_status');
  late final _device_battery_get_status = _device_battery_get_statusPtr
      .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Adds a callback to the observing device state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] type The device type to monitor
  /// @param[in] callback The callback function to add
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_ALREADY_IN_PROGRESS Operation already
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  int device_add_callback(
    int type,
    device_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _device_add_callback(
      type,
      callback,
      user_data,
    );
  }

  late final _device_add_callbackPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, device_changed_cb,
              ffi.Pointer<ffi.Void>)>>('device_add_callback');
  late final _device_add_callback = _device_add_callbackPtr.asFunction<
      int Function(int, device_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Removes a device callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] type The device type to monitor
  /// @param[in] callback The callback function to remove
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  int device_remove_callback(
    int type,
    device_changed_cb callback,
  ) {
    return _device_remove_callback(
      type,
      callback,
    );
  }

  late final _device_remove_callbackPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int32, device_changed_cb)>>(
      'device_remove_callback');
  late final _device_remove_callback = _device_remove_callbackPtr
      .asFunction<int Function(int, device_changed_cb)>();

  /// @brief Gets the number of display devices.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/display
  /// @param[out] device_number The total number of displays
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @see device_display_get_brightness()
  /// @see device_display_set_brightness()
  /// @see device_display_get_max_brightness()
  int device_display_get_numbers(
    ffi.Pointer<ffi.Int> device_number,
  ) {
    return _device_display_get_numbers(
      device_number,
    );
  }

  late final _device_display_get_numbersPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'device_display_get_numbers');
  late final _device_display_get_numbers = _device_display_get_numbersPtr
      .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the maximum brightness value that can be set.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/display
  /// @param[in] display_index The index of the display \n
  /// It can be greater than or equal to @c 0 and less than the number of displays returned by device_display_get_numbers(). \n
  /// The index zero is always assigned to the main display
  /// @param[out] max_brightness The maximum brightness value of the display
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @see device_display_get_numbers()
  /// @see device_display_set_brightness()
  /// @see device_display_get_brightness()
  int device_display_get_max_brightness(
    int display_index,
    ffi.Pointer<ffi.Int> max_brightness,
  ) {
    return _device_display_get_max_brightness(
      display_index,
      max_brightness,
    );
  }

  late final _device_display_get_max_brightnessPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'device_display_get_max_brightness');
  late final _device_display_get_max_brightness =
      _device_display_get_max_brightnessPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the display brightness value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/display
  /// @param[in] display_index The index of the display \n
  /// It can be greater than or equal to @c 0 and less than the number of displays returned by device_display_get_numbers(). \n
  /// The index zero is always assigned to the main display
  /// @param[out] brightness The current brightness value of the display
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @see device_display_get_numbers()
  /// @see device_display_set_brightness()
  /// @see device_display_get_max_brightness()
  int device_display_get_brightness(
    int display_index,
    ffi.Pointer<ffi.Int> brightness,
  ) {
    return _device_display_get_brightness(
      display_index,
      brightness,
    );
  }

  late final _device_display_get_brightnessPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'device_display_get_brightness');
  late final _device_display_get_brightness = _device_display_get_brightnessPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the display brightness value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/display
  /// @param[in] display_index The index of the display \n
  /// It can be greater than or equal to @c 0 and less than the number of displays returned by device_display_get_numbers(). \n
  /// The index zero is always assigned to the main display
  /// @param[in] brightness The new brightness value to set \n
  /// The maximum value can be represented by device_display_get_max_brightness()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @see device_display_get_numbers()
  /// @see device_display_get_max_brightness()
  /// @see device_display_get_brightness()
  int device_display_set_brightness(
    int display_index,
    int brightness,
  ) {
    return _device_display_set_brightness(
      display_index,
      brightness,
    );
  }

  late final _device_display_set_brightnessPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'device_display_set_brightness');
  late final _device_display_set_brightness =
      _device_display_set_brightnessPtr.asFunction<int Function(int, int)>();

  /// @brief Gets the current display state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[out] state The display state
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @see device_add_callback
  /// @see device_remove_callback
  /// @see #DEVICE_CALLBACK_DISPLAY_STATE
  int device_display_get_state(
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _device_display_get_state(
      state,
    );
  }

  late final _device_display_get_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'device_display_get_state');
  late final _device_display_get_state = _device_display_get_statePtr
      .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated Since @if WEARABLE 3.0 @else 2.4 @endif
  /// @brief Changes the display state by force.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/display
  /// @remarks This API triggers display change process and then updates the status when it completes. While the operation is on-going, the device_display_get_state() function returns previous display state.
  /// @param[in] state The display state
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @see device_power_request_lock()
  /// @see device_power_release_lock()
  /// @see device_add_callback
  /// @see device_remove_callback
  /// @see #DEVICE_CALLBACK_DISPLAY_STATE
  ///
  /// @par Example
  /// @code
  /// ...
  /// result = device_display_change_state(DISPLAY_STATE_SCREEN_OFF);
  /// if (result < 0)
  /// dlog_print(DLOG_ERROR, LOG_TAG, "[ERROR] return value result =%d, \n",result);
  /// else
  /// dlog_print(DLOG_DEBUG, LOG_TAG, "[SUCCESS] return value result =%d \n",result);
  /// ...
  /// @endcode
  int device_display_change_state(
    int state,
  ) {
    return _device_display_change_state(
      state,
    );
  }

  late final _device_display_change_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'device_display_change_state');
  late final _device_display_change_state =
      _device_display_change_statePtr.asFunction<int Function(int)>();

  /// @brief Gets the number of vibrators.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/haptic
  /// @param[in] device_number The number of vibrators
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  int device_haptic_get_count(
    ffi.Pointer<ffi.Int> device_number,
  ) {
    return _device_haptic_get_count(
      device_number,
    );
  }

  late final _device_haptic_get_countPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'device_haptic_get_count');
  late final _device_haptic_get_count = _device_haptic_get_countPtr
      .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Opens a haptic-vibration device.
  /// @details Internally, it makes a connection to the vibrator.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/haptic
  /// @remarks You must close the Haptic API using device_haptic_close().
  /// @param[in] device_index The index of device what you want to vibrate \n
  /// The index starts from @c 0
  /// @param[out] device_handle The handle of vibrator
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  /// @see device_haptic_close()
  int device_haptic_open(
    int device_index,
    ffi.Pointer<haptic_device_h> device_handle,
  ) {
    return _device_haptic_open(
      device_index,
      device_handle,
    );
  }

  late final _device_haptic_openPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<haptic_device_h>)>>('device_haptic_open');
  late final _device_haptic_open = _device_haptic_openPtr
      .asFunction<int Function(int, ffi.Pointer<haptic_device_h>)>();

  /// @brief Closes a haptic-vibration device.
  /// @details Internally, it disconnects the connection to the vibrator.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/haptic
  /// @param[in] device_handle The device handle from device_haptic_open()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  /// @see device_haptic_open()
  int device_haptic_close(
    haptic_device_h device_handle,
  ) {
    return _device_haptic_close(
      device_handle,
    );
  }

  late final _device_haptic_closePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(haptic_device_h)>>(
          'device_haptic_close');
  late final _device_haptic_close =
      _device_haptic_closePtr.asFunction<int Function(haptic_device_h)>();

  /// @brief Vibrates during the specified time with a constant intensity.
  /// @details This function can be used to start monotonous vibration for the specified time.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/haptic
  /// @remarks @a feedback level is reserved for auto changing to save variable in the settings.
  /// @remarks @a effect_handle effect_handle value can be @c 0(zero).
  /// @param[in] device_handle The device handle from device_haptic_open()
  /// @param[in] duration The play duration in milliseconds
  /// @param[in] feedback The amount of the intensity variation (@c 0 ~ @c 100)
  /// @param[out] effect_handle The pointer to the variable that will receive a handle to the playing effect
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  /// @see device_haptic_stop()
  int device_haptic_vibrate(
    haptic_device_h device_handle,
    int duration,
    int feedback,
    ffi.Pointer<haptic_effect_h> effect_handle,
  ) {
    return _device_haptic_vibrate(
      device_handle,
      duration,
      feedback,
      effect_handle,
    );
  }

  late final _device_haptic_vibratePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(haptic_device_h, ffi.Int, ffi.Int,
              ffi.Pointer<haptic_effect_h>)>>('device_haptic_vibrate');
  late final _device_haptic_vibrate = _device_haptic_vibratePtr.asFunction<
      int Function(haptic_device_h, int, int, ffi.Pointer<haptic_effect_h>)>();

  /// @brief Stops all vibration effects which are being played.
  /// @details This function can be used to stop all effects started by device_haptic_vibrate().
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/haptic
  /// @param[in] device_handle The device handle from device_haptic_open()
  /// @param[in] effect_handle The effect handle from device_haptic_vibrate()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  /// @see device_haptic_vibrate()
  int device_haptic_stop(
    haptic_device_h device_handle,
    haptic_effect_h effect_handle,
  ) {
    return _device_haptic_stop(
      device_handle,
      effect_handle,
    );
  }

  late final _device_haptic_stopPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              haptic_device_h, haptic_effect_h)>>('device_haptic_stop');
  late final _device_haptic_stop = _device_haptic_stopPtr
      .asFunction<int Function(haptic_device_h, haptic_effect_h)>();

  /// @brief Gets the max brightness value of a LED that is located next to the camera.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/led
  /// @remarks This API is related to the following feature: %http://tizen.org/feature/camera.back.flash
  /// @param[out] max_brightness The max brightness value of the LED
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  int device_flash_get_max_brightness(
    ffi.Pointer<ffi.Int> max_brightness,
  ) {
    return _device_flash_get_max_brightness(
      max_brightness,
    );
  }

  late final _device_flash_get_max_brightnessPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'device_flash_get_max_brightness');
  late final _device_flash_get_max_brightness =
      _device_flash_get_max_brightnessPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the brightness value of a LED that is located next to the camera.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/led
  /// @remarks This API is related to the following feature: %http://tizen.org/feature/camera.back.flash
  /// @param[out] brightness The brightness value of LED (@c 0 ~ MAX)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  int device_flash_get_brightness(
    ffi.Pointer<ffi.Int> brightness,
  ) {
    return _device_flash_get_brightness(
      brightness,
    );
  }

  late final _device_flash_get_brightnessPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'device_flash_get_brightness');
  late final _device_flash_get_brightness = _device_flash_get_brightnessPtr
      .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the brightness value of a LED that is located next to the camera.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/led
  /// @remarks Since @if Mobile 2.4 @elseif WEARABLE 3.0 @endif, this API check camera flash status whether camera API preempted flash or not, so it could be failed if flash was preempted by camera API. In this case, API will return #DEVICE_ERROR_RESOURCE_BUSY error.
  /// This API is related to the following feature: %http://tizen.org/feature/camera.back.flash
  /// @param[in] brightness The brightness value of LED (@c 0 ~ MAX)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  /// @retval #DEVICE_ERROR_RESOURCE_BUSY Device or resource busy
  int device_flash_set_brightness(
    int brightness,
  ) {
    return _device_flash_set_brightness(
      brightness,
    );
  }

  late final _device_flash_set_brightnessPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'device_flash_set_brightness');
  late final _device_flash_set_brightness =
      _device_flash_set_brightnessPtr.asFunction<int Function(int)>();

  /// @brief Plays the custom effect of the service LED that is located to the front of a device.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/led
  /// @remarks This API is related to the following feature: %http://tizen.org/feature/led
  /// @param[in] on Turn on time in milliseconds
  /// @param[in] off Turn off time in milliseconds
  /// @param[in] color The Color value \n
  /// The first byte means opaque and the other 3 bytes are RGB values
  /// @param[in] flags The combination of enum #led_custom_flags
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  int device_led_play_custom(
    int on1,
    int off,
    int color,
    int flags,
  ) {
    return _device_led_play_custom(
      on1,
      off,
      color,
      flags,
    );
  }

  late final _device_led_play_customPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int, ffi.UnsignedInt,
              ffi.UnsignedInt)>>('device_led_play_custom');
  late final _device_led_play_custom =
      _device_led_play_customPtr.asFunction<int Function(int, int, int, int)>();

  /// @brief Stops the custom effect of the service LED that is located to the front of a device.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/led
  /// @remarks This API is related to the following feature: %http://tizen.org/feature/led
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  int device_led_stop_custom() {
    return _device_led_stop_custom();
  }

  late final _device_led_stop_customPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('device_led_stop_custom');
  late final _device_led_stop_custom =
      _device_led_stop_customPtr.asFunction<int Function()>();

  /// @brief Locks the given lock state for a specified time.
  /// @details After the given @a timeout_ms (in milliseconds), unlock the given lock state automatically.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/display
  /// @remarks If the process dies, then every lock will be removed.
  /// @param[in] type The power type to request lock
  /// @param[in] timeout_ms The positive number in milliseconds or @c 0 for permanent lock \n
  /// So you must release the permanent lock of power state with #device_power_release_lock() if @a timeout_ms is zero
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @see device_power_release_lock()
  int device_power_request_lock(
    int type,
    int timeout_ms,
  ) {
    return _device_power_request_lock(
      type,
      timeout_ms,
    );
  }

  late final _device_power_request_lockPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32, ffi.Int)>>(
          'device_power_request_lock');
  late final _device_power_request_lock =
      _device_power_request_lockPtr.asFunction<int Function(int, int)>();

  /// @brief Releases the given lock state which was locked before.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/display
  /// @param[in] type The power type to release lock
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @see device_power_request_lock()
  int device_power_release_lock(
    int type,
  ) {
    return _device_power_release_lock(
      type,
    );
  }

  late final _device_power_release_lockPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'device_power_release_lock');
  late final _device_power_release_lock =
      _device_power_release_lockPtr.asFunction<int Function(int)>();

  /// @deprecated Deprecated Since @if WEARABLE 3.0 @else 2.4 @endif
  /// @brief Changes the current power state to the normal/dim state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/display
  /// @remarks This API triggers turn on process and then updates the status when it completes. While the operation is on-going, the device_display_get_state() function returns previous display state.
  /// @param[in] dim Set @c true to set the dim state,
  /// otherwise set @c false to not set the dim state
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @post The device will be in #DISPLAY_STATE_NORMAL state.
  int device_power_wakeup(
    bool dim,
  ) {
    return _device_power_wakeup(
      dim,
    );
  }

  late final _device_power_wakeupPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Bool)>>(
          'device_power_wakeup');
  late final _device_power_wakeup =
      _device_power_wakeupPtr.asFunction<int Function(bool)>();

  /// @platform
  /// @brief Reboots the device.
  /// @details Will not return if the reboot is successful. \n
  /// It operates asynchronously.
  /// @since_tizen 2.3.1
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/reboot
  /// @param[in] reason Pass to the platform and kernel to request special reboot reason, or null
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  int device_power_reboot(
    ffi.Pointer<ffi.Char> reason,
  ) {
    return _device_power_reboot(
      reason,
    );
  }

  late final _device_power_rebootPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'device_power_reboot');
  late final _device_power_reboot =
      _device_power_rebootPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the information whether IR module is available.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/use_ir
  /// @param[out] available The information whether IR is available
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  int device_ir_is_available(
    ffi.Pointer<ffi.Bool> available,
  ) {
    return _device_ir_is_available(
      available,
    );
  }

  late final _device_ir_is_availablePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Bool>)>>(
          'device_ir_is_available');
  late final _device_ir_is_available = _device_ir_is_availablePtr
      .asFunction<int Function(ffi.Pointer<ffi.Bool>)>();

  /// @brief Transmits IR command.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/use_ir
  /// @param[in] carrier_frequency Carrier frequency to transmit IR command (Hertz)
  /// @param[in] pattern Integer array of IR command
  /// @param[in] size Size of IR command pattern
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #DEVICE_ERROR_NONE Successful
  /// @retval #DEVICE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DEVICE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #DEVICE_ERROR_OPERATION_FAILED Operation failed
  /// @retval #DEVICE_ERROR_NOT_SUPPORTED Not supported device
  int device_ir_transmit(
    int carrier_frequency,
    ffi.Pointer<ffi.Int> pattern,
    int size,
  ) {
    return _device_ir_transmit(
      carrier_frequency,
      pattern,
      size,
    );
  }

  late final _device_ir_transmitPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<ffi.Int>, ffi.Int)>>('device_ir_transmit');
  late final _device_ir_transmit = _device_ir_transmitPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>, int)>();

  /// @brief Sends log with priority and tag.
  /// @details for application.
  /// @if MOBILE @since_tizen 2.3 @elseif WEARABLE @since_tizen 2.3.1 @endif
  /// @param[in] prio priority level of type #log_priority
  /// @param[in] tag tag - a null-terminated string
  /// @param[in] fmt format string - same as printf
  /// @return On success, the function returns the number of bytes written.
  /// On error, a negative errno-style error code
  /// @retval #DLOG_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DLOG_ERROR_NOT_PERMITTED Operation not permitted
  /// @pre none
  /// @post none
  /// @see dlog_vprint
  ///
  /// @code
  /// #include<dlog.h>
  /// int main(void)
  /// {
  /// int integer = 21;
  /// char string[] = "test dlog";
  ///
  /// dlog_print(DLOG_INFO, "USR_TAG", "test dlog");
  /// dlog_print(DLOG_INFO, "USR_TAG", "%s, %d", string, integer);
  /// return 0;
  /// }
  /// @endcode
  int dlog_print(
    int prio,
    ffi.Pointer<ffi.Char> tag,
    ffi.Pointer<ffi.Char> fmt,
  ) {
    return _dlog_print(
      prio,
      tag,
      fmt,
    );
  }

  late final _dlog_printPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('dlog_print');
  late final _dlog_print = _dlog_printPtr.asFunction<
      int Function(int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Sends log with priority, tag, and va_list.
  /// @details for application.
  /// @if MOBILE @since_tizen 2.3 @elseif WEARABLE @since_tizen 2.3.1 @endif
  /// @param[in] prio priority level of type #log_priority
  /// @param[in] tag tag - a null-terminated string
  /// @param[in] fmt format string - same as printf
  /// @param[in] ap va_list
  /// @return On success, the function returns the number of bytes written.
  /// On error, a negative errno-style error code
  /// @retval #DLOG_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #DLOG_ERROR_NOT_PERMITTED Operation not permitted
  /// @pre none
  /// @post none
  /// @see dlog_print
  ///
  /// @code
  /// #include<dlog.h>
  /// void my_debug_print(char *format, ...)
  /// {
  /// va_list ap;
  ///
  /// va_start(ap, format);
  /// dlog_vprint(DLOG_INFO, "USR_TAG", format, ap);
  /// va_end(ap);
  /// }
  ///
  /// int main(void)
  /// {
  /// my_debug_print("%s", "test dlog");
  /// my_debug_print("%s, %d", "test dlog", 21);
  /// return 0;
  /// }
  /// @endcode
  int dlog_vprint(
    int prio,
    ffi.Pointer<ffi.Char> tag,
    ffi.Pointer<ffi.Char> fmt,
    va_list ap,
  ) {
    return _dlog_vprint(
      prio,
      tag,
      fmt,
      ap,
    );
  }

  late final _dlog_vprintPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>, va_list)>>('dlog_vprint');
  late final _dlog_vprint = _dlog_vprintPtr.asFunction<
      int Function(
          int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, va_list)>();

  /// @brief Initializes feedback API.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks If this function is not called in advance, other function will return #FEEDBACK_ERROR_NOT_INITIALIZED.
  /// And for controlling haptic device, the privilege should be set to, %http://tizen.org/privilege/haptic.
  /// If you don't have the haptic privilege, this function initializes only sound.
  /// It does not return any error in this case.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #FEEDBACK_ERROR_NONE Successful
  /// @post feedback_deinitialize()
  /// @see feedback_deinitialize()
  int feedback_initialize() {
    return _feedback_initialize();
  }

  late final _feedback_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('feedback_initialize');
  late final _feedback_initialize =
      _feedback_initializePtr.asFunction<int Function()>();

  /// @brief Deinitializes feedback API.
  /// @details This function must be called when feedback functions are no longer needed.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks If you don't want to use feedback anymore, you need to deinitialize with this function.
  /// And for controlling haptic device, the privilege should be set to, %http://tizen.org/privilege/haptic.
  /// If you don't have the haptic privilege, this function deinitializes only sound.
  /// It does not return any error in this case.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #FEEDBACK_ERROR_NONE Successful
  /// @retval #FEEDBACK_ERROR_NOT_INITIALIZED Not initialized
  /// @pre feedback_initialize()
  /// @see feedback_initialize()
  int feedback_deinitialize() {
    return _feedback_deinitialize();
  }

  late final _feedback_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('feedback_deinitialize');
  late final _feedback_deinitialize =
      _feedback_deinitializePtr.asFunction<int Function()>();

  /// @brief Plays various types of reactions that are pre-defined.
  /// @details This function can be used to react to pre-defined actions. \n
  /// It play various types of system pre-defined media or vibration patterns.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks Currently, there are two types of reactions: sound and vibration. \n
  /// Depending on the settings, some types cannot operate.
  /// For example, when set to silent mode, the device doesn't produce any sound.
  /// If to play one of the devices is successful, this function regards as success.
  /// And for controlling haptic device, the privilege should be set to, %http://tizen.org/privilege/haptic.
  /// If you don't have the haptic privilege, it only works sound operation.
  /// It does not return any error in this case.
  /// @param[in] pattern The pre-defined pattern
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #FEEDBACK_ERROR_NONE Successful
  /// @retval #FEEDBACK_ERROR_OPERATION_FAILED Operation not permitted
  /// @retval #FEEDBACK_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #FEEDBACK_ERROR_NOT_SUPPORTED Not supported device
  /// @retval #FEEDBACK_ERROR_NOT_INITIALIZED Not initialized
  /// @pre feedback_initialize()
  int feedback_play(
    int pattern,
  ) {
    return _feedback_play(
      pattern,
    );
  }

  late final _feedback_playPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>('feedback_play');
  late final _feedback_play = _feedback_playPtr.asFunction<int Function(int)>();

  /// @brief Plays specific type of reactions that are pre-defined.
  /// @details This function can be used to react to pre-defined actions. \n
  /// It play specific type of system pre-defined pattern.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks Currently, there are two types of reactions: sound and vibration. \n
  /// Depending on the settings, some types cannot operate.
  /// For example, when set to silent mode, the device doesn't produce any sound.
  /// And for controlling haptic device, the privilege should be set to, %http://tizen.org/privilege/haptic.
  /// If you don't have the haptic privilege, it returns FEEDBACK_ERROR_PERMISSION_DENIED error.
  /// @param[in] type The pattern type
  /// @param[in] pattern The pre-defined pattern
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #FEEDBACK_ERROR_NONE Successful
  /// @retval #FEEDBACK_ERROR_OPERATION_FAILED Operation not permitted
  /// @retval #FEEDBACK_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #FEEDBACK_ERROR_NOT_SUPPORTED Not supported device
  /// @retval #FEEDBACK_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #FEEDBACK_ERROR_NOT_INITIALIZED Not initialized
  /// @pre feedback_initialize()
  int feedback_play_type(
    int type,
    int pattern,
  ) {
    return _feedback_play_type(
      type,
      pattern,
    );
  }

  late final _feedback_play_typePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32, ffi.Int32)>>(
          'feedback_play_type');
  late final _feedback_play_type =
      _feedback_play_typePtr.asFunction<int Function(int, int)>();

  /// @brief Stops various types of reactions.
  /// @details This function can be used to stop reaction to pre-defined actions. \n
  /// It stops system pre-defined vibration patterns.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks This function does not support to stop media sound actions. \n
  /// In this case, it will return FEEDBACK_ERROR_NOT_SUPPORTED error.
  /// And for controlling haptic device, the privilege should be set to, %http://tizen.org/privilege/haptic.
  /// If you don't have the haptic privilege, it only works sound operation.
  /// It does not return any error in this case.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #FEEDBACK_ERROR_NONE Successful
  /// @retval #FEEDBACK_ERROR_OPERATION_FAILED Operation not permitted
  /// @retval #FEEDBACK_ERROR_NOT_SUPPORTED Not supported device
  /// @retval #FEEDBACK_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #FEEDBACK_ERROR_NOT_INITIALIZED Not initialized
  /// @pre feedback_initialize()
  int feedback_stop() {
    return _feedback_stop();
  }

  late final _feedback_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('feedback_stop');
  late final _feedback_stop = _feedback_stopPtr.asFunction<int Function()>();

  /// @brief Checks if the pattern is supported.
  /// @details This function can be used to check if a specific pattern is supported.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] type The pattern type
  /// @param[in] pattern The pre-defined pattern
  /// @param[out] status True means the pattern is supported,
  /// otherwise not supported
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #FEEDBACK_ERROR_NONE Successful
  /// @retval #FEEDBACK_ERROR_OPERATION_FAILED Operation not permitted
  /// @retval #FEEDBACK_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #FEEDBACK_ERROR_NOT_SUPPORTED Not supported device
  /// @retval #FEEDBACK_ERROR_NOT_INITIALIZED Not initialized
  /// @pre feedback_initialize()
  int feedback_is_supported_pattern(
    int type,
    int pattern,
    ffi.Pointer<ffi.Bool> status,
  ) {
    return _feedback_is_supported_pattern(
      type,
      pattern,
      status,
    );
  }

  late final _feedback_is_supported_patternPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Int32,
              ffi.Pointer<ffi.Bool>)>>('feedback_is_supported_pattern');
  late final _feedback_is_supported_pattern = _feedback_is_supported_patternPtr
      .asFunction<int Function(int, int, ffi.Pointer<ffi.Bool>)>();

  /// @brief Registers a change event callback for all media keys.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #MEDIA_KEY_ERROR_NONE Successful
  /// @retval  #MEDIA_KEY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval  #MEDIA_KEY_ERROR_OPERATION_FAILED Reserve key failed
  /// @see media_key_release()
  int media_key_reserve(
    media_key_event_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _media_key_reserve(
      callback,
      user_data,
    );
  }

  late final _media_key_reservePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              media_key_event_cb, ffi.Pointer<ffi.Void>)>>('media_key_reserve');
  late final _media_key_reserve = _media_key_reservePtr
      .asFunction<int Function(media_key_event_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the change event callback function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval  #MEDIA_KEY_ERROR_NONE Successful
  /// @retval  #MEDIA_KEY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval  #MEDIA_KEY_ERROR_OPERATION_FAILED Release key failed
  /// @see media_key_reserve()
  int media_key_release() {
    return _media_key_release();
  }

  late final _media_key_releasePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('media_key_release');
  late final _media_key_release =
      _media_key_releasePtr.asFunction<int Function()>();

  /// @platform
  /// @brief Opens a GPIO pin.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  /// @remarks @a gpio should be released with peripheral_gpio_close()
  ///
  /// @param[in] gpio_pin The GPIO pin number
  /// @param[out] gpio The GPIO handle is created on success
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_OUT_OF_MEMORY Memory allocation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_RESOURCE_BUSY Device is in use
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @post peripheral_gpio_close()
  int peripheral_gpio_open(
    int gpio_pin,
    ffi.Pointer<peripheral_gpio_h> gpio,
  ) {
    return _peripheral_gpio_open(
      gpio_pin,
      gpio,
    );
  }

  late final _peripheral_gpio_openPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<peripheral_gpio_h>)>>('peripheral_gpio_open');
  late final _peripheral_gpio_open = _peripheral_gpio_openPtr
      .asFunction<int Function(int, ffi.Pointer<peripheral_gpio_h>)>();

  /// @platform
  /// @brief Closes a GPIO pin.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] gpio The GPIO handle
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @pre peripheral_gpio_open()
  int peripheral_gpio_close(
    peripheral_gpio_h gpio,
  ) {
    return _peripheral_gpio_close(
      gpio,
    );
  }

  late final _peripheral_gpio_closePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(peripheral_gpio_h)>>(
          'peripheral_gpio_close');
  late final _peripheral_gpio_close =
      _peripheral_gpio_closePtr.asFunction<int Function(peripheral_gpio_h)>();

  /// @platform
  /// @brief Sets the GPIO direction.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] gpio The GPIO handle
  /// @param[in] direction The direction of the GPIO pin
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_gpio_direction_e
  int peripheral_gpio_set_direction(
    peripheral_gpio_h gpio,
    int direction,
  ) {
    return _peripheral_gpio_set_direction(
      gpio,
      direction,
    );
  }

  late final _peripheral_gpio_set_directionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_gpio_h, ffi.Int32)>>(
      'peripheral_gpio_set_direction');
  late final _peripheral_gpio_set_direction = _peripheral_gpio_set_directionPtr
      .asFunction<int Function(peripheral_gpio_h, int)>();

  /// @platform
  /// @brief Sets the GPIO edge mode.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] gpio The GPIO handle
  /// @param[in] edge The edge mode of the GPIO pin
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_gpio_edge_e
  int peripheral_gpio_set_edge_mode(
    peripheral_gpio_h gpio,
    int edge,
  ) {
    return _peripheral_gpio_set_edge_mode(
      gpio,
      edge,
    );
  }

  late final _peripheral_gpio_set_edge_modePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_gpio_h, ffi.Int32)>>(
      'peripheral_gpio_set_edge_mode');
  late final _peripheral_gpio_set_edge_mode = _peripheral_gpio_set_edge_modePtr
      .asFunction<int Function(peripheral_gpio_h, int)>();

  /// @platform
  /// @brief Sets the GPIO interrupted callback to be invoked when the GPIO interrupt is triggered.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] gpio The GPIO handle
  /// @param[in] callback The GPIO interrupted callback function to set
  /// @param[in] user_data The user data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @post peripheral_gpio_unset_interrupted_cb()
  /// @see peripheral_gpio_set_edge_mode()
  int peripheral_gpio_set_interrupted_cb(
    peripheral_gpio_h gpio,
    peripheral_gpio_interrupted_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _peripheral_gpio_set_interrupted_cb(
      gpio,
      callback,
      user_data,
    );
  }

  late final _peripheral_gpio_set_interrupted_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_gpio_h, peripheral_gpio_interrupted_cb,
              ffi.Pointer<ffi.Void>)>>('peripheral_gpio_set_interrupted_cb');
  late final _peripheral_gpio_set_interrupted_cb =
      _peripheral_gpio_set_interrupted_cbPtr.asFunction<
          int Function(peripheral_gpio_h, peripheral_gpio_interrupted_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @platform
  /// @brief Unsets the GPIO interrupted callback.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] gpio The GPIO handle
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  ///
  /// @pre peripheral_gpio_set_interrupted_cb()
  int peripheral_gpio_unset_interrupted_cb(
    peripheral_gpio_h gpio,
  ) {
    return _peripheral_gpio_unset_interrupted_cb(
      gpio,
    );
  }

  late final _peripheral_gpio_unset_interrupted_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(peripheral_gpio_h)>>(
          'peripheral_gpio_unset_interrupted_cb');
  late final _peripheral_gpio_unset_interrupted_cb =
      _peripheral_gpio_unset_interrupted_cbPtr
          .asFunction<int Function(peripheral_gpio_h)>();

  /// @platform
  /// @brief Gets the current value of the GPIO pin.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] gpio The GPIO handle
  /// @param[out] value The value to get
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_gpio_write()
  int peripheral_gpio_read(
    peripheral_gpio_h gpio,
    ffi.Pointer<ffi.Uint32> value,
  ) {
    return _peripheral_gpio_read(
      gpio,
      value,
    );
  }

  late final _peripheral_gpio_readPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_gpio_h,
              ffi.Pointer<ffi.Uint32>)>>('peripheral_gpio_read');
  late final _peripheral_gpio_read = _peripheral_gpio_readPtr
      .asFunction<int Function(peripheral_gpio_h, ffi.Pointer<ffi.Uint32>)>();

  /// @platform
  /// @brief Sets the value of the GPIO pin.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] gpio The GPIO handle
  /// @param[in] value The value to set (must be 0 or 1)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_gpio_read()
  int peripheral_gpio_write(
    peripheral_gpio_h gpio,
    int value,
  ) {
    return _peripheral_gpio_write(
      gpio,
      value,
    );
  }

  late final _peripheral_gpio_writePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_gpio_h, ffi.Uint32)>>(
      'peripheral_gpio_write');
  late final _peripheral_gpio_write = _peripheral_gpio_writePtr
      .asFunction<int Function(peripheral_gpio_h, int)>();

  /// @platform
  /// @brief Opens an I2C slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  /// @remarks @a i2c should be released with peripheral_i2c_close()
  ///
  /// @param[in] bus The I2C bus number that the slave device is connected
  /// @param[in] address The address of the slave device
  /// @param[out] i2c The I2C handle is created on success
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_OUT_OF_MEMORY Memory allocation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_RESOURCE_BUSY Device is in use
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @post peripheral_i2c_close()
  int peripheral_i2c_open(
    int bus,
    int address,
    ffi.Pointer<peripheral_i2c_h> i2c,
  ) {
    return _peripheral_i2c_open(
      bus,
      address,
      i2c,
    );
  }

  late final _peripheral_i2c_openPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int,
              ffi.Pointer<peripheral_i2c_h>)>>('peripheral_i2c_open');
  late final _peripheral_i2c_open = _peripheral_i2c_openPtr
      .asFunction<int Function(int, int, ffi.Pointer<peripheral_i2c_h>)>();

  /// @platform
  /// @brief Closes an I2C slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] i2c The I2C handle
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @pre peripheral_i2c_open()
  int peripheral_i2c_close(
    peripheral_i2c_h i2c,
  ) {
    return _peripheral_i2c_close(
      i2c,
    );
  }

  late final _peripheral_i2c_closePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(peripheral_i2c_h)>>(
          'peripheral_i2c_close');
  late final _peripheral_i2c_close =
      _peripheral_i2c_closePtr.asFunction<int Function(peripheral_i2c_h)>();

  /// @platform
  /// @brief Reads the bytes data from the I2C slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] i2c The I2C handle
  /// @param[out] data The data buffer to read
  /// @param[in] length The size of data buffer (in bytes)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_i2c_write()
  int peripheral_i2c_read(
    peripheral_i2c_h i2c,
    ffi.Pointer<ffi.Uint8> data,
    int length,
  ) {
    return _peripheral_i2c_read(
      i2c,
      data,
      length,
    );
  }

  late final _peripheral_i2c_readPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_i2c_h, ffi.Pointer<ffi.Uint8>,
              ffi.Uint32)>>('peripheral_i2c_read');
  late final _peripheral_i2c_read = _peripheral_i2c_readPtr.asFunction<
      int Function(peripheral_i2c_h, ffi.Pointer<ffi.Uint8>, int)>();

  /// @platform
  /// @brief Writes the bytes data to the I2C slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] i2c The I2C handle
  /// @param[in] data The data buffer to write
  /// @param[in] length The size of data buffer (in bytes)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_i2c_read()
  int peripheral_i2c_write(
    peripheral_i2c_h i2c,
    ffi.Pointer<ffi.Uint8> data,
    int length,
  ) {
    return _peripheral_i2c_write(
      i2c,
      data,
      length,
    );
  }

  late final _peripheral_i2c_writePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_i2c_h, ffi.Pointer<ffi.Uint8>,
              ffi.Uint32)>>('peripheral_i2c_write');
  late final _peripheral_i2c_write = _peripheral_i2c_writePtr.asFunction<
      int Function(peripheral_i2c_h, ffi.Pointer<ffi.Uint8>, int)>();

  /// @platform
  /// @brief Reads single byte data from the register of the I2C slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] i2c The I2C handle
  /// @param[in] reg The register address of the I2C slave device to read
  /// @param[out] data The single byte data to read
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_i2c_write_register_byte()
  int peripheral_i2c_read_register_byte(
    peripheral_i2c_h i2c,
    int reg,
    ffi.Pointer<ffi.Uint8> data,
  ) {
    return _peripheral_i2c_read_register_byte(
      i2c,
      reg,
      data,
    );
  }

  late final _peripheral_i2c_read_register_bytePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_i2c_h, ffi.Uint8,
              ffi.Pointer<ffi.Uint8>)>>('peripheral_i2c_read_register_byte');
  late final _peripheral_i2c_read_register_byte =
      _peripheral_i2c_read_register_bytePtr.asFunction<
          int Function(peripheral_i2c_h, int, ffi.Pointer<ffi.Uint8>)>();

  /// @platform
  /// @brief Writes single byte data to the register of the I2C slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] i2c The I2C handle
  /// @param[in] reg The register address of the I2C slave device to write
  /// @param[in] data The single byte data to write
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_i2c_read_register_byte()
  int peripheral_i2c_write_register_byte(
    peripheral_i2c_h i2c,
    int reg,
    int data,
  ) {
    return _peripheral_i2c_write_register_byte(
      i2c,
      reg,
      data,
    );
  }

  late final _peripheral_i2c_write_register_bytePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_i2c_h, ffi.Uint8,
              ffi.Uint8)>>('peripheral_i2c_write_register_byte');
  late final _peripheral_i2c_write_register_byte =
      _peripheral_i2c_write_register_bytePtr
          .asFunction<int Function(peripheral_i2c_h, int, int)>();

  /// @platform
  /// @brief Reads word data from the register of the I2C slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] i2c The I2C handle
  /// @param[in] reg The register address of the I2C slave device to read
  /// @param[out] data The word(2 bytes) data to read
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_i2c_write_register_word()
  int peripheral_i2c_read_register_word(
    peripheral_i2c_h i2c,
    int reg,
    ffi.Pointer<ffi.Uint16> data,
  ) {
    return _peripheral_i2c_read_register_word(
      i2c,
      reg,
      data,
    );
  }

  late final _peripheral_i2c_read_register_wordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_i2c_h, ffi.Uint8,
              ffi.Pointer<ffi.Uint16>)>>('peripheral_i2c_read_register_word');
  late final _peripheral_i2c_read_register_word =
      _peripheral_i2c_read_register_wordPtr.asFunction<
          int Function(peripheral_i2c_h, int, ffi.Pointer<ffi.Uint16>)>();

  /// @platform
  /// @brief Writes word data to the register of the I2C slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] i2c The I2C handle
  /// @param[in] reg The register address of the I2C slave device to write
  /// @param[in] data The word(2 bytes) data to write
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_i2c_read_register_word()
  int peripheral_i2c_write_register_word(
    peripheral_i2c_h i2c,
    int reg,
    int data,
  ) {
    return _peripheral_i2c_write_register_word(
      i2c,
      reg,
      data,
    );
  }

  late final _peripheral_i2c_write_register_wordPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_i2c_h, ffi.Uint8,
              ffi.Uint16)>>('peripheral_i2c_write_register_word');
  late final _peripheral_i2c_write_register_word =
      _peripheral_i2c_write_register_wordPtr
          .asFunction<int Function(peripheral_i2c_h, int, int)>();

  /// @platform
  /// @brief Opens the PWM pin.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  /// @remarks @a pwm should be released with peripheral_pwm_close()
  ///
  /// @param[in] chip The PWM chip number
  /// @param[in] pin The PWM pin(channel) number to control
  /// @param[out] pwm The PWM handle is created on success
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_OUT_OF_MEMORY Memory allocation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_RESOURCE_BUSY Device is in use
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @post peripheral_pwm_close()
  int peripheral_pwm_open(
    int chip,
    int pin,
    ffi.Pointer<peripheral_pwm_h> pwm,
  ) {
    return _peripheral_pwm_open(
      chip,
      pin,
      pwm,
    );
  }

  late final _peripheral_pwm_openPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int,
              ffi.Pointer<peripheral_pwm_h>)>>('peripheral_pwm_open');
  late final _peripheral_pwm_open = _peripheral_pwm_openPtr
      .asFunction<int Function(int, int, ffi.Pointer<peripheral_pwm_h>)>();

  /// @platform
  /// @brief Closes the PWM pin.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] pwm The PWM handle
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @pre peripheral_pwm_open()
  int peripheral_pwm_close(
    peripheral_pwm_h pwm,
  ) {
    return _peripheral_pwm_close(
      pwm,
    );
  }

  late final _peripheral_pwm_closePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(peripheral_pwm_h)>>(
          'peripheral_pwm_close');
  late final _peripheral_pwm_close =
      _peripheral_pwm_closePtr.asFunction<int Function(peripheral_pwm_h)>();

  /// @platform
  /// @brief Sets period of the PWM pin.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] pwm The PWM handle
  /// @param[in] period_ns The total period of the PWM pin (in nanoseconds)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  int peripheral_pwm_set_period(
    peripheral_pwm_h pwm,
    int period_ns,
  ) {
    return _peripheral_pwm_set_period(
      pwm,
      period_ns,
    );
  }

  late final _peripheral_pwm_set_periodPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_pwm_h, ffi.Uint32)>>(
      'peripheral_pwm_set_period');
  late final _peripheral_pwm_set_period = _peripheral_pwm_set_periodPtr
      .asFunction<int Function(peripheral_pwm_h, int)>();

  /// @platform
  /// @brief Sets duty cycle of the PWM pin.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] pwm The PWM handle
  /// @param[in] duty_cycle_ns The duty cycle of the PWM pin (in nanoseconds)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  int peripheral_pwm_set_duty_cycle(
    peripheral_pwm_h pwm,
    int duty_cycle_ns,
  ) {
    return _peripheral_pwm_set_duty_cycle(
      pwm,
      duty_cycle_ns,
    );
  }

  late final _peripheral_pwm_set_duty_cyclePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_pwm_h, ffi.Uint32)>>(
      'peripheral_pwm_set_duty_cycle');
  late final _peripheral_pwm_set_duty_cycle = _peripheral_pwm_set_duty_cyclePtr
      .asFunction<int Function(peripheral_pwm_h, int)>();

  /// @platform
  /// @brief Sets polarity of the PWM pin.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] pwm The PWM handle
  /// @param[in] polarity The polarity of the PWM pin
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_pwm_polarity_e
  int peripheral_pwm_set_polarity(
    peripheral_pwm_h pwm,
    int polarity,
  ) {
    return _peripheral_pwm_set_polarity(
      pwm,
      polarity,
    );
  }

  late final _peripheral_pwm_set_polarityPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_pwm_h, ffi.Int32)>>(
      'peripheral_pwm_set_polarity');
  late final _peripheral_pwm_set_polarity = _peripheral_pwm_set_polarityPtr
      .asFunction<int Function(peripheral_pwm_h, int)>();

  /// @platform
  /// @brief Enables the PWM pin.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] pwm The PWM handle
  /// @param[in] enabled Enable/disable the PWM pin
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  int peripheral_pwm_set_enabled(
    peripheral_pwm_h pwm,
    bool enabled,
  ) {
    return _peripheral_pwm_set_enabled(
      pwm,
      enabled,
    );
  }

  late final _peripheral_pwm_set_enabledPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(peripheral_pwm_h, ffi.Bool)>>(
          'peripheral_pwm_set_enabled');
  late final _peripheral_pwm_set_enabled = _peripheral_pwm_set_enabledPtr
      .asFunction<int Function(peripheral_pwm_h, bool)>();

  /// @platform
  /// @brief Opens the UART slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  /// @remarks @a uart should be released with peripheral_uart_close()
  ///
  /// @param[in] port The UART port number that the slave device is connected
  /// @param[out] uart The UART handle is created on success
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_OUT_OF_MEMORY Memory allocation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_RESOURCE_BUSY Device is in use
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @post peripheral_uart_close()
  int peripheral_uart_open(
    int port,
    ffi.Pointer<peripheral_uart_h> uart,
  ) {
    return _peripheral_uart_open(
      port,
      uart,
    );
  }

  late final _peripheral_uart_openPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<peripheral_uart_h>)>>('peripheral_uart_open');
  late final _peripheral_uart_open = _peripheral_uart_openPtr
      .asFunction<int Function(int, ffi.Pointer<peripheral_uart_h>)>();

  /// @platform
  /// @brief Closes the UART slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] uart The UART handle
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @pre peripheral_uart_open()
  int peripheral_uart_close(
    peripheral_uart_h uart,
  ) {
    return _peripheral_uart_close(
      uart,
    );
  }

  late final _peripheral_uart_closePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(peripheral_uart_h)>>(
          'peripheral_uart_close');
  late final _peripheral_uart_close =
      _peripheral_uart_closePtr.asFunction<int Function(peripheral_uart_h)>();

  /// @platform
  /// @brief Sets baud rate of the UART slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] uart The UART handle
  /// @param[in] baud Baud rate of the UART slave device
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_uart_baud_rate_e
  int peripheral_uart_set_baud_rate(
    peripheral_uart_h uart,
    int baud,
  ) {
    return _peripheral_uart_set_baud_rate(
      uart,
      baud,
    );
  }

  late final _peripheral_uart_set_baud_ratePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_uart_h, ffi.Int32)>>(
      'peripheral_uart_set_baud_rate');
  late final _peripheral_uart_set_baud_rate = _peripheral_uart_set_baud_ratePtr
      .asFunction<int Function(peripheral_uart_h, int)>();

  /// @platform
  /// @brief Sets byte size of the UART slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] uart The UART handle
  /// @param[in] byte_size Byte size of the UART slave device
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_uart_byte_size_e
  int peripheral_uart_set_byte_size(
    peripheral_uart_h uart,
    int byte_size,
  ) {
    return _peripheral_uart_set_byte_size(
      uart,
      byte_size,
    );
  }

  late final _peripheral_uart_set_byte_sizePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_uart_h, ffi.Int32)>>(
      'peripheral_uart_set_byte_size');
  late final _peripheral_uart_set_byte_size = _peripheral_uart_set_byte_sizePtr
      .asFunction<int Function(peripheral_uart_h, int)>();

  /// @platform
  /// @brief Sets parity bit of the UART slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] uart The UART handle
  /// @param[in] parity Parity bit of the UART slave device
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_uart_parity_e
  int peripheral_uart_set_parity(
    peripheral_uart_h uart,
    int parity,
  ) {
    return _peripheral_uart_set_parity(
      uart,
      parity,
    );
  }

  late final _peripheral_uart_set_parityPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_uart_h, ffi.Int32)>>(
      'peripheral_uart_set_parity');
  late final _peripheral_uart_set_parity = _peripheral_uart_set_parityPtr
      .asFunction<int Function(peripheral_uart_h, int)>();

  /// @platform
  /// @brief Sets stop bits of the UART slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] uart The UART handle
  /// @param[in] stop_bits Stop bits of the UART slave device
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_uart_stop_bits_e
  int peripheral_uart_set_stop_bits(
    peripheral_uart_h uart,
    int stop_bits,
  ) {
    return _peripheral_uart_set_stop_bits(
      uart,
      stop_bits,
    );
  }

  late final _peripheral_uart_set_stop_bitsPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_uart_h, ffi.Int32)>>(
      'peripheral_uart_set_stop_bits');
  late final _peripheral_uart_set_stop_bits = _peripheral_uart_set_stop_bitsPtr
      .asFunction<int Function(peripheral_uart_h, int)>();

  /// @platform
  /// @brief Sets flow control of the UART slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] uart The UART handle
  /// @param[in] sw_flow_control Software flow control (Turns a transmitter on or off)
  /// @param[in] hw_flow_control Hardware flow control (Turns "Request to Send/Clear to Send" on or off)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_uart_software_flow_control_e
  /// @see peripheral_uart_hardware_flow_control_e
  int peripheral_uart_set_flow_control(
    peripheral_uart_h uart,
    int sw_flow_control,
    int hw_flow_control,
  ) {
    return _peripheral_uart_set_flow_control(
      uart,
      sw_flow_control,
      hw_flow_control,
    );
  }

  late final _peripheral_uart_set_flow_controlPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_uart_h, ffi.Int32,
              ffi.Int32)>>('peripheral_uart_set_flow_control');
  late final _peripheral_uart_set_flow_control =
      _peripheral_uart_set_flow_controlPtr
          .asFunction<int Function(peripheral_uart_h, int, int)>();

  /// @platform
  /// @brief Reads data from the UART slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] uart The UART handle
  /// @param[out] data The buffer to read
  /// @param[out] length The size of buffer (in bytes)
  ///
  /// @return the number of bytes read on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_TRY_AGAIN Try again
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_uart_write()
  int peripheral_uart_read(
    peripheral_uart_h uart,
    ffi.Pointer<ffi.Uint8> data,
    int length,
  ) {
    return _peripheral_uart_read(
      uart,
      data,
      length,
    );
  }

  late final _peripheral_uart_readPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_uart_h, ffi.Pointer<ffi.Uint8>,
              ffi.Uint32)>>('peripheral_uart_read');
  late final _peripheral_uart_read = _peripheral_uart_readPtr.asFunction<
      int Function(peripheral_uart_h, ffi.Pointer<ffi.Uint8>, int)>();

  /// @platform
  /// @brief Writes data to the UART slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] uart The UART handle
  /// @param[in] data The buffer to write
  /// @param[in] length The size of buffer (in bytes)
  ///
  /// @return the number of bytes write on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_TRY_AGAIN Try again
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_uart_read()
  int peripheral_uart_write(
    peripheral_uart_h uart,
    ffi.Pointer<ffi.Uint8> data,
    int length,
  ) {
    return _peripheral_uart_write(
      uart,
      data,
      length,
    );
  }

  late final _peripheral_uart_writePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_uart_h, ffi.Pointer<ffi.Uint8>,
              ffi.Uint32)>>('peripheral_uart_write');
  late final _peripheral_uart_write = _peripheral_uart_writePtr.asFunction<
      int Function(peripheral_uart_h, ffi.Pointer<ffi.Uint8>, int)>();

  /// @platform
  /// @brief Opens a SPI slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  /// @remarks @a spi should be released with peripheral_spi_close()
  ///
  /// @param[in] bus The SPI bus number
  /// @param[in] cs The SPI chip select number
  /// @param[out] spi The SPI slave device handle
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_OUT_OF_MEMORY Memory allocation failed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_RESOURCE_BUSY Device is in use
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @post peripheral_spi_close()
  int peripheral_spi_open(
    int bus,
    int cs,
    ffi.Pointer<peripheral_spi_h> spi,
  ) {
    return _peripheral_spi_open(
      bus,
      cs,
      spi,
    );
  }

  late final _peripheral_spi_openPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int,
              ffi.Pointer<peripheral_spi_h>)>>('peripheral_spi_open');
  late final _peripheral_spi_open = _peripheral_spi_openPtr
      .asFunction<int Function(int, int, ffi.Pointer<peripheral_spi_h>)>();

  /// @platform
  /// @brief Closes the SPI slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] spi The SPI slave device handle
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_spi_open()
  int peripheral_spi_close(
    peripheral_spi_h spi,
  ) {
    return _peripheral_spi_close(
      spi,
    );
  }

  late final _peripheral_spi_closePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(peripheral_spi_h)>>(
          'peripheral_spi_close');
  late final _peripheral_spi_close =
      _peripheral_spi_closePtr.asFunction<int Function(peripheral_spi_h)>();

  /// @platform
  /// @brief Sets the SPI transfer mode.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] spi The SPI slave device handle
  /// @param[in] mode The SPI transfer mode
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_spi_mode_e
  int peripheral_spi_set_mode(
    peripheral_spi_h spi,
    int mode,
  ) {
    return _peripheral_spi_set_mode(
      spi,
      mode,
    );
  }

  late final _peripheral_spi_set_modePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_spi_h, ffi.Int32)>>(
      'peripheral_spi_set_mode');
  late final _peripheral_spi_set_mode = _peripheral_spi_set_modePtr
      .asFunction<int Function(peripheral_spi_h, int)>();

  /// @platform
  /// @brief Sets the SPI bit order.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] spi The SPI slave device handle
  /// @param[in] bit_order The transfer bit order
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_spi_bit_order_e
  int peripheral_spi_set_bit_order(
    peripheral_spi_h spi,
    int bit_order,
  ) {
    return _peripheral_spi_set_bit_order(
      spi,
      bit_order,
    );
  }

  late final _peripheral_spi_set_bit_orderPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_spi_h, ffi.Int32)>>(
      'peripheral_spi_set_bit_order');
  late final _peripheral_spi_set_bit_order = _peripheral_spi_set_bit_orderPtr
      .asFunction<int Function(peripheral_spi_h, int)>();

  /// @platform
  /// @brief Sets the number of bits per word.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] spi The SPI slave device handle
  /// @param[in] bits The number of bits per word (in bits)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  int peripheral_spi_set_bits_per_word(
    peripheral_spi_h spi,
    int bits,
  ) {
    return _peripheral_spi_set_bits_per_word(
      spi,
      bits,
    );
  }

  late final _peripheral_spi_set_bits_per_wordPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_spi_h, ffi.Uint8)>>(
      'peripheral_spi_set_bits_per_word');
  late final _peripheral_spi_set_bits_per_word =
      _peripheral_spi_set_bits_per_wordPtr
          .asFunction<int Function(peripheral_spi_h, int)>();

  /// @platform
  /// @brief Sets the frequency of the SPI bus.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  /// @remarks The frequencies supported are board dependent.
  ///
  /// @param[in] spi The SPI slave device handle
  /// @param[in] freq_hz Frequency to set (in Hz)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  int peripheral_spi_set_frequency(
    peripheral_spi_h spi,
    int freq_hz,
  ) {
    return _peripheral_spi_set_frequency(
      spi,
      freq_hz,
    );
  }

  late final _peripheral_spi_set_frequencyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(peripheral_spi_h, ffi.Uint32)>>(
      'peripheral_spi_set_frequency');
  late final _peripheral_spi_set_frequency = _peripheral_spi_set_frequencyPtr
      .asFunction<int Function(peripheral_spi_h, int)>();

  /// @platform
  /// @brief Reads the bytes data from the SPI slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] spi The SPI slave device handle
  /// @param[out] data The data buffer to read
  /// @param[in] length The size of data buffer (in bytes)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_spi_write()
  int peripheral_spi_read(
    peripheral_spi_h spi,
    ffi.Pointer<ffi.Uint8> data,
    int length,
  ) {
    return _peripheral_spi_read(
      spi,
      data,
      length,
    );
  }

  late final _peripheral_spi_readPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_spi_h, ffi.Pointer<ffi.Uint8>,
              ffi.Uint32)>>('peripheral_spi_read');
  late final _peripheral_spi_read = _peripheral_spi_readPtr.asFunction<
      int Function(peripheral_spi_h, ffi.Pointer<ffi.Uint8>, int)>();

  /// @platform
  /// @brief Writes the bytes data to the SPI slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] spi The SPI slave device handle
  /// @param[in] data The data buffer to write
  /// @param[in] length The size of data buffer (in bytes)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_spi_read()
  int peripheral_spi_write(
    peripheral_spi_h spi,
    ffi.Pointer<ffi.Uint8> data,
    int length,
  ) {
    return _peripheral_spi_write(
      spi,
      data,
      length,
    );
  }

  late final _peripheral_spi_writePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_spi_h, ffi.Pointer<ffi.Uint8>,
              ffi.Uint32)>>('peripheral_spi_write');
  late final _peripheral_spi_write = _peripheral_spi_writePtr.asFunction<
      int Function(peripheral_spi_h, ffi.Pointer<ffi.Uint8>, int)>();

  /// @platform
  /// @brief Exchanges the bytes data to the SPI slave device.
  /// @since_tizen 4.0
  /// @privlevel platform
  /// @privilege http://tizen.org/privilege/peripheralio
  ///
  /// @param[in] spi The SPI slave device handle
  /// @param[in] txdata The data buffer to write
  /// @param[out] rxdata The data buffer to read
  /// @param[in] length The size of txdata and rxdata buffer (in bytes)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #PERIPHERAL_ERROR_NONE Successful
  /// @retval #PERIPHERAL_ERROR_IO_ERROR I/O operation failed
  /// @retval #PERIPHERAL_ERROR_NO_DEVICE Device does not exist or is removed
  /// @retval #PERIPHERAL_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #PERIPHERAL_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #PERIPHERAL_ERROR_NOT_SUPPORTED Not supported
  /// @retval #PERIPHERAL_ERROR_UNKNOWN Unknown internal error
  ///
  /// @see peripheral_spi_read()
  /// @see peripheral_spi_write()
  int peripheral_spi_transfer(
    peripheral_spi_h spi,
    ffi.Pointer<ffi.Uint8> txdata,
    ffi.Pointer<ffi.Uint8> rxdata,
    int length,
  ) {
    return _peripheral_spi_transfer(
      spi,
      txdata,
      rxdata,
      length,
    );
  }

  late final _peripheral_spi_transferPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(peripheral_spi_h, ffi.Pointer<ffi.Uint8>,
              ffi.Pointer<ffi.Uint8>, ffi.Uint32)>>('peripheral_spi_transfer');
  late final _peripheral_spi_transfer = _peripheral_spi_transferPtr.asFunction<
      int Function(peripheral_spi_h, ffi.Pointer<ffi.Uint8>,
          ffi.Pointer<ffi.Uint8>, int)>();

  /// @brief        Gets the integer value of the runtime information.
  /// @details      This function gets current state of the given key which represents specific runtime information.
  /// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in]  key    The runtime information status key from which data should be read
  /// @param[out] value  The current value of the given key
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An input/output error occurred when read value from system
  /// @retval #RUNTIME_INFO_ERROR_PERMISSION_DENIED  No permission to use the api
  /// @retval #RUNTIME_INFO_ERROR_NOT_SUPPORTED      Not supported parameter
  int runtime_info_get_value_int(
    int key,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _runtime_info_get_value_int(
      key,
      value,
    );
  }

  late final _runtime_info_get_value_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Int>)>>('runtime_info_get_value_int');
  late final _runtime_info_get_value_int = _runtime_info_get_value_intPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief        Gets the boolean value from the runtime information.
  /// @details      This function gets current state of the given key which represents specific runtime information.
  /// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in]  key    The runtime information key from which data should be read
  /// @param[out] value  The current value of the given key
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An input/output error occurred when read value from system
  /// @retval #RUNTIME_INFO_ERROR_PERMISSION_DENIED  No permission to use the api
  /// @retval #RUNTIME_INFO_ERROR_NOT_SUPPORTED      Not supported parameter
  int runtime_info_get_value_bool(
    int key,
    ffi.Pointer<ffi.Bool> value,
  ) {
    return _runtime_info_get_value_bool(
      key,
      value,
    );
  }

  late final _runtime_info_get_value_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ffi.Bool>)>>('runtime_info_get_value_bool');
  late final _runtime_info_get_value_bool = _runtime_info_get_value_boolPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief        Gets the double value from the runtime information.
  /// @details      This function gets current state of the given key which represents specific runtime information.
  /// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in]  key    The runtime information key from which data should be read
  /// @param[out] value  The current value of the given key
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An input/output error occurred when read value from system
  /// @retval #RUNTIME_INFO_ERROR_PERMISSION_DENIED  No permission to use the api
  /// @retval #RUNTIME_INFO_ERROR_NOT_SUPPORTED      Not supported parameter
  int runtime_info_get_value_double(
    int key,
    ffi.Pointer<ffi.Double> value,
  ) {
    return _runtime_info_get_value_double(
      key,
      value,
    );
  }

  late final _runtime_info_get_value_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ffi.Double>)>>('runtime_info_get_value_double');
  late final _runtime_info_get_value_double = _runtime_info_get_value_doublePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Double>)>();

  /// @brief        Gets the string value for specified runtime information.
  /// @details      This function gets current state of the given key which represents specific runtime information.
  /// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @remarks  You must release @a value using free().
  ///
  /// @param[in]  key    The runtime information key from which data should be read
  /// @param[out] value  The current value of the given key
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An input/output error occurred when read value from system
  /// @retval #RUNTIME_INFO_ERROR_OUT_OF_MEMORY      Out of memory
  /// @retval #RUNTIME_INFO_ERROR_PERMISSION_DENIED  No permission to use the api
  /// @retval #RUNTIME_INFO_ERROR_NOT_SUPPORTED      Not supported parameter
  int runtime_info_get_value_string(
    int key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _runtime_info_get_value_string(
      key,
      value,
    );
  }

  late final _runtime_info_get_value_stringPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int32, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'runtime_info_get_value_string');
  late final _runtime_info_get_value_string = _runtime_info_get_value_stringPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief        Registers a change event callback for given runtime information key.
  /// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in] key        The runtime information type
  /// @param[in] callback   The callback function to invoke
  /// @param[in] user_data  The user data to be passed to the callback function
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_PERMISSION_DENIED  No permission to use the api
  /// @retval #RUNTIME_INFO_ERROR_NOT_SUPPORTED      Not supported parameter
  ///
  /// @post  runtime_info_changed_cb() will be invoked.
  /// @see   runtime_info_unset_changed_cb()
  /// @see   runtime_info_changed_cb()
  int runtime_info_set_changed_cb(
    int key,
    runtime_info_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _runtime_info_set_changed_cb(
      key,
      callback,
      user_data,
    );
  }

  late final _runtime_info_set_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, runtime_info_changed_cb,
              ffi.Pointer<ffi.Void>)>>('runtime_info_set_changed_cb');
  late final _runtime_info_set_changed_cb =
      _runtime_info_set_changed_cbPtr.asFunction<
          int Function(int, runtime_info_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief        Unregisters the callback function.
  /// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
  ///
  /// @param[in] key  The runtime information type
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  ///
  /// @see  runtime_info_set_changed_cb()
  int runtime_info_unset_changed_cb(
    int key,
  ) {
    return _runtime_info_unset_changed_cb(
      key,
    );
  }

  late final _runtime_info_unset_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'runtime_info_unset_changed_cb');
  late final _runtime_info_unset_changed_cb =
      _runtime_info_unset_changed_cbPtr.asFunction<int Function(int)>();

  /// @brief        Gets system memory information.
  /// @since_tizen  @if WEARABLE 3.0 @else 2.4 @endif
  ///
  /// @param[out] info  The system memory information structure
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An Input/Output error occurred while reading from system
  ///
  /// @see  runtime_info_get_process_memory_info()
  int runtime_info_get_system_memory_info(
    ffi.Pointer<runtime_memory_info_s> info,
  ) {
    return _runtime_info_get_system_memory_info(
      info,
    );
  }

  late final _runtime_info_get_system_memory_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<runtime_memory_info_s>)>>(
      'runtime_info_get_system_memory_info');
  late final _runtime_info_get_system_memory_info =
      _runtime_info_get_system_memory_infoPtr
          .asFunction<int Function(ffi.Pointer<runtime_memory_info_s>)>();

  /// @brief        Gets memory information per process.
  /// @since_tizen  @if WEARABLE 3.0 @else 2.4 @endif
  ///
  /// @privlevel  public
  /// @privilege  %http://tizen.org/privilege/systemmonitor
  /// @remarks    You must release @a s value using free(). \n
  /// The size of @a s is the same with @a size.
  ///
  /// @param[in]  pid   The process unique id array
  /// @param[in]  size  The size of pid array
  /// @param[out] info  The memory information structure array of the processes
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_OUT_OF_MEMORY      Not able to allocate memory (for output param/other operations)
  /// @retval #RUNTIME_INFO_ERROR_REMOTE_IO          Call to resource daemon failed (dbus errors/resource daemon errors)
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An I/O error during dbus message operations
  /// @retval #RUNTIME_INFO_ERROR_PERMISSION_DENIED  Process not authorized to request process usage info
  ///
  /// @see  runtime_info_get_system_memory_info()
  int runtime_info_get_process_memory_info(
    ffi.Pointer<ffi.Int> pid,
    int size,
    ffi.Pointer<ffi.Pointer<process_memory_info_s>> info,
  ) {
    return _runtime_info_get_process_memory_info(
      pid,
      size,
      info,
    );
  }

  late final _runtime_info_get_process_memory_infoPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Int>, ffi.Int,
                  ffi.Pointer<ffi.Pointer<process_memory_info_s>>)>>(
      'runtime_info_get_process_memory_info');
  late final _runtime_info_get_process_memory_info =
      _runtime_info_get_process_memory_infoPtr.asFunction<
          int Function(ffi.Pointer<ffi.Int>, int,
              ffi.Pointer<ffi.Pointer<process_memory_info_s>>)>();

  /// @brief        Gets CPU information.
  /// @since_tizen  @if WEARABLE 3.0 @else 2.4 @endif
  ///
  /// @param[out] usage  The CPU usage structure
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An input/output error occurred while reading from system
  ///
  /// @see  runtime_info_get_process_cpu_usage()
  int runtime_info_get_cpu_usage(
    ffi.Pointer<runtime_cpu_usage_s> usage,
  ) {
    return _runtime_info_get_cpu_usage(
      usage,
    );
  }

  late final _runtime_info_get_cpu_usagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<runtime_cpu_usage_s>)>>('runtime_info_get_cpu_usage');
  late final _runtime_info_get_cpu_usage = _runtime_info_get_cpu_usagePtr
      .asFunction<int Function(ffi.Pointer<runtime_cpu_usage_s>)>();

  /// @brief        Gets CPU usage per process.
  /// @since_tizen  @if WEARABLE 3.0 @else 2.4 @endif
  ///
  /// @privlevel  public
  /// @privilege  %http://tizen.org/privilege/systemmonitor
  /// @remarks    You must release @a s value using free(). \n
  /// The size of @a s is the same with @a size.
  ///
  /// @param[in]  pid   The process unique id array
  /// @param[in]  size  The size of pid array
  /// @param[out] usage The CPU usage structure array of the processes
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_OUT_OF_MEMORY      Not able to allocate memory (for output param/other operations)
  /// @retval #RUNTIME_INFO_ERROR_REMOTE_IO          Call to resource daemon failed (dbus errors/resource daemon errors)
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An I/O error occurred (during dbus message operations/other IO operations)
  /// @retval #RUNTIME_INFO_ERROR_PERMISSION_DENIED  Process not authorized to request process usage info
  ///
  /// @see  runtime_info_get_cpu_usage()
  int runtime_info_get_process_cpu_usage(
    ffi.Pointer<ffi.Int> pid,
    int size,
    ffi.Pointer<ffi.Pointer<process_cpu_usage_s>> usage,
  ) {
    return _runtime_info_get_process_cpu_usage(
      pid,
      size,
      usage,
    );
  }

  late final _runtime_info_get_process_cpu_usagePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Int>, ffi.Int,
                  ffi.Pointer<ffi.Pointer<process_cpu_usage_s>>)>>(
      'runtime_info_get_process_cpu_usage');
  late final _runtime_info_get_process_cpu_usage =
      _runtime_info_get_process_cpu_usagePtr.asFunction<
          int Function(ffi.Pointer<ffi.Int>, int,
              ffi.Pointer<ffi.Pointer<process_cpu_usage_s>>)>();

  /// @brief        Gets the number of processors.
  /// @since_tizen  3.0
  ///
  /// @param[out] num_core  The number of whole processors
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An I/O error occurred (during file open operation)
  int runtime_info_get_processor_count(
    ffi.Pointer<ffi.Int> num_core,
  ) {
    return _runtime_info_get_processor_count(
      num_core,
    );
  }

  late final _runtime_info_get_processor_countPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'runtime_info_get_processor_count');
  late final _runtime_info_get_processor_count =
      _runtime_info_get_processor_countPtr
          .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief        Gets the current frequency of processor.
  /// @since_tizen  3.0
  ///
  /// @param[in]  core_idx  The index (from 0) of CPU core that you want to know the frequency
  /// @param[out] cpu_freq  The current frequency(MHz) of processor
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An I/O error occurred (during file open operation)
  /// @retval #RUNTIME_INFO_ERROR_NO_DATA            No data available (Since 3.0)
  int runtime_info_get_processor_current_frequency(
    int core_idx,
    ffi.Pointer<ffi.Int> cpu_freq,
  ) {
    return _runtime_info_get_processor_current_frequency(
      core_idx,
      cpu_freq,
    );
  }

  late final _runtime_info_get_processor_current_frequencyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'runtime_info_get_processor_current_frequency');
  late final _runtime_info_get_processor_current_frequency =
      _runtime_info_get_processor_current_frequencyPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief        Gets the max frequency of processor.
  /// @since_tizen  3.0
  ///
  /// @param[in]  core_idx  The index (from 0) of CPU core that you want to know the frequency
  /// @param[out] cpu_freq  The max frequency(MHz) of processor
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An I/O error occurred (during file open operation)
  /// @retval #RUNTIME_INFO_ERROR_NO_DATA            No data available (Since 3.0)
  int runtime_info_get_processor_max_frequency(
    int core_idx,
    ffi.Pointer<ffi.Int> cpu_freq,
  ) {
    return _runtime_info_get_processor_max_frequency(
      core_idx,
      cpu_freq,
    );
  }

  late final _runtime_info_get_processor_max_frequencyPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Int>)>>(
      'runtime_info_get_processor_max_frequency');
  late final _runtime_info_get_processor_max_frequency =
      _runtime_info_get_processor_max_frequencyPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @brief        Gets the physical memory size.
  /// @since_tizen  4.0
  ///
  /// @param[out] size  Physical memory size (KiB)
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An I/O error occurred (during file open operation)
  int runtime_info_get_physical_memory_size(
    ffi.Pointer<ffi.Int> size,
  ) {
    return _runtime_info_get_physical_memory_size(
      size,
    );
  }

  late final _runtime_info_get_physical_memory_sizePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int>)>>(
          'runtime_info_get_physical_memory_size');
  late final _runtime_info_get_physical_memory_size =
      _runtime_info_get_physical_memory_sizePtr
          .asFunction<int Function(ffi.Pointer<ffi.Int>)>();

  /// @brief        Frees an app usage handle.
  /// @since_tizen  4.0
  ///
  /// @param[in] handle  App usage handle to free
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  int runtime_info_app_usage_destroy(
    app_usage_h handle,
  ) {
    return _runtime_info_app_usage_destroy(
      handle,
    );
  }

  late final _runtime_info_app_usage_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(app_usage_h)>>(
          'runtime_info_app_usage_destroy');
  late final _runtime_info_app_usage_destroy =
      _runtime_info_app_usage_destroyPtr
          .asFunction<int Function(app_usage_h)>();

  /// @brief        Gets the app count from an app usage handle.
  /// @since_tizen  4.0
  ///
  /// @param[in]  handle  The app usage handle
  /// @param[out] count   The number of apps on the app list
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  ///
  /// @see  runtime_info_get_all_apps_memory_usage()
  /// @see  runtime_info_get_all_apps_cpu_rate()
  int runtime_info_app_usage_get_count(
    app_usage_h handle,
    ffi.Pointer<ffi.Int> count,
  ) {
    return _runtime_info_app_usage_get_count(
      handle,
      count,
    );
  }

  late final _runtime_info_app_usage_get_countPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(app_usage_h,
              ffi.Pointer<ffi.Int>)>>('runtime_info_app_usage_get_count');
  late final _runtime_info_app_usage_get_count =
      _runtime_info_app_usage_get_countPtr
          .asFunction<int Function(app_usage_h, ffi.Pointer<ffi.Int>)>();

  /// @brief        Gets the app ID from an app usage handle.
  /// @since_tizen  4.0
  ///
  /// @remarks  You must release @a appid using free().
  ///
  /// @param[in]  handle  The app usage handle
  /// @param[in]  index   The index in the app list; should be between 0 and @a count - 1 (inclusive), \n
  /// where @a count is provided by runtime_info_app_usage_get_count()
  /// @param[out] appid   The app ID
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  ///
  /// @see  runtime_info_get_all_apps_memory_usage()
  /// @see  runtime_info_get_all_apps_cpu_rate()
  int runtime_info_app_usage_get_appid(
    app_usage_h handle,
    int index,
    ffi.Pointer<ffi.Pointer<ffi.Char>> appid,
  ) {
    return _runtime_info_app_usage_get_appid(
      handle,
      index,
      appid,
    );
  }

  late final _runtime_info_app_usage_get_appidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  app_usage_h, ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'runtime_info_app_usage_get_appid');
  late final _runtime_info_app_usage_get_appid =
      _runtime_info_app_usage_get_appidPtr.asFunction<
          int Function(app_usage_h, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief        Gets resource usage from an app usage handle.
  /// @since_tizen  4.0
  ///
  /// @remarks  The meaning of @a usage depends on which function was used to create @a handle.
  ///
  /// @param[in]  handle  The app usage handle
  /// @param[in]  index   The index in the app list; should be between 0 and @a count - 1 (inclusive), \n
  /// where @a count is provided by runtime_info_app_usage_get_count()
  /// @param[out] usage   Resource usage
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  ///
  /// @see  runtime_info_get_all_apps_memory_usage()
  /// @see  runtime_info_get_all_apps_cpu_rate()
  int runtime_info_app_usage_get_usage(
    app_usage_h handle,
    int index,
    ffi.Pointer<ffi.UnsignedInt> usage,
  ) {
    return _runtime_info_app_usage_get_usage(
      handle,
      index,
      usage,
    );
  }

  late final _runtime_info_app_usage_get_usagePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  app_usage_h, ffi.Int, ffi.Pointer<ffi.UnsignedInt>)>>(
      'runtime_info_app_usage_get_usage');
  late final _runtime_info_app_usage_get_usage =
      _runtime_info_app_usage_get_usagePtr.asFunction<
          int Function(app_usage_h, int, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief        Gets memory usage of all apps.
  /// @since_tizen  4.0
  ///
  /// @privlevel  public
  /// @privilege  %http://tizen.org/privilege/systemmonitor
  /// @remarks    You must release @a usage using runtime_info_app_usage_destroy().
  ///
  /// @param[out] usage  An array of each app's memory usage (KB)
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_OUT_OF_MEMORY      Not able to allocate memory (for output param/other operations)
  /// @retval #RUNTIME_INFO_ERROR_REMOTE_IO          Call to resource daemon failed (dbus errors/resource daemon errors)
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An I/O error during dbus message operations
  /// @retval #RUNTIME_INFO_ERROR_PERMISSION_DENIED  Process not authorized to request app usage info
  /// @retval #RUNTIME_INFO_ERROR_NO_DATA            No app running
  ///
  /// @code
  /// #include <runtime_info.h>
  ///
  /// void print_memory_usage(void)
  /// {
  /// int i;
  /// int count;
  /// app_usage_h mem_usage_handle;
  /// char *appid;
  /// unsigned int usage;
  ///
  /// runtime_info_get_all_apps_memory_usage(&mem_usage_handle);
  /// runtime_info_app_usage_get_count(mem_usage_handle, &count);
  ///
  /// for (i = 0; i < count; i++) {
  /// runtime_info_app_usage_get_appid(mem_usage_handle, i, &appid);
  /// runtime_info_app_usage_get_usage(mem_usage_handle, i, &usage);
  /// printf("appid = %s, usage = %u KB\n", appid, usage);
  /// free(appid);
  /// }
  ///
  /// runtime_info_app_usage_destroy(mem_usage_handle);
  ///
  /// }
  /// @endcode
  int runtime_info_get_all_apps_memory_usage(
    ffi.Pointer<app_usage_h> usage,
  ) {
    return _runtime_info_get_all_apps_memory_usage(
      usage,
    );
  }

  late final _runtime_info_get_all_apps_memory_usagePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<app_usage_h>)>>(
          'runtime_info_get_all_apps_memory_usage');
  late final _runtime_info_get_all_apps_memory_usage =
      _runtime_info_get_all_apps_memory_usagePtr
          .asFunction<int Function(ffi.Pointer<app_usage_h>)>();

  /// @brief        Gets CPU rate of all apps.
  /// @since_tizen  4.0
  ///
  /// @privlevel  public
  /// @privilege  %http://tizen.org/privilege/systemmonitor
  /// @remarks    You must release @a rate using runtime_info_app_usage_destroy().
  ///
  /// @param[out] rate  An array of each app's CPU usage rate (%), the values are rounded down.
  ///
  /// @return  @c 0 on success,
  /// otherwise a negative error value
  /// @retval #RUNTIME_INFO_ERROR_NONE               Successful
  /// @retval #RUNTIME_INFO_ERROR_INVALID_PARAMETER  Invalid parameter
  /// @retval #RUNTIME_INFO_ERROR_OUT_OF_MEMORY      Not able to allocate memory (for output param/other operations)
  /// @retval #RUNTIME_INFO_ERROR_REMOTE_IO          Call to resource daemon failed (dbus errors/resource daemon errors)
  /// @retval #RUNTIME_INFO_ERROR_IO_ERROR           An I/O error during dbus message operations
  /// @retval #RUNTIME_INFO_ERROR_PERMISSION_DENIED  Process not authorized to request app usage info
  /// @retval #RUNTIME_INFO_ERROR_NO_DATA            No app running
  ///
  /// @code
  /// #include <runtime_info.h>
  ///
  /// void print_cpu_usage(void)
  /// {
  /// int i;
  /// int count;
  /// app_usage_h cpu_rate_handle;
  /// char *appid;
  /// unsigned int rate;
  ///
  /// runtime_info_get_all_apps_cpu_rate(&cpu_rate_handle);
  /// runtime_info_app_usage_get_count(cpu_rate_handle, &count);
  ///
  /// for (i = 0; i < count; i++) {
  /// runtime_info_app_usage_get_appid(cpu_rate_handle, i, &appid);
  /// runtime_info_app_usage_get_usage(cpu_rate_handle, i, &rate);
  /// printf("appid = %s, rate = %u %%\n", appid, rate);
  /// free(appid);
  /// }
  ///
  /// runtime_info_app_usage_destroy(cpu_rate_handle);
  ///
  /// }
  /// @endcode
  int runtime_info_get_all_apps_cpu_rate(
    ffi.Pointer<app_usage_h> rate,
  ) {
    return _runtime_info_get_all_apps_cpu_rate(
      rate,
    );
  }

  late final _runtime_info_get_all_apps_cpu_ratePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<app_usage_h>)>>(
          'runtime_info_get_all_apps_cpu_rate');
  late final _runtime_info_get_all_apps_cpu_rate =
      _runtime_info_get_all_apps_cpu_ratePtr
          .asFunction<int Function(ffi.Pointer<app_usage_h>)>();

  /// @brief   Checks whether a given sensor type is supported in the current device.
  /// @details If the given sensor type is not supported, sensor_get_default_sensor() will return an error.
  /// It is thus recommended to check the availability of the sensor before actually acquiring #sensor_h.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   type        A sensor type to check
  /// @param[out]  supported   If supported, @c true; Otherwise @c false
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  ///
  /// @see     sensor_is_supported_by_uri()
  int sensor_is_supported(
    int type,
    ffi.Pointer<ffi.Bool> supported,
  ) {
    return _sensor_is_supported(
      type,
      supported,
    );
  }

  late final _sensor_is_supportedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Bool>)>>('sensor_is_supported');
  late final _sensor_is_supported = _sensor_is_supportedPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief   Checks whether a sensor corresponding to a given URI is supported in the current device.
  /// @details To correctly check the availability of a sensor, a valid URI should be provided.
  /// The valid form of URIs is explained in \ref CAPI_SYSTEM_SENSOR_LISTENER_MODULE_URI.\n
  /// If a URI with the sensor's name is given, for example, %http://tizen.org/sensor/general/light/front,
  /// the availability of the @"front@" light sensor is checked.
  /// Otherwise, if a URI without the name, %http://tizen.org/sensor/general/light, is given,
  /// this function checks the availability of any light sensor in the device.\n
  /// It is recommended to check the availability of the sensors corresponding to the URI
  /// before actually acquiring #sensor_h.
  /// @since_tizen 4.0
  ///
  /// @param[in]   uri         A sensor or a sensor type URI to check
  /// @param[out]  supported   If supported, @c true, otherwise @c false
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER   Invalid parameter
  ///
  /// @see     sensor_is_supported()
  int sensor_is_supported_by_uri(
    ffi.Pointer<ffi.Char> uri,
    ffi.Pointer<ffi.Bool> supported,
  ) {
    return _sensor_is_supported_by_uri(
      uri,
      supported,
    );
  }

  late final _sensor_is_supported_by_uriPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('sensor_is_supported_by_uri');
  late final _sensor_is_supported_by_uri = _sensor_is_supported_by_uriPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief   Checks whether a given sensor is a wake-up sensor or not.
  /// @details If a sensor is a wake-up sensor, the sensor is able to wake-up the system
  /// to report its sensor data even if the system is in sleep mode.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]   sensor  A sensor handle to check
  /// @param[out]  wakeup  If the sensor is a wake-up sensor, @c true;
  /// Otherwise @c false
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  ///
  /// @pre     The handle @c sensor needs to be initialized using
  /// sensor_get_default_sensor() or sensor_get_sensor_list() in advance.
  int sensor_is_wake_up(
    sensor_h sensor,
    ffi.Pointer<ffi.Bool> wakeup,
  ) {
    return _sensor_is_wake_up(
      sensor,
      wakeup,
    );
  }

  late final _sensor_is_wake_upPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sensor_h, ffi.Pointer<ffi.Bool>)>>('sensor_is_wake_up');
  late final _sensor_is_wake_up = _sensor_is_wake_upPtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief   Gets the handle for the default sensor of a given type.
  /// @details This function returns the handle for the sensor of a given type.
  /// If the device has more than one sensor of the given type,
  /// this function returns the default sensor of the given type,
  /// which is designated by the device.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Some sensor types are privileged. An application should have the privilege
  /// http://tizen.org/privilege/healthinfo to get handles for the following sensors:
  /// #SENSOR_HRM, #SENSOR_HRM_LED_GREEN, #SENSOR_HRM_LED_IR, #SENSOR_HRM_LED_RED,
  /// #SENSOR_HUMAN_PEDOMETER, #SENSOR_HUMAN_SLEEP_MONITOR, #SENSOR_HUMAN_SLEEP_DETECTOR,
  /// and #SENSOR_HUMAN_STRESS_MONITOR.
  ///
  /// @param[in]  type     A sensor type to get the handle of its default sensor
  /// @param[out] sensor   The sensor handle of the default sensor
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_NOT_SUPPORTED        The sensor type is not supported in the current device
  /// @retval  #SENSOR_ERROR_PERMISSION_DENIED    Permission denied
  ///
  /// @see     sensor_get_default_sensor_by_uri()
  /// @see     sensor_get_sensor_list()
  int sensor_get_default_sensor(
    int type,
    ffi.Pointer<sensor_h> sensor,
  ) {
    return _sensor_get_default_sensor(
      type,
      sensor,
    );
  }

  late final _sensor_get_default_sensorPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<sensor_h>)>>('sensor_get_default_sensor');
  late final _sensor_get_default_sensor = _sensor_get_default_sensorPtr
      .asFunction<int Function(int, ffi.Pointer<sensor_h>)>();

  /// @brief   Gets the handle for the default sensor of a given sensor URI.
  /// @details This function returns the handle for the sensor of a given URI.
  /// If the device has more than one sensor of the given URI,
  /// this function returns the default sensor of the URI, which is designated by the device.\n
  /// See \ref CAPI_SYSTEM_SENSOR_LISTENER_MODULE_URI for more details about the URI format.
  /// @since_tizen 4.0
  ///
  /// @remarks Some sensor types are privileged. An application should have the privilege
  /// http://tizen.org/privilege/healthinfo to get handles for the sensor URIs of @"healthinfo@" category.
  /// See \ref CAPI_SYSTEM_SENSOR_LISTENER_MODULE_URI to find the @"healthinfo@" category sensor URIs.
  ///
  /// @param[in]    uri      A sensor or a sensor type URI to get the handle of its default sensor
  /// @param[out]   sensor   The default sensor handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_NOT_SUPPORTED        The URI is not supported in the current device
  /// @retval  #SENSOR_ERROR_PERMISSION_DENIED    Permission denied
  ///
  /// @see     sensor_get_default_sensor()
  /// @see     sensor_get_sensor_list_by_uri()
  int sensor_get_default_sensor_by_uri(
    ffi.Pointer<ffi.Char> uri,
    ffi.Pointer<sensor_h> sensor,
  ) {
    return _sensor_get_default_sensor_by_uri(
      uri,
      sensor,
    );
  }

  late final _sensor_get_default_sensor_by_uriPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<sensor_h>)>>('sensor_get_default_sensor_by_uri');
  late final _sensor_get_default_sensor_by_uri =
      _sensor_get_default_sensor_by_uriPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<sensor_h>)>();

  /// @brief   Gets the handle list of the sensors of a given type.
  /// @details A device may have more than one sensors of the given type.
  /// In such case, this function can be used to get the handles of all sensors of the type.@n
  /// The first element of the @a list denotes the default sensor,
  /// which can be retrieved by sensor_get_default_sensor().
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Some sensor types are privileged. An application should have the privilege
  /// http://tizen.org/privilege/healthinfo to get handles for the following sensors:
  /// #SENSOR_HRM, #SENSOR_HRM_LED_GREEN, #SENSOR_HRM_LED_IR, #SENSOR_HRM_LED_RED,
  /// #SENSOR_HUMAN_PEDOMETER, #SENSOR_HUMAN_SLEEP_MONITOR, #SENSOR_HUMAN_SLEEP_DETECTOR,
  /// and #SENSOR_HUMAN_STRESS_MONITOR.@n
  /// Instead of specifying a sensor type, by using #SENSOR_ALL,
  /// applications can get the list of handles for all available sensors.@n
  /// The @a list must be released using free(), if not being used anymore.@n
  ///
  /// @param[in]  type         A sensor type to get the list of sensor handles
  /// @param[out] list         An array of the sensor handles
  /// @param[out] sensor_count The number of handles contained in @a list
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_NOT_SUPPORTED        The sensor type is not supported in the current device
  /// @retval  #SENSOR_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval  #SENSOR_ERROR_OUT_OF_MEMORY        Out of memory
  int sensor_get_sensor_list(
    int type,
    ffi.Pointer<ffi.Pointer<sensor_h>> list,
    ffi.Pointer<ffi.Int> sensor_count,
  ) {
    return _sensor_get_sensor_list(
      type,
      list,
      sensor_count,
    );
  }

  late final _sensor_get_sensor_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Pointer<ffi.Pointer<sensor_h>>,
              ffi.Pointer<ffi.Int>)>>('sensor_get_sensor_list');
  late final _sensor_get_sensor_list = _sensor_get_sensor_listPtr.asFunction<
      int Function(
          int, ffi.Pointer<ffi.Pointer<sensor_h>>, ffi.Pointer<ffi.Int>)>();

  /// @brief   Gets the handle list of the sensors of a given URI.
  /// @details A device may have more than one sensor of the given URI.
  /// In such case, this function can be used to get the handles of all sensors of the given URI.\n
  /// See \ref CAPI_SYSTEM_SENSOR_LISTENER_MODULE_URI for more details about the URI format.
  /// @since_tizen 4.0
  ///
  /// @remarks Some sensors require one or more privileges. An application should have the corresponding privilege
  /// to get handles for such sensors.
  /// See sensor_get_default_sensor_by_uri() for more details.@n
  /// The @a list must be released using free(), if not being used anymore.
  ///
  /// @param[in]   uri            A sensor or a sensor type URI to get the list of sensor handles
  /// @param[out]  list           An array of the sensor handles
  /// @param[out]  sensor_count   The number of handles contained in @a list
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER   Invalid parameter
  /// @retval  #SENSOR_ERROR_NOT_SUPPORTED       The URI is not supported in the current device
  /// @retval  #SENSOR_ERROR_PERMISSION_DENIED   Permission denied
  /// @retval  #SENSOR_ERROR_OUT_OF_MEMORY       Out of memory
  int sensor_get_sensor_list_by_uri(
    ffi.Pointer<ffi.Char> uri,
    ffi.Pointer<ffi.Pointer<sensor_h>> list,
    ffi.Pointer<ffi.Int> sensor_count,
  ) {
    return _sensor_get_sensor_list_by_uri(
      uri,
      list,
      sensor_count,
    );
  }

  late final _sensor_get_sensor_list_by_uriPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<sensor_h>>,
              ffi.Pointer<ffi.Int>)>>('sensor_get_sensor_list_by_uri');
  late final _sensor_get_sensor_list_by_uri =
      _sensor_get_sensor_list_by_uriPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<sensor_h>>, ffi.Pointer<ffi.Int>)>();

  /// @brief   Gets the URI of a sensor.
  /// @since_tizen 4.0
  ///
  /// @remarks The @a uri must be released using free(), if not being used anymore.
  ///
  /// @param[in]   sensor   A sensor handle
  /// @param[out]  uri      The URI of the sensor
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_get_uri(
    sensor_h sensor,
    ffi.Pointer<ffi.Pointer<ffi.Char>> uri,
  ) {
    return _sensor_get_uri(
      sensor,
      uri,
    );
  }

  late final _sensor_get_uriPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sensor_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('sensor_get_uri');
  late final _sensor_get_uri = _sensor_get_uriPtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief   Gets the name of a sensor.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks  The @a name must be released using free(), if not being used anymore.
  ///
  /// @param[in]   sensor  A sensor handle
  /// @param[out]  name    The name of the sensor
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_get_name(
    sensor_h sensor,
    ffi.Pointer<ffi.Pointer<ffi.Char>> name,
  ) {
    return _sensor_get_name(
      sensor,
      name,
    );
  }

  late final _sensor_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('sensor_get_name');
  late final _sensor_get_name = _sensor_get_namePtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief   Gets the vendor of a sensor.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks  The @a vendor must be released using free(), if not being used anymore.
  ///
  /// @param[in]   sensor  A sensor handle
  /// @param[out]  vendor  The vendor of the sensor
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_get_vendor(
    sensor_h sensor,
    ffi.Pointer<ffi.Pointer<ffi.Char>> vendor,
  ) {
    return _sensor_get_vendor(
      sensor,
      vendor,
    );
  }

  late final _sensor_get_vendorPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('sensor_get_vendor');
  late final _sensor_get_vendor = _sensor_get_vendorPtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief   Gets the type of a sensor, if it belongs to the known types defined in #sensor_type_e.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   sensor  A sensor handle
  /// @param[out]  type    The type of the sensor
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_NO_DATA              No known sensor type for the given sensor
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_get_type(
    sensor_h sensor,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _sensor_get_type(
      sensor,
      type,
    );
  }

  late final _sensor_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sensor_h, ffi.Pointer<ffi.Int32>)>>('sensor_get_type');
  late final _sensor_get_type = _sensor_get_typePtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief   Gets the lower bound of the sensor reading of a sensor.
  /// @details This function returns the lower bound of the range of possible sensor values,
  /// which are generated by the corresponding sensor denoted by a sensor handle.@n
  /// If all sensor values are in the same unit, e.g., \f$\mbox{m/s}^2\f$ or degrees,
  /// the lower bound of all sensor values is returned.
  /// Otherwise, the lower bound of the representative sensor value, e.g.,
  /// the step count of #SENSOR_HUMAN_PEDOMETER, is returned.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   sensor      A sensor handle
  /// @param[out]  min_range   The lower bound
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_get_max_range()
  int sensor_get_min_range(
    sensor_h sensor,
    ffi.Pointer<ffi.Float> min_range,
  ) {
    return _sensor_get_min_range(
      sensor,
      min_range,
    );
  }

  late final _sensor_get_min_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sensor_h, ffi.Pointer<ffi.Float>)>>('sensor_get_min_range');
  late final _sensor_get_min_range = _sensor_get_min_rangePtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Float>)>();

  /// @brief   Gets the upper bound of the sensor readings of a sensor.
  /// @details This function returns the upper bound of the range of possible sensor values,
  /// which are generated by the corresponding sensor denoted by a sensor handle.@n
  /// If all sensor values are in the same unit, e.g., \f$\mbox{m/s}^2\f$ or degrees,
  /// the upper bound of all sensor values is returned.
  /// Otherwise, the upper bound of the representative sensor value, e.g.,
  /// the step count of #SENSOR_HUMAN_PEDOMETER, is returned.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   sensor      A sensor handle
  /// @param[out]  max_range   The upper bound
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_get_min_range()
  int sensor_get_max_range(
    sensor_h sensor,
    ffi.Pointer<ffi.Float> max_range,
  ) {
    return _sensor_get_max_range(
      sensor,
      max_range,
    );
  }

  late final _sensor_get_max_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sensor_h, ffi.Pointer<ffi.Float>)>>('sensor_get_max_range');
  late final _sensor_get_max_range = _sensor_get_max_rangePtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Float>)>();

  /// @brief   Gets the resolution of the sensor readings of a sensor.
  /// @details This function returns the resolution of the sensor readings.
  /// The resolution denotes the smallest difference between sensor readings,
  /// each of which is in the range that can be verified by
  /// sensor_get_min_range() and sensor_get_max_range().
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   sensor      A sensor handle
  /// @param[out]  resolution  The resolution
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_get_resolution(
    sensor_h sensor,
    ffi.Pointer<ffi.Float> resolution,
  ) {
    return _sensor_get_resolution(
      sensor,
      resolution,
    );
  }

  late final _sensor_get_resolutionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sensor_h, ffi.Pointer<ffi.Float>)>>('sensor_get_resolution');
  late final _sensor_get_resolution = _sensor_get_resolutionPtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Float>)>();

  /// @brief   Gets the possible shorted update interval of a sensor.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   sensor          A sensor handle
  /// @param[out]  min_interval    The shorted interval in milliseconds
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_get_min_interval(
    sensor_h sensor,
    ffi.Pointer<ffi.Int> min_interval,
  ) {
    return _sensor_get_min_interval(
      sensor,
      min_interval,
    );
  }

  late final _sensor_get_min_intervalPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(sensor_h, ffi.Pointer<ffi.Int>)>>(
      'sensor_get_min_interval');
  late final _sensor_get_min_interval = _sensor_get_min_intervalPtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Int>)>();

  /// @brief   Gets the size of the hardware FIFO of a sensor.
  /// @details This function returns the size of the hardware FIFO that may be used by
  /// a specific sensor to support batching.
  /// However, regarding the underlying hardware configuration,
  /// the returned count may not mean the maximum number of sensor data that can be batched.
  /// See sensor_get_max_batch_count() for such purpose, finding out the
  /// possible maximum number of batched data.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   sensor          A sensor handle
  /// @param[out]  fifo_count      The FIFO count
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_get_fifo_count(
    sensor_h sensor,
    ffi.Pointer<ffi.Int> fifo_count,
  ) {
    return _sensor_get_fifo_count(
      sensor,
      fifo_count,
    );
  }

  late final _sensor_get_fifo_countPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(sensor_h, ffi.Pointer<ffi.Int>)>>(
      'sensor_get_fifo_count');
  late final _sensor_get_fifo_count = _sensor_get_fifo_countPtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Int>)>();

  /// @brief   Gets the maximum batch count of a sensor.
  /// @details This function returns the maximum number of sensor data events
  /// that can be possibly delivered when the batched data are flushed.
  /// Therefore, this count can be used to check whether the sensor supports
  /// batching or not.@n
  /// If this returns a positive count, i.e., the sensor supports batching,
  /// the count also can be used to guess the possible longest batch latency
  /// of the sensor, with respect to the update interval to use.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   sensor          A sensor handle
  /// @param[out]  max_batch_count If the sensor does not support batching, 0;
  /// Otherwise a positive integer.
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_listener_set_max_batch_latency()
  int sensor_get_max_batch_count(
    sensor_h sensor,
    ffi.Pointer<ffi.Int> max_batch_count,
  ) {
    return _sensor_get_max_batch_count(
      sensor,
      max_batch_count,
    );
  }

  late final _sensor_get_max_batch_countPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(sensor_h, ffi.Pointer<ffi.Int>)>>(
      'sensor_get_max_batch_count');
  late final _sensor_get_max_batch_count = _sensor_get_max_batch_countPtr
      .asFunction<int Function(sensor_h, ffi.Pointer<ffi.Int>)>();

  /// @brief  Adds a callback function to be invoked when a new sensor is added.
  /// @since_tizen 4.0
  ///
  /// @param[in]  callback   A callback function to be added
  /// @param[in]  user_data  A user data to be passed to the callback function
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_remove_sensor_added_cb()
  int sensor_add_sensor_added_cb(
    sensor_added_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sensor_add_sensor_added_cb(
      callback,
      user_data,
    );
  }

  late final _sensor_add_sensor_added_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_added_cb,
              ffi.Pointer<ffi.Void>)>>('sensor_add_sensor_added_cb');
  late final _sensor_add_sensor_added_cb = _sensor_add_sensor_added_cbPtr
      .asFunction<int Function(sensor_added_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief  Removes a callback function added using sensor_add_sensor_added_cb().
  /// @since_tizen 4.0
  ///
  /// @param[in]  callback  A callback function to be removed
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_add_sensor_added_cb()
  int sensor_remove_sensor_added_cb(
    sensor_added_cb callback,
  ) {
    return _sensor_remove_sensor_added_cb(
      callback,
    );
  }

  late final _sensor_remove_sensor_added_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_added_cb)>>(
          'sensor_remove_sensor_added_cb');
  late final _sensor_remove_sensor_added_cb = _sensor_remove_sensor_added_cbPtr
      .asFunction<int Function(sensor_added_cb)>();

  /// @brief  Adds a callback function to be invoked when a sensor is removed.
  /// @since_tizen 4.0
  ///
  /// @param[in]  callback   A callback function to be removed
  /// @param[in]  user_data  A user data to be passed to the callback function
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see   sensor_remove_sensor_removed_cb()
  int sensor_add_sensor_removed_cb(
    sensor_removed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sensor_add_sensor_removed_cb(
      callback,
      user_data,
    );
  }

  late final _sensor_add_sensor_removed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_removed_cb,
              ffi.Pointer<ffi.Void>)>>('sensor_add_sensor_removed_cb');
  late final _sensor_add_sensor_removed_cb = _sensor_add_sensor_removed_cbPtr
      .asFunction<int Function(sensor_removed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief  Removes a callback function added using sensor_add_sensor_removed_cb().
  /// @since_tizen 4.0
  ///
  /// @param[in]  callback  A callback function to be removed
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see   sensor_add_sensor_removed_cb()
  int sensor_remove_sensor_removed_cb(
    sensor_removed_cb callback,
  ) {
    return _sensor_remove_sensor_removed_cb(
      callback,
    );
  }

  late final _sensor_remove_sensor_removed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_removed_cb)>>(
          'sensor_remove_sensor_removed_cb');
  late final _sensor_remove_sensor_removed_cb =
      _sensor_remove_sensor_removed_cbPtr
          .asFunction<int Function(sensor_removed_cb)>();

  /// @brief   Creates a sensor listener.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks The @a listener must be released using sensor_destroy_listener().
  ///
  /// @param[in]  sensor          A sensor handle
  /// @param[out] listener        A listener handle of @a sensor
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @pre     The handle @a sensor needs to be initialized using
  /// sensor_get_default_sensor() or sensor_get_sensor_list() in advance.
  int sensor_create_listener(
    sensor_h sensor,
    ffi.Pointer<sensor_listener_h> listener,
  ) {
    return _sensor_create_listener(
      sensor,
      listener,
    );
  }

  late final _sensor_create_listenerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_h,
              ffi.Pointer<sensor_listener_h>)>>('sensor_create_listener');
  late final _sensor_create_listener = _sensor_create_listenerPtr
      .asFunction<int Function(sensor_h, ffi.Pointer<sensor_listener_h>)>();

  /// @brief   Releases all the resources allocated for a listener.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks If this function is called while the sensor is still running,
  /// that is, sensor_listener_start() was called but sensor_listener_stop() was not,
  /// then it is implicitly stopped.
  ///
  /// @param[in] listener  A listener handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  ///
  /// @see     sensor_create_listener()
  int sensor_destroy_listener(
    sensor_listener_h listener,
  ) {
    return _sensor_destroy_listener(
      listener,
    );
  }

  late final _sensor_destroy_listenerPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_listener_h)>>(
          'sensor_destroy_listener');
  late final _sensor_destroy_listener =
      _sensor_destroy_listenerPtr.asFunction<int Function(sensor_listener_h)>();

  /// @brief   Starts observing the sensor events regarding a given sensor listener.
  /// @details If a sensor listener is started, its event callback function starts to be called
  /// whenever the corresponding sensor events occur.@n
  /// For example, #SENSOR_ACCELEROMETER reports its sensor readings repeatedly,
  /// with a specific update interval.
  /// Note that, unlike the accelerometer, sensors like #SENSOR_PROXIMITY emit events
  /// only if their states change.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   listener  A listener handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @pre     The @a listener needs to be created in advance, by using sensor_create_listener().
  /// Then the callback function needs to be attached to the @a listener, by using
  /// sensor_listener_set_event_cb().
  /// @see     sensor_listener_stop()
  int sensor_listener_start(
    sensor_listener_h listener,
  ) {
    return _sensor_listener_start(
      listener,
    );
  }

  late final _sensor_listener_startPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_listener_h)>>(
          'sensor_listener_start');
  late final _sensor_listener_start =
      _sensor_listener_startPtr.asFunction<int Function(sensor_listener_h)>();

  /// @brief   Stops observing the sensor events regarding a given sensor listener.
  /// @details The listener's event callback function stops being called.
  /// But the sensor itself may not be stopped if there are other listeners
  /// that are using the same sensor.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   listener  A listener handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_listener_start()
  int sensor_listener_stop(
    sensor_listener_h listener,
  ) {
    return _sensor_listener_stop(
      listener,
    );
  }

  late final _sensor_listener_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_listener_h)>>(
          'sensor_listener_stop');
  late final _sensor_listener_stop =
      _sensor_listener_stopPtr.asFunction<int Function(sensor_listener_h)>();

  /// @brief   Registers the callback function to be invoked when sensor events are delivered via a sensor listener.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   listener    A listener handle
  /// @param[in]   interval_ms A desired update interval between sensor events in milliseconds.@n
  /// If 0, it will be automatically set to the default interval of the corresponding sensor.@n
  /// See sensor_listener_set_interval() for more details.
  /// @param[in]   callback    A callback function to attach with the @a listener handle
  /// @param[in]   data        A user data to be passed to the callback function
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see sensor_listener_unset_event_cb()
  int sensor_listener_set_event_cb(
    sensor_listener_h listener,
    int interval_ms,
    sensor_event_cb callback,
    ffi.Pointer<ffi.Void> data,
  ) {
    return _sensor_listener_set_event_cb(
      listener,
      interval_ms,
      callback,
      data,
    );
  }

  late final _sensor_listener_set_event_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_listener_h, ffi.UnsignedInt, sensor_event_cb,
              ffi.Pointer<ffi.Void>)>>('sensor_listener_set_event_cb');
  late final _sensor_listener_set_event_cb =
      _sensor_listener_set_event_cbPtr.asFunction<
          int Function(sensor_listener_h, int, sensor_event_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief   Unregisters the sensor event callback function attached to a given sensor listener.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   listener    A listener handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_listener_set_event_cb()
  int sensor_listener_unset_event_cb(
    sensor_listener_h listener,
  ) {
    return _sensor_listener_unset_event_cb(
      listener,
    );
  }

  late final _sensor_listener_unset_event_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_listener_h)>>(
          'sensor_listener_unset_event_cb');
  late final _sensor_listener_unset_event_cb =
      _sensor_listener_unset_event_cbPtr
          .asFunction<int Function(sensor_listener_h)>();

  /// @brief   Registers the callback function to be invoked when the accuracy of a sensor changes.
  /// @details In addition to sensor_event_cb(), sensor_accuracy_changed_cb() also can be attached
  /// to sensor listeners. With this accuracy callback function, applications can be notified
  /// the changes of the corresponding sensors separately.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   listener    A listener handle
  /// @param[in]   callback    A callback function to attach with the @a listener handle
  /// @param[in]   data        A user data to be passed to the callback function
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @pre     The @a listener needs to be started to get the change callbacks.
  /// @see     sensor_listener_unset_accuracy_cb()
  int sensor_listener_set_accuracy_cb(
    sensor_listener_h listener,
    sensor_accuracy_changed_cb callback,
    ffi.Pointer<ffi.Void> data,
  ) {
    return _sensor_listener_set_accuracy_cb(
      listener,
      callback,
      data,
    );
  }

  late final _sensor_listener_set_accuracy_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_listener_h, sensor_accuracy_changed_cb,
              ffi.Pointer<ffi.Void>)>>('sensor_listener_set_accuracy_cb');
  late final _sensor_listener_set_accuracy_cb =
      _sensor_listener_set_accuracy_cbPtr.asFunction<
          int Function(sensor_listener_h, sensor_accuracy_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief   Unregisters the sensor accuracy change callback function attached to a given sensor listener.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]   listener    A listener handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_listener_set_accuracy_cb()
  int sensor_listener_unset_accuracy_cb(
    sensor_listener_h listener,
  ) {
    return _sensor_listener_unset_accuracy_cb(
      listener,
    );
  }

  late final _sensor_listener_unset_accuracy_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_listener_h)>>(
          'sensor_listener_unset_accuracy_cb');
  late final _sensor_listener_unset_accuracy_cb =
      _sensor_listener_unset_accuracy_cbPtr
          .asFunction<int Function(sensor_listener_h)>();

  /// @brief   Reads the current sensor data via a given sensor listener.
  /// @details This function synchronously reads the sensor reading of the corresponding sensor, if available.
  /// Otherwise, if the sensor is not ready to report its values, this function fails and returns
  /// #SENSOR_ERROR_OPERATION_FAILED.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remark  As a sensor usually works in an event-driven manner, it may not be able to read its data on demand.
  /// Then this function tries to return the last known values.@n
  /// To be able to read the current values or the last known values, the sensor needs to be
  /// enabled in advance. As an application cannot be sure that the sensor is already enabled
  /// by other applications, it is recommended to start the sensor explicitly by using sensor_listener_start().@n
  /// But note that, even if the sensor is started, on-demand reading can fail always,
  /// thus it would be better to use the asynchronous callback approach.
  ///
  /// @param[in]   listener    A listener handle
  /// @param[out]  event       The retrieved sensor data
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_listener_read_data(
    sensor_listener_h listener,
    ffi.Pointer<sensor_event_s> event,
  ) {
    return _sensor_listener_read_data(
      listener,
      event,
    );
  }

  late final _sensor_listener_read_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_listener_h,
              ffi.Pointer<sensor_event_s>)>>('sensor_listener_read_data');
  late final _sensor_listener_read_data =
      _sensor_listener_read_dataPtr.asFunction<
          int Function(sensor_listener_h, ffi.Pointer<sensor_event_s>)>();

  /// @brief   Changes the update interval of a sensor.
  /// @details The specified interval is only a suggested interval between sensor measurements.
  /// You will get at least one sensor measurement within the interval you specify,
  /// but the actual interval between sensor measurements can be affected by other applications and the system.
  /// To reduce the system overhead, it is recommended to set the longest interval that you can,
  /// because the system usually chooses the shortest interval among all intervals specified.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Normally, a sensor's default update interval is 100 ms,
  /// and you can use the default interval by setting the interval to 0.
  /// However, please note that, the default interval varies with the sensor and the device.@n
  /// In addition, a sensor has the lower and the upper bound of its update interval,
  /// usually 10 and 1000 ms respectively.
  /// These lower and upper bounds also can vary with the sensor and the device,
  /// any invalid input values exceeding the bounds will be implicitly adjusted into the valid range.
  ///
  /// @param[in]   listener    A listener handle
  /// @param[in]   interval_ms A desired update interval between sensor events in milliseconds.
  /// If 0, it will be automatically set to the default interval of the corresponding sensor.
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_get_min_interval()
  int sensor_listener_set_interval(
    sensor_listener_h listener,
    int interval_ms,
  ) {
    return _sensor_listener_set_interval(
      listener,
      interval_ms,
    );
  }

  late final _sensor_listener_set_intervalPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_listener_h,
              ffi.UnsignedInt)>>('sensor_listener_set_interval');
  late final _sensor_listener_set_interval = _sensor_listener_set_intervalPtr
      .asFunction<int Function(sensor_listener_h, int)>();

  /// @brief   Sets the desired max batch latency of a sensor.
  /// @details Sensors that support batching may allow applications to change their maximum batch latencies.
  /// For example, if you set the latency as 10,000 ms, the sensor may store its data
  /// up to 10,000 ms, before delivering the data through the HAL.@n
  /// In cases of non-batching sensors, this function returns #SENSOR_ERROR_NONE,
  /// but nothing is affected by the input latency value.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Even if you set a batch latency, the sensor may not work as you intended,
  /// as one sensor can be used by more than one listeners.
  /// In addition, some batch sensors may already have fixed batching latency
  /// or batching queue size, which cannot be altered by applications.
  ///
  /// @param[in]   listener           A listener handle
  /// @param[in]   max_batch_latency  A desired batch latency in milliseconds
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_listener_set_max_batch_latency(
    sensor_listener_h listener,
    int max_batch_latency,
  ) {
    return _sensor_listener_set_max_batch_latency(
      listener,
      max_batch_latency,
    );
  }

  late final _sensor_listener_set_max_batch_latencyPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_listener_h,
              ffi.UnsignedInt)>>('sensor_listener_set_max_batch_latency');
  late final _sensor_listener_set_max_batch_latency =
      _sensor_listener_set_max_batch_latencyPtr
          .asFunction<int Function(sensor_listener_h, int)>();

  /// @brief   Sets an attribute to control the behavior of a sensor listener.
  /// @details Applications can change the behavior of a sensor listener, for example,
  /// what is the reference coordinate of the sensor values,
  /// and when the system is allowed to turn off the sensor implicitly to reduce the power consumption.
  /// See #sensor_attribute_e for more details about the available control parameters.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]   listener	A listener handle
  /// @param[in]   attribute	An attribute to change
  /// @param[in]   value		An attribute value
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_listener_set_attribute_int(
    sensor_listener_h listener,
    int attribute,
    int value,
  ) {
    return _sensor_listener_set_attribute_int(
      listener,
      attribute,
      value,
    );
  }

  late final _sensor_listener_set_attribute_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_listener_h, ffi.Int32,
              ffi.Int)>>('sensor_listener_set_attribute_int');
  late final _sensor_listener_set_attribute_int =
      _sensor_listener_set_attribute_intPtr
          .asFunction<int Function(sensor_listener_h, int, int)>();

  /// @brief   Changes the power-saving behavior of a sensor listener.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remark  sensor_listener_set_attribute_int() with #SENSOR_ATTRIBUTE_PAUSE_POLICY replaces this function.
  ///
  /// @param[in]   listener        A listener handle
  /// @param[in]   option          A sensor option
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_listener_set_option(
    sensor_listener_h listener,
    int option,
  ) {
    return _sensor_listener_set_option(
      listener,
      option,
    );
  }

  late final _sensor_listener_set_optionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(sensor_listener_h, ffi.Int32)>>(
      'sensor_listener_set_option');
  late final _sensor_listener_set_option = _sensor_listener_set_optionPtr
      .asFunction<int Function(sensor_listener_h, int)>();

  /// @brief   Creates a sensor provider.
  /// @details This function creates a sensor provider handle with a given URI.
  /// The URI should be in the valid form described in \ref CAPI_SYSTEM_SENSOR_LISTENER_MODULE_URI.
  /// In addition, it is not allowed to set the vendor in the URI to @"tizen.org@",
  /// as it is pre-assigned to the platform-defined sensors.\n
  /// @since_tizen 4.0
  ///
  /// @remarks If your application needs to publish health-related sensor data,
  /// the URI category should be @"healthinfo@".
  /// Then the applications without the privilege http://tizen.org/privilege/healthinfo
  /// are not allowed to listen your application's health-related sensor.
  ///
  /// @remarks The @a provider must be released using sensor_destroy_provider().
  ///
  /// @param[in]  uri             The URI of sensor to be created
  /// @param[out] provider        The sensor provider handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_destroy_provider()
  int sensor_create_provider(
    ffi.Pointer<ffi.Char> uri,
    ffi.Pointer<sensor_provider_h> provider,
  ) {
    return _sensor_create_provider(
      uri,
      provider,
    );
  }

  late final _sensor_create_providerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<sensor_provider_h>)>>('sensor_create_provider');
  late final _sensor_create_provider = _sensor_create_providerPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<sensor_provider_h>)>();

  /// @brief    Registers the sensor provider.
  /// @details  A sensor provider is created via sensor_create_provider(),
  /// and the three callback functions sensor_provider_start_cb(), sensor_provider_stop_cb(),
  /// and sensor_provider_set_interval_changed_cb() should be set in advance.
  /// @since_tizen 4.0
  ///
  /// @param[in]   provider  The sensor provider handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_remove_provider()
  int sensor_add_provider(
    sensor_provider_h provider,
  ) {
    return _sensor_add_provider(
      provider,
    );
  }

  late final _sensor_add_providerPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_provider_h)>>(
          'sensor_add_provider');
  late final _sensor_add_provider =
      _sensor_add_providerPtr.asFunction<int Function(sensor_provider_h)>();

  /// @brief   Unregisters the sensor provider.
  /// @since_tizen 4.0
  ///
  /// @param[in]  provider  The sensor provider handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_add_provider()
  int sensor_remove_provider(
    sensor_provider_h provider,
  ) {
    return _sensor_remove_provider(
      provider,
    );
  }

  late final _sensor_remove_providerPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_provider_h)>>(
          'sensor_remove_provider');
  late final _sensor_remove_provider =
      _sensor_remove_providerPtr.asFunction<int Function(sensor_provider_h)>();

  /// @brief   Releases all the resources allocated for the sensor provider.
  /// @since_tizen 4.0
  ///
  /// @remarks If this function is called before sensor_remove_provider() is called,
  /// then the sensor provider will be implicitly unregistered.
  ///
  /// @param[in]  provider  The sensor provider handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  ///
  /// @see     sensor_create_provider()
  int sensor_destroy_provider(
    sensor_provider_h provider,
  ) {
    return _sensor_destroy_provider(
      provider,
    );
  }

  late final _sensor_destroy_providerPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_provider_h)>>(
          'sensor_destroy_provider');
  late final _sensor_destroy_provider =
      _sensor_destroy_providerPtr.asFunction<int Function(sensor_provider_h)>();

  /// @brief   Sets the name to the sensor provider.
  /// @since_tizen 4.0
  ///
  /// @param[in]  provider    The sensor provider handle
  /// @param[in]  name        The name of the sensor
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  ///
  /// @pre     sensor_create_provider()
  /// @see     sensor_provider_set_vendor()
  /// sensor_provider_set_range()
  /// sensor_provider_set_resolution()
  int sensor_provider_set_name(
    sensor_provider_h provider,
    ffi.Pointer<ffi.Char> name,
  ) {
    return _sensor_provider_set_name(
      provider,
      name,
    );
  }

  late final _sensor_provider_set_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_provider_h,
              ffi.Pointer<ffi.Char>)>>('sensor_provider_set_name');
  late final _sensor_provider_set_name = _sensor_provider_set_namePtr
      .asFunction<int Function(sensor_provider_h, ffi.Pointer<ffi.Char>)>();

  /// @brief   Sets the vendor to the sensor provider.
  /// @since_tizen 4.0
  ///
  /// @param[in]  provider    The sensor provider handle
  /// @param[in]  vendor      The vendor of the sensor
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  ///
  /// @pre     sensor_create_provider()
  /// @see     sensor_provider_set_name()
  /// sensor_provider_set_range()
  /// sensor_provider_set_resolution()
  int sensor_provider_set_vendor(
    sensor_provider_h provider,
    ffi.Pointer<ffi.Char> vendor,
  ) {
    return _sensor_provider_set_vendor(
      provider,
      vendor,
    );
  }

  late final _sensor_provider_set_vendorPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_provider_h,
              ffi.Pointer<ffi.Char>)>>('sensor_provider_set_vendor');
  late final _sensor_provider_set_vendor = _sensor_provider_set_vendorPtr
      .asFunction<int Function(sensor_provider_h, ffi.Pointer<ffi.Char>)>();

  /// @brief   Sets the range of possible sensor values to the sensor provider.
  /// @since_tizen 4.0
  ///
  /// @remarks    If the application does not set the range, the default values are 0 and 1.
  ///
  /// @param[in]  provider    The sensor provider handle
  /// @param[in]  min_range   The lower bound
  /// @param[in]  max_range   The upper bound
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  ///
  /// @pre     sensor_create_provider()
  /// @see     sensor_provider_set_name()
  /// sensor_provider_set_vendor()
  /// sensor_provider_set_resolution()
  int sensor_provider_set_range(
    sensor_provider_h provider,
    double min_range,
    double max_range,
  ) {
    return _sensor_provider_set_range(
      provider,
      min_range,
      max_range,
    );
  }

  late final _sensor_provider_set_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_provider_h, ffi.Float,
              ffi.Float)>>('sensor_provider_set_range');
  late final _sensor_provider_set_range = _sensor_provider_set_rangePtr
      .asFunction<int Function(sensor_provider_h, double, double)>();

  /// @brief   Sets the resolution of sensor values to the sensor provider.
  /// @since_tizen 4.0
  ///
  /// @remarks    If the application does not set the resolution, the default value is 1.
  ///
  /// @param[in]  provider    The sensor provider handle
  /// @param[in]  resolution  The resolution
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  ///
  /// @pre     sensor_create_provider()
  /// @see     sensor_provider_set_name()
  /// sensor_provider_set_vendor()
  /// sensor_provider_set_range()
  int sensor_provider_set_resolution(
    sensor_provider_h provider,
    double resolution,
  ) {
    return _sensor_provider_set_resolution(
      provider,
      resolution,
    );
  }

  late final _sensor_provider_set_resolutionPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(sensor_provider_h, ffi.Float)>>(
      'sensor_provider_set_resolution');
  late final _sensor_provider_set_resolution =
      _sensor_provider_set_resolutionPtr
          .asFunction<int Function(sensor_provider_h, double)>();

  /// @brief   Registers the callback function to be invoked when a listener starts the sensor provider.
  /// @since_tizen 4.0
  ///
  /// @param[in]  provider    The provider handle
  /// @param[in]  callback    The callback function to attach to the @a provider handle
  /// @param[in]  user_data   The user data to be passed to the callback function
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_provider_set_start_cb(
    sensor_provider_h provider,
    sensor_provider_start_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sensor_provider_set_start_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _sensor_provider_set_start_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_provider_h, sensor_provider_start_cb,
              ffi.Pointer<ffi.Void>)>>('sensor_provider_set_start_cb');
  late final _sensor_provider_set_start_cb =
      _sensor_provider_set_start_cbPtr.asFunction<
          int Function(sensor_provider_h, sensor_provider_start_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief   Registers the callback function to be invoked when a sensor listener stops the sensor provider.
  /// @since_tizen 4.0
  ///
  /// @param[in]  provider    The sensor provider handle
  /// @param[in]  callback    The callback function to attach to the @a provider handle
  /// @param[in]  user_data   The user data to be passed to the callback function
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_provider_set_stop_cb(
    sensor_provider_h provider,
    sensor_provider_stop_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sensor_provider_set_stop_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _sensor_provider_set_stop_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_provider_h, sensor_provider_stop_cb,
              ffi.Pointer<ffi.Void>)>>('sensor_provider_set_stop_cb');
  late final _sensor_provider_set_stop_cb =
      _sensor_provider_set_stop_cbPtr.asFunction<
          int Function(sensor_provider_h, sensor_provider_stop_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief   Registers the callback function to be invoked when the interval is changed.
  /// @since_tizen 4.0
  ///
  /// @param[in]  provider    The sensor provider handle
  /// @param[in]  callback    The callback function to attach to the @a provider handle
  /// @param[in]  user_data   The user data to be passed to the callback function
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_provider_set_interval_changed_cb(
    sensor_provider_h provider,
    sensor_provider_interval_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sensor_provider_set_interval_changed_cb(
      provider,
      callback,
      user_data,
    );
  }

  late final _sensor_provider_set_interval_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(sensor_provider_h,
                  sensor_provider_interval_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'sensor_provider_set_interval_changed_cb');
  late final _sensor_provider_set_interval_changed_cb =
      _sensor_provider_set_interval_changed_cbPtr.asFunction<
          int Function(sensor_provider_h, sensor_provider_interval_changed_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief   Publishes a sensor event through the declared sensor.
  /// @details This function publishes a sensor's data to its listeners.
  /// @since_tizen 4.0
  ///
  /// @param[in]   provider    The sensor provider handle
  /// @param[out]  event       The sensor event
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_provider_publish(
    sensor_provider_h provider,
    sensor_event_s event,
  ) {
    return _sensor_provider_publish(
      provider,
      event,
    );
  }

  late final _sensor_provider_publishPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              sensor_provider_h, sensor_event_s)>>('sensor_provider_publish');
  late final _sensor_provider_publish = _sensor_provider_publishPtr
      .asFunction<int Function(sensor_provider_h, sensor_event_s)>();

  /// @brief   Checks whether it is supported to record a given sensor type.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]   type        A sensor type to check
  /// @param[out]  supported   If supported, @c true; Otherwise @c false
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_recorder_is_supported(
    int type,
    ffi.Pointer<ffi.Bool> supported,
  ) {
    return _sensor_recorder_is_supported(
      type,
      supported,
    );
  }

  late final _sensor_recorder_is_supportedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ffi.Bool>)>>('sensor_recorder_is_supported');
  late final _sensor_recorder_is_supported = _sensor_recorder_is_supportedPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @brief   Starts to record a given sensor type.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @remarks Some sensor types are privileged. An application should have the privilege
  /// http://tizen.org/privilege/healthinfo to get access to the following sensors:
  /// #SENSOR_HRM, #SENSOR_HRM_LED_GREEN, #SENSOR_HRM_LED_IR, #SENSOR_HRM_LED_RED,
  /// #SENSOR_HUMAN_PEDOMETER, #SENSOR_HUMAN_SLEEP_MONITOR, #SENSOR_HUMAN_SLEEP_DETECTOR,
  /// and #SENSOR_HUMAN_STRESS_MONITOR.
  ///
  /// @param[in]  type    A sensor type to be recorded
  /// @param[in]  option  Option
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_NOT_SUPPORTED        Not supported to record the sensor type
  /// @retval  #SENSOR_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  /// @retval  #SENSOR_ERROR_NOT_AVAILABLE        The sensor is already being recorded by the request of the current application
  ///
  /// @see sensor_recorder_stop()
  int sensor_recorder_start(
    int type,
    sensor_recorder_option_h option,
  ) {
    return _sensor_recorder_start(
      type,
      option,
    );
  }

  late final _sensor_recorder_startPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, sensor_recorder_option_h)>>('sensor_recorder_start');
  late final _sensor_recorder_start = _sensor_recorder_startPtr
      .asFunction<int Function(int, sensor_recorder_option_h)>();

  /// @brief   Stops recording a given sensor type.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]  type    A sensor type being recorded
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_NOT_SUPPORTED        The sensor type is not supported
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see sensor_recorder_start()
  int sensor_recorder_stop(
    int type,
  ) {
    return _sensor_recorder_stop(
      type,
    );
  }

  late final _sensor_recorder_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'sensor_recorder_stop');
  late final _sensor_recorder_stop =
      _sensor_recorder_stopPtr.asFunction<int Function(int)>();

  /// @brief   Creates a recorder option handle.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @remarks The @a option must be released using sensor_recorder_destroy_option().
  ///
  /// @param[out]  option  Option handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_recorder_create_option(
    ffi.Pointer<sensor_recorder_option_h> option,
  ) {
    return _sensor_recorder_create_option(
      option,
    );
  }

  late final _sensor_recorder_create_optionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<sensor_recorder_option_h>)>>(
      'sensor_recorder_create_option');
  late final _sensor_recorder_create_option = _sensor_recorder_create_optionPtr
      .asFunction<int Function(ffi.Pointer<sensor_recorder_option_h>)>();

  /// @brief   Destroys a recorder option handle.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]  option  Option handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_recorder_destroy_option(
    sensor_recorder_option_h option,
  ) {
    return _sensor_recorder_destroy_option(
      option,
    );
  }

  late final _sensor_recorder_destroy_optionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_recorder_option_h)>>(
          'sensor_recorder_destroy_option');
  late final _sensor_recorder_destroy_option =
      _sensor_recorder_destroy_optionPtr
          .asFunction<int Function(sensor_recorder_option_h)>();

  /// @brief   Sets a recording option parameter.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]  option      Option handle
  /// @param[in]  param       Option parameter
  /// @param[in]  value       Value
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_recorder_option_set_int(
    sensor_recorder_option_h option,
    int param,
    int value,
  ) {
    return _sensor_recorder_option_set_int(
      option,
      param,
      value,
    );
  }

  late final _sensor_recorder_option_set_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_recorder_option_h, ffi.Int32,
              ffi.Int)>>('sensor_recorder_option_set_int');
  late final _sensor_recorder_option_set_int =
      _sensor_recorder_option_set_intPtr
          .asFunction<int Function(sensor_recorder_option_h, int, int)>();

  /// @brief   Creates a recorder query handle.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @remarks The @a query must be released using sensor_recorder_destroy_query().
  ///
  /// @param[out]  query  Query handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OUT_OF_MEMORY        Out of memory
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_recorder_create_query(
    ffi.Pointer<sensor_recorder_query_h> query,
  ) {
    return _sensor_recorder_create_query(
      query,
    );
  }

  late final _sensor_recorder_create_queryPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<sensor_recorder_query_h>)>>(
      'sensor_recorder_create_query');
  late final _sensor_recorder_create_query = _sensor_recorder_create_queryPtr
      .asFunction<int Function(ffi.Pointer<sensor_recorder_query_h>)>();

  /// @brief   Destroys a recorder query handle.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]  query  Query handle
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_recorder_destroy_query(
    sensor_recorder_query_h query,
  ) {
    return _sensor_recorder_destroy_query(
      query,
    );
  }

  late final _sensor_recorder_destroy_queryPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(sensor_recorder_query_h)>>(
          'sensor_recorder_destroy_query');
  late final _sensor_recorder_destroy_query = _sensor_recorder_destroy_queryPtr
      .asFunction<int Function(sensor_recorder_query_h)>();

  /// @brief   Sets an integer-type query parameter
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]  query       Query handle
  /// @param[in]  param       Query parameter
  /// @param[in]  value       Value
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_recorder_query_set_int(
    sensor_recorder_query_h query,
    int param,
    int value,
  ) {
    return _sensor_recorder_query_set_int(
      query,
      param,
      value,
    );
  }

  late final _sensor_recorder_query_set_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_recorder_query_h, ffi.Int32,
              ffi.Int)>>('sensor_recorder_query_set_int');
  late final _sensor_recorder_query_set_int = _sensor_recorder_query_set_intPtr
      .asFunction<int Function(sensor_recorder_query_h, int, int)>();

  /// @brief   Sets a time-type query parameter.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]  query       Query handle
  /// @param[in]  param       Query parameter
  /// @param[in]  t           Time
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_recorder_query_set_time(
    sensor_recorder_query_h query,
    int param,
    int t,
  ) {
    return _sensor_recorder_query_set_time(
      query,
      param,
      t,
    );
  }

  late final _sensor_recorder_query_set_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_recorder_query_h, ffi.Int32,
              time_t)>>('sensor_recorder_query_set_time');
  late final _sensor_recorder_query_set_time =
      _sensor_recorder_query_set_timePtr
          .asFunction<int Function(sensor_recorder_query_h, int, int)>();

  /// @brief    Queries the recorded data asynchronously.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @remarks Some sensor types are privileged. An application should have the privilege
  /// http://tizen.org/privilege/healthinfo to get access to the following sensors:
  /// #SENSOR_HRM, #SENSOR_HRM_LED_GREEN, #SENSOR_HRM_LED_IR, #SENSOR_HRM_LED_RED,
  /// #SENSOR_HUMAN_PEDOMETER, #SENSOR_HUMAN_SLEEP_MONITOR, #SENSOR_HUMAN_SLEEP_DETECTOR,
  /// and #SENSOR_HUMAN_STRESS_MONITOR.
  ///
  /// @param[in]  type        Sensor type
  /// @param[in]  query       Query handle
  /// @param[in]  cb          Callback function to receive the queried data
  /// @param[in]  user_data   User data to be passed to the callback function
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_NOT_SUPPORTED        Not supported to record the sensor type
  /// @retval  #SENSOR_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  ///
  /// @see     sensor_recorder_read_sync()
  int sensor_recorder_read(
    int type,
    sensor_recorder_query_h query,
    sensor_recorder_data_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sensor_recorder_read(
      type,
      query,
      cb,
      user_data,
    );
  }

  late final _sensor_recorder_readPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              sensor_recorder_query_h,
              sensor_recorder_data_cb,
              ffi.Pointer<ffi.Void>)>>('sensor_recorder_read');
  late final _sensor_recorder_read = _sensor_recorder_readPtr.asFunction<
      int Function(int, sensor_recorder_query_h, sensor_recorder_data_cb,
          ffi.Pointer<ffi.Void>)>();

  /// @brief    Queries the recorded data synchronously.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @remarks Some sensor types are privileged. An application should have the privilege
  /// http://tizen.org/privilege/healthinfo to get access to the following sensors:
  /// #SENSOR_HRM, #SENSOR_HRM_LED_GREEN, #SENSOR_HRM_LED_IR, #SENSOR_HRM_LED_RED,
  /// #SENSOR_HUMAN_PEDOMETER, #SENSOR_HUMAN_SLEEP_MONITOR, #SENSOR_HUMAN_SLEEP_DETECTOR,
  /// and #SENSOR_HUMAN_STRESS_MONITOR.
  ///
  /// @param[in]  type        Sensor type
  /// @param[in]  query       Query handle
  /// @param[in]  cb          Callback function to receive the queried data
  /// @param[in]  user_data   User data to be passed to the callback function
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_NOT_SUPPORTED        Not supported to record the sensor type
  /// @retval  #SENSOR_ERROR_PERMISSION_DENIED    Permission denied
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  /// @retval  #SENSOR_ERROR_NO_DATA              No data retrieved
  ///
  /// @see     sensor_recorder_read()
  int sensor_recorder_read_sync(
    int type,
    sensor_recorder_query_h query,
    sensor_recorder_data_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _sensor_recorder_read_sync(
      type,
      query,
      cb,
      user_data,
    );
  }

  late final _sensor_recorder_read_syncPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              sensor_recorder_query_h,
              sensor_recorder_data_cb,
              ffi.Pointer<ffi.Void>)>>('sensor_recorder_read_sync');
  late final _sensor_recorder_read_sync =
      _sensor_recorder_read_syncPtr.asFunction<
          int Function(int, sensor_recorder_query_h, sensor_recorder_data_cb,
              ffi.Pointer<ffi.Void>)>();

  /// @brief    Gets the start and the end time of the time period of a given record data.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]  data        Record data handle
  /// @param[out] start_time  Start time of the time period of the record
  /// @param[out] end_time    End time of the time period of the record
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  int sensor_recorder_data_get_time(
    sensor_recorder_data_h data,
    ffi.Pointer<time_t> start_time,
    ffi.Pointer<time_t> end_time,
  ) {
    return _sensor_recorder_data_get_time(
      data,
      start_time,
      end_time,
    );
  }

  late final _sensor_recorder_data_get_timePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_recorder_data_h, ffi.Pointer<time_t>,
              ffi.Pointer<time_t>)>>('sensor_recorder_data_get_time');
  late final _sensor_recorder_data_get_time =
      _sensor_recorder_data_get_timePtr.asFunction<
          int Function(sensor_recorder_data_h, ffi.Pointer<time_t>,
              ffi.Pointer<time_t>)>();

  /// @brief    Gets an integer value from a record data.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]  data        Record data handle
  /// @param[in]  key         Data attribute to retrieve
  /// @param[out] value       Retrieved value
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  /// @retval  #SENSOR_ERROR_NO_DATA              No data retrieved
  int sensor_recorder_data_get_int(
    sensor_recorder_data_h data,
    int key,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _sensor_recorder_data_get_int(
      data,
      key,
      value,
    );
  }

  late final _sensor_recorder_data_get_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_recorder_data_h, ffi.Int32,
              ffi.Pointer<ffi.Int>)>>('sensor_recorder_data_get_int');
  late final _sensor_recorder_data_get_int =
      _sensor_recorder_data_get_intPtr.asFunction<
          int Function(sensor_recorder_data_h, int, ffi.Pointer<ffi.Int>)>();

  /// @brief    Gets a double value from a record data.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  ///
  /// @param[in]  data        Record data handle
  /// @param[in]  key         Data attribute to retrieve
  /// @param[out] value       Retrieved value
  ///
  /// @return  #SENSOR_ERROR_NONE on success, otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  /// @retval  #SENSOR_ERROR_OPERATION_FAILED     Operation failed
  /// @retval  #SENSOR_ERROR_NO_DATA              No data retrieved
  int sensor_recorder_data_get_double(
    sensor_recorder_data_h data,
    int key,
    ffi.Pointer<ffi.Double> value,
  ) {
    return _sensor_recorder_data_get_double(
      data,
      key,
      value,
    );
  }

  late final _sensor_recorder_data_get_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(sensor_recorder_data_h, ffi.Int32,
              ffi.Pointer<ffi.Double>)>>('sensor_recorder_data_get_double');
  late final _sensor_recorder_data_get_double =
      _sensor_recorder_data_get_doublePtr.asFunction<
          int Function(sensor_recorder_data_h, int, ffi.Pointer<ffi.Double>)>();

  /// @brief   Gets the inclination matrix @"I@" and rotation matrix @"R@" transforming a vector from the device coordinate to the world's coordinate.
  ///
  /// @details [0 0 g] = R * gravity (g = magnitude of gravity) \n
  /// [0 m 0] = I * R * geomagnetic (m = magnitude of the geomagnetic field) \n
  /// R is the identity matrix when the device is aligned with the world's coordinate system, that is, when the device's X axis points towards the East, the Y axis points to the North Pole and the device is facing the sky. \n
  /// I is a rotation matrix transforming the geomagnetic vector into the same coordinate space as gravity (the world's coordinate space). I is a simple rotation around the X axis. \n
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Parameters Gx, Gy, and Gz can be obtained from the values returned by #SENSOR_GRAVITY. \n
  /// Parameters Mx, My, and Mz can be obtained from the values returned by #SENSOR_MAGNETIC.
  /// Output parameter R and I are always returned as a 3x3 matrix array of 9 floats like this form:
  /// <pre>
  /// { R[0], R[1], R[2],
  /// R[3], R[4], R[5],
  /// R[6], R[7], R[6] }
  /// </pre>
  ///
  ///
  /// @param[in]  Gx   The X-axis gravity vector in the device's coordinate
  /// @param[in]  Gy   The Y-axis gravity vector in the device's coordinate
  /// @param[in]  Gz   The Z-axis gravity vector in the device's coordinate
  /// @param[in]  Mx   The X-axis geomagnetic vector in the device's coordinate
  /// @param[in]  My   The Y-axis geomagnetic vector in the device's coordinate
  /// @param[in]  Mz   The Z-axis geomagnetic vector in the device's coordinate
  /// @param[out] R    The array of 9 floats that represent the rotation matrix @"R@" \n
  /// It can be null.
  /// @param[out] I    The array of 9 floats that represent the inclination matrix @"I@" \n
  /// It can be null.
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_util_get_rotation_matrix(
    double Gx,
    double Gy,
    double Gz,
    double Mx,
    double My,
    double Mz,
    ffi.Pointer<ffi.Float> R,
    ffi.Pointer<ffi.Float> I,
  ) {
    return _sensor_util_get_rotation_matrix(
      Gx,
      Gy,
      Gz,
      Mx,
      My,
      Mz,
      R,
      I,
    );
  }

  late final _sensor_util_get_rotation_matrixPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Float,
              ffi.Float,
              ffi.Float,
              ffi.Float,
              ffi.Float,
              ffi.Float,
              ffi.Pointer<ffi.Float>,
              ffi.Pointer<ffi.Float>)>>('sensor_util_get_rotation_matrix');
  late final _sensor_util_get_rotation_matrix =
      _sensor_util_get_rotation_matrixPtr.asFunction<
          int Function(double, double, double, double, double, double,
              ffi.Pointer<ffi.Float>, ffi.Pointer<ffi.Float>)>();

  /// @brief Converts a rotation vector to a rotation matrix.
  ///
  /// @details Rotation vectors (Vx, Vy, Vz) can be obtained from #SENSOR_ROTATION_VECTOR.
  /// It returns a 9 element rotation matrix in the array R. R must have length as 9.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  Vx   The X-axis rotation vector
  /// @param[in]  Vy   The Y-axis rotation vector
  /// @param[in]  Vz   The Z-axis rotation vector
  /// @param[out] R    A 9 element rotation matrix in the array R that must have length as 9
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_util_get_rotation_matrix_from_vector(
    double Vx,
    double Vy,
    double Vz,
    ffi.Pointer<ffi.Float> R,
  ) {
    return _sensor_util_get_rotation_matrix_from_vector(
      Vx,
      Vy,
      Vz,
      R,
    );
  }

  late final _sensor_util_get_rotation_matrix_from_vectorPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Float, ffi.Float, ffi.Float, ffi.Pointer<ffi.Float>)>>(
      'sensor_util_get_rotation_matrix_from_vector');
  late final _sensor_util_get_rotation_matrix_from_vector =
      _sensor_util_get_rotation_matrix_from_vectorPtr.asFunction<
          int Function(double, double, double, ffi.Pointer<ffi.Float>)>();

  /// @brief Rotates the supplied rotation matrix so that it is expressed in a different coordinate system.
  ///
  /// @details This is typically used when an application needs to compute the three orientation angles of the device in a different coordinate system.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks inR and outR can be the same array, but this is not recommended for performance reasons.
  /// This returns an error when X and Y define the same axis.
  ///
  /// @param[in]  inR  The rotation matrix (3x3) to be transformed
  /// @param[in]  x    The world axis and direction on which the X axis of the device is mapped
  /// @param[in]  y    The world axis and direction on which the Y axis of the device is mapped
  /// @param[out] outR The transformed rotation matrix (3x3)
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_util_remap_coordinate_system(
    ffi.Pointer<ffi.Float> inR,
    int x,
    int y,
    ffi.Pointer<ffi.Float> outR,
  ) {
    return _sensor_util_remap_coordinate_system(
      inR,
      x,
      y,
      outR,
    );
  }

  late final _sensor_util_remap_coordinate_systemPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Float>, ffi.Int32, ffi.Int32,
              ffi.Pointer<ffi.Float>)>>('sensor_util_remap_coordinate_system');
  late final _sensor_util_remap_coordinate_system =
      _sensor_util_remap_coordinate_systemPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Float>, int, int, ffi.Pointer<ffi.Float>)>();

  /// @brief Computes the geomagnetic inclination angle in radians from the inclination matrix I returned by sensor_util_get_rotation_matrix().
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  I            The inclination matrix from sensor_util_get_rotation_matrix()
  /// @param[out] inclination  The geomagnetic inclination angle in radians
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  ///
  /// @see sensor_util_get_rotation_matrix()
  int sensor_util_get_inclination(
    ffi.Pointer<ffi.Float> I,
    ffi.Pointer<ffi.Float> inclination,
  ) {
    return _sensor_util_get_inclination(
      I,
      inclination,
    );
  }

  late final _sensor_util_get_inclinationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Float>,
              ffi.Pointer<ffi.Float>)>>('sensor_util_get_inclination');
  late final _sensor_util_get_inclination =
      _sensor_util_get_inclinationPtr.asFunction<
          int Function(ffi.Pointer<ffi.Float>, ffi.Pointer<ffi.Float>)>();

  /// @brief Computes the device's orientation based on the rotation matrix.
  ///
  /// @details When it returns, the array values are filled with the result:
  /// - values[0]: azimuth, rotation around the Z axis.
  /// - values[1]: pitch, rotation around the X axis.
  /// - values[2]: roll, rotation around the Y axis.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Parameter R must be an array of 9 floats from sensor_util_get_rotation_matrix() \n
  /// Returned values are always arrays of 3 floats.
  ///
  /// @param[in]  R         A 9 element rotation matrix in the array
  /// @param[out] values    An array of 3 floats to hold the result
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  ///
  /// @see sensor_util_get_rotation_matrix()
  int sensor_util_get_orientation(
    ffi.Pointer<ffi.Float> R,
    ffi.Pointer<ffi.Float> values,
  ) {
    return _sensor_util_get_orientation(
      R,
      values,
    );
  }

  late final _sensor_util_get_orientationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Float>,
              ffi.Pointer<ffi.Float>)>>('sensor_util_get_orientation');
  late final _sensor_util_get_orientation =
      _sensor_util_get_orientationPtr.asFunction<
          int Function(ffi.Pointer<ffi.Float>, ffi.Pointer<ffi.Float>)>();

  /// @brief Computes the angle change between two rotation matrices.
  ///
  /// @details Given a current rotation matrix (R) and a previous rotation matrix (prevR), it computes
  /// the rotation around the x,y, and z axes which transforms prevR to R.
  /// It outputs a 3 element vector containing the x,y, and z angle change at indexes 0, 1, and 2 respectively. \n
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks Each input matrix is a 3x3 matrix like this form:
  /// <pre>
  /// { R[0], R[1], R[2],
  /// R[3], R[4], R[5],
  /// R[6], R[7], R[6] }
  /// </pre>
  ///
  /// @param[in] R             The current rotation matrix
  /// @param[in] prevR         The previous rotation matrix
  /// @param[out] angleChange  An array of floats in which the angle change is stored
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_util_get_angle_change(
    ffi.Pointer<ffi.Float> R,
    ffi.Pointer<ffi.Float> prevR,
    ffi.Pointer<ffi.Float> angleChange,
  ) {
    return _sensor_util_get_angle_change(
      R,
      prevR,
      angleChange,
    );
  }

  late final _sensor_util_get_angle_changePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Float>, ffi.Pointer<ffi.Float>,
              ffi.Pointer<ffi.Float>)>>('sensor_util_get_angle_change');
  late final _sensor_util_get_angle_change =
      _sensor_util_get_angle_changePtr.asFunction<
          int Function(ffi.Pointer<ffi.Float>, ffi.Pointer<ffi.Float>,
              ffi.Pointer<ffi.Float>)>();

  /// @brief Gets the declination of the horizontal component of the magnetic field from true north, in degrees.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in]  latitude     The latitude in geodetic coordinates
  /// @param[in]  longitude    The longitude in geodetic coordinates
  /// @param[in]  altitude     The altitude in geodetic coordinates
  /// @param[out] declination  The declination of the horizontal component of the magnetic field in degrees
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_util_get_declination(
    double latitude,
    double longitude,
    double altitude,
    ffi.Pointer<ffi.Float> declination,
  ) {
    return _sensor_util_get_declination(
      latitude,
      longitude,
      altitude,
      declination,
    );
  }

  late final _sensor_util_get_declinationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Float, ffi.Float, ffi.Float,
              ffi.Pointer<ffi.Float>)>>('sensor_util_get_declination');
  late final _sensor_util_get_declination =
      _sensor_util_get_declinationPtr.asFunction<
          int Function(double, double, double, ffi.Pointer<ffi.Float>)>();

  /// @brief Gets the altitude from the atmospheric pressure, the pressure at sea level and temperature, in meters.
  /// @since_tizen 4.0
  ///
  /// @param[in]  pressure           The atmospheric pressure (hPa)
  /// @param[in]  sea_level_pressure The sea level pressure (hPa) @n
  /// If the sea level pressure is not known, you can use 1013.25 hPa, mean sea level pressure
  /// @param[in]  temperature        The temperature (degrees Celsius) @n
  /// If the temperature is not known, you can use 15 degrees Celsius
  /// @param[out] altitude           The altitude (meters)
  ///
  /// @return  #SENSOR_ERROR_NONE on success; Otherwise a negative error value
  /// @retval  #SENSOR_ERROR_NONE                 Successful
  /// @retval  #SENSOR_ERROR_INVALID_PARAMETER    Invalid parameter
  int sensor_util_get_altitude(
    double pressure,
    double sea_level_pressure,
    double temperature,
    ffi.Pointer<ffi.Float> altitude,
  ) {
    return _sensor_util_get_altitude(
      pressure,
      sea_level_pressure,
      temperature,
      altitude,
    );
  }

  late final _sensor_util_get_altitudePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Float, ffi.Float, ffi.Float,
              ffi.Pointer<ffi.Float>)>>('sensor_util_get_altitude');
  late final _sensor_util_get_altitude =
      _sensor_util_get_altitudePtr.asFunction<
          int Function(double, double, double, ffi.Pointer<ffi.Float>)>();

  /// @brief Retrieves all the storage in a device.
  /// @details This function invokes the callback function once for each storage in a device. \n
  /// If storage_device_supported_cb() returns @c false, then the iteration will be finished.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] callback The iteration callback function
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @post This function invokes storage_device_supported_cb() repeatedly for each supported device.
  /// @see storage_device_supported_cb()
  int storage_foreach_device_supported(
    storage_device_supported_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _storage_foreach_device_supported(
      callback,
      user_data,
    );
  }

  late final _storage_foreach_device_supportedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(storage_device_supported_cb,
              ffi.Pointer<ffi.Void>)>>('storage_foreach_device_supported');
  late final _storage_foreach_device_supported =
      _storage_foreach_device_supportedPtr.asFunction<
          int Function(storage_device_supported_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the absolute path to the root directory of the given storage.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Files saved on the internal/external storage are readable or writable by all applications.\n
  /// When an application is uninstalled, the files written by that application are not removed from the internal/external storage.\n
  /// If you want to access files or directories in internal storage, you must declare http://tizen.org/privilege/mediastorage.\n
  /// If you want to access files or directories in external storage, you must declare http://tizen.org/privilege/externalstorage.\n
  /// You must release @a path using free().
  /// @param[in] storage_id The storage device
  /// @param[out] path The absolute path to the storage directory
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STORAGE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #STORAGE_ERROR_NOT_SUPPORTED Storage not supported
  /// @see storage_get_state()
  int storage_get_root_directory(
    int storage_id,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _storage_get_root_directory(
      storage_id,
      path,
    );
  }

  late final _storage_get_root_directoryPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'storage_get_root_directory');
  late final _storage_get_root_directory = _storage_get_root_directoryPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the absolute path to the each directory of the given storage.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Files saved on the internal/external storage are readable or writable by all applications.\n
  /// When an application is uninstalled, the files written by that application are not removed from the internal/external storage.\n
  /// The directory path may not exist, so you must make sure that it exists before using it.\n
  /// If you want to access files or directories in internal storage except #STORAGE_DIRECTORY_SYSTEM_RINGTONES, you must declare http://tizen.org/privilege/mediastorage.\n
  /// If you want to access files or directories in #STORAGE_DIRECTORY_SYSTEM_RINGTONES, you must declare %http://tizen.org/privilege/systemsettings.\n
  /// If you want to access files or directories in external storage, you must declare http://tizen.org/privilege/externalstorage.\n
  /// You must release @a path using free().
  /// @param[in] storage_id The storage device
  /// @param[in] type The directory type
  /// @param[out] path The absolute path to the directory type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STORAGE_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #STORAGE_ERROR_NOT_SUPPORTED Storage not supported
  /// @see storage_get_state()
  int storage_get_directory(
    int storage_id,
    int type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> path,
  ) {
    return _storage_get_directory(
      storage_id,
      type,
      path,
    );
  }

  late final _storage_get_directoryPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int32,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('storage_get_directory');
  late final _storage_get_directory = _storage_get_directoryPtr
      .asFunction<int Function(int, int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the type of the given storage.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] storage_id The storage device
  /// @param[out] type The type of the storage
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STORAGE_ERROR_NOT_SUPPORTED Storage not supported
  int storage_get_type(
    int storage_id,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _storage_get_type(
      storage_id,
      type,
    );
  }

  late final _storage_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<ffi.Int32>)>>('storage_get_type');
  late final _storage_get_type = _storage_get_typePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the current state of the given storage.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] storage_id The storage device
  /// @param[out] state The current state of the storage
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STORAGE_ERROR_NOT_SUPPORTED Storage not supported
  /// @see storage_get_root_directory()
  /// @see storage_get_total_space()
  /// @see storage_get_available_space()
  int storage_get_state(
    int storage_id,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _storage_get_state(
      storage_id,
      state,
    );
  }

  late final _storage_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Pointer<ffi.Int32>)>>('storage_get_state');
  late final _storage_get_state = _storage_get_statePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Registers a callback function to be invoked when the state of the storage changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] storage_id The storage device
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STORAGE_ERROR_NOT_SUPPORTED Storage not supported
  /// @retval #STORAGE_ERROR_OPERATION_FAILED Operation failed
  /// @post storage_state_changed_cb() will be invoked if the state of the registered storage changes.
  /// @see storage_state_changed_cb()
  /// @see storage_unset_state_changed_cb()
  int storage_set_state_changed_cb(
    int storage_id,
    storage_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _storage_set_state_changed_cb(
      storage_id,
      callback,
      user_data,
    );
  }

  late final _storage_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, storage_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('storage_set_state_changed_cb');
  late final _storage_set_state_changed_cb =
      _storage_set_state_changed_cbPtr.asFunction<
          int Function(int, storage_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] storage_id The storage device to monitor
  /// @param[in] callback The callback function to register
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STORAGE_ERROR_NOT_SUPPORTED Storage not supported
  /// @retval #STORAGE_ERROR_OPERATION_FAILED Operation failed
  /// @see storage_state_changed_cb()
  /// @see storage_set_state_changed_cb()
  int storage_unset_state_changed_cb(
    int storage_id,
    storage_state_changed_cb callback,
  ) {
    return _storage_unset_state_changed_cb(
      storage_id,
      callback,
    );
  }

  late final _storage_unset_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              storage_state_changed_cb)>>('storage_unset_state_changed_cb');
  late final _storage_unset_state_changed_cb =
      _storage_unset_state_changed_cbPtr
          .asFunction<int Function(int, storage_state_changed_cb)>();

  /// @brief Registers a callback function to be invoked when the state of the specified storage device type changes.
  /// @since_tizen 3.0
  /// @param[in] type The type of the storage device
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STORAGE_ERROR_NOT_SUPPORTED Storage not supported
  /// @retval #STORAGE_ERROR_OPERATION_FAILED Operation failed
  /// @post storage_changed_cb() will be invoked if the state of the registered storage type changes.
  /// @see storage_changed_cb()
  /// @see storage_unset_changed_cb()
  int storage_set_changed_cb(
    int type,
    storage_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _storage_set_changed_cb(
      type,
      callback,
      user_data,
    );
  }

  late final _storage_set_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, storage_changed_cb,
              ffi.Pointer<ffi.Void>)>>('storage_set_changed_cb');
  late final _storage_set_changed_cb = _storage_set_changed_cbPtr.asFunction<
      int Function(int, storage_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function for storage type state changes.
  /// @since_tizen 3.0
  /// @param[in] type The type of the the storage device
  /// @param[in] callback The callback function to unregister
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STORAGE_ERROR_NOT_SUPPORTED Storage not supported
  /// @retval #STORAGE_ERROR_OPERATION_FAILED Operation failed
  /// @see storage_changed_cb()
  /// @see storage_set_changed_cb()
  int storage_unset_changed_cb(
    int type,
    storage_changed_cb callback,
  ) {
    return _storage_unset_changed_cb(
      type,
      callback,
    );
  }

  late final _storage_unset_changed_cbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int32, storage_changed_cb)>>(
      'storage_unset_changed_cb');
  late final _storage_unset_changed_cb = _storage_unset_changed_cbPtr
      .asFunction<int Function(int, storage_changed_cb)>();

  /// @brief Gets the total space of the given storage in bytes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] storage_id The storage device
  /// @param[out] bytes The total space size of the storage (bytes)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STORAGE_ERROR_NOT_SUPPORTED Storage not supported
  /// @retval #STORAGE_ERROR_OPERATION_FAILED Operation failed
  /// @see storage_get_state()
  /// @see storage_get_available_space()
  int storage_get_total_space(
    int storage_id,
    ffi.Pointer<ffi.UnsignedLongLong> bytes,
  ) {
    return _storage_get_total_space(
      storage_id,
      bytes,
    );
  }

  late final _storage_get_total_spacePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int,
              ffi.Pointer<ffi.UnsignedLongLong>)>>('storage_get_total_space');
  late final _storage_get_total_space = _storage_get_total_spacePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.UnsignedLongLong>)>();

  /// @brief Gets the available space size of the given storage in bytes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] storage_id The storage device
  /// @param[out] bytes The available space size of the storage (bytes)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STORAGE_ERROR_NONE Successful
  /// @retval #STORAGE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STORAGE_ERROR_NOT_SUPPORTED Storage not supported
  /// @retval #STORAGE_ERROR_OPERATION_FAILED Operation failed
  /// @see storage_get_state()
  /// @see storage_get_total_space()
  int storage_get_available_space(
    int storage_id,
    ffi.Pointer<ffi.UnsignedLongLong> bytes,
  ) {
    return _storage_get_available_space(
      storage_id,
      bytes,
    );
  }

  late final _storage_get_available_spacePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int, ffi.Pointer<ffi.UnsignedLongLong>)>>(
      'storage_get_available_space');
  late final _storage_get_available_space = _storage_get_available_spacePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.UnsignedLongLong>)>();

  int storage_get_internal_memory_size(
    ffi.Pointer<statvfs> buf,
  ) {
    return _storage_get_internal_memory_size(
      buf,
    );
  }

  late final _storage_get_internal_memory_sizePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<statvfs>)>>(
          'storage_get_internal_memory_size');
  late final _storage_get_internal_memory_size =
      _storage_get_internal_memory_sizePtr
          .asFunction<int Function(ffi.Pointer<statvfs>)>();

  int storage_get_external_memory_size(
    ffi.Pointer<statvfs> buf,
  ) {
    return _storage_get_external_memory_size(
      buf,
    );
  }

  late final _storage_get_external_memory_sizePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<statvfs>)>>(
          'storage_get_external_memory_size');
  late final _storage_get_external_memory_size =
      _storage_get_external_memory_sizePtr
          .asFunction<int Function(ffi.Pointer<statvfs>)>();

  /// @brief Gets the boolean value of the @a platform feature.
  /// @since_tizen 2.3
  /// @param[in] key The name of the platform feature to get
  /// @param[out] value The value of the given platform feature
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SYSTEM_INFO_ERROR_NONE Successful
  /// @retval #SYSTEM_INFO_ERROR_INVALID_PARAMETER Cannot find the @a key in the model config file
  /// @retval #SYSTEM_INFO_ERROR_IO_ERROR An input/output error occurred while reading the @a value from the model config file
  /// @retval #SYSTEM_INFO_ERROR_PERMISSION_DENIED No permission to use the API
  int system_info_get_platform_bool(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Bool> value,
  ) {
    return _system_info_get_platform_bool(
      key,
      value,
    );
  }

  late final _system_info_get_platform_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('system_info_get_platform_bool');
  late final _system_info_get_platform_bool = _system_info_get_platform_boolPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the integer value of the @a platform feature.
  /// @since_tizen 2.3
  /// @param[in] key The name of the platform feature to get
  /// @param[out] value The value of the given platform feature
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SYSTEM_INFO_ERROR_NONE Successful
  /// @retval #SYSTEM_INFO_ERROR_INVALID_PARAMETER Cannot find the @a key in the model config file
  /// @retval #SYSTEM_INFO_ERROR_IO_ERROR An input/output error occurred while reading the @a value from the model config file
  /// @retval #SYSTEM_INFO_ERROR_PERMISSION_DENIED No permission to use the API
  int system_info_get_platform_int(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _system_info_get_platform_int(
      key,
      value,
    );
  }

  late final _system_info_get_platform_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('system_info_get_platform_int');
  late final _system_info_get_platform_int = _system_info_get_platform_intPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the double value of the @a platform feature.
  /// @since_tizen 2.3
  /// @param[in] key The name of the platform feature to get
  /// @param[out] value The value of the given platform feature
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SYSTEM_INFO_ERROR_NONE Successful
  /// @retval #SYSTEM_INFO_ERROR_INVALID_PARAMETER Cannot find the @a key in the model config file
  /// @retval #SYSTEM_INFO_ERROR_IO_ERROR An input/output error occurred while reading the @a value from the model config file
  /// @retval #SYSTEM_INFO_ERROR_PERMISSION_DENIED No permission to use the API
  int system_info_get_platform_double(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Double> value,
  ) {
    return _system_info_get_platform_double(
      key,
      value,
    );
  }

  late final _system_info_get_platform_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Double>)>>('system_info_get_platform_double');
  late final _system_info_get_platform_double =
      _system_info_get_platform_doublePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Double>)>();

  /// @brief Gets the string value of the @a platform feature.
  /// @since_tizen 2.3
  /// @remarks You must release the @a value using free().
  /// @param[in] key The name of the platform feature to get
  /// @param[out] value The value of the given platform feature
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SYSTEM_INFO_ERROR_NONE Successful
  /// @retval #SYSTEM_INFO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SYSTEM_INFO_ERROR_INVALID_PARAMETER Cannot find the @a key in the model config file
  /// @retval #SYSTEM_INFO_ERROR_IO_ERROR An input/output error occurred while reading the @a value from the model config file
  /// @retval #SYSTEM_INFO_ERROR_PERMISSION_DENIED No permission to use the API
  int system_info_get_platform_string(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _system_info_get_platform_string(
      key,
      value,
    );
  }

  late final _system_info_get_platform_stringPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'system_info_get_platform_string');
  late final _system_info_get_platform_string =
      _system_info_get_platform_stringPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the boolean value of the @a custom feature.
  /// @since_tizen 2.3
  /// @param[in] key The name of the custom feature to get. NOTE: This custom function uses a custom key which is provided by OEM's
  /// @param[out] value The value of the given custom feature
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SYSTEM_INFO_ERROR_NONE Successful
  /// @retval #SYSTEM_INFO_ERROR_INVALID_PARAMETER Cannot find the @a key in the model config file
  /// @retval #SYSTEM_INFO_ERROR_IO_ERROR An input/output error occurred while reading the @a value from the model config file
  /// @retval #SYSTEM_INFO_ERROR_PERMISSION_DENIED No permission to use the API
  int system_info_get_custom_bool(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Bool> value,
  ) {
    return _system_info_get_custom_bool(
      key,
      value,
    );
  }

  late final _system_info_get_custom_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('system_info_get_custom_bool');
  late final _system_info_get_custom_bool = _system_info_get_custom_boolPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the integer value of the @a custom feature.
  /// @since_tizen 2.3
  /// @param[in] key The name of the custom feature to get. NOTE: This custom function uses a custom key which is provided by OEM's
  /// @param[out] value The value of the given custom feature
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SYSTEM_INFO_ERROR_NONE Successful
  /// @retval #SYSTEM_INFO_ERROR_INVALID_PARAMETER Cannot the find @a key in the model config file
  /// @retval #SYSTEM_INFO_ERROR_IO_ERROR An input/output error occurred while reading the @a value from the model config file
  /// @retval #SYSTEM_INFO_ERROR_PERMISSION_DENIED No permission to use the API
  int system_info_get_custom_int(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _system_info_get_custom_int(
      key,
      value,
    );
  }

  late final _system_info_get_custom_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int>)>>('system_info_get_custom_int');
  late final _system_info_get_custom_int = _system_info_get_custom_intPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the double value of the @a custom feature.
  /// @since_tizen 2.3
  /// @param[in] key The name of the custom feature to get. NOTE: This custom function uses a custom key which is provided by OEM's
  /// @param[out] value The value of the given custom feature
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SYSTEM_INFO_ERROR_NONE Successful
  /// @retval #SYSTEM_INFO_ERROR_INVALID_PARAMETER Cannot find the @a key in the model config file
  /// @retval #SYSTEM_INFO_ERROR_IO_ERROR An input/output error occurred while reading the @a value from the model config file
  /// @retval #SYSTEM_INFO_ERROR_PERMISSION_DENIED No permission to use the API
  int system_info_get_custom_double(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Double> value,
  ) {
    return _system_info_get_custom_double(
      key,
      value,
    );
  }

  late final _system_info_get_custom_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Double>)>>('system_info_get_custom_double');
  late final _system_info_get_custom_double =
      _system_info_get_custom_doublePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Double>)>();

  /// @brief Gets the string value of the @a custom feature.
  /// @since_tizen 2.3
  /// @remarks You must release the @a value using free().
  /// @param[in] key The name of the custom feature to get. NOTE: This custom function uses a custom key which is provided by OEM's
  /// @param[out] value The value of the given custom feature
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #SYSTEM_INFO_ERROR_NONE Successful
  /// @retval #SYSTEM_INFO_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #SYSTEM_INFO_ERROR_INVALID_PARAMETER Cannot find the @a key in the model config file
  /// @retval #SYSTEM_INFO_ERROR_IO_ERROR An input/output error occurred while reading the @a value from the model config file
  /// @retval #SYSTEM_INFO_ERROR_PERMISSION_DENIED No permission to use the API
  int system_info_get_custom_string(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _system_info_get_custom_string(
      key,
      value,
    );
  }

  late final _system_info_get_custom_stringPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'system_info_get_custom_string');
  late final _system_info_get_custom_string =
      _system_info_get_custom_stringPtr.asFunction<
          int Function(
              ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @internal
  /// @brief Do not use it. It will be removed.
  int system_info_get_value_int(
    int key,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _system_info_get_value_int(
      key,
      value,
    );
  }

  late final _system_info_get_value_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Int>)>>('system_info_get_value_int');
  late final _system_info_get_value_int = _system_info_get_value_intPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @internal
  /// @brief Do not use it. It will be removed.
  int system_info_get_value_bool(
    int key,
    ffi.Pointer<ffi.Bool> value,
  ) {
    return _system_info_get_value_bool(
      key,
      value,
    );
  }

  late final _system_info_get_value_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Bool>)>>('system_info_get_value_bool');
  late final _system_info_get_value_bool = _system_info_get_value_boolPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @internal
  /// @brief Do not use it. It will be removed.
  int system_info_get_value_double(
    int key,
    ffi.Pointer<ffi.Double> value,
  ) {
    return _system_info_get_value_double(
      key,
      value,
    );
  }

  late final _system_info_get_value_doublePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ffi.Double>)>>('system_info_get_value_double');
  late final _system_info_get_value_double = _system_info_get_value_doublePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Double>)>();

  /// @internal
  /// @brief Do not use it. It will be removed.
  int system_info_get_value_string(
    int key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _system_info_get_value_string(
      key,
      value,
    );
  }

  late final _system_info_get_value_stringPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int32, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'system_info_get_value_string');
  late final _system_info_get_value_string = _system_info_get_value_stringPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @internal
  /// @brief It is not decided if it should be opened to public.
  int system_info_get_platform_type(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _system_info_get_platform_type(
      key,
      type,
    );
  }

  late final _system_info_get_platform_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>>('system_info_get_platform_type');
  late final _system_info_get_platform_type =
      _system_info_get_platform_typePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int32>)>();

  /// @internal
  /// @brief It is not decided if it should be opened to public.
  int system_info_get_custom_type(
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _system_info_get_custom_type(
      key,
      type,
    );
  }

  late final _system_info_get_custom_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Int32>)>>('system_info_get_custom_type');
  late final _system_info_get_custom_type =
      _system_info_get_custom_typePtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Int32>)>();

  /// @platform
  /// @brief Sets the system settings value associated with the given key as an integer.
  /// @since_tizen 2.3
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/systemsettings.admin
  /// @remarks When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[out] value The new system settings value of the given key
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_IO_ERROR Internal I/O error
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  int system_settings_set_value_int(
    int key,
    int value,
  ) {
    return _system_settings_set_value_int(
      key,
      value,
    );
  }

  late final _system_settings_set_value_intPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32, ffi.Int)>>(
          'system_settings_set_value_int');
  late final _system_settings_set_value_int =
      _system_settings_set_value_intPtr.asFunction<int Function(int, int)>();

  /// @brief Gets the system settings value associated with the given key as an integer.
  /// @since_tizen 2.3
  /// @remarks When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[out] value The current system settings value of the given key
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_IO_ERROR Internal I/O error
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  /// @warning %http://tizen.org/privilege/systemsettings (public level privilege) <b>MUST NOT</b> be declared to use this API since 2.3.1.
  int system_settings_get_value_int(
    int key,
    ffi.Pointer<ffi.Int> value,
  ) {
    return _system_settings_get_value_int(
      key,
      value,
    );
  }

  late final _system_settings_get_value_intPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ffi.Int>)>>('system_settings_get_value_int');
  late final _system_settings_get_value_int = _system_settings_get_value_intPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int>)>();

  /// @platform
  /// @brief Sets the system settings value associated with the given key as a boolean.
  /// @since_tizen 2.3
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/systemsettings.admin
  /// @remarks When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[out] value The new system settings value of the given key
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_IO_ERROR Internal I/O error
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  int system_settings_set_value_bool(
    int key,
    bool value,
  ) {
    return _system_settings_set_value_bool(
      key,
      value,
    );
  }

  late final _system_settings_set_value_boolPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32, ffi.Bool)>>(
          'system_settings_set_value_bool');
  late final _system_settings_set_value_bool =
      _system_settings_set_value_boolPtr.asFunction<int Function(int, bool)>();

  /// @brief Gets the system settings value associated with the given key as a boolean.
  /// @since_tizen 2.3
  /// @remarks When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[out] value The current system settings value of the given key
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_IO_ERROR Internal I/O error
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  /// @warning %http://tizen.org/privilege/systemsettings (public level privilege) <b>MUST NOT</b> be declared to use this API since 2.3.1.
  int system_settings_get_value_bool(
    int key,
    ffi.Pointer<ffi.Bool> value,
  ) {
    return _system_settings_get_value_bool(
      key,
      value,
    );
  }

  late final _system_settings_get_value_boolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ffi.Bool>)>>('system_settings_get_value_bool');
  late final _system_settings_get_value_bool =
      _system_settings_get_value_boolPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Bool>)>();

  /// @platform
  /// @brief Sets the system settings value associated with the given key as a string.
  /// @since_tizen 2.3
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/systemsettings.admin
  /// @remarks #SYSTEM_SETTINGS_KEY_DEFAULT_FONT_TYPE is not available for setting. When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[out] value The new system settings value of the given key
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_IO_ERROR Internal I/O error
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  int system_settings_set_value_string(
    int key,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _system_settings_set_value_string(
      key,
      value,
    );
  }

  late final _system_settings_set_value_stringPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('system_settings_set_value_string');
  late final _system_settings_set_value_string =
      _system_settings_set_value_stringPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the system settings value associated with the given key as a string.
  /// @since_tizen 2.3
  /// @remarks You must release @a value using free(). When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[out] value The current system settings value of the given key
  /// @return	0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_IO_ERROR Internal I/O error
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  /// @warning %http://tizen.org/privilege/systemsettings (public level privilege) <b>MUST NOT</b> be declared to use this API since 2.3.1.
  int system_settings_get_value_string(
    int key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> value,
  ) {
    return _system_settings_get_value_string(
      key,
      value,
    );
  }

  late final _system_settings_get_value_stringPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int32, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'system_settings_get_value_string');
  late final _system_settings_get_value_string =
      _system_settings_get_value_stringPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Registers a change event callback for the given system settings key.
  /// @since_tizen 2.3
  /// @remarks #SYSTEM_SETTINGS_KEY_DEFAULT_FONT_TYPE is not available for set_changed_cb. When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return	0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  /// @post system_settings_changed_cb() will be invoked.
  ///
  /// @see system_settings_unset_changed_cb()
  /// @see system_settings_changed_cb()
  /// @warning %http://tizen.org/privilege/systemsettings (public level privilege) <b>MUST NOT</b> be declared to use this API since 2.3.1.
  int system_settings_set_changed_cb(
    int key,
    system_settings_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _system_settings_set_changed_cb(
      key,
      callback,
      user_data,
    );
  }

  late final _system_settings_set_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, system_settings_changed_cb,
              ffi.Pointer<ffi.Void>)>>('system_settings_set_changed_cb');
  late final _system_settings_set_changed_cb =
      _system_settings_set_changed_cbPtr.asFunction<
          int Function(
              int, system_settings_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen 2.3
  /// @remarks #SYSTEM_SETTINGS_KEY_DEFAULT_FONT_TYPE is not available for set_changed_cb. When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @return	0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  ///
  /// @see system_settings_set_changed_cb()
  /// @warning %http://tizen.org/privilege/systemsettings (public level privilege) <b>MUST NOT</b> be declared to use this API since 2.3.1.
  int system_settings_unset_changed_cb(
    int key,
  ) {
    return _system_settings_unset_changed_cb(
      key,
    );
  }

  late final _system_settings_unset_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int32)>>(
          'system_settings_unset_changed_cb');
  late final _system_settings_unset_changed_cb =
      _system_settings_unset_changed_cbPtr.asFunction<int Function(int)>();

  /// @platform
  /// @brief Iterate the system settings value associated with the given key as a string type.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/systemsettings.admin
  /// @remarks When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[in] callback The callback-function name for iteration
  /// @param[in] user_data  The user data passed from caller-side
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_IO_ERROR Internal I/O error
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  int system_settings_foreach_value_string(
    int key,
    system_settings_iter_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _system_settings_foreach_value_string(
      key,
      callback,
      user_data,
    );
  }

  late final _system_settings_foreach_value_stringPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, system_settings_iter_cb,
              ffi.Pointer<ffi.Void>)>>('system_settings_foreach_value_string');
  late final _system_settings_foreach_value_string =
      _system_settings_foreach_value_stringPtr.asFunction<
          int Function(int, system_settings_iter_cb, ffi.Pointer<ffi.Void>)>();

  /// @platform
  /// @brief Adds the system settings value associated with the given key as a string type if it supports List iteration.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/systemsettings.admin
  /// @remarks When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[in] value string typed value to be appended
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_IO_ERROR Internal I/O error
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  int system_settings_add_value_string(
    int key,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _system_settings_add_value_string(
      key,
      value,
    );
  }

  late final _system_settings_add_value_stringPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('system_settings_add_value_string');
  late final _system_settings_add_value_string =
      _system_settings_add_value_stringPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @platform
  /// @brief Delete the system settings value associated with the given key as an string type if it supports List iteration.
  /// @since_tizen 3.0
  /// @privlevel platform
  /// @privilege %http://tizen.org/privilege/systemsettings.admin
  /// @remarks When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[in] value string typed value to be removed
  /// @return @c 0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_IO_ERROR Internal I/O error
  /// @retval	#SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED Permission violation error
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  int system_settings_delete_value_string(
    int key,
    ffi.Pointer<ffi.Char> value,
  ) {
    return _system_settings_delete_value_string(
      key,
      value,
    );
  }

  late final _system_settings_delete_value_stringPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32,
              ffi.Pointer<ffi.Char>)>>('system_settings_delete_value_string');
  late final _system_settings_delete_value_string =
      _system_settings_delete_value_stringPtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Adds a change event callback for the given system settings key.
  /// @details The difference between this function and system_settings_set_changed_cb() is that system_settings_set_changed_cb() can set only one callback for a given key, while system_settings_add_changed_cb() can set multiple callbacks for a given key.
  /// @since_tizen 4.0
  /// @remarks The @a key cannot be #SYSTEM_SETTINGS_KEY_DEFAULT_FONT_TYPE. When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return	0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  /// @post system_settings_changed_cb() will be invoked.
  ///
  /// @see system_settings_remove_changed_cb()
  /// @see system_settings_changed_cb()
  int system_settings_add_changed_cb(
    int key,
    system_settings_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _system_settings_add_changed_cb(
      key,
      callback,
      user_data,
    );
  }

  late final _system_settings_add_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, system_settings_changed_cb,
              ffi.Pointer<ffi.Void>)>>('system_settings_add_changed_cb');
  late final _system_settings_add_changed_cb =
      _system_settings_add_changed_cbPtr.asFunction<
          int Function(
              int, system_settings_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Removes a change event callback function.
  /// @details The difference between this function and system_settings_unset_changed_cb() is that system_settings_unset_changed_cb() unsets the callback set with system_settings_set_changed_cb(), while system_settings_remove_changed_cb() removes callbacks added with system_settings_add_changed_cb()
  /// @since_tizen 4.0
  /// @remarks The @a key cannot be #SYSTEM_SETTINGS_KEY_DEFAULT_FONT_TYPE. When the feature related to the @a key is not supported on the device, #SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED will be returned.
  /// @param[in] key The key name of the system settings
  /// @param[in] callback The callback function to be removed
  /// @return	0 on success, otherwise a negative error value
  /// @retval	#SYSTEM_SETTINGS_ERROR_NONE Successful
  /// @retval	#SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval	#SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED The related feature is not supported on the device
  ///
  /// @see system_settings_add_changed_cb()
  int system_settings_remove_changed_cb(
    int key,
    system_settings_changed_cb callback,
  ) {
    return _system_settings_remove_changed_cb(
      key,
      callback,
    );
  }

  late final _system_settings_remove_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Int32, system_settings_changed_cb)>>(
      'system_settings_remove_changed_cb');
  late final _system_settings_remove_changed_cb =
      _system_settings_remove_changed_cbPtr
          .asFunction<int Function(int, system_settings_changed_cb)>();

  /// @brief Writes a trace event to indicate that a synchronous event has begun.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 2.3.2 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] name The name of event (optionally containing format specifiers)
  /// @exception TRACE_ERROR_NONE	Success
  /// @exception TRACE_ERROR_IO_ERROR	I/O error
  /// @see trace_end()
  void trace_begin(
    ffi.Pointer<ffi.Char> name,
  ) {
    return _trace_begin(
      name,
    );
  }

  late final _trace_beginPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Char>)>>(
          'trace_begin');
  late final _trace_begin =
      _trace_beginPtr.asFunction<void Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Writes a trace event to indicate that the synchronous event has ended.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 2.3.2 @endif
  /// @remarks trace_end() ends the most recently called trace_begin().
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @exception TRACE_ERROR_NONE  Success
  /// @exception TRACE_ERROR_IO_ERROR      I/O error
  /// @see trace_begin()
  void trace_end() {
    return _trace_end();
  }

  late final _trace_endPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function()>>('trace_end');
  late final _trace_end = _trace_endPtr.asFunction<void Function()>();

  /// @brief Writes a trace event to indicate that an asynchronous event has begun.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 2.3.2 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] cookie An unique identifier for distinguishing simultaneous events
  /// @param[in] name The name of event (optionally containing format specifiers)
  /// @exception TRACE_ERROR_NONE	Success
  /// @exception TRACE_ERROR_IO_ERROR	I/O error
  /// @see trace_async_end()
  void trace_async_begin(
    int cookie,
    ffi.Pointer<ffi.Char> name,
  ) {
    return _trace_async_begin(
      cookie,
      name,
    );
  }

  late final _trace_async_beginPtr = _lookup<
      ffi.NativeFunction<
          ffi.Void Function(
              ffi.Int, ffi.Pointer<ffi.Char>)>>('trace_async_begin');
  late final _trace_async_begin = _trace_async_beginPtr
      .asFunction<void Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Writes a trace event to indicate that the asynchronous event has ended.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 2.3.2 @endif
  /// @remarks trace_async_end() ends matched trace_async_begin() which has same cookie and name.
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] cookie An unique identifier for distinguishing simultaneous events
  /// @param[in] name The name of event (optionally containing format specifiers)
  /// @exception TRACE_ERROR_NONE  Success
  /// @exception TRACE_ERROR_IO_ERROR      I/O error
  /// @see trace_async_begin()
  void trace_async_end(
    int cookie,
    ffi.Pointer<ffi.Char> name,
  ) {
    return _trace_async_end(
      cookie,
      name,
    );
  }

  late final _trace_async_endPtr = _lookup<
      ffi.NativeFunction<
          ffi.Void Function(
              ffi.Int, ffi.Pointer<ffi.Char>)>>('trace_async_end');
  late final _trace_async_end = _trace_async_endPtr
      .asFunction<void Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Writes a trace event to track change of integer counter
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 2.3.2 @endif
  /// @remarks The specific error code can be obtained using the get_last_result() method. Error codes are described in Exception section.
  /// @param[in] value The counter value
  /// @param[in] name The name of event (optionally containing format specifiers)
  /// @exception TRACE_ERROR_NONE  Success
  /// @exception TRACE_ERROR_IO_ERROR      I/O error
  void trace_update_counter(
    int value,
    ffi.Pointer<ffi.Char> name,
  ) {
    return _trace_update_counter(
      value,
      name,
    );
  }

  late final _trace_update_counterPtr = _lookup<
      ffi.NativeFunction<
          ffi.Void Function(
              ffi.Int, ffi.Pointer<ffi.Char>)>>('trace_update_counter');
  late final _trace_update_counter = _trace_update_counterPtr
      .asFunction<void Function(int, ffi.Pointer<ffi.Char>)>();

  /// @ingroup CAPI_USB_HOST_MODULE
  /// @brief Initializes usb_host context.
  /// @details This function must be called before any other function from this module.
  /// @since_tizen 3.0
  /// @remarks @a ctx should be destroyed by calling usb_host_destroy() when no longer needed.
  /// @param[out] ctx Context pointer
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @post usb_host_destroy() should be called to free resources allocated for ctx by this function.
  int usb_host_create(
    ffi.Pointer<usb_host_context_h> ctx,
  ) {
    return _usb_host_create(
      ctx,
    );
  }

  late final _usb_host_createPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<usb_host_context_h>)>>('usb_host_create');
  late final _usb_host_create = _usb_host_createPtr
      .asFunction<int Function(ffi.Pointer<usb_host_context_h>)>();

  /// @ingroup CAPI_USB_HOST_MODULE
  /// @brief Deinitializes usb_host context.
  /// @details This function must be called after closing all devices
  /// and before application close. It has to be called to clean
  /// the memory used by library.
  /// @since_tizen 3.0
  /// @param[in] ctx Context to deinitialize
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NONE Success
  /// @pre Context must be initialized by usb_host_create().
  int usb_host_destroy(
    usb_host_context_h ctx,
  ) {
    return _usb_host_destroy(
      ctx,
    );
  }

  late final _usb_host_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(usb_host_context_h)>>(
          'usb_host_destroy');
  late final _usb_host_destroy =
      _usb_host_destroyPtr.asFunction<int Function(usb_host_context_h)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets USB device list.
  /// @details This function returns list of USB devices attached to system.
  /// To free obtained device list usb_host_free_device_list() should be used, this
  /// function can also unref devices. Do not unref device and then open it.
  ///
  /// All devices have reference counter. Functions usb_host_ref_device() and
  /// usb_host_unref_device() are used to ref or unref device. When ref counter
  /// reaches 0 device will be freed.
  /// Devices reached by calling usb_host_get_device_list() have a reference count of
  /// 1, and usb_host_free_device_list() can optionally decrease the reference count
  /// on all devices in the list. usb_host_device_open() adds another reference which is
  /// later destroyed by usb_host_device_close().
  ///
  /// @since_tizen 3.0
  /// @param[in] ctx Context handle
  /// @param[out] devs An array of devices
  /// @param[out] length Number of devices
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Operation not supported
  /// @retval #USB_HOST_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @post @a devs must be freed with usb_host_free_device_list() when no longer needed.
  int usb_host_get_device_list(
    usb_host_context_h ctx,
    ffi.Pointer<ffi.Pointer<usb_host_device_h>> devs,
    ffi.Pointer<ffi.Int> length,
  ) {
    return _usb_host_get_device_list(
      ctx,
      devs,
      length,
    );
  }

  late final _usb_host_get_device_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              usb_host_context_h,
              ffi.Pointer<ffi.Pointer<usb_host_device_h>>,
              ffi.Pointer<ffi.Int>)>>('usb_host_get_device_list');
  late final _usb_host_get_device_list =
      _usb_host_get_device_listPtr.asFunction<
          int Function(
              usb_host_context_h,
              ffi.Pointer<ffi.Pointer<usb_host_device_h>>,
              ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Frees devices list.
  /// @details This function needs to be called to free device list. This
  /// function can also unref devices if unref_devices is set to non-zero value.
  /// Do not unref device and then open it.
  /// @since_tizen 3.0
  /// @param[in] devs List of devices
  /// @param[in] unref_devices Set to true to unreference devices, set to false to not unref
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @pre usb_host_get_device_list() must be called before using this function.
  int usb_host_free_device_list(
    ffi.Pointer<usb_host_device_h> devs,
    bool unref_devices,
  ) {
    return _usb_host_free_device_list(
      devs,
      unref_devices,
    );
  }

  late final _usb_host_free_device_listPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<usb_host_device_h>,
              ffi.Bool)>>('usb_host_free_device_list');
  late final _usb_host_free_device_list = _usb_host_free_device_listPtr
      .asFunction<int Function(ffi.Pointer<usb_host_device_h>, bool)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Refs a device.
  /// @details Increment ref count of device.
  /// @since_tizen 3.0
  /// @param[in] dev Device to reference
  /// @return 0 on success, error code otherwise
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NONE Successful
  int usb_host_ref_device(
    usb_host_device_h dev,
  ) {
    return _usb_host_ref_device(
      dev,
    );
  }

  late final _usb_host_ref_devicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(usb_host_device_h)>>(
          'usb_host_ref_device');
  late final _usb_host_ref_device =
      _usb_host_ref_devicePtr.asFunction<int Function(usb_host_device_h)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Unrefs a device.
  /// @details Decrements ref count of device. If ref count reaches zero,
  /// device will be destroyed.
  /// @since_tizen 3.0
  /// @param[in] dev Device to unreference
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_unref_device(
    usb_host_device_h dev,
  ) {
    return _usb_host_unref_device(
      dev,
    );
  }

  late final _usb_host_unref_devicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(usb_host_device_h)>>(
          'usb_host_unref_device');
  late final _usb_host_unref_device =
      _usb_host_unref_devicePtr.asFunction<int Function(usb_host_device_h)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Opens a device.
  /// @details This function opens a device, which allows performing operations on it
  /// (including transfer operations and strings introspection).
  /// @since_tizen 3.0
  /// @param[in] dev Device to open
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_OUT_OF_MEMORY Memory allocation failure
  /// @retval #USB_HOST_ERROR_NO_SUCH_DEVICE There is no device connected
  /// @retval #USB_HOST_ERROR_PERMISSION_DENIED No proper permission to access device
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Operation not supported
  /// @see usb_host_is_device_opened()
  int usb_host_device_open(
    usb_host_device_h dev,
  ) {
    return _usb_host_device_open(
      dev,
    );
  }

  late final _usb_host_device_openPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(usb_host_device_h)>>(
          'usb_host_device_open');
  late final _usb_host_device_open =
      _usb_host_device_openPtr.asFunction<int Function(usb_host_device_h)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Closes device.
  /// @details Function should be called before usb_host_destroy().
  /// It destroys reference that was added by usb_host_device_open().
  /// @since_tizen 3.0
  /// @param[in] dev Device that should be closed
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_DEVICE_NOT_OPENED If device is not opened
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NONE Successful
  int usb_host_device_close(
    usb_host_device_h dev,
  ) {
    return _usb_host_device_close(
      dev,
    );
  }

  late final _usb_host_device_closePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(usb_host_device_h)>>(
          'usb_host_device_close');
  late final _usb_host_device_close =
      _usb_host_device_closePtr.asFunction<int Function(usb_host_device_h)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Opens device with valid idVendor and idProduct.
  /// @details This function can be used to open device with known idVendor and
  /// idProduct. If two or more devices have same vendor and product id only
  /// first will be opened.
  /// @since_tizen 3.0
  /// @param[in] ctx Context
  /// @param[in] vendor_id idVendor of connected device
  /// @param[in] product_id idProduct of connected device
  /// @param[out] device_handle Opened device handle
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_OUT_OF_MEMORY Insufficient memory
  /// @retval #USB_HOST_ERROR_NO_SUCH_DEVICE No device
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_device_open_with_vid_pid(
    usb_host_context_h ctx,
    int vendor_id,
    int product_id,
    ffi.Pointer<usb_host_device_h> device_handle,
  ) {
    return _usb_host_device_open_with_vid_pid(
      ctx,
      vendor_id,
      product_id,
      device_handle,
    );
  }

  late final _usb_host_device_open_with_vid_pidPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(usb_host_context_h, ffi.Int, ffi.Int,
                  ffi.Pointer<usb_host_device_h>)>>(
      'usb_host_device_open_with_vid_pid');
  late final _usb_host_device_open_with_vid_pid =
      _usb_host_device_open_with_vid_pidPtr.asFunction<
          int Function(
              usb_host_context_h, int, int, ffi.Pointer<usb_host_device_h>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets bus number.
  /// @details Gets device bus number. This is number of the bus
  /// that device is connected to.
  /// @since_tizen 3.0
  /// @param[in] dev Device handle
  /// @param[out] bus_number Device bus number
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_PERMISSION_DENIED Permission denied
  int usb_host_device_get_bus_number(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> bus_number,
  ) {
    return _usb_host_device_get_bus_number(
      dev,
      bus_number,
    );
  }

  late final _usb_host_device_get_bus_numberPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_bus_number');
  late final _usb_host_device_get_bus_number =
      _usb_host_device_get_bus_numberPtr
          .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets address.
  /// @details Gets device address. This is address of device on the bus
  /// that device is connected to.
  /// @since_tizen 3.0
  /// @param[in] dev Device
  /// @param[out] device_address Device address
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  int usb_host_device_get_address(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> device_address,
  ) {
    return _usb_host_device_get_address(
      dev,
      device_address,
    );
  }

  late final _usb_host_device_get_addressPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_address');
  late final _usb_host_device_get_address = _usb_host_device_get_addressPtr
      .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets list of port numbers.
  /// @details Gets list of all port numbers from a device.
  /// @since_tizen 3.0
  /// @param[in] dev Device
  /// @param[out] port_numbers Array to be filled with port numbers
  /// @param[in] port_numbers_len Max length of array
  /// @param[out] ports_count Number of all ports obtained from device
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_OUT_OF_MEMORY Insufficient memory
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  int usb_host_device_get_port_numbers(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> port_numbers,
    int port_numbers_len,
    ffi.Pointer<ffi.Int> ports_count,
  ) {
    return _usb_host_device_get_port_numbers(
      dev,
      port_numbers,
      port_numbers_len,
      ports_count,
    );
  }

  late final _usb_host_device_get_port_numbersPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h, ffi.Pointer<ffi.Int>, ffi.Int,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_port_numbers');
  late final _usb_host_device_get_port_numbers =
      _usb_host_device_get_port_numbersPtr.asFunction<
          int Function(usb_host_device_h, ffi.Pointer<ffi.Int>, int,
              ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets a configuration.
  /// @details Gets a USB configuration from a device.
  /// @since_tizen 3.0
  /// @remarks @a config must be freed with usb_host_config_destroy().
  /// @param[in] dev Device
  /// @param[in] config_index index of configuration to retrieve (counting from 0)
  /// @param[out] config Output location for USB configuration
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_FOUND The configuration does not exist
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @post Returned configuration should be destroyed by usb_host_config_destroy()
  /// when no longer needed.
  int usb_host_device_get_config(
    usb_host_device_h dev,
    int config_index,
    ffi.Pointer<usb_host_config_h> config,
  ) {
    return _usb_host_device_get_config(
      dev,
      config_index,
      config,
    );
  }

  late final _usb_host_device_get_configPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h, ffi.Int,
              ffi.Pointer<usb_host_config_h>)>>('usb_host_device_get_config');
  late final _usb_host_device_get_config =
      _usb_host_device_get_configPtr.asFunction<
          int Function(
              usb_host_device_h, int, ffi.Pointer<usb_host_config_h>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets an active config.
  /// @details Gets handle to active configuration.
  /// This function will return 0 value in config parameter :if device is unconfigured.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] config Handle to active configuration
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NO_SUCH_DEVICE the dev has been disconnected
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_DEVICE_NOT_OPENED The device was not opened
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @post Obtained configuration should be destroyed by usb_host_config_destroy()
  /// when no longer needed.
  int usb_host_get_active_config(
    usb_host_device_h dev,
    ffi.Pointer<usb_host_config_h> config,
  ) {
    return _usb_host_get_active_config(
      dev,
      config,
    );
  }

  late final _usb_host_get_active_configPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<usb_host_config_h>)>>('usb_host_get_active_config');
  late final _usb_host_get_active_config =
      _usb_host_get_active_configPtr.asFunction<
          int Function(usb_host_device_h, ffi.Pointer<usb_host_config_h>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Sets a configuration.
  /// @details Set active configuration for a device.
  /// @since_tizen 3.0
  /// @param[in] configuration Handle to configuration to be activated
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_FOUND Requested configuration does not exist
  /// @retval #USB_HOST_ERROR_RESOURCE_BUSY Interfaces are currently claimed
  /// @retval #USB_HOST_ERROR_NO_SUCH_DEVICE The device has been disconnected
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_DEVICE_NOT_OPENED The device was not opened
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  int usb_host_set_config(
    usb_host_config_h configuration,
  ) {
    return _usb_host_set_config(
      configuration,
    );
  }

  late final _usb_host_set_configPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(usb_host_config_h)>>(
          'usb_host_set_config');
  late final _usb_host_set_config =
      _usb_host_set_configPtr.asFunction<int Function(usb_host_config_h)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Puts a device in unconfigured state.
  /// @since_tizen 4.0
  /// @param[in] dev Device to be unconfigured
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_RESOURCE_BUSY Interfaces are currently claimed
  /// @retval #USB_HOST_ERROR_NO_SUCH_DEVICE Device has beed disconnected
  int usb_host_device_unconfigure(
    usb_host_device_h dev,
  ) {
    return _usb_host_device_unconfigure(
      dev,
    );
  }

  late final _usb_host_device_unconfigurePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(usb_host_device_h)>>(
          'usb_host_device_unconfigure');
  late final _usb_host_device_unconfigure = _usb_host_device_unconfigurePtr
      .asFunction<int Function(usb_host_device_h)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets USB specification release number.
  /// @details Gets binary-coded decimal USB specification release number.
  /// This value is equal to bcdUSB field of device descriptor. See USB specification
  /// for more info.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] bcd_usb Bcd release number of USB
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_PERMISSION_DENIED Permission denied
  int usb_host_device_get_bcd_usb(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> bcd_usb,
  ) {
    return _usb_host_device_get_bcd_usb(
      dev,
      bcd_usb,
    );
  }

  late final _usb_host_device_get_bcd_usbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_bcd_usb');
  late final _usb_host_device_get_bcd_usb = _usb_host_device_get_bcd_usbPtr
      .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets device class.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] device_class Device class
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_device_get_class(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> device_class,
  ) {
    return _usb_host_device_get_class(
      dev,
      device_class,
    );
  }

  late final _usb_host_device_get_classPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_class');
  late final _usb_host_device_get_class = _usb_host_device_get_classPtr
      .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets device sub class.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] subclass Device subclass
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_device_get_sub_class(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> subclass,
  ) {
    return _usb_host_device_get_sub_class(
      dev,
      subclass,
    );
  }

  late final _usb_host_device_get_sub_classPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_sub_class');
  late final _usb_host_device_get_sub_class = _usb_host_device_get_sub_classPtr
      .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets device protocol.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] protocol Device protocol
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_device_get_protocol(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> protocol,
  ) {
    return _usb_host_device_get_protocol(
      dev,
      protocol,
    );
  }

  late final _usb_host_device_get_protocolPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_protocol');
  late final _usb_host_device_get_protocol = _usb_host_device_get_protocolPtr
      .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets maximum packet size for endpoint 0.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] max_packet_size Maximum size of single packet, in bytes
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_device_get_max_packet_size_0(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> max_packet_size,
  ) {
    return _usb_host_device_get_max_packet_size_0(
      dev,
      max_packet_size,
    );
  }

  late final _usb_host_device_get_max_packet_size_0Ptr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_max_packet_size_0');
  late final _usb_host_device_get_max_packet_size_0 =
      _usb_host_device_get_max_packet_size_0Ptr
          .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets vendor id.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] vendor_id Vendor id of @a dev
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_device_get_id_vendor(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> vendor_id,
  ) {
    return _usb_host_device_get_id_vendor(
      dev,
      vendor_id,
    );
  }

  late final _usb_host_device_get_id_vendorPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_id_vendor');
  late final _usb_host_device_get_id_vendor = _usb_host_device_get_id_vendorPtr
      .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets product id.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] product_id Product id of @a dev
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_device_get_id_product(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> product_id,
  ) {
    return _usb_host_device_get_id_product(
      dev,
      product_id,
    );
  }

  late final _usb_host_device_get_id_productPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_id_product');
  late final _usb_host_device_get_id_product =
      _usb_host_device_get_id_productPtr
          .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets device release number in binary-coded decimal.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] device_bcd Device release number
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_device_get_bcd_device(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> device_bcd,
  ) {
    return _usb_host_device_get_bcd_device(
      dev,
      device_bcd,
    );
  }

  late final _usb_host_device_get_bcd_devicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_bcd_device');
  late final _usb_host_device_get_bcd_device =
      _usb_host_device_get_bcd_devicePtr
          .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets number of configurations for given device.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] num_configurations Number of configurations for given device
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_device_get_num_configurations(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> num_configurations,
  ) {
    return _usb_host_device_get_num_configurations(
      dev,
      num_configurations,
    );
  }

  late final _usb_host_device_get_num_configurationsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_device_get_num_configurations');
  late final _usb_host_device_get_num_configurations =
      _usb_host_device_get_num_configurationsPtr
          .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Checks if device is opened.
  /// @since_tizen 3.0
  /// @param[in] dev A device
  /// @param[out] is_opened True if device is opened, false otherwise
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_is_device_opened(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Bool> is_opened,
  ) {
    return _usb_host_is_device_opened(
      dev,
      is_opened,
    );
  }

  late final _usb_host_is_device_openedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_device_h,
              ffi.Pointer<ffi.Bool>)>>('usb_host_is_device_opened');
  late final _usb_host_is_device_opened = _usb_host_is_device_openedPtr
      .asFunction<int Function(usb_host_device_h, ffi.Pointer<ffi.Bool>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets string describing device manufacturer, in ASCII.
  /// @since_tizen 3.0
  /// @param[in] dev A handle to opened device
  /// @param[in, out] length Data buffer size/how much was actually used
  /// @param[out] data Buffer to store string
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_OVERFLOW There was no space in buffer
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_PERMISSION_DENIED Permission denied
  /// @pre dev must point to device opened by usb_host_device_open() or usb_host_device_open_with_vid_pid().
  int usb_host_device_get_manufacturer_str(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> length,
    ffi.Pointer<ffi.UnsignedChar> data,
  ) {
    return _usb_host_device_get_manufacturer_str(
      dev,
      length,
      data,
    );
  }

  late final _usb_host_device_get_manufacturer_strPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(usb_host_device_h, ffi.Pointer<ffi.Int>,
                  ffi.Pointer<ffi.UnsignedChar>)>>(
      'usb_host_device_get_manufacturer_str');
  late final _usb_host_device_get_manufacturer_str =
      _usb_host_device_get_manufacturer_strPtr.asFunction<
          int Function(usb_host_device_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.UnsignedChar>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets product string of device, in ASCII.
  /// @since_tizen 3.0
  /// @param[in] dev A handle to opened device
  /// @param[in, out] length Data buffer size/how much was actually used
  /// @param[out] data Buffer to store string
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_OVERFLOW There was no space in buffer
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_PERMISSION_DENIED Permission denied
  /// @pre dev must point to device opened by usb_host_device_open() or usb_host_device_open_with_vid_pid().
  int usb_host_device_get_product_str(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> length,
    ffi.Pointer<ffi.UnsignedChar> data,
  ) {
    return _usb_host_device_get_product_str(
      dev,
      length,
      data,
    );
  }

  late final _usb_host_device_get_product_strPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(usb_host_device_h, ffi.Pointer<ffi.Int>,
                  ffi.Pointer<ffi.UnsignedChar>)>>(
      'usb_host_device_get_product_str');
  late final _usb_host_device_get_product_str =
      _usb_host_device_get_product_strPtr.asFunction<
          int Function(usb_host_device_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.UnsignedChar>)>();

  /// @ingroup CAPI_USB_HOST_DEV_MODULE
  /// @brief Gets serial number of a device, in ASCII.
  /// @since_tizen 3.0
  /// @param[in] dev A handle to opened device
  /// @param[in, out] length Data buffer size/how much was actually used
  /// @param[out] data Buffer to store string
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_OVERFLOW There was no space in buffer
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_PERMISSION_DENIED Permission denied
  /// @pre dev must point to device opened by usb_host_device_open() or usb_host_device_open_with_vid_pid().
  int usb_host_device_get_serial_number_str(
    usb_host_device_h dev,
    ffi.Pointer<ffi.Int> length,
    ffi.Pointer<ffi.UnsignedChar> data,
  ) {
    return _usb_host_device_get_serial_number_str(
      dev,
      length,
      data,
    );
  }

  late final _usb_host_device_get_serial_number_strPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(usb_host_device_h, ffi.Pointer<ffi.Int>,
                  ffi.Pointer<ffi.UnsignedChar>)>>(
      'usb_host_device_get_serial_number_str');
  late final _usb_host_device_get_serial_number_str =
      _usb_host_device_get_serial_number_strPtr.asFunction<
          int Function(usb_host_device_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.UnsignedChar>)>();

  /// @ingroup CAPI_USB_HOST_CONFIG_MODULE
  /// @brief Gets number of interfaces for given configuration.
  /// @since_tizen 3.0
  /// @param[in] config A configuration
  /// @param[out] num_interfaces Number of interfaces
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_config_get_num_interfaces(
    usb_host_config_h config,
    ffi.Pointer<ffi.Int> num_interfaces,
  ) {
    return _usb_host_config_get_num_interfaces(
      config,
      num_interfaces,
    );
  }

  late final _usb_host_config_get_num_interfacesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_config_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_config_get_num_interfaces');
  late final _usb_host_config_get_num_interfaces =
      _usb_host_config_get_num_interfacesPtr
          .asFunction<int Function(usb_host_config_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_CONFIG_MODULE
  /// @brief Checks if device is self-powered in given configuration.
  /// @since_tizen 3.0
  /// @param[in] config A configuration
  /// @param[out] self_powered True if device is self-powered in given configuration,
  /// false otherwise
  /// @return 0 on success, negative error code otherwise
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  int usb_host_config_is_self_powered(
    usb_host_config_h config,
    ffi.Pointer<ffi.Bool> self_powered,
  ) {
    return _usb_host_config_is_self_powered(
      config,
      self_powered,
    );
  }

  late final _usb_host_config_is_self_poweredPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_config_h,
              ffi.Pointer<ffi.Bool>)>>('usb_host_config_is_self_powered');
  late final _usb_host_config_is_self_powered =
      _usb_host_config_is_self_poweredPtr
          .asFunction<int Function(usb_host_config_h, ffi.Pointer<ffi.Bool>)>();

  /// @ingroup CAPI_USB_HOST_CONFIG_MODULE
  /// @brief Checks if device in given configuration supports remote wakeup.
  /// @since_tizen 3.0
  /// @param[in] config A configuration
  /// @param[out] remote_wakeup True if device supports remote wakeup in given configuration,
  /// false otherwise
  /// @return 0 on success, negative error code otherwise
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval @USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  int usb_host_config_support_remote_wakeup(
    usb_host_config_h config,
    ffi.Pointer<ffi.Bool> remote_wakeup,
  ) {
    return _usb_host_config_support_remote_wakeup(
      config,
      remote_wakeup,
    );
  }

  late final _usb_host_config_support_remote_wakeupPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_config_h,
              ffi.Pointer<ffi.Bool>)>>('usb_host_config_support_remote_wakeup');
  late final _usb_host_config_support_remote_wakeup =
      _usb_host_config_support_remote_wakeupPtr
          .asFunction<int Function(usb_host_config_h, ffi.Pointer<ffi.Bool>)>();

  /// @ingroup CAPI_USB_HOST_CONFIG_MODULE
  /// @brief Gets maximum power in given configuration, in mA.
  /// @since_tizen 3.0
  /// @param[in] config A configuration
  /// @param[out] max_power Maximum power, in mA
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_config_get_max_power(
    usb_host_config_h config,
    ffi.Pointer<ffi.Int> max_power,
  ) {
    return _usb_host_config_get_max_power(
      config,
      max_power,
    );
  }

  late final _usb_host_config_get_max_powerPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_config_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_config_get_max_power');
  late final _usb_host_config_get_max_power = _usb_host_config_get_max_powerPtr
      .asFunction<int Function(usb_host_config_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_CONFIG_MODULE
  /// @brief Gets string describing a configuration.
  /// @since_tizen 3.0
  /// @param[in] config A configuration
  /// @param[in, out] length Data buffer size/how much was actually used
  /// @param[out] data Buffer to store string
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_OVERFLOW There was no space in buffer
  /// @retval #USB_HOST_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @pre config must be configuration of device opened by usb_host_device_open() or
  /// usb_host_device_open_with_vid_pid()
  int usb_host_device_get_config_str(
    usb_host_config_h config,
    ffi.Pointer<ffi.Int> length,
    ffi.Pointer<ffi.UnsignedChar> data,
  ) {
    return _usb_host_device_get_config_str(
      config,
      length,
      data,
    );
  }

  late final _usb_host_device_get_config_strPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(usb_host_config_h, ffi.Pointer<ffi.Int>,
                  ffi.Pointer<ffi.UnsignedChar>)>>(
      'usb_host_device_get_config_str');
  late final _usb_host_device_get_config_str =
      _usb_host_device_get_config_strPtr.asFunction<
          int Function(usb_host_config_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.UnsignedChar>)>();

  /// @ingroup CAPI_USB_HOST_CONFIG_MODULE
  /// @brief Gets an interface from configuration.
  /// @details Gets a USB interface from configuration by its index.
  /// @since_tizen 3.0
  /// @param[in] config Configuration handle
  /// @param[in] interface_index index of interface to retrieve (counting from 0)
  /// @param[out] interface Interface handle
  /// @remarks There is no need to destroy the @a interface handle. It is no longer valid
  /// when config is destroyed.
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_FOUND Configuration does not exist
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_PERMISSION_DENIED Permission denied
  int usb_host_config_get_interface(
    usb_host_config_h config,
    int interface_index,
    ffi.Pointer<usb_host_interface_h> interface1,
  ) {
    return _usb_host_config_get_interface(
      config,
      interface_index,
      interface1,
    );
  }

  late final _usb_host_config_get_interfacePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(usb_host_config_h, ffi.Int,
                  ffi.Pointer<usb_host_interface_h>)>>(
      'usb_host_config_get_interface');
  late final _usb_host_config_get_interface =
      _usb_host_config_get_interfacePtr.asFunction<
          int Function(
              usb_host_config_h, int, ffi.Pointer<usb_host_interface_h>)>();

  /// @ingroup CAPI_USB_HOST_CONFIG_MODULE
  /// @brief Frees configuration.
  /// @details Frees configuration obtained from usb_host_device_get_config().
  /// @since_tizen 3.0
  /// @param[in] config Configuration to free
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_PERMISSION_DENIED Permission denied
  /// @pre config must be obtained by usb_host_device_get_config().
  int usb_host_config_destroy(
    usb_host_config_h config,
  ) {
    return _usb_host_config_destroy(
      config,
    );
  }

  late final _usb_host_config_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(usb_host_config_h)>>(
          'usb_host_config_destroy');
  late final _usb_host_config_destroy =
      _usb_host_config_destroyPtr.asFunction<int Function(usb_host_config_h)>();

  /// @ingroup CAPI_USB_HOST_INTERFACE_MODULE
  /// @brief Claims interface.
  /// @details Claims interface on a device.
  /// To perform I/O operations on interface user has to claim it.
  /// Remember to call usb_host_release_interface() when communication
  /// with the device is finished.
  /// @since_tizen 3.0
  /// @param[in] interface The bInterfaceNumber of interface to claim
  /// @param[in] force Set to true to auto detach kernel driver, set to false to not detach it
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_FOUND Requested interface does not exist
  /// @retval #USB_HOST_ERROR_RESOURCE_BUSY Another program or driver has claimed the
  /// interface
  /// @retval #USB_HOST_ERROR_NO_SUCH_DEVICE Device has been disconnected
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_DEVICE_NOT_OPENED The device was not opened
  int usb_host_claim_interface(
    usb_host_interface_h interface1,
    bool force,
  ) {
    return _usb_host_claim_interface(
      interface1,
      force,
    );
  }

  late final _usb_host_claim_interfacePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(usb_host_interface_h, ffi.Bool)>>(
      'usb_host_claim_interface');
  late final _usb_host_claim_interface = _usb_host_claim_interfacePtr
      .asFunction<int Function(usb_host_interface_h, bool)>();

  /// @ingroup CAPI_USB_HOST_INTERFACE_MODULE
  /// @brief Releases interface.
  /// @details Releases interface previously claimed by usb_host_claim_interface().
  /// This is a blocking function.
  /// @since_tizen 3.0
  /// @param[in] interface The bInterfaceNumber of interface to release
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_FOUND Interface was not claimed
  /// @retval #USB_HOST_ERROR_NO_SUCH_DEVICE Device has been disconnected
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_DEVICE_NOT_OPENED The device was not opened
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_PERMISSION_DENIED Permission denied
  int usb_host_release_interface(
    usb_host_interface_h interface1,
  ) {
    return _usb_host_release_interface(
      interface1,
    );
  }

  late final _usb_host_release_interfacePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(usb_host_interface_h)>>(
          'usb_host_release_interface');
  late final _usb_host_release_interface = _usb_host_release_interfacePtr
      .asFunction<int Function(usb_host_interface_h)>();

  /// @ingroup CAPI_USB_HOST_INTERFACE_MODULE
  /// @brief Gets number of given interface.
  /// @since_tizen 3.0
  /// @param[in] interface An interface
  /// @param[out] number Number of given interface
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_interface_get_number(
    usb_host_interface_h interface1,
    ffi.Pointer<ffi.Int> number,
  ) {
    return _usb_host_interface_get_number(
      interface1,
      number,
    );
  }

  late final _usb_host_interface_get_numberPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_interface_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_interface_get_number');
  late final _usb_host_interface_get_number = _usb_host_interface_get_numberPtr
      .asFunction<int Function(usb_host_interface_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_INTERFACE_MODULE
  /// @brief Gets number of endpoints in given interface.
  /// @since_tizen 3.0
  /// @param[in] interface An interface
  /// @param[out] num_endpoints Number of endpoints in @a interface
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_interface_get_num_endpoints(
    usb_host_interface_h interface1,
    ffi.Pointer<ffi.Int> num_endpoints,
  ) {
    return _usb_host_interface_get_num_endpoints(
      interface1,
      num_endpoints,
    );
  }

  late final _usb_host_interface_get_num_endpointsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_interface_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_interface_get_num_endpoints');
  late final _usb_host_interface_get_num_endpoints =
      _usb_host_interface_get_num_endpointsPtr.asFunction<
          int Function(usb_host_interface_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_INTERFACE_MODULE
  /// @brief Gets an endpoint from interface.
  /// @details Get a USB endpoint from interface by its index.
  /// @since_tizen 3.0
  /// @param[in] interface Interface handle
  /// @param[in] ep_index index of endpoint to retrieve (counting from 0)
  /// @param[out] ep Endpoint handle
  /// @remarks @a ep handle is no longer valid when config will be destroyed. There is no need to destroy it,
  /// it is done automatically when the configuration is destroyed.
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_interface_get_endpoint(
    usb_host_interface_h interface1,
    int ep_index,
    ffi.Pointer<usb_host_endpoint_h> ep,
  ) {
    return _usb_host_interface_get_endpoint(
      interface1,
      ep_index,
      ep,
    );
  }

  late final _usb_host_interface_get_endpointPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(usb_host_interface_h, ffi.Int,
                  ffi.Pointer<usb_host_endpoint_h>)>>(
      'usb_host_interface_get_endpoint');
  late final _usb_host_interface_get_endpoint =
      _usb_host_interface_get_endpointPtr.asFunction<
          int Function(
              usb_host_interface_h, int, ffi.Pointer<usb_host_endpoint_h>)>();

  /// @ingroup CAPI_USB_HOST_INTERFACE_MODULE
  /// @brief Sets alternative setting for interface.
  /// @since_tizen 3.0
  /// @param[in] interface Interface handle
  /// @param[in] altsetting Index of new alternative setting for given interface
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_interface_set_altsetting(
    usb_host_interface_h interface1,
    int altsetting,
  ) {
    return _usb_host_interface_set_altsetting(
      interface1,
      altsetting,
    );
  }

  late final _usb_host_interface_set_altsettingPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(usb_host_interface_h, ffi.Int)>>(
      'usb_host_interface_set_altsetting');
  late final _usb_host_interface_set_altsetting =
      _usb_host_interface_set_altsettingPtr
          .asFunction<int Function(usb_host_interface_h, int)>();

  /// @ingroup CAPI_USB_HOST_INTERFACE_MODULE
  /// @brief Gets current alternative setting from an interface.
  /// @since_tizen 4.0
  /// @param[in] interface Interface handle
  /// @param[out] altsetting Index of alternative setting set for the given interface
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_interface_get_altsetting(
    usb_host_interface_h interface1,
    ffi.Pointer<ffi.Int> altsetting,
  ) {
    return _usb_host_interface_get_altsetting(
      interface1,
      altsetting,
    );
  }

  late final _usb_host_interface_get_altsettingPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_interface_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_interface_get_altsetting');
  late final _usb_host_interface_get_altsetting =
      _usb_host_interface_get_altsettingPtr.asFunction<
          int Function(usb_host_interface_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_INTERFACE_MODULE
  /// @brief Gets string describing an interface.
  /// @since_tizen 3.0
  /// @param[in] interface An interface
  /// @param[in, out] length Data buffer size/how much was actually used
  /// @param[out] data Buffer to store string
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_OVERFLOW There was no space in buffer
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @pre device which interface is part of must be opened by usb_host_device_open() or
  /// usb_host_device_open_with_vid_pid()
  int usb_host_interface_get_str(
    usb_host_interface_h interface1,
    ffi.Pointer<ffi.Int> length,
    ffi.Pointer<ffi.UnsignedChar> data,
  ) {
    return _usb_host_interface_get_str(
      interface1,
      length,
      data,
    );
  }

  late final _usb_host_interface_get_strPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_interface_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.UnsignedChar>)>>('usb_host_interface_get_str');
  late final _usb_host_interface_get_str =
      _usb_host_interface_get_strPtr.asFunction<
          int Function(usb_host_interface_h, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.UnsignedChar>)>();

  /// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
  /// @brief Gets number of given endpoint.
  /// @since_tizen 3.0
  /// @param[in] ep An endpoint
  /// @param[out] number Number of given endpoint
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_endpoint_get_number(
    usb_host_endpoint_h ep,
    ffi.Pointer<ffi.Int> number,
  ) {
    return _usb_host_endpoint_get_number(
      ep,
      number,
    );
  }

  late final _usb_host_endpoint_get_numberPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_endpoint_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_endpoint_get_number');
  late final _usb_host_endpoint_get_number = _usb_host_endpoint_get_numberPtr
      .asFunction<int Function(usb_host_endpoint_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
  /// @brief Gets direction of an endpoint.
  /// @since_tizen 3.0
  /// @param[in] ep An endpoint
  /// @param[out] direction Direction of endpoint (a value from enum #usb_host_endpoint_direction_e)
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_endpoint_get_direction(
    usb_host_endpoint_h ep,
    ffi.Pointer<ffi.Int32> direction,
  ) {
    return _usb_host_endpoint_get_direction(
      ep,
      direction,
    );
  }

  late final _usb_host_endpoint_get_directionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_endpoint_h,
              ffi.Pointer<ffi.Int32>)>>('usb_host_endpoint_get_direction');
  late final _usb_host_endpoint_get_direction =
      _usb_host_endpoint_get_directionPtr.asFunction<
          int Function(usb_host_endpoint_h, ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
  /// @brief Gets transfer type of given endpoint.
  /// @since_tizen 3.0
  /// @param[in] ep An endpoint
  /// @param[out] transfer_type Transfer type (a value from enum #usb_host_transfer_type_e)
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_endpoint_get_transfer_type(
    usb_host_endpoint_h ep,
    ffi.Pointer<ffi.Int32> transfer_type,
  ) {
    return _usb_host_endpoint_get_transfer_type(
      ep,
      transfer_type,
    );
  }

  late final _usb_host_endpoint_get_transfer_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_endpoint_h,
              ffi.Pointer<ffi.Int32>)>>('usb_host_endpoint_get_transfer_type');
  late final _usb_host_endpoint_get_transfer_type =
      _usb_host_endpoint_get_transfer_typePtr.asFunction<
          int Function(usb_host_endpoint_h, ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
  /// @brief Gets synchronization type of given endpoint.
  /// @since_tizen 3.0
  /// @param[in] ep An endpoint
  /// @param[out] synch_type Synch type (a value from enum #usb_host_iso_sync_type_e)
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_endpoint_get_synch_type(
    usb_host_endpoint_h ep,
    ffi.Pointer<ffi.Int32> synch_type,
  ) {
    return _usb_host_endpoint_get_synch_type(
      ep,
      synch_type,
    );
  }

  late final _usb_host_endpoint_get_synch_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_endpoint_h,
              ffi.Pointer<ffi.Int32>)>>('usb_host_endpoint_get_synch_type');
  late final _usb_host_endpoint_get_synch_type =
      _usb_host_endpoint_get_synch_typePtr.asFunction<
          int Function(usb_host_endpoint_h, ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
  /// @brief Gets usage type of given endpoint.
  /// @since_tizen 3.0
  /// @param[in] ep An endpoint
  /// @param[out] usage_type Usage type (a value from enum #usb_host_usage_type_e)
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_endpoint_get_usage_type(
    usb_host_endpoint_h ep,
    ffi.Pointer<ffi.Int32> usage_type,
  ) {
    return _usb_host_endpoint_get_usage_type(
      ep,
      usage_type,
    );
  }

  late final _usb_host_endpoint_get_usage_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_endpoint_h,
              ffi.Pointer<ffi.Int32>)>>('usb_host_endpoint_get_usage_type');
  late final _usb_host_endpoint_get_usage_type =
      _usb_host_endpoint_get_usage_typePtr.asFunction<
          int Function(usb_host_endpoint_h, ffi.Pointer<ffi.Int32>)>();

  /// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
  /// @brief Gets max packet size of given endpoint.
  /// @since_tizen 3.0
  /// @param[in] ep An endpoint
  /// @param[out] max_packet_size Max packet size, in bytes
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_endpoint_get_max_packet_size(
    usb_host_endpoint_h ep,
    ffi.Pointer<ffi.Int> max_packet_size,
  ) {
    return _usb_host_endpoint_get_max_packet_size(
      ep,
      max_packet_size,
    );
  }

  late final _usb_host_endpoint_get_max_packet_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_endpoint_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_endpoint_get_max_packet_size');
  late final _usb_host_endpoint_get_max_packet_size =
      _usb_host_endpoint_get_max_packet_sizePtr.asFunction<
          int Function(usb_host_endpoint_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
  /// @brief Gets interval for polling endpoint for data transfers.
  /// @since_tizen 3.0
  /// @param[in] ep An endpoint
  /// @param[out] interval Interval for polling, in frame counts (refer to USB protocol specification)
  /// @return 0 on success, otherwise a negative error value
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  int usb_host_endpoint_get_interval(
    usb_host_endpoint_h ep,
    ffi.Pointer<ffi.Int> interval,
  ) {
    return _usb_host_endpoint_get_interval(
      ep,
      interval,
    );
  }

  late final _usb_host_endpoint_get_intervalPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(usb_host_endpoint_h,
              ffi.Pointer<ffi.Int>)>>('usb_host_endpoint_get_interval');
  late final _usb_host_endpoint_get_interval =
      _usb_host_endpoint_get_intervalPtr.asFunction<
          int Function(usb_host_endpoint_h, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_SYNCIO_MODULE
  /// @brief Performs USB control transfer.
  /// @details For more explanation about the values please refer to USB protocol specification
  /// @since_tizen 3.0
  /// @remarks The wValue, wIndex and wLength fields values should be given in host-endian
  /// byte order.
  /// @param[in] dev Device handle
  /// @param[in] bm_request_type bmRequestType type field for the setup packet
  /// @param[in] b_request bRequest field for the setup packet
  /// @param[in] w_value wValue field for the setup packet
  /// @param[in] w_index wIndex field for the setup packet
  /// @param[in] data Suitably-sized data buffer for either input or output
  /// (depending on direction bits within bmRequestType)
  /// @param[in] w_length wLength field for the setup packet. The data buffer should
  /// be at least this size
  /// @param[in] timeout Timeout (in milliseconds) that this function should wait
  /// before giving up due to no response being received. For an unlimited
  /// @param[out] transferred Number of transferred bytes
  /// timeout, 0 value should be used.
  /// @return  0 on success, negative error code otherwise
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_TIMED_OUT Transfer timed out
  /// @retval #USB_HOST_ERROR_BROKEN_PIPE Control request was not supported by the device
  /// @retval #USB_HOST_ERROR_NO_SUCH_DEVICE The device has been disconnected
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_DEVICE_NOT_OPENED The device was not opened
  /// @retval #USB_HOST_ERROR_OVERFLOW Device offered more data
  /// @pre dev must point to device opened by usb_host_device_open() or usb_host_device_open_with_vid_pid()
  int usb_host_control_transfer(
    usb_host_device_h dev,
    int bm_request_type,
    int b_request,
    int w_value,
    int w_index,
    ffi.Pointer<ffi.UnsignedChar> data,
    int w_length,
    int timeout,
    ffi.Pointer<ffi.Int> transferred,
  ) {
    return _usb_host_control_transfer(
      dev,
      bm_request_type,
      b_request,
      w_value,
      w_index,
      data,
      w_length,
      timeout,
      transferred,
    );
  }

  late final _usb_host_control_transferPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              usb_host_device_h,
              ffi.Uint8,
              ffi.Uint8,
              ffi.Uint16,
              ffi.Uint16,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Uint16,
              ffi.UnsignedInt,
              ffi.Pointer<ffi.Int>)>>('usb_host_control_transfer');
  late final _usb_host_control_transfer =
      _usb_host_control_transferPtr.asFunction<
          int Function(usb_host_device_h, int, int, int, int,
              ffi.Pointer<ffi.UnsignedChar>, int, int, ffi.Pointer<ffi.Int>)>();

  /// @ingroup CAPI_USB_HOST_SYNCIO_MODULE
  /// @brief Performs transfer on given endpoint.
  /// @details Performs a USB transfer on given endpoint. Direction of transfer is
  /// determined by the endpoint.
  /// @since_tizen 3.0
  /// @param[in] ep Endpoint handle
  /// @param[in] data Suitably-sized data buffer for either input or output
  /// (depending on endpoint)
  /// @param[in] length For writes, the number of bytes from data to be sent, for
  /// reads the maximum number of bytes to receive into the data buffer
  /// @param[out] transferred number of bytes actually transferred
  /// @param[in] timeout Timeout (in milliseconds) that this function should wait
  /// before giving up due to no response being received (for an unlimited
  /// timeout 0 value should be used)
  /// @return 0 on success (and populates @a transferred), negative error code on error
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_TIMED_OUT Transfer timed out
  /// @retval #USB_HOST_ERROR_BROKEN_PIPE Endpoint halted
  /// @retval #USB_HOST_ERROR_OVERFLOW Device offered more data
  /// @retval #USB_HOST_ERROR_NO_SUCH_DEVICE Device has been disconnected
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_DEVICE_NOT_OPENED The device was not opened
  /// @pre ep must be a valid endpoint received from usb_host_interface_get_endpoint().
  /// @pre ep must be an endpoint of device opened by usb_host_device_open() or
  /// usb_host_device_open_with_vid_pid().
  int usb_host_transfer(
    usb_host_endpoint_h ep,
    ffi.Pointer<ffi.UnsignedChar> data,
    int length,
    ffi.Pointer<ffi.Int> transferred,
    int timeout,
  ) {
    return _usb_host_transfer(
      ep,
      data,
      length,
      transferred,
      timeout,
    );
  }

  late final _usb_host_transferPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              usb_host_endpoint_h,
              ffi.Pointer<ffi.UnsignedChar>,
              ffi.Int,
              ffi.Pointer<ffi.Int>,
              ffi.UnsignedInt)>>('usb_host_transfer');
  late final _usb_host_transfer = _usb_host_transferPtr.asFunction<
      int Function(usb_host_endpoint_h, ffi.Pointer<ffi.UnsignedChar>, int,
          ffi.Pointer<ffi.Int>, int)>();

  /// @ingroup CAPI_USB_HOST_HOTPLUG_MODULE
  /// @brief Registers a callback function to be invoked when a device is connected or disconnected.
  /// @since_tizen 4.0
  /// @param[in] ctx Context handle
  /// @param[in] cb The callback function to be registered
  /// @param[in] event Event that will trigger registered callback
  /// @param[in] user_data The user data to be passed to the callback function
  /// @param[out] handle Handle of the registered callback
  /// @return 0 on success, negative error code on error
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_OUT_OF_MEMORY Out of memory
  int usb_host_set_hotplug_cb(
    usb_host_context_h ctx,
    usb_host_hotplug_cb cb,
    int event,
    ffi.Pointer<ffi.Void> user_data,
    ffi.Pointer<usb_host_hotplug_h> handle,
  ) {
    return _usb_host_set_hotplug_cb(
      ctx,
      cb,
      event,
      user_data,
      handle,
    );
  }

  late final _usb_host_set_hotplug_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              usb_host_context_h,
              usb_host_hotplug_cb,
              ffi.Int32,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<usb_host_hotplug_h>)>>('usb_host_set_hotplug_cb');
  late final _usb_host_set_hotplug_cb = _usb_host_set_hotplug_cbPtr.asFunction<
      int Function(usb_host_context_h, usb_host_hotplug_cb, int,
          ffi.Pointer<ffi.Void>, ffi.Pointer<usb_host_hotplug_h>)>();

  /// @ingroup CAPI_USB_HOST_HOTPLUG_MODULE
  /// @brief Unregisters the hotplug callback function.
  /// @since_tizen 4.0
  /// @param[in] handle Handle of the callback to be unregistered
  /// @return 0 on success, negative error code on error
  /// @retval #USB_HOST_ERROR_NONE Successful
  /// @retval #USB_HOST_ERROR_INVALID_PARAMETER Invalid parameter was passed
  /// @retval #USB_HOST_ERROR_NOT_SUPPORTED Not supported
  int usb_host_unset_hotplug_cb(
    usb_host_hotplug_h handle,
  ) {
    return _usb_host_unset_hotplug_cb(
      handle,
    );
  }

  late final _usb_host_unset_hotplug_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(usb_host_hotplug_h)>>(
          'usb_host_unset_hotplug_cb');
  late final _usb_host_unset_hotplug_cb = _usb_host_unset_hotplug_cbPtr
      .asFunction<int Function(usb_host_hotplug_h)>();

  /// @brief Sets a callback function to be invoked when the telephony state changes.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks An application should have the privilege corresponding to each notificaiton ID. \n
  /// Please see the #telephony_noti_e to know the privilege. \n
  /// If an application has no proper privilege, callback will not be invoked although API returns success.
  ///
  /// @param[in] handle  The handle to use the telephony API
  /// @param[in] noti_id The notification ID to set the callback
  /// @param[in] cb The callback to be invoked when the telephony state changes
  /// @param[in] user_data The user data passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @post telephony_noti_cb() will be invoked.
  ///
  /// @see telephony_unset_noti_cb()
  int telephony_set_noti_cb(
    telephony_h handle,
    int noti_id,
    telephony_noti_cb cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _telephony_set_noti_cb(
      handle,
      noti_id,
      cb,
      user_data,
    );
  }

  late final _telephony_set_noti_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h, ffi.Int32, telephony_noti_cb,
              ffi.Pointer<ffi.Void>)>>('telephony_set_noti_cb');
  late final _telephony_set_noti_cb = _telephony_set_noti_cbPtr.asFunction<
      int Function(
          telephony_h, int, telephony_noti_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets a callback function.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] handle The handle to use the telephony API
  /// @param[in] noti_id The notification ID to unset a callback
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_set_noti_cb()
  int telephony_unset_noti_cb(
    telephony_h handle,
    int noti_id,
  ) {
    return _telephony_unset_noti_cb(
      handle,
      noti_id,
    );
  }

  late final _telephony_unset_noti_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(telephony_h, ffi.Int32)>>(
          'telephony_unset_noti_cb');
  late final _telephony_unset_noti_cb =
      _telephony_unset_noti_cbPtr.asFunction<int Function(telephony_h, int)>();

  /// @brief Acquires the list of available handles to use the telephony API.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @remarks You will get two handles in case of dual SIM device. \n
  /// In this case, handle[0] means Primary SIM and handle[1] means Secondary SIM.
  ///
  /// @param[out] list The list contains the number of
  /// available handles and array of handles
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_OUT_OF_MEMORY     Out of memory
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_deinit()
  int telephony_init(
    ffi.Pointer<telephony_handle_list_s> list,
  ) {
    return _telephony_init(
      list,
    );
  }

  late final _telephony_initPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<telephony_handle_list_s>)>>('telephony_init');
  late final _telephony_init = _telephony_initPtr
      .asFunction<int Function(ffi.Pointer<telephony_handle_list_s>)>();

  /// @brief Deinitializes the telephony handle list.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  ///
  /// @param[in] list The handle list to be deinitialized
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_init()
  int telephony_deinit(
    ffi.Pointer<telephony_handle_list_s> list,
  ) {
    return _telephony_deinit(
      list,
    );
  }

  late final _telephony_deinitPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<telephony_handle_list_s>)>>('telephony_deinit');
  late final _telephony_deinit = _telephony_deinitPtr
      .asFunction<int Function(ffi.Pointer<telephony_handle_list_s>)>();

  /// @brief Acquires the telephony state value.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[out] state The state value of telephony
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_set_state_changed_cb()
  /// @see telephony_unset_state_changed_cb()
  int telephony_get_state(
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _telephony_get_state(
      state,
    );
  }

  late final _telephony_get_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'telephony_get_state');
  late final _telephony_get_state = _telephony_get_statePtr
      .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets a callback function to be invoked when the telephony state changes.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] callback The callback to be invoked when the telephony state changes
  /// @param[in] user_data The user data passed to the callback function
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @post telephony_state_changed_cb() will be invoked.
  ///
  /// @see telephony_unset_state_changed_cb()
  int telephony_set_state_changed_cb(
    telephony_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _telephony_set_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _telephony_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('telephony_set_state_changed_cb');
  late final _telephony_set_state_changed_cb =
      _telephony_set_state_changed_cbPtr.asFunction<
          int Function(telephony_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unsets a telephony state callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] callback The callback to unset when the telephony state changes
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_set_state_changed_cb()
  int telephony_unset_state_changed_cb(
    telephony_state_changed_cb callback,
  ) {
    return _telephony_unset_state_changed_cb(
      callback,
    );
  }

  late final _telephony_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(telephony_state_changed_cb)>>(
          'telephony_unset_state_changed_cb');
  late final _telephony_unset_state_changed_cb =
      _telephony_unset_state_changed_cbPtr
          .asFunction<int Function(telephony_state_changed_cb)>();

  /// @deprecated Deprecated Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. Use #telephony_call_get_status instead.
  ///
  /// @brief Gets the voice call state of the telephony service.
  /// @details Determines if the voice call is connecting, connected, or idle.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks When you are dialing a number or a new voice call is ringing,
  /// the state of the voice call is #TELEPHONY_CALL_STATE_CONNECTING.
  /// When a new voice call is connecting while another voice call is already connected,
  /// the state of the voice call is #TELEPHONY_CALL_STATE_CONNECTING as well.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] call_state The current state of the voice call
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_call_get_voice_call_state(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> call_state,
  ) {
    return _telephony_call_get_voice_call_state(
      handle,
      call_state,
    );
  }

  late final _telephony_call_get_voice_call_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_call_get_voice_call_state');
  late final _telephony_call_get_voice_call_state =
      _telephony_call_get_voice_call_statePtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @deprecated Deprecated Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. Use #telephony_call_get_status instead.
  ///
  /// @brief Gets the video call state of the telephony service.
  /// @details Determines if the video call is connecting, connected, or idle.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks When you are dialing a number or a new video call is ringing,
  /// the state of the video call is #TELEPHONY_CALL_STATE_CONNECTING.
  /// If a video call is connected, then the state of any other call cannot be
  /// #TELEPHONY_CALL_STATE_CONNECTING and #TELEPHONY_CALL_STATE_CONNECTED.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] call_state The current state of the video call
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_call_get_video_call_state(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> call_state,
  ) {
    return _telephony_call_get_video_call_state(
      handle,
      call_state,
    );
  }

  late final _telephony_call_get_video_call_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_call_get_video_call_state');
  late final _telephony_call_get_video_call_state =
      _telephony_call_get_video_call_statePtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the current value for the preferred voice call subscription.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] call_sub The currently set preferred call subscription value. (telephony_call_preferred_voice_subs_e)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_call_get_preferred_voice_subscription(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> call_sub,
  ) {
    return _telephony_call_get_preferred_voice_subscription(
      handle,
      call_sub,
    );
  }

  late final _telephony_call_get_preferred_voice_subscriptionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(telephony_h, ffi.Pointer<ffi.Int32>)>>(
      'telephony_call_get_preferred_voice_subscription');
  late final _telephony_call_get_preferred_voice_subscription =
      _telephony_call_get_preferred_voice_subscriptionPtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the list of the current call.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks You must release @c call_list using telephony_call_release_call_list().
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] count Count of the existing calls
  /// @param[out] call_list List of call information for existing calls
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_call_get_call_list(
    telephony_h handle,
    ffi.Pointer<ffi.UnsignedInt> count,
    ffi.Pointer<ffi.Pointer<telephony_call_h>> call_list,
  ) {
    return _telephony_call_get_call_list(
      handle,
      count,
      call_list,
    );
  }

  late final _telephony_call_get_call_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(telephony_h, ffi.Pointer<ffi.UnsignedInt>,
                  ffi.Pointer<ffi.Pointer<telephony_call_h>>)>>(
      'telephony_call_get_call_list');
  late final _telephony_call_get_call_list =
      _telephony_call_get_call_listPtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.UnsignedInt>,
              ffi.Pointer<ffi.Pointer<telephony_call_h>>)>();

  /// @brief Releases the list allocated from #telephony_call_get_call_list().
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] count The count of the calls from #telephony_call_get_call_list()
  /// @param[in] call_list The handle from #telephony_call_get_call_list()
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The call list should be validated from #telephony_call_get_call_list().
  int telephony_call_release_call_list(
    int count,
    ffi.Pointer<ffi.Pointer<telephony_call_h>> call_list,
  ) {
    return _telephony_call_release_call_list(
      count,
      call_list,
    );
  }

  late final _telephony_call_release_call_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.UnsignedInt,
                  ffi.Pointer<ffi.Pointer<telephony_call_h>>)>>(
      'telephony_call_release_call_list');
  late final _telephony_call_release_call_list =
      _telephony_call_release_call_listPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Pointer<telephony_call_h>>)>();

  /// @brief Gets the call handle ID.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] call_handle The handle from #telephony_call_get_call_list()
  /// @param[out] handle_id The ID of the call handle
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The call handle should be obtained from #telephony_call_get_call_list().
  /// @post The call list should be released by using #telephony_call_release_call_list().
  int telephony_call_get_handle_id(
    telephony_call_h call_handle,
    ffi.Pointer<ffi.UnsignedInt> handle_id,
  ) {
    return _telephony_call_get_handle_id(
      call_handle,
      handle_id,
    );
  }

  late final _telephony_call_get_handle_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_call_h,
              ffi.Pointer<ffi.UnsignedInt>)>>('telephony_call_get_handle_id');
  late final _telephony_call_get_handle_id =
      _telephony_call_get_handle_idPtr.asFunction<
          int Function(telephony_call_h, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets the call number.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @remarks You must release @c number using free() on success case.
  ///
  /// @param[in] call_handle The handle from #telephony_call_get_call_list()
  /// @param[out] number The number of the call
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The call handle should be obtained from #telephony_call_get_call_list().
  /// @post The call list should be released by using #telephony_call_release_call_list().
  int telephony_call_get_number(
    telephony_call_h call_handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> number,
  ) {
    return _telephony_call_get_number(
      call_handle,
      number,
    );
  }

  late final _telephony_call_get_numberPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  telephony_call_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'telephony_call_get_number');
  late final _telephony_call_get_number =
      _telephony_call_get_numberPtr.asFunction<
          int Function(telephony_call_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the call type.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] call_handle The handle from #telephony_call_get_call_list()
  /// @param[out] type The type of the call (#telephony_call_type_e)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The call handle should be obtained from #telephony_call_get_call_list().
  /// @post The call list should be released by using #telephony_call_release_call_list().
  int telephony_call_get_type(
    telephony_call_h call_handle,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _telephony_call_get_type(
      call_handle,
      type,
    );
  }

  late final _telephony_call_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_call_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_call_get_type');
  late final _telephony_call_get_type = _telephony_call_get_typePtr
      .asFunction<int Function(telephony_call_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the call status.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] call_handle The handle from #telephony_call_get_call_list()
  /// @param[out] status The status of the call (#telephony_call_status_e)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The call handle should be obtained from #telephony_call_get_call_list().
  /// @post The call list should be released by using #telephony_call_release_call_list().
  int telephony_call_get_status(
    telephony_call_h call_handle,
    ffi.Pointer<ffi.Int32> status,
  ) {
    return _telephony_call_get_status(
      call_handle,
      status,
    );
  }

  late final _telephony_call_get_statusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_call_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_call_get_status');
  late final _telephony_call_get_status = _telephony_call_get_statusPtr
      .asFunction<int Function(telephony_call_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets whether the call is MO(Mobile Originated) call or MT(Mobile Terminated).
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] call_handle The handle from #telephony_call_get_call_list()
  /// @param[out] direction The direction of the call (#telephony_call_direction_e)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The call handle should be obtained from #telephony_call_get_call_list().
  /// @post The call list should be released by using #telephony_call_release_call_list().
  int telephony_call_get_direction(
    telephony_call_h call_handle,
    ffi.Pointer<ffi.Int32> direction,
  ) {
    return _telephony_call_get_direction(
      call_handle,
      direction,
    );
  }

  late final _telephony_call_get_directionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_call_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_call_get_direction');
  late final _telephony_call_get_direction = _telephony_call_get_directionPtr
      .asFunction<int Function(telephony_call_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets whether the call is conference call or not.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  ///
  /// @param[in] call_handle The handle from #telephony_call_get_call_list()
  /// @param[out] conference_status The value whether the call is conference call or not
  /// (true: Conference call, false: Single call)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  ///
  /// @pre The call handle should be obtained from #telephony_call_get_call_list().
  /// @post The call list should be released by using #telephony_call_release_call_list().
  int telephony_call_get_conference_status(
    telephony_call_h call_handle,
    ffi.Pointer<ffi.Bool> conference_status,
  ) {
    return _telephony_call_get_conference_status(
      call_handle,
      conference_status,
    );
  }

  late final _telephony_call_get_conference_statusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_call_h,
              ffi.Pointer<ffi.Bool>)>>('telephony_call_get_conference_status');
  late final _telephony_call_get_conference_status =
      _telephony_call_get_conference_statusPtr
          .asFunction<int Function(telephony_call_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the Integrated Circuit Card IDentification (ICC-ID).
  /// @details The Integrated Circuit Card Identification number internationally identifies SIM cards.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks You must release @c icc_id using free() on success case.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] icc_id The Integrated Circuit Card Identification
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #TELEPHONY_ERROR_SIM_NOT_AVAILABLE SIM is not available
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_AVAILABLE.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_get_icc_id(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> icc_id,
  ) {
    return _telephony_sim_get_icc_id(
      handle,
      icc_id,
    );
  }

  late final _telephony_sim_get_icc_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('telephony_sim_get_icc_id');
  late final _telephony_sim_get_icc_id =
      _telephony_sim_get_icc_idPtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the SIM Operator (MCC [3 digits] + MNC [2~3 digits]).
  /// @details The Operator is embedded in the SIM card.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks You must release @c sim_operator using free() on success case.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] sim_operator The SIM Operator
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #TELEPHONY_ERROR_SIM_NOT_AVAILABLE SIM is not available
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_AVAILABLE.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_get_operator(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> sim_operator,
  ) {
    return _telephony_sim_get_operator(
      handle,
      sim_operator,
    );
  }

  late final _telephony_sim_get_operatorPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'telephony_sim_get_operator');
  late final _telephony_sim_get_operator =
      _telephony_sim_get_operatorPtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the Mobile Subscription Identification Number (MSIN [9~10 digits]) of the SIM provider.
  /// @details This function gets Mobile Subscription Identification Number embedded in the SIM card.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks You must release @c msin using free() on success case.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] msin The Mobile Subscription Identification Number
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #TELEPHONY_ERROR_SIM_NOT_AVAILABLE SIM is not available
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_AVAILABLE.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_get_msin(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> msin,
  ) {
    return _telephony_sim_get_msin(
      handle,
      msin,
    );
  }

  late final _telephony_sim_get_msinPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('telephony_sim_get_msin');
  late final _telephony_sim_get_msin = _telephony_sim_get_msinPtr.asFunction<
      int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the Service Provider Name (SPN) of the SIM card.
  /// @details This function gets Service Provider Name embedded in the SIM card.
  /// If this value is not stored in SIM card, @c NULL will be returned.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks You must release @c spn using free() on success case.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] spn The Service Provider Name
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #TELEPHONY_ERROR_SIM_NOT_AVAILABLE SIM is not available
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_AVAILABLE.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_get_spn(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> spn,
  ) {
    return _telephony_sim_get_spn(
      handle,
      spn,
    );
  }

  late final _telephony_sim_get_spnPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('telephony_sim_get_spn');
  late final _telephony_sim_get_spn = _telephony_sim_get_spnPtr.asFunction<
      int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Checks whether the current SIM card is different from the previous SIM card.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] is_changed @c true if the current SIM card is different from the previous SIM card,
  /// otherwise @c false if the SIM card is not changed
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #TELEPHONY_ERROR_SIM_NOT_AVAILABLE SIM is not available
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_AVAILABLE.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_is_changed(
    telephony_h handle,
    ffi.Pointer<ffi.Bool> is_changed,
  ) {
    return _telephony_sim_is_changed(
      handle,
      is_changed,
    );
  }

  late final _telephony_sim_is_changedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              telephony_h, ffi.Pointer<ffi.Bool>)>>('telephony_sim_is_changed');
  late final _telephony_sim_is_changed = _telephony_sim_is_changedPtr
      .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the state of the SIM.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] sim_state The current state of the SIM
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_sim_get_state(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> sim_state,
  ) {
    return _telephony_sim_get_state(
      handle,
      sim_state,
    );
  }

  late final _telephony_sim_get_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              telephony_h, ffi.Pointer<ffi.Int32>)>>('telephony_sim_get_state');
  late final _telephony_sim_get_state = _telephony_sim_get_statePtr
      .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the list of application on UICC.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] app_list The masking value for below values
  /// #TELEPHONY_SIM_APP_TYPE_SIM 0x01 GSM Application
  /// #TELEPHONY_SIM_APP_TYPE_USIM 0x02 USIM Application
  /// #TELEPHONY_SIM_APP_TYPE_CSIM 0x04 CSIM Application
  /// #TELEPHONY_SIM_APP_TYPE_ISIM 0x08 ISIM Application
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #TELEPHONY_ERROR_SIM_NOT_AVAILABLE SIM is not available
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_AVAILABLE.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_get_application_list(
    telephony_h handle,
    ffi.Pointer<ffi.UnsignedInt> app_list,
  ) {
    return _telephony_sim_get_application_list(
      handle,
      app_list,
    );
  }

  late final _telephony_sim_get_application_listPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(telephony_h, ffi.Pointer<ffi.UnsignedInt>)>>(
      'telephony_sim_get_application_list');
  late final _telephony_sim_get_application_list =
      _telephony_sim_get_application_listPtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets the SIM card subscriber number.
  /// @details This function gets subscriber number embedded in the SIM card.
  /// This value contains MSISDN related to the subscriber.
  /// If this value is not stored in SIM card, @c NULL will be returned.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks You must release @c subscriber_number using free() on success case.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] subscriber_number The subscriber number in the SIM
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #TELEPHONY_ERROR_SIM_NOT_AVAILABLE SIM is not available
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_AVAILABLE.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_get_subscriber_number(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> subscriber_number,
  ) {
    return _telephony_sim_get_subscriber_number(
      handle,
      subscriber_number,
    );
  }

  late final _telephony_sim_get_subscriber_numberPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'telephony_sim_get_subscriber_number');
  late final _telephony_sim_get_subscriber_number =
      _telephony_sim_get_subscriber_numberPtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the Subscriber ID.
  /// @details This function gets subscriber ID encoded.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks You must release @c subscriber_id using free() on success case.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] subscriber_id The subscriber ID
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #TELEPHONY_ERROR_SIM_NOT_AVAILABLE SIM is not available
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_AVAILABLE.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_get_subscriber_id(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> subscriber_id,
  ) {
    return _telephony_sim_get_subscriber_id(
      handle,
      subscriber_id,
    );
  }

  late final _telephony_sim_get_subscriber_idPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'telephony_sim_get_subscriber_id');
  late final _telephony_sim_get_subscriber_id =
      _telephony_sim_get_subscriber_idPtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the lock state of the SIM.
  /// @details This function gets SIM card lock state.
  /// If SIM state is #TELEPHONY_SIM_STATE_LOCKED, you can use this function to retrieve lock state.
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] lock_state The current lock state of the SIM
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_LOCKED.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_get_lock_state(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> lock_state,
  ) {
    return _telephony_sim_get_lock_state(
      handle,
      lock_state,
    );
  }

  late final _telephony_sim_get_lock_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_sim_get_lock_state');
  late final _telephony_sim_get_lock_state = _telephony_sim_get_lock_statePtr
      .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the GID1 (Group Identifier Level 1).
  /// @details This function gets Group Identifier Level 1(GID1) embedded in the SIM card.
  /// If this value is not stored in SIM card, @c NULL will be returned.
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks You must release @c gid1 using free() on success case.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] gid1 The GID1
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #TELEPHONY_ERROR_SIM_NOT_AVAILABLE SIM is not available
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_AVAILABLE.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_get_group_id1(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> gid1,
  ) {
    return _telephony_sim_get_group_id1(
      handle,
      gid1,
    );
  }

  late final _telephony_sim_get_group_id1Ptr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'telephony_sim_get_group_id1');
  late final _telephony_sim_get_group_id1 =
      _telephony_sim_get_group_id1Ptr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the call forwarding indicator state of the SIM.
  /// @details If the state is @c true, incoming call will be forwarded to the selected number.
  /// @c state indicates the CFU (Call Forwarding Unconditional) indicator status - Voice.
  /// (3GPP TS 31.102 4.2.64 EF CFIS)
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] state The value whether incoming call will be forwarded or not.
  /// (@c true: forwarded, @c false: not forwarded)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  /// @retval #TELEPHONY_ERROR_SIM_NOT_AVAILABLE SIM is not available
  ///
  /// @pre The SIM state must be #TELEPHONY_SIM_STATE_AVAILABLE.
  ///
  /// @see telephony_sim_get_state()
  int telephony_sim_get_call_forwarding_indicator_state(
    telephony_h handle,
    ffi.Pointer<ffi.Bool> state,
  ) {
    return _telephony_sim_get_call_forwarding_indicator_state(
      handle,
      state,
    );
  }

  late final _telephony_sim_get_call_forwarding_indicator_statePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(telephony_h, ffi.Pointer<ffi.Bool>)>>(
      'telephony_sim_get_call_forwarding_indicator_state');
  late final _telephony_sim_get_call_forwarding_indicator_state =
      _telephony_sim_get_call_forwarding_indicator_statePtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the LAC (Location Area Code) of the current location.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/location.coarse
  ///
  /// @remarks This API can be used in GSM / WCDMA network. @n
  /// http://tizen.org/privilege/location.coarse privilege is required to use this API since 3.0. @n
  /// http://tizen.org/privilege/telephony privilege is no longer required since 3.0.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] lac   The Location Area Code, @c -1 if unknown
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_network_get_service_state()
  /// @see telephony_network_get_type()
  int telephony_network_get_lac(
    telephony_h handle,
    ffi.Pointer<ffi.Int> lac,
  ) {
    return _telephony_network_get_lac(
      handle,
      lac,
    );
  }

  late final _telephony_network_get_lacPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              telephony_h, ffi.Pointer<ffi.Int>)>>('telephony_network_get_lac');
  late final _telephony_network_get_lac = _telephony_network_get_lacPtr
      .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the cell ID of the current location.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/location.coarse
  ///
  /// @remarks This API can be used in GSM / WCDMA / LTE network. @n
  /// http://tizen.org/privilege/location.coarse privilege is required to use this API since 3.0. @n
  /// http://tizen.org/privilege/telephony privilege is no longer required since 3.0.
  ///
  /// @param[in] handle   The handle from telephony_init()
  /// @param[out] cell_id The cell identification number, @c -1 if unknown
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_network_get_service_state()
  /// @see telephony_network_get_type()
  int telephony_network_get_cell_id(
    telephony_h handle,
    ffi.Pointer<ffi.Int> cell_id,
  ) {
    return _telephony_network_get_cell_id(
      handle,
      cell_id,
    );
  }

  late final _telephony_network_get_cell_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int>)>>('telephony_network_get_cell_id');
  late final _telephony_network_get_cell_id = _telephony_network_get_cell_idPtr
      .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the RSSI (Received Signal Strength Indicator).
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] rssi  The Received Signal Strength Indicator \n
  /// Higher the received number, the stronger the signal strength
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_rssi(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> rssi,
  ) {
    return _telephony_network_get_rssi(
      handle,
      rssi,
    );
  }

  late final _telephony_network_get_rssiPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_network_get_rssi');
  late final _telephony_network_get_rssi = _telephony_network_get_rssiPtr
      .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the roaming state of the current registered network.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle  The handle from telephony_init()
  /// @param[out] status @c true if roaming,
  /// otherwise @c false if not roaming
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_roaming_status(
    telephony_h handle,
    ffi.Pointer<ffi.Bool> status,
  ) {
    return _telephony_network_get_roaming_status(
      handle,
      status,
    );
  }

  late final _telephony_network_get_roaming_statusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Bool>)>>('telephony_network_get_roaming_status');
  late final _telephony_network_get_roaming_status =
      _telephony_network_get_roaming_statusPtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the MCC (Mobile Country Code) of the current registered network.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks This API can be used in GSM / WCDMA / LTE network.
  /// You must release @c mcc using free() on success case, empty string if unknown.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] mcc   The Mobile Country Code (three digits)
  /// Mobile Country Code (MCC) identifies the country where the cell is being used
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_mcc(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mcc,
  ) {
    return _telephony_network_get_mcc(
      handle,
      mcc,
    );
  }

  late final _telephony_network_get_mccPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'telephony_network_get_mcc');
  late final _telephony_network_get_mcc =
      _telephony_network_get_mccPtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the MNC (Mobile Network Code) of the current registered network.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks This API can be used in GSM / WCDMA / LTE network.
  /// You must release @c mnc using free() on success case, empty string if unknown.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] mnc   The Mobile Network Code (three digits)
  /// The Mobile Network Code (MNC) identifies the mobile phone operator and network provider
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_mnc(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> mnc,
  ) {
    return _telephony_network_get_mnc(
      handle,
      mnc,
    );
  }

  late final _telephony_network_get_mncPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'telephony_network_get_mnc');
  late final _telephony_network_get_mnc =
      _telephony_network_get_mncPtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the name of the current registered network.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks This API can be used in GSM / WCDMA / LTE network.
  /// You must release @c network_name using free() on success case.
  ///
  /// @param[in] handle        The handle from telephony_init()
  /// @param[out] network_name The name of the current registered network, empty string if unknown
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_network_name(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> network_name,
  ) {
    return _telephony_network_get_network_name(
      handle,
      network_name,
    );
  }

  late final _telephony_network_get_network_namePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'telephony_network_get_network_name');
  late final _telephony_network_get_network_name =
      _telephony_network_get_network_namePtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the network service type of the current registered network.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks This API can be used in case network is in service.
  ///
  /// @param[in] handle        The handle from telephony_init()
  /// @param[out] network_type The network service type
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_network_get_service_state()
  int telephony_network_get_type(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> network_type,
  ) {
    return _telephony_network_get_type(
      handle,
      network_type,
    );
  }

  late final _telephony_network_get_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_network_get_type');
  late final _telephony_network_get_type = _telephony_network_get_typePtr
      .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the packet service type of the current registered network.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks This API can be used in HSDPA network.
  ///
  /// @param[in] handle   The handle from telephony_init()
  /// @param[out] ps_type The type of packet service
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_network_get_service_state()
  /// @see telephony_network_get_type()
  int telephony_network_get_ps_type(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> ps_type,
  ) {
    return _telephony_network_get_ps_type(
      handle,
      ps_type,
    );
  }

  late final _telephony_network_get_ps_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_network_get_ps_type');
  late final _telephony_network_get_ps_type = _telephony_network_get_ps_typePtr
      .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the network name option of the current registered network.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle               The handle from telephony_init()
  /// @param[out] network_name_option The network name display option
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_network_name_option(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> network_name_option,
  ) {
    return _telephony_network_get_network_name_option(
      handle,
      network_name_option,
    );
  }

  late final _telephony_network_get_network_name_optionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(telephony_h, ffi.Pointer<ffi.Int32>)>>(
      'telephony_network_get_network_name_option');
  late final _telephony_network_get_network_name_option =
      _telephony_network_get_network_name_optionPtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the current network state of the telephony service.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks To know the state of data network, refer connection API.
  ///
  /// @param[in] handle                 The handle from telephony_init()
  /// @param[out] network_service_state The current network state
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_service_state(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> network_service_state,
  ) {
    return _telephony_network_get_service_state(
      handle,
      network_service_state,
    );
  }

  late final _telephony_network_get_service_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_network_get_service_state');
  late final _telephony_network_get_service_state =
      _telephony_network_get_service_statePtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the current default subscription for data service (Packet Switched).
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  ///
  /// @param[in] handle       The handle from telephony_init()
  /// @param[out] default_sub The current default data subscription
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_default_data_subscription(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> default_sub,
  ) {
    return _telephony_network_get_default_data_subscription(
      handle,
      default_sub,
    );
  }

  late final _telephony_network_get_default_data_subscriptionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(telephony_h, ffi.Pointer<ffi.Int32>)>>(
      'telephony_network_get_default_data_subscription');
  late final _telephony_network_get_default_data_subscription =
      _telephony_network_get_default_data_subscriptionPtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the current default subscription for voice service (Circuit Switched).
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  ///
  /// @param[in] handle       The handle from telephony_init()
  /// @param[out] default_sub The current default voice subscription
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_default_subscription(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> default_sub,
  ) {
    return _telephony_network_get_default_subscription(
      handle,
      default_sub,
    );
  }

  late final _telephony_network_get_default_subscriptionPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(telephony_h, ffi.Pointer<ffi.Int32>)>>(
      'telephony_network_get_default_subscription');
  late final _telephony_network_get_default_subscription =
      _telephony_network_get_default_subscriptionPtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the network selection mode.
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] mode  The network selection mode
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_selection_mode(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _telephony_network_get_selection_mode(
      handle,
      mode,
    );
  }

  late final _telephony_network_get_selection_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_network_get_selection_mode');
  late final _telephony_network_get_selection_mode =
      _telephony_network_get_selection_modePtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the TAC (Tracking Area Code) of the current location.
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/location.coarse
  ///
  /// @remarks This API can be used in LTE network.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] tac   The Tracking Area Code, @c -1 if unknown
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_network_get_service_state()
  /// @see telephony_network_get_type()
  int telephony_network_get_tac(
    telephony_h handle,
    ffi.Pointer<ffi.Int> tac,
  ) {
    return _telephony_network_get_tac(
      handle,
      tac,
    );
  }

  late final _telephony_network_get_tacPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              telephony_h, ffi.Pointer<ffi.Int>)>>('telephony_network_get_tac');
  late final _telephony_network_get_tac = _telephony_network_get_tacPtr
      .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the system ID of the current location.
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/location.coarse
  ///
  /// @remarks This API can be used in CDMA network.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] sid   The system ID, @c -1 if unknown
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_network_get_service_state()
  /// @see telephony_network_get_type()
  int telephony_network_get_system_id(
    telephony_h handle,
    ffi.Pointer<ffi.Int> sid,
  ) {
    return _telephony_network_get_system_id(
      handle,
      sid,
    );
  }

  late final _telephony_network_get_system_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int>)>>('telephony_network_get_system_id');
  late final _telephony_network_get_system_id =
      _telephony_network_get_system_idPtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the network ID of the current location.
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/location.coarse
  ///
  /// @remarks This API can be used in CDMA network.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] nid   The network ID, @c -1 if unknown
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_network_get_service_state()
  /// @see telephony_network_get_type()
  int telephony_network_get_network_id(
    telephony_h handle,
    ffi.Pointer<ffi.Int> nid,
  ) {
    return _telephony_network_get_network_id(
      handle,
      nid,
    );
  }

  late final _telephony_network_get_network_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int>)>>('telephony_network_get_network_id');
  late final _telephony_network_get_network_id =
      _telephony_network_get_network_idPtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the base station ID of the current location.
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/location.coarse
  ///
  /// @remarks This API can be used in CDMA network.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] bs_id The base station ID, @c -1 if unknown
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_network_get_service_state()
  /// @see telephony_network_get_type()
  int telephony_network_get_base_station_id(
    telephony_h handle,
    ffi.Pointer<ffi.Int> bs_id,
  ) {
    return _telephony_network_get_base_station_id(
      handle,
      bs_id,
    );
  }

  late final _telephony_network_get_base_station_idPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int>)>>('telephony_network_get_base_station_id');
  late final _telephony_network_get_base_station_id =
      _telephony_network_get_base_station_idPtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the base station latitude of the current location.
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/location.coarse
  ///
  /// @remarks This API can be used in CDMA network.
  ///
  /// @param[in] handle       The handle from telephony_init()
  /// @param[out] bs_latitude The base station latitude, @c 0x7FFFFFFF if unknown
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_network_get_service_state()
  /// @see telephony_network_get_type()
  int telephony_network_get_base_station_latitude(
    telephony_h handle,
    ffi.Pointer<ffi.Int> bs_latitude,
  ) {
    return _telephony_network_get_base_station_latitude(
      handle,
      bs_latitude,
    );
  }

  late final _telephony_network_get_base_station_latitudePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(telephony_h, ffi.Pointer<ffi.Int>)>>(
      'telephony_network_get_base_station_latitude');
  late final _telephony_network_get_base_station_latitude =
      _telephony_network_get_base_station_latitudePtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the base station longitude of the current location.
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/location.coarse
  ///
  /// @remarks This API can be used in CDMA network.
  ///
  /// @param[in] handle        The handle from telephony_init()
  /// @param[out] bs_longitude The base station longitude, @c 0x7FFFFFFF if unknown
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  ///
  /// @see telephony_network_get_service_state()
  /// @see telephony_network_get_type()
  int telephony_network_get_base_station_longitude(
    telephony_h handle,
    ffi.Pointer<ffi.Int> bs_longitude,
  ) {
    return _telephony_network_get_base_station_longitude(
      handle,
      bs_longitude,
    );
  }

  late final _telephony_network_get_base_station_longitudePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(telephony_h, ffi.Pointer<ffi.Int>)>>(
      'telephony_network_get_base_station_longitude');
  late final _telephony_network_get_base_station_longitude =
      _telephony_network_get_base_station_longitudePtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the received signal strength (dBm).
  ///
  /// @since_tizen 4.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] dbm   The received signal strength in dBm, @c 0 if unknown \n
  /// The higher the received number, the stronger the signal
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_network_get_signal_strength(
    telephony_h handle,
    ffi.Pointer<ffi.Int> dbm,
  ) {
    return _telephony_network_get_signal_strength(
      handle,
      dbm,
    );
  }

  late final _telephony_network_get_signal_strengthPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int>)>>('telephony_network_get_signal_strength');
  late final _telephony_network_get_signal_strength =
      _telephony_network_get_signal_strengthPtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the IMEI (International Mobile Station Equipment Identity) of a mobile phone.
  /// @details The IMEI number is used by a GSM network to identify valid devices
  /// and therefore can be used for stopping a stolen phone from accessing that network.
  ///
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks You must release @c imei using free() on success case.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] imei The International Mobile Station Equipment Identity
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_modem_get_imei(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> imei,
  ) {
    return _telephony_modem_get_imei(
      handle,
      imei,
    );
  }

  late final _telephony_modem_get_imeiPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('telephony_modem_get_imei');
  late final _telephony_modem_get_imei =
      _telephony_modem_get_imeiPtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the power status of the modem.
  ///
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] status The Modem power status (0=on,1=off,2=reset,3=low)
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_modem_get_power_status(
    telephony_h handle,
    ffi.Pointer<ffi.Int32> status,
  ) {
    return _telephony_modem_get_power_status(
      handle,
      status,
    );
  }

  late final _telephony_modem_get_power_statusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Int32>)>>('telephony_modem_get_power_status');
  late final _telephony_modem_get_power_status =
      _telephony_modem_get_power_statusPtr
          .asFunction<int Function(telephony_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the MEID (Mobile Equipment Identifier) of a mobile phone (for CDMA).
  ///
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/telephony
  ///
  /// @remarks You must release @c meid using free() on success case.
  ///
  /// @param[in] handle The handle from telephony_init()
  /// @param[out] meid The Mobile Equipment Identifier
  ///
  /// @return @c 0 on success,
  /// otherwise a negative error value
  ///
  /// @retval #TELEPHONY_ERROR_NONE              Successful
  /// @retval #TELEPHONY_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TELEPHONY_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #TELEPHONY_ERROR_NOT_SUPPORTED     Not supported
  /// @retval #TELEPHONY_ERROR_OPERATION_FAILED  Operation failed
  int telephony_modem_get_meid(
    telephony_h handle,
    ffi.Pointer<ffi.Pointer<ffi.Char>> meid,
  ) {
    return _telephony_modem_get_meid(
      handle,
      meid,
    );
  }

  late final _telephony_modem_get_meidPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(telephony_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('telephony_modem_get_meid');
  late final _telephony_modem_get_meid =
      _telephony_modem_get_meidPtr.asFunction<
          int Function(telephony_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Creates and initializes clipboard handle.
  /// @since_tizen 3.0
  /// @param[out] cbhm_handle Clipboard handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @retval #CBHM_ERROR_OUT_OF_MEMORY Out of memory
  /// @see cbhm_close_service()
  int cbhm_open_service(
    ffi.Pointer<cbhm_h> cbhm_handle,
  ) {
    return _cbhm_open_service(
      cbhm_handle,
    );
  }

  late final _cbhm_open_servicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<cbhm_h>)>>(
          'cbhm_open_service');
  late final _cbhm_open_service =
      _cbhm_open_servicePtr.asFunction<int Function(ffi.Pointer<cbhm_h>)>();

  /// @brief Closes clipboard handle.
  /// @since_tizen 3.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @see cbhm_open_service()
  int cbhm_close_service(
    cbhm_h cbhm_handle,
  ) {
    return _cbhm_close_service(
      cbhm_handle,
    );
  }

  late final _cbhm_close_servicePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(cbhm_h)>>(
          'cbhm_close_service');
  late final _cbhm_close_service =
      _cbhm_close_servicePtr.asFunction<int Function(cbhm_h)>();

  /// @brief Shows clipboard.
  /// @since_tizen 3.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @see cbhm_hide()
  int cbhm_show(
    cbhm_h cbhm_handle,
  ) {
    return _cbhm_show(
      cbhm_handle,
    );
  }

  late final _cbhm_showPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(cbhm_h)>>('cbhm_show');
  late final _cbhm_show = _cbhm_showPtr.asFunction<int Function(cbhm_h)>();

  /// @brief Hides clipboard.
  /// @since_tizen 3.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @see cbhm_show()
  int cbhm_hide(
    cbhm_h cbhm_handle,
  ) {
    return _cbhm_hide(
      cbhm_handle,
    );
  }

  late final _cbhm_hidePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(cbhm_h)>>('cbhm_hide');
  late final _cbhm_hide = _cbhm_hidePtr.asFunction<int Function(cbhm_h)>();

  /// @brief Sets clipboard selection type.
  /// @since_tizen 3.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @param[in] type Selection type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @see cbhm_selection_type_get()
  int cbhm_selection_type_set(
    cbhm_h cbhm_handle,
    int type,
  ) {
    return _cbhm_selection_type_set(
      cbhm_handle,
      type,
    );
  }

  late final _cbhm_selection_type_setPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(cbhm_h, ffi.Int32)>>(
          'cbhm_selection_type_set');
  late final _cbhm_selection_type_set =
      _cbhm_selection_type_setPtr.asFunction<int Function(cbhm_h, int)>();

  /// @brief Gets clipboard selection type.
  /// @since_tizen 3.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @param[out] type Selection type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @see cbhm_selection_type_set()
  int cbhm_selection_type_get(
    cbhm_h cbhm_handle,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _cbhm_selection_type_get(
      cbhm_handle,
      type,
    );
  }

  late final _cbhm_selection_type_getPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(cbhm_h, ffi.Pointer<ffi.Int32>)>>(
      'cbhm_selection_type_get');
  late final _cbhm_selection_type_get = _cbhm_selection_type_getPtr
      .asFunction<int Function(cbhm_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Adds event callback function of selecting a clipboard item.
  /// @since_tizen 3.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @param[in] callback Callback function called when a clipboard item is selected
  /// @param[in] user_data User data to be passed to the given event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @retval #CBHM_ERROR_OUT_OF_MEMORY Out of memory
  int cbhm_item_selected_callback_add(
    cbhm_h cbhm_handle,
    cbhm_selected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _cbhm_item_selected_callback_add(
      cbhm_handle,
      callback,
      user_data,
    );
  }

  late final _cbhm_item_selected_callback_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(cbhm_h, cbhm_selected_cb,
              ffi.Pointer<ffi.Void>)>>('cbhm_item_selected_callback_add');
  late final _cbhm_item_selected_callback_add =
      _cbhm_item_selected_callback_addPtr.asFunction<
          int Function(cbhm_h, cbhm_selected_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Removes event callback function for selecting a clipboard item.
  /// @since_tizen 4.0
  /// @param[in] cbhm_handle The clipboard handle
  /// @param[in] callback The callback function to be deleted
  /// @param[in] user_data User data to be passed to the given event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  int cbhm_item_selected_callback_remove(
    cbhm_h cbhm_handle,
    cbhm_selected_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _cbhm_item_selected_callback_remove(
      cbhm_handle,
      callback,
      user_data,
    );
  }

  late final _cbhm_item_selected_callback_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(cbhm_h, cbhm_selected_cb,
              ffi.Pointer<ffi.Void>)>>('cbhm_item_selected_callback_remove');
  late final _cbhm_item_selected_callback_remove =
      _cbhm_item_selected_callback_removePtr.asFunction<
          int Function(cbhm_h, cbhm_selected_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sends data to clipboard.
  /// @since_tizen 3.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @param[in] type Selection type
  /// @param[in] data Data to be sent
  /// @param[in] len The length of data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @retval #CBHM_ERROR_OUT_OF_MEMORY Out of memory
  /// @see cbhm_selection_get()
  int cbhm_selection_set(
    cbhm_h cbhm_handle,
    int type,
    ffi.Pointer<ffi.Void> data,
    int len,
  ) {
    return _cbhm_selection_set(
      cbhm_handle,
      type,
      data,
      len,
    );
  }

  late final _cbhm_selection_setPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(cbhm_h, ffi.Int32, ffi.Pointer<ffi.Void>,
              ffi.Size)>>('cbhm_selection_set');
  late final _cbhm_selection_set = _cbhm_selection_setPtr
      .asFunction<int Function(cbhm_h, int, ffi.Pointer<ffi.Void>, int)>();

  /// @brief Receives data from clipboard.
  /// @since_tizen 3.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @param[in] type Selection type
  /// @param[in] callback Callback function receiving data from clipboard
  /// @param[in] user_data User data to be passed to the given event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @retval #CBHM_ERROR_NO_DATA No data available
  /// @see cbhm_selection_set()
  int cbhm_selection_get(
    cbhm_h cbhm_handle,
    int type,
    cbhm_selection_data_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _cbhm_selection_get(
      cbhm_handle,
      type,
      callback,
      user_data,
    );
  }

  late final _cbhm_selection_getPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(cbhm_h, ffi.Int32, cbhm_selection_data_cb,
              ffi.Pointer<ffi.Void>)>>('cbhm_selection_get');
  late final _cbhm_selection_get = _cbhm_selection_getPtr.asFunction<
      int Function(
          cbhm_h, int, cbhm_selection_data_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the count of clipboard items.
  /// @since_tizen 3.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @return The count of clipboard items
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  int cbhm_item_count_get(
    cbhm_h cbhm_handle,
  ) {
    return _cbhm_item_count_get(
      cbhm_handle,
    );
  }

  late final _cbhm_item_count_getPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(cbhm_h)>>(
          'cbhm_item_count_get');
  late final _cbhm_item_count_get =
      _cbhm_item_count_getPtr.asFunction<int Function(cbhm_h)>();

  /// @brief Gets the type of the latest item in clipboard.
  /// @since_tizen 4.0
  /// @param[in] cbhm_handle The clipboard handle
  /// @param[out] type The type of the latest item
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @see cbhm_selection_type_set()
  int cbhm_latest_item_type_get(
    cbhm_h cbhm_handle,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _cbhm_latest_item_type_get(
      cbhm_handle,
      type,
    );
  }

  late final _cbhm_latest_item_type_getPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(cbhm_h, ffi.Pointer<ffi.Int32>)>>(
      'cbhm_latest_item_type_get');
  late final _cbhm_latest_item_type_get = _cbhm_latest_item_type_getPtr
      .asFunction<int Function(cbhm_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Adds event callback function for receiving changed event of clipboard items.
  /// @since_tizen 4.0
  /// @param[in] cbhm_handle The clipboard handle
  /// @param[in] callback The callback function called when a clipboard item is changed
  /// @param[in] user_data User data to be passed to the given event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @retval #CBHM_ERROR_OUT_OF_MEMORY Out of memory
  int cbhm_item_changed_callback_add(
    cbhm_h cbhm_handle,
    cbhm_item_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _cbhm_item_changed_callback_add(
      cbhm_handle,
      callback,
      user_data,
    );
  }

  late final _cbhm_item_changed_callback_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(cbhm_h, cbhm_item_changed_cb,
              ffi.Pointer<ffi.Void>)>>('cbhm_item_changed_callback_add');
  late final _cbhm_item_changed_callback_add =
      _cbhm_item_changed_callback_addPtr.asFunction<
          int Function(cbhm_h, cbhm_item_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Removes event callback function for receiving changed event of clipboard items.
  /// @since_tizen 4.0
  /// @param[in] cbhm_handle The clipboard handle
  /// @param[in] callback The callback function to be removed
  /// @param[in] user_data User data to be passed to the given event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  int cbhm_item_changed_callback_remove(
    cbhm_h cbhm_handle,
    cbhm_item_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _cbhm_item_changed_callback_remove(
      cbhm_handle,
      callback,
      user_data,
    );
  }

  late final _cbhm_item_changed_callback_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(cbhm_h, cbhm_item_changed_cb,
              ffi.Pointer<ffi.Void>)>>('cbhm_item_changed_callback_remove');
  late final _cbhm_item_changed_callback_remove =
      _cbhm_item_changed_callback_removePtr.asFunction<
          int Function(cbhm_h, cbhm_item_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the clipboard state.
  /// @since_tizen 4.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @param[out] type State type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  int cbhm_state_get(
    cbhm_h cbhm_handle,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _cbhm_state_get(
      cbhm_handle,
      type,
    );
  }

  late final _cbhm_state_getPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(cbhm_h, ffi.Pointer<ffi.Int32>)>>(
      'cbhm_state_get');
  late final _cbhm_state_get = _cbhm_state_getPtr
      .asFunction<int Function(cbhm_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Adds event callback function of receiving monitored event of clipboard.
  /// @since_tizen 4.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @param[in] callback Callback function called when clipboard becomes active or inactive
  /// @param[in] user_data User data to be passed to the given event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @retval #CBHM_ERROR_OUT_OF_MEMORY Out of memory
  /// @see cbhm_monitor_callback_remove()
  int cbhm_monitor_callback_add(
    cbhm_h cbhm_handle,
    cbhm_monitor_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _cbhm_monitor_callback_add(
      cbhm_handle,
      callback,
      user_data,
    );
  }

  late final _cbhm_monitor_callback_addPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(cbhm_h, cbhm_monitor_cb,
              ffi.Pointer<ffi.Void>)>>('cbhm_monitor_callback_add');
  late final _cbhm_monitor_callback_add =
      _cbhm_monitor_callback_addPtr.asFunction<
          int Function(cbhm_h, cbhm_monitor_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Deletes event callback function of receiving monitored event of clipboard.
  /// @since_tizen 4.0
  /// @param[in] cbhm_handle Clipboard handle
  /// @param[in] callback Callback function to be deleted
  /// @param[in] user_data User data to be passed to the given event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #CBHM_ERROR_NONE Successful
  /// @retval #CBHM_ERROR_INVALID_PARAMETER Invalid function parameters
  /// @see cbhm_monitor_callback_add()
  int cbhm_monitor_callback_remove(
    cbhm_h cbhm_handle,
    cbhm_monitor_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _cbhm_monitor_callback_remove(
      cbhm_handle,
      callback,
      user_data,
    );
  }

  late final _cbhm_monitor_callback_removePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(cbhm_h, cbhm_monitor_cb,
              ffi.Pointer<ffi.Void>)>>('cbhm_monitor_callback_remove');
  late final _cbhm_monitor_callback_remove =
      _cbhm_monitor_callback_removePtr.asFunction<
          int Function(cbhm_h, cbhm_monitor_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Initializes External Output Manager (EOM).
  /// @details User should call this function previously for using EOM.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks After all using, call eom_deinit() function for resource returning.
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_CONNECTION_FAILURE The EOM connection failure
  /// @see eom_deinit()
  /// @see #eom_error_e
  int eom_init() {
    return _eom_init();
  }

  late final _eom_initPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('eom_init');
  late final _eom_init = _eom_initPtr.asFunction<int Function()>();

  /// @brief Finalizes External Output Manager (EOM).
  /// @details User should call this function after using EOM to release all
  /// resources of EOM.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @see eom_init()
  void eom_deinit() {
    return _eom_deinit();
  }

  late final _eom_deinitPtr =
      _lookup<ffi.NativeFunction<ffi.Void Function()>>('eom_deinit');
  late final _eom_deinit = _eom_deinitPtr.asFunction<void Function()>();

  /// @brief Registers a callback function to get output connection notification
  /// from External Output Manager (EOM) module.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback  The function pointer of eom_output_added_cb callback
  /// function
  /// @param[in] user_data  The pointer of user data which is passed to
  /// eom_output_added_cb function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_OUT_OF_MEMORY Memory allocation failure
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see eom_unset_output_added_cb()
  /// @see #eom_output_added_cb
  int eom_set_output_added_cb(
    eom_output_added_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _eom_set_output_added_cb(
      callback,
      user_data,
    );
  }

  late final _eom_set_output_added_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(eom_output_added_cb,
              ffi.Pointer<ffi.Void>)>>('eom_set_output_added_cb');
  late final _eom_set_output_added_cb = _eom_set_output_added_cbPtr
      .asFunction<int Function(eom_output_added_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback  The function pointer of eom_output_added_cb callback
  /// function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see eom_set_output_added_cb()
  /// @see #eom_output_added_cb
  int eom_unset_output_added_cb(
    eom_output_added_cb callback,
  ) {
    return _eom_unset_output_added_cb(
      callback,
    );
  }

  late final _eom_unset_output_added_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(eom_output_added_cb)>>(
          'eom_unset_output_added_cb');
  late final _eom_unset_output_added_cb = _eom_unset_output_added_cbPtr
      .asFunction<int Function(eom_output_added_cb)>();

  /// @brief Registers a callback function to get output disconnection
  /// notification from External Output Manager (EOM) module.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback  The function pointer of eom_output_removed_cb callback
  /// function
  /// @param[in] user_data  The pointer of user data which is passed to
  /// eom_output_removed_cb function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_OUT_OF_MEMORY Memory allocation failure
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see eom_unset_output_removed_cb()
  /// @see #eom_output_removed_cb
  int eom_set_output_removed_cb(
    eom_output_removed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _eom_set_output_removed_cb(
      callback,
      user_data,
    );
  }

  late final _eom_set_output_removed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(eom_output_removed_cb,
              ffi.Pointer<ffi.Void>)>>('eom_set_output_removed_cb');
  late final _eom_set_output_removed_cb = _eom_set_output_removed_cbPtr
      .asFunction<int Function(eom_output_removed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback  The function pointer of eom_output_removed_cb callback
  /// function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see eom_set_output_removed_cb()
  /// @see #eom_output_removed_cb
  int eom_unset_output_removed_cb(
    eom_output_removed_cb callback,
  ) {
    return _eom_unset_output_removed_cb(
      callback,
    );
  }

  late final _eom_unset_output_removed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(eom_output_removed_cb)>>(
          'eom_unset_output_removed_cb');
  late final _eom_unset_output_removed_cb = _eom_unset_output_removed_cbPtr
      .asFunction<int Function(eom_output_removed_cb)>();

  /// @brief Registers a callback function to get output mode changing
  /// notification from External Output Manager (EOM) module.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback  The function pointer of eom_mode_changed_cb callback
  /// function
  /// @param[in] user_data  The pointer of user data which is passed to
  /// eom_mode_changed_cb function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_OUT_OF_MEMORY Memory allocation failure
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see eom_unset_mode_changed_cb()
  /// @see #eom_mode_changed_cb
  int eom_set_mode_changed_cb(
    eom_mode_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _eom_set_mode_changed_cb(
      callback,
      user_data,
    );
  }

  late final _eom_set_mode_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(eom_mode_changed_cb,
              ffi.Pointer<ffi.Void>)>>('eom_set_mode_changed_cb');
  late final _eom_set_mode_changed_cb = _eom_set_mode_changed_cbPtr
      .asFunction<int Function(eom_mode_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback  The function pointer of eom_mode_changed_cb callback
  /// function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see eom_set_mode_changed_cb()
  /// @see #eom_mode_changed_cb
  int eom_unset_mode_changed_cb(
    eom_mode_changed_cb callback,
  ) {
    return _eom_unset_mode_changed_cb(
      callback,
    );
  }

  late final _eom_unset_mode_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(eom_mode_changed_cb)>>(
          'eom_unset_mode_changed_cb');
  late final _eom_unset_mode_changed_cb = _eom_unset_mode_changed_cbPtr
      .asFunction<int Function(eom_mode_changed_cb)>();

  /// @brief Registers a callback function to get output attribute changing
  /// notification from External Output Manager (EOM) module.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback  The function pointer of eom_attribute_changed_cb
  /// callback function
  /// @param[in] user_data  The pointer of user data which is passed to
  /// eom_attribute_changed_cb function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_OUT_OF_MEMORY Memory allocation failure
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see eom_unset_attribute_changed_cb()
  /// @see #eom_attribute_changed_cb
  int eom_set_attribute_changed_cb(
    eom_attribute_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _eom_set_attribute_changed_cb(
      callback,
      user_data,
    );
  }

  late final _eom_set_attribute_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(eom_attribute_changed_cb,
              ffi.Pointer<ffi.Void>)>>('eom_set_attribute_changed_cb');
  late final _eom_set_attribute_changed_cb =
      _eom_set_attribute_changed_cbPtr.asFunction<
          int Function(eom_attribute_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] callback  The function pointer of eom_attribute_changed_cb
  /// callback function
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see eom_set_attribute_changed_cb()
  /// @see #eom_attribute_changed_cb
  int eom_unset_attribute_changed_cb(
    eom_attribute_changed_cb callback,
  ) {
    return _eom_unset_attribute_changed_cb(
      callback,
    );
  }

  late final _eom_unset_attribute_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(eom_attribute_changed_cb)>>(
          'eom_unset_attribute_changed_cb');
  late final _eom_unset_attribute_changed_cb =
      _eom_unset_attribute_changed_cbPtr
          .asFunction<int Function(eom_attribute_changed_cb)>();

  /// @brief Gets the IDs and count of external output.
  /// @details This function returns the IDs of external output which are
  /// available to connect to target device, and the count of them
  /// also. User can get the id of external output.
  /// which user want to watch.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks User should free return value by using free().
  /// The specific error code can be obtained using the get_last_result() method.
  /// Error codes are described in Exception section.
  /// @param[out] count  The count of the eom_output_id supported by system
  /// @return The array of the eom_output_id if this function succeeds, otherwise
  /// NULL
  /// @retval The pointer of #eom_output_id
  /// @exception #EOM_ERROR_NONE Successful
  /// @exception #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @exception #EOM_ERROR_OUT_OF_MEMORY Memory allocation failure
  /// @pre eom_init()
  /// @see #eom_output_id
  /// @see #eom_error_e
  ffi.Pointer<eom_output_id> eom_get_eom_output_ids(
    ffi.Pointer<ffi.Int> count,
  ) {
    return _eom_get_eom_output_ids(
      count,
    );
  }

  late final _eom_get_eom_output_idsPtr = _lookup<
      ffi.NativeFunction<
          ffi.Pointer<eom_output_id> Function(
              ffi.Pointer<ffi.Int>)>>('eom_get_eom_output_ids');
  late final _eom_get_eom_output_ids = _eom_get_eom_output_idsPtr
      .asFunction<ffi.Pointer<eom_output_id> Function(ffi.Pointer<ffi.Int>)>();

  /// @brief Gets type of external output.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks The specific error code can be obtained using the get_last_result()
  /// method. Error codes are described in Exception section.
  /// @param[in] output_id  The id of external output device
  /// @param[out] type  The type of external output instance
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see #eom_output_id
  /// @see #eom_error_e
  /// @see #eom_output_type_e
  int eom_get_output_type(
    int output_id,
    ffi.Pointer<ffi.Int32> type,
  ) {
    return _eom_get_output_type(
      output_id,
      type,
    );
  }

  late final _eom_get_output_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              eom_output_id, ffi.Pointer<ffi.Int32>)>>('eom_get_output_type');
  late final _eom_get_output_type = _eom_get_output_typePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets mode of external output.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks The specific error code can be obtained using the get_last_result()
  /// method. Error codes are described in Exception section.
  /// @param[in] output_id  The id of external output device
  /// @param[out] mode  The mode of external output instance
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EOM_ERROR_NO_SUCH_DEVICE Invalid external output instance
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see #eom_output_id
  /// @see #eom_error_e
  /// @see #eom_output_mode_e
  int eom_get_output_mode(
    int output_id,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _eom_get_output_mode(
      output_id,
      mode,
    );
  }

  late final _eom_get_output_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              eom_output_id, ffi.Pointer<ffi.Int32>)>>('eom_get_output_mode');
  late final _eom_get_output_mode = _eom_get_output_modePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets attribute of external output.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks The specific error code can be obtained using the get_last_result()
  /// method. Error codes are described in Exception section.
  /// @param[in] output_id  The id of external output device
  /// @param[out] attribute  The attribute of external output instance
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EOM_ERROR_NO_SUCH_DEVICE Invalid external output instance
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see #eom_output_id
  /// @see #eom_error_e
  /// @see #eom_output_attribute_e
  int eom_get_output_attribute(
    int output_id,
    ffi.Pointer<ffi.Int32> attribute,
  ) {
    return _eom_get_output_attribute(
      output_id,
      attribute,
    );
  }

  late final _eom_get_output_attributePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(eom_output_id,
              ffi.Pointer<ffi.Int32>)>>('eom_get_output_attribute');
  late final _eom_get_output_attribute = _eom_get_output_attributePtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets attribute state of external output.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @remarks The specific error code can be obtained using the get_last_result()
  /// method. Error codes are described in Exception section.
  /// @param[in] output_id  The id of external output device
  /// @param[out] state  The attribute state of external output instance
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EOM_ERROR_NO_SUCH_DEVICE Invalid external output instance
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see #eom_output_id
  /// @see #eom_error_e
  /// @see #eom_output_attribute_state_e
  int eom_get_output_attribute_state(
    int output_id,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _eom_get_output_attribute_state(
      output_id,
      state,
    );
  }

  late final _eom_get_output_attribute_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(eom_output_id,
              ffi.Pointer<ffi.Int32>)>>('eom_get_output_attribute_state');
  late final _eom_get_output_attribute_state =
      _eom_get_output_attribute_statePtr
          .asFunction<int Function(int, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets resolution of external output.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] output_id  The id of external output device
  /// @param[out] width  The width of external output instance
  /// @param[out] height  The height of external output instance
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EOM_ERROR_NO_SUCH_DEVICE Invalid external output instance
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see #eom_output_id
  /// @see #eom_error_e
  int eom_get_output_resolution(
    int output_id,
    ffi.Pointer<ffi.Int> width,
    ffi.Pointer<ffi.Int> height,
  ) {
    return _eom_get_output_resolution(
      output_id,
      width,
      height,
    );
  }

  late final _eom_get_output_resolutionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(eom_output_id, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('eom_get_output_resolution');
  late final _eom_get_output_resolution =
      _eom_get_output_resolutionPtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets physical width/height (millimeters) of external output.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] output_id  The id of external output device
  /// @param[out] phy_width  The physical mm width of external output instance
  /// @param[out] phy_height  The physical mm height of external output instance
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EOM_ERROR_NO_SUCH_DEVICE Invalid external output instance
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see #eom_output_id
  /// @see #eom_error_e
  int eom_get_output_physical_size(
    int output_id,
    ffi.Pointer<ffi.Int> phy_width,
    ffi.Pointer<ffi.Int> phy_height,
  ) {
    return _eom_get_output_physical_size(
      output_id,
      phy_width,
      phy_height,
    );
  }

  late final _eom_get_output_physical_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(eom_output_id, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('eom_get_output_physical_size');
  late final _eom_get_output_physical_size =
      _eom_get_output_physical_sizePtr.asFunction<
          int Function(int, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the attribute of the external output ID.
  /// @details The application can set the External Output Manager (EOM) attribute
  /// to the external output ID.
  /// The EOM module manages the windows to display on external output and
  /// control the policy of external output. The application can recognize
  /// the attribute state and manage the resources when the application receives
  /// several notification callback from EOM module.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] output_id  The id of external output device
  /// @param[in] attr  The attribute of the external output
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EOM_ERROR_NO_SUCH_DEVICE Invalid external output instance
  /// @retval #EOM_ERROR_MESSAGE_SENDING_FAILURE Communication failure with EOM
  /// module
  /// @retval #EOM_ERROR_MESSAGE_OPERATION_FAILURE Operation failure
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see #eom_output_id
  /// @see #eom_error_e
  int eom_set_output_attribute(
    int output_id,
    int attr,
  ) {
    return _eom_set_output_attribute(
      output_id,
      attr,
    );
  }

  late final _eom_set_output_attributePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(eom_output_id, ffi.Int32)>>(
          'eom_set_output_attribute');
  late final _eom_set_output_attribute =
      _eom_set_output_attributePtr.asFunction<int Function(int, int)>();

  /// @brief Sets window to the external output best resolution of external output
  /// device.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @param[in] output_id  The id of external output device
  /// @param[in] win  The pointer of evas object
  /// @return 0 on success, otherwise a negative error value
  /// @retval #EOM_ERROR_NONE Successful
  /// @retval #EOM_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #EOM_ERROR_NO_SUCH_DEVICE Invalid external output instance
  /// @retval #EOM_ERROR_MESSAGE_SENDING_FAILURE Communication failure with EOM
  /// module
  /// @retval #EOM_ERROR_MESSAGE_OPERATION_FAILURE Operation failure
  /// @pre eom_init()
  /// @pre eom_get_eom_output_ids()
  /// @see #eom_output_id
  /// @see #eom_error_e
  int eom_set_output_window(
    int output_id,
    ffi.Pointer<Evas_Object> win,
  ) {
    return _eom_set_output_window(
      output_id,
      win,
    );
  }

  late final _eom_set_output_windowPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(eom_output_id,
              ffi.Pointer<Evas_Object>)>>('eom_set_output_window');
  late final _eom_set_output_window = _eom_set_output_windowPtr
      .asFunction<int Function(int, ffi.Pointer<Evas_Object>)>();

  /// @brief Runs the main loop of IME application.
  ///
  /// @details This function starts to run IME application's main loop. The ime_create_cb()
  /// callback function is called to initialize IME application before the main loop starts up. And
  /// the ime_terminate_cb() callback function is called when IME application is terminated.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks IME application MUST implement ime_app_main() function which is the main
  /// entry point of IME application. In ime_app_main() function, the ime_run()
  /// function MUST be called with the necessary callback functions; ime_create_cb(),
  /// ime_terminate_cb(), ime_show_cb(), and ime_hide_cb() callback functions
  /// are mandatory for IME application.
  ///
  /// @param[in] basic_cb The structure pointer of the essential callback functions
  /// @param[in] user_data User data to be passed to the callback functions
  ///
  /// @return 0 if IME application ends successfully, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NO_CALLBACK_FUNCTION Necessary callback function is not set
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @pre The ime_event_set_***() functions can be called to set the event handling callback functions.
  ///
  /// @see ime_callback_s()
  /// @see ime_event_set_focus_in_cb()
  /// @see ime_event_set_focus_out_cb()
  /// @see ime_event_set_surrounding_text_updated_cb()
  /// @see ime_event_set_input_context_reset_cb()
  /// @see ime_event_set_cursor_position_updated_cb()
  /// @see ime_event_set_language_requested_cb()
  /// @see ime_event_set_language_set_cb()
  /// @see ime_event_set_imdata_set_cb()
  /// @see ime_event_set_layout_set_cb()
  /// @see ime_event_set_return_key_type_set_cb()
  /// @see ime_event_set_return_key_state_set_cb()
  /// @see ime_event_set_geometry_requested_cb()
  /// @see ime_event_set_display_language_changed_cb()
  /// @see ime_event_set_rotation_degree_changed_cb()
  /// @see ime_event_set_accessibility_state_changed_cb()
  /// @see ime_event_set_option_window_created_cb()
  /// @see ime_event_set_option_window_destroyed_cb()
  /// @see ime_event_set_prediction_hint_set_cb()
  ///
  /// @code
  /// static void inputmethod_create_cb(void *user_data);
  /// static void inputmethod_terminate_cb(void *user_data);
  /// static void inputmethod_show_cb(int context_id, ime_context_h context, void *user_data);
  /// static void inputmethod_hide_cb(int context_id, void *user_data);
  /// static void inputmethod_focus_in_cb(int context_id, void *user_data);
  /// static void inputmethod_focus_out_cb(int context_id, void *user_data);
  /// static void inputmethod_cursor_position_updated_cb(int cursor_pos, void *user_data);
  ///
  /// static void inputmethod_create_cb(void *user_data)
  /// {
  /// Evas_Object *ime_win = NULL;
  ///
  /// ime_set_size(480, 400, 800, 400);
  /// ime_win = ime_get_main_window();
  /// if (ime_win) {
  /// // Prepare before showing IME window.
  /// }
  /// }
  ///
  /// static void inputmethod_show_cb(int context_id, ime_context_h context, void *user_data)
  /// {
  /// Ecore_IMF_Input_Panel_Layout layout;
  /// ime_layout_variation_e layout_variation;
  /// Evas_Object *ime_win;
  ///
  /// ime_context_get_layout(context, &layout);
  /// ime_context_get_layout_variation(context, &layout_variation);
  ///
  /// ime_win = ime_get_main_window();
  /// if (ime_win) {
  /// // Compose IME UI properly with the context information and show.
  ///
  /// evas_object_show(ime_win);
  /// }
  /// }
  ///
  /// static void inputmethod_hide_cb(int context_id, void *user_data)
  /// {
  /// Evas_Object *ime_win = ime_get_main_window();
  /// if (ime_win) {
  /// evas_object_hide(ime_win);
  /// }
  /// }
  ///
  /// void ime_app_main(int argc, char **argv)
  /// {
  /// ime_callback_s basic_callback = {
  /// inputmethod_create_cb,
  /// inputmethod_terminate_cb,
  /// inputmethod_show_cb,
  /// inputmethod_hide_cb,
  /// };
  ///
  /// ime_event_set_focus_in_cb(inputmethod_focus_in_cb, NULL);
  /// ime_event_set_focus_out_cb(inputmethod_focus_out_cb, NULL);
  /// ime_event_set_cursor_position_updated_cb(inputmethod_cursor_position_updated_cb, NULL);
  ///
  /// ime_run(&basic_callback, NULL);
  /// }
  /// @endcode
  int ime_run(
    ffi.Pointer<ime_callback_s> basic_cb,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_run(
      basic_cb,
      user_data,
    );
  }

  late final _ime_runPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ime_callback_s>, ffi.Pointer<ffi.Void>)>>('ime_run');
  late final _ime_run = _ime_runPtr.asFunction<
      int Function(ffi.Pointer<ime_callback_s>, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c focus_in event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_focus_in_cb() callback function is called when an associated text input
  /// UI control has focus.
  ///
  /// @param[in] callback_func @c focus_in event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_focus_in_cb()
  /// @see ime_run()
  int ime_event_set_focus_in_cb(
    ime_focus_in_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_focus_in_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_focus_in_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_focus_in_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_focus_in_cb');
  late final _ime_event_set_focus_in_cb = _ime_event_set_focus_in_cbPtr
      .asFunction<int Function(ime_focus_in_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c focus_out event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_focus_out_cb() callback function is called when an associated text input
  /// UI control loses focus.
  ///
  /// @param[in] callback_func @c focus_out event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_focus_out_cb()
  /// @see ime_run()
  int ime_event_set_focus_out_cb(
    ime_focus_out_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_focus_out_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_focus_out_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_focus_out_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_focus_out_cb');
  late final _ime_event_set_focus_out_cb = _ime_event_set_focus_out_cbPtr
      .asFunction<int Function(ime_focus_out_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c surrounding_text_updated event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_surrounding_text_updated_cb() callback function is called when an
  /// associated text input UI control responds to a request with the surrounding text.
  ///
  /// @param[in] callback_func @c surrounding_text_updated event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_surrounding_text_updated_cb()
  /// @see ime_run()
  int ime_event_set_surrounding_text_updated_cb(
    ime_surrounding_text_updated_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_surrounding_text_updated_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_surrounding_text_updated_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ime_surrounding_text_updated_cb, ffi.Pointer<ffi.Void>)>>(
      'ime_event_set_surrounding_text_updated_cb');
  late final _ime_event_set_surrounding_text_updated_cb =
      _ime_event_set_surrounding_text_updated_cbPtr.asFunction<
          int Function(
              ime_surrounding_text_updated_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c input_context_reset event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_input_context_reset_cb() callback function is called to reset the input
  /// context of an associated text input UI control.
  ///
  /// @param[in] callback_func @c input_context_reset event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_input_context_reset_cb()
  /// @see ime_run()
  int ime_event_set_input_context_reset_cb(
    ime_input_context_reset_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_input_context_reset_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_input_context_reset_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_input_context_reset_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_input_context_reset_cb');
  late final _ime_event_set_input_context_reset_cb =
      _ime_event_set_input_context_reset_cbPtr.asFunction<
          int Function(ime_input_context_reset_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c cursor_position_updated event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_cursor_position_updated_cb() callback function is called when the position
  /// of the cursor in an associated text input UI control changes.
  ///
  /// @param[in] callback_func @c cursor_position_updated event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_cursor_position_updated_cb()
  /// @see ime_run()
  int ime_event_set_cursor_position_updated_cb(
    ime_cursor_position_updated_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_cursor_position_updated_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_cursor_position_updated_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ime_cursor_position_updated_cb, ffi.Pointer<ffi.Void>)>>(
      'ime_event_set_cursor_position_updated_cb');
  late final _ime_event_set_cursor_position_updated_cb =
      _ime_event_set_cursor_position_updated_cbPtr.asFunction<
          int Function(
              ime_cursor_position_updated_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c language_requested event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_language_requested_cb() callback function is called when an associated
  /// text input UI control requests the language from the input panel.
  ///
  /// @param[in] callback_func @c language_requested event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_language_requested_cb()
  /// @see ime_run()
  int ime_event_set_language_requested_cb(
    ime_language_requested_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_language_requested_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_language_requested_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_language_requested_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_language_requested_cb');
  late final _ime_event_set_language_requested_cb =
      _ime_event_set_language_requested_cbPtr.asFunction<
          int Function(ime_language_requested_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c language_set event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_language_set_cb() callback function is called to set the preferred
  /// language to the input panel.
  ///
  /// @param[in] callback_func @c language_set event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_language_set_cb()
  /// @see ime_run()
  int ime_event_set_language_set_cb(
    ime_language_set_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_language_set_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_language_set_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_language_set_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_language_set_cb');
  late final _ime_event_set_language_set_cb = _ime_event_set_language_set_cbPtr
      .asFunction<int Function(ime_language_set_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c imdata_set event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_imdata_set_cb() callback function is called to set the application
  /// specific data to deliver to the input panel.
  ///
  /// @param[in] callback_func @c imdata_set event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_imdata_set_cb()
  /// @see ime_event_set_imdata_requested_cb()
  /// @see ime_run()
  int ime_event_set_imdata_set_cb(
    ime_imdata_set_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_imdata_set_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_imdata_set_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_imdata_set_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_imdata_set_cb');
  late final _ime_event_set_imdata_set_cb = _ime_event_set_imdata_set_cbPtr
      .asFunction<int Function(ime_imdata_set_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c imdata_requested event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_imdata_requested_cb() callback function is called when an associated
  /// text input UI control requests the application specific data from the input panel.
  ///
  /// @param[in] callback_func @c imdata_requested event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_imdata_requested_cb()
  /// @see ime_event_set_imdata_set_cb()
  /// @see ime_run()
  int ime_event_set_imdata_requested_cb(
    ime_imdata_requested_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_imdata_requested_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_imdata_requested_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_imdata_requested_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_imdata_requested_cb');
  late final _ime_event_set_imdata_requested_cb =
      _ime_event_set_imdata_requested_cbPtr.asFunction<
          int Function(ime_imdata_requested_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c layout_set event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_layout_set_cb() callback function is called when an associated text input
  /// UI control requests the input panel to set its layout.
  ///
  /// @param[in] callback_func @c layout_set event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_layout_set_cb()
  /// @see ime_run()
  int ime_event_set_layout_set_cb(
    ime_layout_set_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_layout_set_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_layout_set_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_layout_set_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_layout_set_cb');
  late final _ime_event_set_layout_set_cb = _ime_event_set_layout_set_cbPtr
      .asFunction<int Function(ime_layout_set_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c return_key_type_set event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_return_key_type_set_cb() callback function is called when an associated
  /// text input UI control requests the input panel to set the @c Return key label.
  ///
  /// @param[in] callback_func @c return_key_type_set event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_return_key_type_set_cb()
  /// @see ime_run()
  int ime_event_set_return_key_type_set_cb(
    ime_return_key_type_set_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_return_key_type_set_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_return_key_type_set_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_return_key_type_set_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_return_key_type_set_cb');
  late final _ime_event_set_return_key_type_set_cb =
      _ime_event_set_return_key_type_set_cbPtr.asFunction<
          int Function(ime_return_key_type_set_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c return_key_state_set event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_return_key_state_set_cb() callback function is called when an associated
  /// text input UI control requests the input panel to enable or disable the @c Return key state.
  ///
  /// @param[in] callback_func @c return_key_state_set event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_return_key_state_set_cb()
  /// @see ime_run()
  int ime_event_set_return_key_state_set_cb(
    ime_return_key_state_set_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_return_key_state_set_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_return_key_state_set_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_return_key_state_set_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_return_key_state_set_cb');
  late final _ime_event_set_return_key_state_set_cb =
      _ime_event_set_return_key_state_set_cbPtr.asFunction<
          int Function(ime_return_key_state_set_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c geometry_requested event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_geometry_requested_cb() callback function is called when an associated
  /// text input UI control requests the position and size from the input panel.
  ///
  /// @param[in] callback_func @c geometry_requested event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_geometry_requested_cb()
  /// @see ime_run()
  int ime_event_set_geometry_requested_cb(
    ime_geometry_requested_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_geometry_requested_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_geometry_requested_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_geometry_requested_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_geometry_requested_cb');
  late final _ime_event_set_geometry_requested_cb =
      _ime_event_set_geometry_requested_cbPtr.asFunction<
          int Function(ime_geometry_requested_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c process_key_event event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_process_key_event_cb() callback function is called when the key event
  /// is received from the external keyboard devices or ime_send_key_event() function.
  ///
  /// @param[in] callback_func @c process_key_event event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_process_key_event_cb()
  /// @see ime_run()
  ///
  /// @code
  /// static void inputmethod_create_cb(void *user_data);
  /// static void inputmethod_terminate_cb(void *user_data);
  /// static void inputmethod_show_cb(int context_id, ime_context_h context, void *user_data);
  /// static void inputmethod_hide_cb(int context_id, void *user_data);
  ///
  /// static bool inputmethod_process_key_event_cb(ime_key_code_e keycode, ime_key_mask_e keymask, void *user_data);
  /// {
  /// if (keymask & IME_KEY_MASK_CONTROL) {
  /// return false; // e.g., Cotrol+C key event would be forwarded to UI control of the client application
  /// }
  /// if (keymask & IME_KEY_MASK_ALT) {
  /// return false;
  /// }
  ///
  /// if (!(keymask & IME_KEY_MASK_RELEASED)) { // The key is pressed
  /// if (keycode == IME_KEY_1) {
  /// ime_update_preedit_string("1"); // Show "1" preedit string
  /// return true;
  /// }
  /// else if (keycode == IME_KEY_2) {
  /// ime_commit_string("12"); // Input "12" string
  /// return true;
  /// }
  /// }
  ///
  /// return false;
  /// }
  ///
  /// void ime_app_main(int argc, char **argv)
  /// {
  /// ime_callback_s basic_callback = {
  /// inputmethod_create_cb,
  /// inputmethod_terminate_cb,
  /// inputmethod_show_cb,
  /// inputmethod_hide_cb,
  /// };
  ///
  /// ime_event_set_process_key_event_cb(inputmethod_process_key_event_cb, NULL);
  ///
  /// ime_run(&basic_callback, NULL);
  /// }
  /// @endcode
  int ime_event_set_process_key_event_cb(
    ime_process_key_event_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_process_key_event_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_process_key_event_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_process_key_event_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_process_key_event_cb');
  late final _ime_event_set_process_key_event_cb =
      _ime_event_set_process_key_event_cbPtr.asFunction<
          int Function(ime_process_key_event_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c display_language_changed event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_display_language_changed_cb() callback function is called when the system
  /// display language is changed.
  ///
  /// @param[in] callback_func @c display_language_changed event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_display_language_changed_cb()
  /// @see ime_run()
  int ime_event_set_display_language_changed_cb(
    ime_display_language_changed_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_display_language_changed_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_display_language_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ime_display_language_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'ime_event_set_display_language_changed_cb');
  late final _ime_event_set_display_language_changed_cb =
      _ime_event_set_display_language_changed_cbPtr.asFunction<
          int Function(
              ime_display_language_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c rotation_degree_changed event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_rotation_degree_changed_cb() callback function is called when the device
  /// is rotated.
  ///
  /// @param[in] callback_func @c rotation_degree_changed event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_rotation_degree_changed_cb()
  /// @see ime_run()
  int ime_event_set_rotation_degree_changed_cb(
    ime_rotation_degree_changed_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_rotation_degree_changed_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_rotation_degree_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ime_rotation_degree_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'ime_event_set_rotation_degree_changed_cb');
  late final _ime_event_set_rotation_degree_changed_cb =
      _ime_event_set_rotation_degree_changed_cbPtr.asFunction<
          int Function(
              ime_rotation_degree_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c accessibility_state_changed event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_accessibility_state_changed_cb() callback function is called when
  /// Accessibility in Settings application is on or off.
  ///
  /// @param[in] callback_func @c accessibility_state_changed event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_accessibility_state_changed_cb()
  /// @see ime_run()
  int ime_event_set_accessibility_state_changed_cb(
    ime_accessibility_state_changed_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_accessibility_state_changed_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_accessibility_state_changed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ime_accessibility_state_changed_cb, ffi.Pointer<ffi.Void>)>>(
      'ime_event_set_accessibility_state_changed_cb');
  late final _ime_event_set_accessibility_state_changed_cb =
      _ime_event_set_accessibility_state_changed_cbPtr.asFunction<
          int Function(
              ime_accessibility_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c option_window_created event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_option_window_created_cb() callback function is called to create the option window.
  ///
  /// @param[in] callback_func @c option_window_created event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_option_window_created_cb()
  /// @see ime_run()
  int ime_event_set_option_window_created_cb(
    ime_option_window_created_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_option_window_created_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_option_window_created_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ime_option_window_created_cb, ffi.Pointer<ffi.Void>)>>(
      'ime_event_set_option_window_created_cb');
  late final _ime_event_set_option_window_created_cb =
      _ime_event_set_option_window_created_cbPtr.asFunction<
          int Function(ime_option_window_created_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets @c option_window_destroyed event callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_option_window_destroyed_cb() callback function is called to destroy the option window.
  ///
  /// @param[in] callback_func @c option_window_destroyed event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_option_window_destroyed_cb()
  /// @see ime_run()
  int ime_event_set_option_window_destroyed_cb(
    ime_option_window_destroyed_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_option_window_destroyed_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_option_window_destroyed_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ime_option_window_destroyed_cb, ffi.Pointer<ffi.Void>)>>(
      'ime_event_set_option_window_destroyed_cb');
  late final _ime_event_set_option_window_destroyed_cb =
      _ime_event_set_option_window_destroyed_cbPtr.asFunction<
          int Function(
              ime_option_window_destroyed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sends a key event to the associated text input UI control.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @details This function sends key down or up event with key mask to the client application.
  /// If @a forward_key is @c true, this key event goes to the edit filed directly. And if @a forward_key
  /// is @c false, the ime_process_key_event_cb() callback function receives the key event before the edit field.
  ///
  /// @param[in] keycode The key code to be sent
  /// @param[in] keymask The modifier key mask
  /// @param[in] forward_key The flag to send the key event directly to the edit field
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post If @a forward_key is @c false, the ime_process_key_event_cb() callback function can compose the text with the key events.
  ///
  /// @see ime_key_code_e
  /// @see ime_key_mask_e
  /// @see ime_process_key_event_cb()
  int ime_send_key_event(
    int keycode,
    int keymask,
    bool forward_key,
  ) {
    return _ime_send_key_event(
      keycode,
      keymask,
      forward_key,
    );
  }

  late final _ime_send_key_eventPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ffi.Int32, ffi.Int32, ffi.Bool)>>(
      'ime_send_key_event');
  late final _ime_send_key_event =
      _ime_send_key_eventPtr.asFunction<int Function(int, int, bool)>();

  /// @brief Sends the text to the associated text input UI control.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] str The UTF-8 string to be committed
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @see ime_show_preedit_string()
  /// @see ime_hide_preedit_string()
  /// @see ime_update_preedit_string()
  int ime_commit_string(
    ffi.Pointer<ffi.Char> str,
  ) {
    return _ime_commit_string(
      str,
    );
  }

  late final _ime_commit_stringPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'ime_commit_string');
  late final _ime_commit_string =
      _ime_commit_stringPtr.asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Requests to show preedit string.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @see ime_commit_string()
  /// @see ime_hide_preedit_string()
  /// @see ime_update_preedit_string()
  int ime_show_preedit_string() {
    return _ime_show_preedit_string();
  }

  late final _ime_show_preedit_stringPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'ime_show_preedit_string');
  late final _ime_show_preedit_string =
      _ime_show_preedit_stringPtr.asFunction<int Function()>();

  /// @brief Requests to hide preedit string.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @see ime_commit_string()
  /// @see ime_show_preedit_string()
  /// @see ime_update_preedit_string()
  int ime_hide_preedit_string() {
    return _ime_hide_preedit_string();
  }

  late final _ime_hide_preedit_stringPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'ime_hide_preedit_string');
  late final _ime_hide_preedit_string =
      _ime_hide_preedit_stringPtr.asFunction<int Function()>();

  /// @brief Updates a new preedit string.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] str The UTF-8 string to be updated in preedit
  /// @param[in] attrs The Eina_List which has #ime_preedit_attribute lists; @a str can be composed of multiple
  /// string attributes: underline, highlight color and reversal color. The @a attrs will be released internally
  /// on success and it can be NULL if no attributes to set
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post This function is supposed to be followed by the ime_show_preedit_string() function.
  ///
  /// @see ime_preedit_attribute
  /// @see ime_commit_string()
  /// @see ime_show_preedit_string()
  /// @see ime_hide_preedit_string()
  ///
  /// @code
  /// {
  /// int ret;
  /// Eina_List *list = NULL;
  ///
  /// ime_preedit_attribute *attr = calloc(1, sizeof (ime_preedit_attribute));
  /// attr->start = 0;
  /// attr->length = 1;
  /// attr->type = IME_ATTR_FONTSTYLE;
  /// attr->value = IME_ATTR_FONTSTYLE_UNDERLINE;
  /// list = eina_list_append(list, attr);
  ///
  /// attr = calloc(1, sizeof (ime_preedit_attribute));
  /// attr->start = 1;
  /// attr->length = 1;
  /// attr->type = IME_ATTR_FONTSTYLE;
  /// attr->value = IME_ATTR_FONTSTYLE_HIGHLIGHT;
  /// list = eina_list_append(list, attr);
  ///
  /// attr = calloc(1, sizeof (ime_preedit_attribute));
  /// attr->start = 2;
  /// attr->length = 1;
  /// attr->type = IME_ATTR_FONTSTYLE;
  /// attr->value = IME_ATTR_FONTSTYLE_REVERSAL;
  /// list = eina_list_append(list, attr);
  ///
  /// ret = ime_update_preedit_string("abcd", list);
  /// if (ret != IME_ERROR_NONE) {
  /// EINA_LIST_FREE(list, attr)
  /// free(attr);
  /// }
  /// }
  /// @endcode
  int ime_update_preedit_string(
    ffi.Pointer<ffi.Char> str,
    ffi.Pointer<Eina_List> attrs,
  ) {
    return _ime_update_preedit_string(
      str,
      attrs,
    );
  }

  late final _ime_update_preedit_stringPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<Eina_List>)>>('ime_update_preedit_string');
  late final _ime_update_preedit_string =
      _ime_update_preedit_stringPtr.asFunction<
          int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<Eina_List>)>();

  /// @brief Requests the surrounding text from the position of the cursor, asynchronously.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] maxlen_before The maximum length of string to be retrieved before the cursor; -1 means unlimited
  /// @param[in] maxlen_after The maximum length of string to be retrieved after the cursor; -1 means unlimited
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NO_CALLBACK_FUNCTION Necessary callback function is not set
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @pre The ime_surrounding_text_updated_cb() callback function MUST be set by ime_event_set_surrounding_text_updated_cb().
  ///
  /// @post The requested surrounding text can be received using the ime_surrounding_text_updated_cb() callback function.
  ///
  /// @see ime_delete_surrounding_text()
  /// @see ime_event_set_surrounding_text_updated_cb()
  /// @see ime_surrounding_text_updated_cb()
  int ime_request_surrounding_text(
    int maxlen_before,
    int maxlen_after,
  ) {
    return _ime_request_surrounding_text(
      maxlen_before,
      maxlen_after,
    );
  }

  late final _ime_request_surrounding_textPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'ime_request_surrounding_text');
  late final _ime_request_surrounding_text =
      _ime_request_surrounding_textPtr.asFunction<int Function(int, int)>();

  /// @brief Requests to delete surrounding text.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] offset The offset value from the cursor position
  /// @param[in] len The length of the text to delete
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @see ime_request_surrounding_text()
  int ime_delete_surrounding_text(
    int offset,
    int len,
  ) {
    return _ime_delete_surrounding_text(
      offset,
      len,
    );
  }

  late final _ime_delete_surrounding_textPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'ime_delete_surrounding_text');
  late final _ime_delete_surrounding_text =
      _ime_delete_surrounding_textPtr.asFunction<int Function(int, int)>();

  /// @brief Gets the surrounding text from the position of the cursor, synchronously.
  ///
  /// @remarks @a text must be released using free().
  ///
  /// @since_tizen 3.0
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] maxlen_before The maximum length of string to be retrieved before the cursor; -1 means unlimited
  /// @param[in] maxlen_after The maximum length of string to be retrieved after the cursor; -1 means unlimited
  /// @param[out] text The surrounding text
  /// @param[out] cursor_pos The cursor position
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  /// @retval #IME_ERROR_OUT_OF_MEMORY Failed to obtain text due to out of memory
  ///
  /// @see ime_delete_surrounding_text()
  int ime_get_surrounding_text(
    int maxlen_before,
    int maxlen_after,
    ffi.Pointer<ffi.Pointer<ffi.Char>> text,
    ffi.Pointer<ffi.Int> cursor_pos,
  ) {
    return _ime_get_surrounding_text(
      maxlen_before,
      maxlen_after,
      text,
      cursor_pos,
    );
  }

  late final _ime_get_surrounding_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int>)>>('ime_get_surrounding_text');
  late final _ime_get_surrounding_text =
      _ime_get_surrounding_textPtr.asFunction<
          int Function(int, int, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int>)>();

  /// @brief Requests to set selection.
  ///
  /// @since_tizen 3.0
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] start The start cursor position in text (in characters not bytes)
  /// @param[in] end The end cursor position in text (in characters not bytes)
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  int ime_set_selection(
    int start,
    int end,
  ) {
    return _ime_set_selection(
      start,
      end,
    );
  }

  late final _ime_set_selectionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Int)>>(
          'ime_set_selection');
  late final _ime_set_selection =
      _ime_set_selectionPtr.asFunction<int Function(int, int)>();

  /// @brief Gets the selected text synchronously.
  ///
  /// @details If multi-line text is selected, the result will contain '\n' for each newline character.
  /// And if the selected text is empty, the result will be an empty string.
  ///
  /// @since_tizen 4.0
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks @a text must be released using free().
  ///
  /// @param[out] text The selected text
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  int ime_get_selected_text(
    ffi.Pointer<ffi.Pointer<ffi.Char>> text,
  ) {
    return _ime_get_selected_text(
      text,
    );
  }

  late final _ime_get_selected_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('ime_get_selected_text');
  late final _ime_get_selected_text = _ime_get_selected_textPtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief This API returns the pointer of input panel main window.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The specific error code can be obtained using the get_last_result() method if this function returns NULL.
  ///
  /// @return The input panel main window object on success, otherwise NULL
  ///
  /// @exception #IME_ERROR_NONE Successful
  /// #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  /// #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @see ime_create_cb()
  /// @see ime_terminate_cb()
  /// @see ime_show_cb()
  /// @see ime_hide_cb()
  ffi.Pointer<Evas_Object> ime_get_main_window() {
    return _ime_get_main_window();
  }

  late final _ime_get_main_windowPtr =
      _lookup<ffi.NativeFunction<ffi.Pointer<Evas_Object> Function()>>(
          'ime_get_main_window');
  late final _ime_get_main_window =
      _ime_get_main_windowPtr.asFunction<ffi.Pointer<Evas_Object> Function()>();

  /// @brief This API updates the input panel window's size information.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] portrait_width The width in portrait mode
  /// @param[in] portrait_height The height in portrait mode
  /// @param[in] landscape_width The width in landscape mode
  /// @param[in] landscape_height The height in landscape mode
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @see ime_create_cb()
  int ime_set_size(
    int portrait_width,
    int portrait_height,
    int landscape_width,
    int landscape_height,
  ) {
    return _ime_set_size(
      portrait_width,
      portrait_height,
      landscape_width,
      landscape_height,
    );
  }

  late final _ime_set_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int, ffi.Int, ffi.Int, ffi.Int)>>('ime_set_size');
  late final _ime_set_size =
      _ime_set_sizePtr.asFunction<int Function(int, int, int, int)>();

  /// @brief Requests to create an option window from the input panel.
  ///
  /// @details The input panel can call this function to open the option window. This
  /// function calls ime_option_window_created_cb() callback function with
  /// #IME_OPTION_WINDOW_TYPE_KEYBOARD parameter.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NO_CALLBACK_FUNCTION Necessary callback function is not set
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  /// @retval #IME_ERROR_OPERATION_FAILED Operation failed
  ///
  /// @pre The ime_option_window_created_cb() and ime_option_window_destroyed_cb()
  /// callback functions MUST be set by ime_event_set_option_window_created_cb() and
  /// ime_event_set_option_window_destroyed_cb() respectively.
  ///
  /// @post This function calls ime_option_window_created_cb() callback function to
  /// create the option window. And ime_destroy_option_window() function can be called
  /// to close the option window.
  ///
  /// @see ime_event_set_option_window_created_cb()
  /// @see ime_option_window_created_cb()
  /// @see ime_destroy_option_window()
  int ime_create_option_window() {
    return _ime_create_option_window();
  }

  late final _ime_create_option_windowPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'ime_create_option_window');
  late final _ime_create_option_window =
      _ime_create_option_windowPtr.asFunction<int Function()>();

  /// @brief Requests to destroy an option window.
  ///
  /// @details The input panel can call this function to close the option window which
  /// is created from either the input panel or Settings application.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] window The option window to destroy
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NO_CALLBACK_FUNCTION Necessary callback function is not set
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @pre The ime_option_window_created_cb() and ime_option_window_destroyed_cb()
  /// callback functions MUST be set by ime_event_set_option_window_created_cb() and
  /// ime_event_set_option_window_destroyed_cb() respectively.
  ///
  /// @post This function calls ime_option_window_destroyed_cb() callback function
  /// to destroy the option window.
  ///
  /// @see ime_event_set_option_window_destroyed_cb()
  /// @see ime_option_window_destroyed_cb()
  /// @see ime_create_option_window()
  int ime_destroy_option_window(
    ffi.Pointer<Evas_Object> window,
  ) {
    return _ime_destroy_option_window(
      window,
    );
  }

  late final _ime_destroy_option_windowPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<Evas_Object>)>>(
          'ime_destroy_option_window');
  late final _ime_destroy_option_window = _ime_destroy_option_windowPtr
      .asFunction<int Function(ffi.Pointer<Evas_Object>)>();

  /// @brief Gets the layout information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the layout information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] layout Layout information
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  /// @see ime_layout_set_cb()
  int ime_context_get_layout(
    ime_context_h context,
    ffi.Pointer<ffi.Int32> layout,
  ) {
    return _ime_context_get_layout(
      context,
      layout,
    );
  }

  late final _ime_context_get_layoutPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Int32>)>>('ime_context_get_layout');
  late final _ime_context_get_layout = _ime_context_get_layoutPtr
      .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the layout variation information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the layout variation information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] layout_variation Layout variation information
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  /// @see ime_layout_variation_e
  int ime_context_get_layout_variation(
    ime_context_h context,
    ffi.Pointer<ffi.Int32> layout_variation,
  ) {
    return _ime_context_get_layout_variation(
      context,
      layout_variation,
    );
  }

  late final _ime_context_get_layout_variationPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Int32>)>>('ime_context_get_layout_variation');
  late final _ime_context_get_layout_variation =
      _ime_context_get_layout_variationPtr
          .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the cursor position information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the cursor position information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] cursor_pos Cursor position information
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  /// @see ime_cursor_position_updated_cb()
  int ime_context_get_cursor_position(
    ime_context_h context,
    ffi.Pointer<ffi.Int> cursor_pos,
  ) {
    return _ime_context_get_cursor_position(
      context,
      cursor_pos,
    );
  }

  late final _ime_context_get_cursor_positionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Int>)>>('ime_context_get_cursor_position');
  late final _ime_context_get_cursor_position =
      _ime_context_get_cursor_positionPtr
          .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the autocapital type information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the autocapital type information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] autocapital_type Autocapital type information
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  int ime_context_get_autocapital_type(
    ime_context_h context,
    ffi.Pointer<ffi.Int32> autocapital_type,
  ) {
    return _ime_context_get_autocapital_type(
      context,
      autocapital_type,
    );
  }

  late final _ime_context_get_autocapital_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Int32>)>>('ime_context_get_autocapital_type');
  late final _ime_context_get_autocapital_type =
      _ime_context_get_autocapital_typePtr
          .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the @c Return key label type information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the @c Return key label type information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] return_key_type The @c Return key label type information
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  /// @see ime_return_key_type_set_cb()
  int ime_context_get_return_key_type(
    ime_context_h context,
    ffi.Pointer<ffi.Int32> return_key_type,
  ) {
    return _ime_context_get_return_key_type(
      context,
      return_key_type,
    );
  }

  late final _ime_context_get_return_key_typePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Int32>)>>('ime_context_get_return_key_type');
  late final _ime_context_get_return_key_type =
      _ime_context_get_return_key_typePtr
          .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the @c Return key state information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the @c Return key state information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] return_key_state The @c Return key state information \n @c true to enable @c Return key
  /// button, @c false to disable @c Return key button
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  /// @see ime_return_key_state_set_cb()
  int ime_context_get_return_key_state(
    ime_context_h context,
    ffi.Pointer<ffi.Bool> return_key_state,
  ) {
    return _ime_context_get_return_key_state(
      context,
      return_key_state,
    );
  }

  late final _ime_context_get_return_key_statePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Bool>)>>('ime_context_get_return_key_state');
  late final _ime_context_get_return_key_state =
      _ime_context_get_return_key_statePtr
          .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the prediction mode information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the prediction mode information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] prediction_mode Prediction mode information \n @c true to allow the predictive
  /// text feature if available, @c false to disable the predictive text feature
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  int ime_context_get_prediction_mode(
    ime_context_h context,
    ffi.Pointer<ffi.Bool> prediction_mode,
  ) {
    return _ime_context_get_prediction_mode(
      context,
      prediction_mode,
    );
  }

  late final _ime_context_get_prediction_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Bool>)>>('ime_context_get_prediction_mode');
  late final _ime_context_get_prediction_mode =
      _ime_context_get_prediction_modePtr
          .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the password mode information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the password mode information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks If @a password_mode is @c true, the input panel is advised not to support the predictive text.
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] password_mode Password mode information \n @c true to indicate that a password being inputted,
  /// @c false to indicate non-password edit field.
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  int ime_context_get_password_mode(
    ime_context_h context,
    ffi.Pointer<ffi.Bool> password_mode,
  ) {
    return _ime_context_get_password_mode(
      context,
      password_mode,
    );
  }

  late final _ime_context_get_password_modePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Bool>)>>('ime_context_get_password_mode');
  late final _ime_context_get_password_mode = _ime_context_get_password_modePtr
      .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Bool>)>();

  /// @brief Gets the input hint information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the input hint information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks @a input_hint is a bit-wise value which recommends the input panel provide
  /// an auto completion and so on if it is capable of supporting such features.
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] input_hint Input hint information
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  int ime_context_get_input_hint(
    ime_context_h context,
    ffi.Pointer<ffi.Int32> input_hint,
  ) {
    return _ime_context_get_input_hint(
      context,
      input_hint,
    );
  }

  late final _ime_context_get_input_hintPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Int32>)>>('ime_context_get_input_hint');
  late final _ime_context_get_input_hint = _ime_context_get_input_hintPtr
      .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the text bidirectional information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the bidirectional information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] bidi Text bidirectional information
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  int ime_context_get_bidi_direction(
    ime_context_h context,
    ffi.Pointer<ffi.Int32> bidi,
  ) {
    return _ime_context_get_bidi_direction(
      context,
      bidi,
    );
  }

  late final _ime_context_get_bidi_directionPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Int32>)>>('ime_context_get_bidi_direction');
  late final _ime_context_get_bidi_direction =
      _ime_context_get_bidi_directionPtr
          .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the preferred language information from the given input context.
  ///
  /// @details Each edit field has various attributes for input panel. This function can be
  /// called to get the preferred language information in ime_show_cb() callback function.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] context The input context information of an associated text input UI control
  /// @param[out] language Preferred language information
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @post Input panel UI should be drawn or operated by this information accordingly.
  ///
  /// @see ime_show_cb()
  int ime_context_get_language(
    ime_context_h context,
    ffi.Pointer<ffi.Int32> language,
  ) {
    return _ime_context_get_language(
      context,
      language,
    );
  }

  late final _ime_context_get_languagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_context_h,
              ffi.Pointer<ffi.Int32>)>>('ime_context_get_language');
  late final _ime_context_get_language = _ime_context_get_languagePtr
      .asFunction<int Function(ime_context_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the device name of the key event.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks @a dev_name must be released using free().
  ///
  /// @param[in] dev_info The device information from the key event
  /// @param[out] dev_name The name of key input device. This can be an empty string if the device name is not available
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @see ime_process_key_event_cb()
  /// @see ime_device_info_get_class()
  /// @see ime_device_info_get_subclass()
  int ime_device_info_get_name(
    ime_device_info_h dev_info,
    ffi.Pointer<ffi.Pointer<ffi.Char>> dev_name,
  ) {
    return _ime_device_info_get_name(
      dev_info,
      dev_name,
    );
  }

  late final _ime_device_info_get_namePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_device_info_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('ime_device_info_get_name');
  late final _ime_device_info_get_name =
      _ime_device_info_get_namePtr.asFunction<
          int Function(
              ime_device_info_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the device class of the key event.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] dev_info The device information from the key event
  /// @param[out] dev_class The class of key input device. This can be #ECORE_IMF_DEVICE_CLASS_NONE if the device class is not available
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @see ime_process_key_event_cb()
  /// @see ime_device_info_get_name()
  /// @see ime_device_info_get_subclass()
  int ime_device_info_get_class(
    ime_device_info_h dev_info,
    ffi.Pointer<ffi.Int32> dev_class,
  ) {
    return _ime_device_info_get_class(
      dev_info,
      dev_class,
    );
  }

  late final _ime_device_info_get_classPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_device_info_h,
              ffi.Pointer<ffi.Int32>)>>('ime_device_info_get_class');
  late final _ime_device_info_get_class = _ime_device_info_get_classPtr
      .asFunction<int Function(ime_device_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the device subclass of the key event.
  ///
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] dev_info The device information from the key event
  /// @param[out] dev_subclass The subclass of key input device. This can be #ECORE_IMF_DEVICE_SUBCLASS_NONE if the device subclass is not available
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @see ime_process_key_event_cb()
  /// @see ime_device_info_get_name()
  /// @see ime_device_info_get_class()
  int ime_device_info_get_subclass(
    ime_device_info_h dev_info,
    ffi.Pointer<ffi.Int32> dev_subclass,
  ) {
    return _ime_device_info_get_subclass(
      dev_info,
      dev_subclass,
    );
  }

  late final _ime_device_info_get_subclassPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_device_info_h,
              ffi.Pointer<ffi.Int32>)>>('ime_device_info_get_subclass');
  late final _ime_device_info_get_subclass = _ime_device_info_get_subclassPtr
      .asFunction<int Function(ime_device_info_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets prediction hint event callback function.
  ///
  /// @since_tizen 4.0
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_prediction_hint_set_cb() callback function is called to set the prediction
  /// hint string to deliver to the input panel.
  ///
  /// @param[in] callback_func The prediction hint event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_prediction_hint_set_cb()
  /// @see ime_run()
  int ime_event_set_prediction_hint_set_cb(
    ime_prediction_hint_set_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_prediction_hint_set_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_prediction_hint_set_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ime_prediction_hint_set_cb,
              ffi.Pointer<ffi.Void>)>>('ime_event_set_prediction_hint_set_cb');
  late final _ime_event_set_prediction_hint_set_cb =
      _ime_event_set_prediction_hint_set_cbPtr.asFunction<
          int Function(ime_prediction_hint_set_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets MIME type event callback function.
  ///
  /// @since_tizen 4.0
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks The ime_mime_type_set_request_cb() callback function is called when an associated text input
  /// UI control requests the text entry to set the MIME type.
  ///
  /// @param[in] callback_func MIME type event callback function
  /// @param[in] user_data User data to be passed to the callback function
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  ///
  /// @post The ime_run() function should be called to start to run IME application's main loop.
  ///
  /// @see ime_mime_type_set_request_cb()
  /// @see ime_run()
  int ime_event_set_mime_type_set_request_cb(
    ime_mime_type_set_request_cb callback_func,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ime_event_set_mime_type_set_request_cb(
      callback_func,
      user_data,
    );
  }

  late final _ime_event_set_mime_type_set_request_cbPtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(
                  ime_mime_type_set_request_cb, ffi.Pointer<ffi.Void>)>>(
      'ime_event_set_mime_type_set_request_cb');
  late final _ime_event_set_mime_type_set_request_cb =
      _ime_event_set_mime_type_set_request_cbPtr.asFunction<
          int Function(ime_mime_type_set_request_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Sends a private command to the associated text input UI control.
  ///
  /// @details This can be used by IME to deliver specific data to an application.
  /// The data format MUST be negotiated by both application and IME.
  ///
  /// @since_tizen 4.0
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] command The UTF-8 string to be sent
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  int ime_send_private_command(
    ffi.Pointer<ffi.Char> command,
  ) {
    return _ime_send_private_command(
      command,
    );
  }

  late final _ime_send_private_commandPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'ime_send_private_command');
  late final _ime_send_private_command = _ime_send_private_commandPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Commits contents such as image to the associated text input UI control.
  ///
  /// @since_tizen 4.0
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] content The content URI to be sent
  /// @param[in] description The content description
  /// @param[in] mime_type The MIME type received from the ime_mime_type_set_request_cb()
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @see ime_mime_type_set_request_cb()
  /// @see ime_event_set_mime_type_set_request_cb()
  int ime_commit_content(
    ffi.Pointer<ffi.Char> content,
    ffi.Pointer<ffi.Char> description,
    ffi.Pointer<ffi.Char> mime_type,
  ) {
    return _ime_commit_content(
      content,
      description,
      mime_type,
    );
  }

  late final _ime_commit_contentPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('ime_commit_content');
  late final _ime_commit_content = _ime_commit_contentPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the floating mode or not.
  ///
  /// @since_tizen 4.0
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @param[in] floating_mode @c true - floating mode on, @c false - floating mode off
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @see ime_set_floating_drag_start()
  /// @see ime_set_floating_drag_end()
  int ime_set_floating_mode(
    bool floating_mode,
  ) {
    return _ime_set_floating_mode(
      floating_mode,
    );
  }

  late final _ime_set_floating_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Bool)>>(
          'ime_set_floating_mode');
  late final _ime_set_floating_mode =
      _ime_set_floating_modePtr.asFunction<int Function(bool)>();

  /// @brief Allows the floating input panel window to move along with the mouse pointer when the mouse is pressed.
  ///
  /// @since_tizen 4.0
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks This function can be used in floating mode. If the floating mode is deactivated, calling this function has no effect.
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @pre The floating mode was turned on with ime_set_floating_mode().
  ///
  /// @see ime_set_floating_mode()
  /// @see ime_set_floating_drag_end()
  int ime_set_floating_drag_start() {
    return _ime_set_floating_drag_start();
  }

  late final _ime_set_floating_drag_startPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'ime_set_floating_drag_start');
  late final _ime_set_floating_drag_start =
      _ime_set_floating_drag_startPtr.asFunction<int Function()>();

  /// @brief Disallows the movement of the floating input panel window with the mouse pointer when the mouse is pressed.
  ///
  /// @details This function must be called after invoking ime_set_floating_drag_start(). Otherwise the call is ignored.
  ///
  /// @since_tizen 4.0
  ///
  /// @privlevel public
  ///
  /// @privilege %http://tizen.org/privilege/ime
  ///
  /// @remarks This function can be used in floating mode. If the floating mode is deactivated, calling this function has no effect.
  ///
  /// @return 0 on success, otherwise a negative error value
  /// @retval #IME_ERROR_NONE No error
  /// @retval #IME_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_ERROR_NOT_RUNNING IME main loop isn't started yet
  ///
  /// @pre The floating mode was turned on with ime_set_floating_mode().
  /// @pre ime_set_floating_drag_start() was called before.
  ///
  /// @see ime_set_floating_mode()
  /// @see ime_set_floating_drag_start()
  int ime_set_floating_drag_end() {
    return _ime_set_floating_drag_end();
  }

  late final _ime_set_floating_drag_endPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'ime_set_floating_drag_end');
  late final _ime_set_floating_drag_end =
      _ime_set_floating_drag_endPtr.asFunction<int Function()>();

  /// @brief Requests to open the installed IME list menu.
  /// @details This function provides the installed IME list menu for the IME developers who might want to open it to enable their IME.
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/imemanager
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IME_MANAGER_ERROR_NONE No error
  /// @retval #IME_MANAGER_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_MANAGER_ERROR_OPERATION_FAILED Operation failed
  /// @see ime_manager_show_ime_selector()
  int ime_manager_show_ime_list() {
    return _ime_manager_show_ime_list();
  }

  late final _ime_manager_show_ime_listPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'ime_manager_show_ime_list');
  late final _ime_manager_show_ime_list =
      _ime_manager_show_ime_listPtr.asFunction<int Function()>();

  /// @brief Requests to open the IME selector menu.
  /// @details This function provides the IME selector menu for the IME or other application developers who might want to change the default IME.
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/imemanager
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IME_MANAGER_ERROR_NONE No error
  /// @retval #IME_MANAGER_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_MANAGER_ERROR_OPERATION_FAILED Operation failed
  /// @see ime_manager_show_ime_list()
  int ime_manager_show_ime_selector() {
    return _ime_manager_show_ime_selector();
  }

  late final _ime_manager_show_ime_selectorPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'ime_manager_show_ime_selector');
  late final _ime_manager_show_ime_selector =
      _ime_manager_show_ime_selectorPtr.asFunction<int Function()>();

  /// @brief Checks if the specific IME is enabled or disabled in the system keyboard setting.
  /// @details The IME developers can use this function to check their IME is enabled or not.
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/imemanager
  /// @param[in] app_id The application ID of the IME
  /// @param[out] enabled The On (enabled) and Off (disabled) state of the IME
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IME_MANAGER_ERROR_NONE No error
  /// @retval #IME_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_MANAGER_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_MANAGER_ERROR_OPERATION_FAILED Operation failed
  /// @see ime_manager_show_ime_list()
  int ime_manager_is_ime_enabled(
    ffi.Pointer<ffi.Char> app_id,
    ffi.Pointer<ffi.Bool> enabled,
  ) {
    return _ime_manager_is_ime_enabled(
      app_id,
      enabled,
    );
  }

  late final _ime_manager_is_ime_enabledPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('ime_manager_is_ime_enabled');
  late final _ime_manager_is_ime_enabled = _ime_manager_is_ime_enabledPtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief Checks which IME is the current activated (selected) IME.
  /// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
  /// @remarks @a app_id must be released using free().
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/imemanager
  /// @param[out] app_id The application ID of the active IME
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #IME_MANAGER_ERROR_NONE No error
  /// @retval #IME_MANAGER_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #IME_MANAGER_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @retval #IME_MANAGER_ERROR_OPERATION_FAILED Operation failed
  /// @see ime_manager_show_ime_selector()
  int ime_manager_get_active_ime(
    ffi.Pointer<ffi.Pointer<ffi.Char>> app_id,
  ) {
    return _ime_manager_get_active_ime(
      app_id,
    );
  }

  late final _ime_manager_get_active_imePtr = _lookup<
          ffi.NativeFunction<
              ffi.Int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>>(
      'ime_manager_get_active_ime');
  late final _ime_manager_get_active_ime = _ime_manager_get_active_imePtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the number of IMEs which are enabled (usable).
  /// @since_tizen 3.0
  /// @remarks The specific error code can be obtained using the get_last_result() method.
  /// Error codes are described in Exception section.
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/imemanager
  /// @return The @a number of enabled IMEs on success,
  /// otherwise @c 0
  /// @exception IME_MANAGER_ERROR_NONE Successful
  /// @exception IME_MANAGER_ERROR_PERMISSION_DENIED The application does not have the privilege to call this function
  /// @exception IME_MANAGER_ERROR_OPERATION_FAILED Operation failed
  /// @see ime_manager_is_ime_enabled()
  /// @see ime_manager_show_ime_selector()
  int ime_manager_get_enabled_ime_count() {
    return _ime_manager_get_enabled_ime_count();
  }

  late final _ime_manager_get_enabled_ime_countPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'ime_manager_get_enabled_ime_count');
  late final _ime_manager_get_enabled_ime_count =
      _ime_manager_get_enabled_ime_countPtr.asFunction<int Function()>();

  /// @brief Creates a STT handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks If the function succeeds, @a stt handle must be released with stt_destroy().
  /// @param[out] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @post If this function is called, the STT state will be #STT_STATE_CREATED.
  /// @see stt_destroy()
  int stt_create(
    ffi.Pointer<stt_h> stt,
  ) {
    return _stt_create(
      stt,
    );
  }

  late final _stt_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<stt_h>)>>(
          'stt_create');
  late final _stt_create =
      _stt_createPtr.asFunction<int Function(ffi.Pointer<stt_h>)>();

  /// @brief Destroys a STT handle.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @see stt_create()
  int stt_destroy(
    stt_h stt,
  ) {
    return _stt_destroy(
      stt,
    );
  }

  late final _stt_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>('stt_destroy');
  late final _stt_destroy = _stt_destroyPtr.asFunction<int Function(stt_h)>();

  /// @brief Retrieves supported engine information using a callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Success
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE STT Not initialized
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @post This function invokes stt_supported_engine_cb() repeatedly for getting engine information.
  /// @see stt_supported_engine_cb()
  int stt_foreach_supported_engines(
    stt_h stt,
    stt_supported_engine_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _stt_foreach_supported_engines(
      stt,
      callback,
      user_data,
    );
  }

  late final _stt_foreach_supported_enginesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, stt_supported_engine_cb,
              ffi.Pointer<ffi.Void>)>>('stt_foreach_supported_engines');
  late final _stt_foreach_supported_engines =
      _stt_foreach_supported_enginesPtr.asFunction<
          int Function(
              stt_h, stt_supported_engine_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the current engine ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks If the function is success, @a engine_id must be released using free().
  /// @param[in] stt The STT handle
  /// @param[out] engine_id Engine ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Success
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE STT Not initialized
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_set_engine()
  int stt_get_engine(
    stt_h stt,
    ffi.Pointer<ffi.Pointer<ffi.Char>> engine_id,
  ) {
    return _stt_get_engine(
      stt,
      engine_id,
    );
  }

  late final _stt_get_enginePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              stt_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('stt_get_engine');
  late final _stt_get_engine = _stt_get_enginePtr
      .asFunction<int Function(stt_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Sets the engine ID.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @privilege %http://tizen.org/privilege/appmanager.launch
  /// @remarks A privilege (%http://tizen.org/privilege/appmanager.launch) is necessary since 3.0.
  /// @param[in] stt The STT handle
  /// @param[in] engine_id Engine ID
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Success
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE STT Not initialized
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_get_engine()
  int stt_set_engine(
    stt_h stt,
    ffi.Pointer<ffi.Char> engine_id,
  ) {
    return _stt_set_engine(
      stt,
      engine_id,
    );
  }

  late final _stt_set_enginePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(stt_h, ffi.Pointer<ffi.Char>)>>(
      'stt_set_engine');
  late final _stt_set_engine = _stt_set_enginePtr
      .asFunction<int Function(stt_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the app credential.
  /// @details Using this API, the application can set a credential.
  /// The credential is a key to verify the authorization about using the engine.
  /// If the application sets the credential, it will be able to use functions of the engine entirely.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @remarks The necessity of the credential depends on the engine. In case of the engine which is basically embedded in Tizen, the credential is not necessary so far.
  /// However, if the user wants to apply the 3rd party's engine, the credential may be necessary. In that case, please follow the policy provided by the corresponding engine.
  /// @param[in] stt The STT handle
  /// @param[in] credential The app credential
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Success
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @pre The state should be #STT_STATE_CREATED or #STT_STATE_READY.
  /// @see stt_start()
  int stt_set_credential(
    stt_h stt,
    ffi.Pointer<ffi.Char> credential,
  ) {
    return _stt_set_credential(
      stt,
      credential,
    );
  }

  late final _stt_set_credentialPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(stt_h, ffi.Pointer<ffi.Char>)>>(
      'stt_set_credential');
  late final _stt_set_credential = _stt_set_credentialPtr
      .asFunction<int Function(stt_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets the private data to stt engine.
  /// @details The private data is the setting parameter for applying keys provided by the engine.
  /// Using this API, the application can set the private data and use the corresponding key of the engine.
  /// For example, if the engine provides 'partial recognition' as a recognition type, the application can set the private data as the following.
  /// int ret = stt_set_private_data(stt_h, "recognition_type", "PARTIAL");
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @remarks If the engine is replaced with the other engine, the key may be ignored.
  /// @param[in] stt The STT handle
  /// @param[in] key The field name of private data
  /// @param[in] data The data for set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_TIMED_OUT No answer from the STT service
  /// @pre The state should be #STT_STATE_READY.
  /// @see stt_get_private_data()
  int stt_set_private_data(
    stt_h stt,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> data,
  ) {
    return _stt_set_private_data(
      stt,
      key,
      data,
    );
  }

  late final _stt_set_private_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('stt_set_private_data');
  late final _stt_set_private_data = _stt_set_private_dataPtr.asFunction<
      int Function(stt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the private data from stt engine.
  /// @details The private data is the information provided by the engine.
  /// Using this API, the application can get the private data which corresponds to the key from the engine.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @remarks If the engine is replaced with the other engine, the key may be ignored.
  /// @remarks The @a data must be released using free() when it is no longer required.
  /// @param[in] stt The STT handle
  /// @param[in] key The field name of private data
  /// @param[out] data The data field of private data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_TIMED_OUT No answer from the STT service
  /// @pre The state should be #STT_STATE_READY.
  /// @see stt_set_private_data()
  int stt_get_private_data(
    stt_h stt,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> data,
  ) {
    return _stt_get_private_data(
      stt,
      key,
      data,
    );
  }

  late final _stt_get_private_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('stt_get_private_data');
  late final _stt_get_private_data = _stt_get_private_dataPtr.asFunction<
      int Function(
          stt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Connects the STT service asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @post If this function is successful, the STT state will be #STT_STATE_READY.
  /// If this function is failed, the error callback is called. (e.g. #STT_ERROR_ENGINE_NOT_FOUND)
  /// @see stt_unprepare()
  int stt_prepare(
    stt_h stt,
  ) {
    return _stt_prepare(
      stt,
    );
  }

  late final _stt_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>('stt_prepare');
  late final _stt_prepare = _stt_preparePtr.asFunction<int Function(stt_h)>();

  /// @brief Disconnects the STT service.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_READY.
  /// @post If this function is called, the STT state will be #STT_STATE_CREATED.
  /// @see stt_prepare()
  int stt_unprepare(
    stt_h stt,
  ) {
    return _stt_unprepare(
      stt,
    );
  }

  late final _stt_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>('stt_unprepare');
  late final _stt_unprepare =
      _stt_unpreparePtr.asFunction<int Function(stt_h)>();

  /// @brief Retrieves all supported languages of current engine using callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_ENGINE_NOT_FOUND No available engine
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @post This function invokes stt_supported_language_cb() repeatedly for getting languages.
  /// @see stt_supported_language_cb()
  /// @see stt_get_default_language()
  int stt_foreach_supported_languages(
    stt_h stt,
    stt_supported_language_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _stt_foreach_supported_languages(
      stt,
      callback,
      user_data,
    );
  }

  late final _stt_foreach_supported_languagesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, stt_supported_language_cb,
              ffi.Pointer<ffi.Void>)>>('stt_foreach_supported_languages');
  late final _stt_foreach_supported_languages =
      _stt_foreach_supported_languagesPtr.asFunction<
          int Function(
              stt_h, stt_supported_language_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the default language set by the user.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks The language is specified as an ISO 3166 alpha-2 two letter country-code followed by ISO 639-1 for the two-letter language code.
  /// For example, "ko_KR" for Korean, "en_US" for American English.
  /// If the function succeeds, @a language must be released using free() when it is no longer required.
  /// @param[in] stt The STT handle
  /// @param[out] language The language
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @see stt_foreach_supported_languages()
  int stt_get_default_language(
    stt_h stt,
    ffi.Pointer<ffi.Pointer<ffi.Char>> language,
  ) {
    return _stt_get_default_language(
      stt,
      language,
    );
  }

  late final _stt_get_default_languagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('stt_get_default_language');
  late final _stt_get_default_language = _stt_get_default_languagePtr
      .asFunction<int Function(stt_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the current STT state.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @param[out] state The current STT state
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @see stt_start()
  /// @see stt_stop()
  /// @see stt_cancel()
  /// @see stt_state_changed_cb()
  int stt_get_state(
    stt_h stt,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _stt_get_state(
      stt,
      state,
    );
  }

  late final _stt_get_statePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(stt_h, ffi.Pointer<ffi.Int32>)>>(
      'stt_get_state');
  late final _stt_get_state = _stt_get_statePtr
      .asFunction<int Function(stt_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the current error message.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @remarks This function should be called during an stt error callback. If not, the error as operation failure will be returned.
  /// If the function succeeds, @a err_msg must be released using free() when it is no longer required.
  /// @param[in] stt The STT handle
  /// @param[out] err_msg The current error message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @see stt_set_error_cb()
  /// @see stt_unset_error_cb()
  int stt_get_error_message(
    stt_h stt,
    ffi.Pointer<ffi.Pointer<ffi.Char>> err_msg,
  ) {
    return _stt_get_error_message(
      stt,
      err_msg,
    );
  }

  late final _stt_get_error_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('stt_get_error_message');
  late final _stt_get_error_message = _stt_get_error_messagePtr
      .asFunction<int Function(stt_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Checks whether the recognition type is supported.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @param[in] type The type for recognition (e.g. #STT_RECOGNITION_TYPE_FREE, #STT_RECOGNITION_TYPE_FREE_PARTIAL)
  /// @param[out] support The result status @c true = supported,
  /// @c false = not supported
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_READY.
  int stt_is_recognition_type_supported(
    stt_h stt,
    ffi.Pointer<ffi.Char> type,
    ffi.Pointer<ffi.Bool> support,
  ) {
    return _stt_is_recognition_type_supported(
      stt,
      type,
      support,
    );
  }

  late final _stt_is_recognition_type_supportedPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Bool>)>>('stt_is_recognition_type_supported');
  late final _stt_is_recognition_type_supported =
      _stt_is_recognition_type_supportedPtr.asFunction<
          int Function(stt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>();

  /// @brief Sets the silence detection.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @param[in] type The option type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED_FEATURE Not supported feature of current engine
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_READY.
  int stt_set_silence_detection(
    stt_h stt,
    int type,
  ) {
    return _stt_set_silence_detection(
      stt,
      type,
    );
  }

  late final _stt_set_silence_detectionPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h, ffi.Int32)>>(
          'stt_set_silence_detection');
  late final _stt_set_silence_detection =
      _stt_set_silence_detectionPtr.asFunction<int Function(stt_h, int)>();

  /// @brief Sets the sound to start recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks Sound file type should be wav type.
  /// @param[in] stt The STT handle
  /// @param[in] filename The sound file path
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_READY.
  int stt_set_start_sound(
    stt_h stt,
    ffi.Pointer<ffi.Char> filename,
  ) {
    return _stt_set_start_sound(
      stt,
      filename,
    );
  }

  late final _stt_set_start_soundPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(stt_h, ffi.Pointer<ffi.Char>)>>(
      'stt_set_start_sound');
  late final _stt_set_start_sound = _stt_set_start_soundPtr
      .asFunction<int Function(stt_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Unsets the sound to start recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_READY.
  int stt_unset_start_sound(
    stt_h stt,
  ) {
    return _stt_unset_start_sound(
      stt,
    );
  }

  late final _stt_unset_start_soundPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>(
          'stt_unset_start_sound');
  late final _stt_unset_start_sound =
      _stt_unset_start_soundPtr.asFunction<int Function(stt_h)>();

  /// @brief Sets the sound to stop recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks Sound file type should be wav type.
  /// @param[in] stt The STT handle
  /// @param[in] filename The sound file path
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_READY.
  int stt_set_stop_sound(
    stt_h stt,
    ffi.Pointer<ffi.Char> filename,
  ) {
    return _stt_set_stop_sound(
      stt,
      filename,
    );
  }

  late final _stt_set_stop_soundPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(stt_h, ffi.Pointer<ffi.Char>)>>(
      'stt_set_stop_sound');
  late final _stt_set_stop_sound = _stt_set_stop_soundPtr
      .asFunction<int Function(stt_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Unsets the sound to stop recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_READY.
  int stt_unset_stop_sound(
    stt_h stt,
  ) {
    return _stt_unset_stop_sound(
      stt,
    );
  }

  late final _stt_unset_stop_soundPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>(
          'stt_unset_stop_sound');
  late final _stt_unset_stop_sound =
      _stt_unset_stop_soundPtr.asFunction<int Function(stt_h)>();

  /// @brief Starts recording and recognition asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks This function starts recording in the STT service and sending recording data to engine.
  /// This work continues until stt_stop(), stt_cancel() or silence detected by engine.
  /// @param[in] stt The STT handle
  /// @param[in] language The language selected from stt_foreach_supported_languages()
  /// @param[in] type The type for recognition (e.g. #STT_RECOGNITION_TYPE_FREE, #STT_RECOGNITION_TYPE_FREE_PARTIAL)
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_RECORDER_BUSY Recorder busy
  /// @retval #STT_ERROR_INVALID_LANGUAGE Invalid language
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #STT_ERROR_IN_PROGRESS_TO_RECORDING Progress to recording is not finished
  /// @pre The state should be #STT_STATE_READY.
  /// @post It will invoke stt_state_changed_cb(), if you register a callback with stt_state_changed_cb().
  /// If this function succeeds, the STT state will be #STT_STATE_RECORDING.
  /// If you call this function again before state changes, you will receive STT_ERROR_IN_PROGRESS_TO_RECORDING.
  /// @see stt_stop()
  /// @see stt_cancel()
  /// @see stt_state_changed_cb()
  int stt_start(
    stt_h stt,
    ffi.Pointer<ffi.Char> language,
    ffi.Pointer<ffi.Char> type,
  ) {
    return _stt_start(
      stt,
      language,
      type,
    );
  }

  late final _stt_startPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('stt_start');
  late final _stt_start = _stt_startPtr.asFunction<
      int Function(stt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Finishes the recording and starts recognition processing in engine asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #STT_ERROR_IN_PROGRESS_TO_READY Progress to ready is not finished
  /// @retval #STT_ERROR_IN_PROGRESS_TO_RECORDING Progress to recording is not finished
  /// @retval #STT_ERROR_IN_PROGRESS_TO_PROCESSING Progress to processing is not finished
  /// @pre The state should be #STT_STATE_RECORDING.
  /// @post It will invoke stt_state_changed_cb(), if you register a callback with stt_state_changed_cb().
  /// If this function succeeds, the STT state will be #STT_STATE_PROCESSING.
  /// If you call this function again before state changes, you will receive STT_ERROR_IN_PROGRESS_TO_PROCESSING.
  /// After processing of engine, stt_result_cb() is called.
  /// @see stt_start()
  /// @see stt_cancel()
  /// @see stt_state_changed_cb()
  int stt_stop(
    stt_h stt,
  ) {
    return _stt_stop(
      stt,
    );
  }

  late final _stt_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>('stt_stop');
  late final _stt_stop = _stt_stopPtr.asFunction<int Function(stt_h)>();

  /// @brief Cancels processing recognition and recording asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks This function cancels recording and engine cancels recognition processing.
  /// After successful cancel, stt_state_changed_cb() is called otherwise if error is occurred, stt_error_cb() is called.
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #STT_ERROR_IN_PROGRESS_TO_READY Progress to ready is not finished
  /// @retval #STT_ERROR_IN_PROGRESS_TO_RECORDING Progress to recording is not finished
  /// @retval #STT_ERROR_IN_PROGRESS_TO_PROCESSING Progress to processing is not finished
  /// @pre The state should be #STT_STATE_RECORDING or #STT_STATE_PROCESSING.
  /// @post It will invoke stt_state_changed_cb(), if you register a callback with stt_state_changed_cb().
  /// If this function succeeds, the STT state will be #STT_STATE_READY.
  /// If you call this function again before state changes, you will receive STT_ERROR_IN_PROGRESS_TO_READY.
  /// @see stt_start()
  /// @see stt_stop()
  /// @see stt_state_changed_cb()
  int stt_cancel(
    stt_h stt,
  ) {
    return _stt_cancel(
      stt,
    );
  }

  late final _stt_cancelPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>('stt_cancel');
  late final _stt_cancel = _stt_cancelPtr.asFunction<int Function(stt_h)>();

  /// @brief Gets the microphone volume during recording.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @param[out] volume Recording volume
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_RECORDING.
  /// @see stt_start()
  int stt_get_recording_volume(
    stt_h stt,
    ffi.Pointer<ffi.Float> volume,
  ) {
    return _stt_get_recording_volume(
      stt,
      volume,
    );
  }

  late final _stt_get_recording_volumePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(stt_h, ffi.Pointer<ffi.Float>)>>(
      'stt_get_recording_volume');
  late final _stt_get_recording_volume = _stt_get_recording_volumePtr
      .asFunction<int Function(stt_h, ffi.Pointer<ffi.Float>)>();

  /// @brief Retrieves the time stamp of the current recognition result using the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks This function should be called in stt_recognition_result_cb().
  /// After stt_recognition_result_cb(), result data is NOT valid.
  /// @param[in] stt The STT handle
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_OPERATION_FAILED Operation failure
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre This function should be called in stt_recognition_result_cb().
  /// @post This function invokes stt_result_time_cb() repeatedly for getting time information.
  /// @see stt_result_time_cb()
  /// @see stt_recognition_result_cb()
  int stt_foreach_detailed_result(
    stt_h stt,
    stt_result_time_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _stt_foreach_detailed_result(
      stt,
      callback,
      user_data,
    );
  }

  late final _stt_foreach_detailed_resultPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, stt_result_time_cb,
              ffi.Pointer<ffi.Void>)>>('stt_foreach_detailed_result');
  late final _stt_foreach_detailed_result =
      _stt_foreach_detailed_resultPtr.asFunction<
          int Function(stt_h, stt_result_time_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Registers a callback function to get the recognition result.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_recognition_result_cb()
  /// @see stt_unset_recognition_result_cb()
  int stt_set_recognition_result_cb(
    stt_h stt,
    stt_recognition_result_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _stt_set_recognition_result_cb(
      stt,
      callback,
      user_data,
    );
  }

  late final _stt_set_recognition_result_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, stt_recognition_result_cb,
              ffi.Pointer<ffi.Void>)>>('stt_set_recognition_result_cb');
  late final _stt_set_recognition_result_cb =
      _stt_set_recognition_result_cbPtr.asFunction<
          int Function(
              stt_h, stt_recognition_result_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_set_recognition_result_cb()
  int stt_unset_recognition_result_cb(
    stt_h stt,
  ) {
    return _stt_unset_recognition_result_cb(
      stt,
    );
  }

  late final _stt_unset_recognition_result_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>(
          'stt_unset_recognition_result_cb');
  late final _stt_unset_recognition_result_cb =
      _stt_unset_recognition_result_cbPtr.asFunction<int Function(stt_h)>();

  /// @brief Registers a callback function to be called when STT state changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_state_changed_cb()
  /// @see stt_unset_state_changed_cb()
  int stt_set_state_changed_cb(
    stt_h stt,
    stt_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _stt_set_state_changed_cb(
      stt,
      callback,
      user_data,
    );
  }

  late final _stt_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, stt_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('stt_set_state_changed_cb');
  late final _stt_set_state_changed_cb =
      _stt_set_state_changed_cbPtr.asFunction<
          int Function(stt_h, stt_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_set_state_changed_cb()
  int stt_unset_state_changed_cb(
    stt_h stt,
  ) {
    return _stt_unset_state_changed_cb(
      stt,
    );
  }

  late final _stt_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>(
          'stt_unset_state_changed_cb');
  late final _stt_unset_state_changed_cb =
      _stt_unset_state_changed_cbPtr.asFunction<int Function(stt_h)>();

  /// @brief Registers a callback function to be called when an error occurred.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_error_cb()
  /// @see stt_unset_error_cb()
  int stt_set_error_cb(
    stt_h stt,
    stt_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _stt_set_error_cb(
      stt,
      callback,
      user_data,
    );
  }

  late final _stt_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              stt_h, stt_error_cb, ffi.Pointer<ffi.Void>)>>('stt_set_error_cb');
  late final _stt_set_error_cb = _stt_set_error_cbPtr
      .asFunction<int Function(stt_h, stt_error_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_set_error_cb()
  int stt_unset_error_cb(
    stt_h stt,
  ) {
    return _stt_unset_error_cb(
      stt,
    );
  }

  late final _stt_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>(
          'stt_unset_error_cb');
  late final _stt_unset_error_cb =
      _stt_unset_error_cbPtr.asFunction<int Function(stt_h)>();

  /// @brief Registers a callback function to detect the default language change.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_default_language_changed_cb()
  /// @see stt_unset_default_language_changed_cb()
  int stt_set_default_language_changed_cb(
    stt_h stt,
    stt_default_language_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _stt_set_default_language_changed_cb(
      stt,
      callback,
      user_data,
    );
  }

  late final _stt_set_default_language_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, stt_default_language_changed_cb,
              ffi.Pointer<ffi.Void>)>>('stt_set_default_language_changed_cb');
  late final _stt_set_default_language_changed_cb =
      _stt_set_default_language_changed_cbPtr.asFunction<
          int Function(
              stt_h, stt_default_language_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @retval #STT_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_set_default_language_changed_cb()
  int stt_unset_default_language_changed_cb(
    stt_h stt,
  ) {
    return _stt_unset_default_language_changed_cb(
      stt,
    );
  }

  late final _stt_unset_default_language_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>(
          'stt_unset_default_language_changed_cb');
  late final _stt_unset_default_language_changed_cb =
      _stt_unset_default_language_changed_cbPtr
          .asFunction<int Function(stt_h)>();

  /// @brief Registers a callback function to detect the engine change.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @param[in] stt The STT handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_engine_changed_cb()
  /// @see stt_unset_engine_changed_cb()
  int stt_set_engine_changed_cb(
    stt_h stt,
    stt_engine_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _stt_set_engine_changed_cb(
      stt,
      callback,
      user_data,
    );
  }

  late final _stt_set_engine_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(stt_h, stt_engine_changed_cb,
              ffi.Pointer<ffi.Void>)>>('stt_set_engine_changed_cb');
  late final _stt_set_engine_changed_cb =
      _stt_set_engine_changed_cbPtr.asFunction<
          int Function(stt_h, stt_engine_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @param[in] stt The STT handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STT_ERROR_NONE Successful
  /// @retval #STT_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STT_ERROR_INVALID_STATE Invalid state
  /// @retval #STT_ERROR_NOT_SUPPORTED STT NOT supported
  /// @pre The state should be #STT_STATE_CREATED.
  /// @see stt_set_engine_changed_cb()
  int stt_unset_engine_changed_cb(
    stt_h stt,
  ) {
    return _stt_unset_engine_changed_cb(
      stt,
    );
  }

  late final _stt_unset_engine_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stt_h)>>(
          'stt_unset_engine_changed_cb');
  late final _stt_unset_engine_changed_cb =
      _stt_unset_engine_changed_cbPtr.asFunction<int Function(stt_h)>();

  /// @brief Main function for Speech-To-Text (STT) engine.
  /// @details This function is the main function for operating STT engine.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks The service_app_main() should be used for working the engine after this function.
  /// @param[in] argc The argument count(original)
  /// @param[in] argv The argument(original)
  /// @param[in] callback The structure of engine request callback function
  /// @return This function returns @c zero on success,
  /// or negative with error code on failure
  /// @retval #STTE_ERROR_NONE Successful
  /// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STTE_ERROR_PERMISSION_DENIED	Permission denied
  /// @retval #STTE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
  /// @see stte_request_callback_s
  /// @code
  /// #include <stte.h>
  ///
  /// // Required callback functions - MUST BE IMPLEMENTED
  /// static int sttengine_get_info_cb(char** engine_uuid, char** engine_name, char** engine_setting, bool* use_network);
  /// static int sttengine_initialize_cb(void);
  /// static int sttengine_deinitialize_cb(void);
  /// static int sttengine_is_valid_language_cb(const char* language, bool* is_valid);
  /// static int sttengine_foreach_supported_langs_cb(stte_supported_language_cb callback, void* user_data);
  /// static bool sttengine_support_silence_detection_cb(void);
  /// static int sttengine_set_silence_detection_cb(bool is_set);
  /// static int sttengine_support_recognition_type_cb(const char* type, bool* is_supported);
  /// static int sttengine_get_recording_format_cb(stte_audio_type_e* types, int* rate, int* channels);
  /// static int sttengine_set_recording_data_cb(const void* data, unsigned int length);
  /// static int sttengine_foreach_result_time_cb(void* time_info, stte_result_time_cb callback, void* user_data);
  /// static int sttengine_start_cb(const char* language, const char* type, const char* appid, const char* credential, void *user_data);
  /// static int sttengine_stop_cb(void);
  /// static int sttengine_cancel_cb(void);
  /// static int sttengine_check_app_agreed_cb(const char* appid, bool* is_agreed);
  /// static bool sttengine_need_app_credential_cb(void);
  ///
  /// // Optional callback function
  /// static int sttengine_private_data_set_cb(const char* key, const char* data);
  ///
  /// int main(int argc, char* argv[])
  /// {
  /// // 1. Create a structure 'stte_request_callback_s'
  /// stte_request_callback_s engine_callback = { 0, };
  ///
  /// engine_callback.size = sizeof(stte_request_callback_s);
  /// engine_callback.version = 1;
  /// engine_callback.get_info = sttengine_get_info_cb;
  ///
  /// engine_callback.initialize = sttengine_initialize_cb;
  /// engine_callback.deinitialize = sttengine_deinitialize_cb;
  ///
  /// engine_callback.foreach_langs = sttengine_foreach_supported_langs_cb;
  /// engine_callback.is_valid_lang = sttengine_is_valid_language_cb;
  /// engine_callback.support_silence = sttengine_support_silence_detection_cb;
  /// engine_callback.support_recognition_type = sttengine_support_recognition_type_cb;
  ///
  /// engine_callback.get_audio_format = sttengine_get_recording_format_cb;
  /// engine_callback.foreach_result_time = sttengine_foreach_result_time_cb;
  ///
  /// engine_callback.set_silence_detection = sttengine_set_silence_detection_cb;
  ///
  /// engine_callback.start = sttengine_start_cb;
  /// engine_callback.set_recording = sttengine_set_recording_data_cb;
  /// engine_callback.stop = sttengine_stop_cb;
  /// engine_callback.cancel = sttengine_cancel_cb;
  ///
  /// engine_callback.check_app_agreed = sttengine_check_app_agreed_cb;
  /// engine_callback.need_app_credential = sttengine_need_app_credential_cb;
  ///
  /// // 2. Run 'stte_main()'
  /// if (0 != stte_main(argc, argv, &engine_callback)) {
  /// return -1;
  /// }
  ///
  /// // Optional
  /// stte_set_private_data_set_cb(sttengine_private_data_set_cb);
  ///
  /// // 3. Set event callbacks for service app and Run 'service_app_main()'
  /// char ad[50] = { 0, };
  ///
  /// service_app_lifecycle_callback_s event_callback;
  /// app_event_handler_h handlers[5] = { NULL, };
  ///
  /// event_callback.create = service_app_create;
  /// event_callback.terminate = service_app_terminate;
  /// event_callback.app_control = service_app_control;
  ///
  /// service_app_add_event_handler(&handlers[APP_EVENT_LOW_BATTERY], APP_EVENT_LOW_BATTERY, service_app_low_battery, &ad);
  /// service_app_add_event_handler(&handlers[APP_EVENT_LOW_MEMORY], APP_EVENT_LOW_MEMORY, service_app_low_memory, &ad);
  /// service_app_add_event_handler(&handlers[APP_EVENT_LANGUAGE_CHANGED], APP_EVENT_LANGUAGE_CHANGED, service_app_lang_changed, &ad);
  /// service_app_add_event_handler(&handlers[APP_EVENT_REGION_FORMAT_CHANGED], APP_EVENT_REGION_FORMAT_CHANGED, service_app_region_changed, &ad);
  ///
  /// return service_app_main(argc, argv, &event_callback, ad);
  /// }
  ///
  /// @endcode
  int stte_main(
    int argc,
    ffi.Pointer<ffi.Pointer<ffi.Char>> argv,
    ffi.Pointer<stte_request_callback_s> callback,
  ) {
    return _stte_main(
      argc,
      argv,
      callback,
    );
  }

  late final _stte_mainPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<stte_request_callback_s>)>>('stte_main');
  late final _stte_main = _stte_mainPtr.asFunction<
      int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>,
          ffi.Pointer<stte_request_callback_s>)>();

  /// @brief Sends the recognition result to the engine service user.
  /// @since_tizen 3.0
  /// @remarks This API is used in stte_set_recording_data_cb() and stte_stop_cb(), when STT engine sends the recognition result to the engine service user.
  /// This function is called in the following situations; 1) after stte_stop_cb() is called, 2) the end point of speech is detected from recording, or 3) partial result is occurred.
  /// The recognition result and @a user_data must be transferred to the engine service user through this function.
  /// Also, @a time_info must be transferred to stte_foreach_result_time_cb(). The type of @a time_info is up to the STT engine developer.
  /// @param[in] event The result event
  /// @param[in] type The recognition type (e.g. #STTE_RECOGNITION_TYPE_FREE, #STTE_RECOGNITION_TYPE_FREE_PARTIAL)
  /// @param[in] result Result texts
  /// @param[in] result_count Result text count
  /// @param[in] msg Engine message (e.g. #STTE_RESULT_MESSAGE_NONE, #STTE_RESULT_MESSAGE_ERROR_TOO_SHORT)
  /// @param[in] time_info The time information
  /// @param[in] user_data The user data passed from stte_start_cb()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STTE_ERROR_NONE Successful
  /// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STTE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #STTE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
  /// @pre The stte_main() function should be invoked before this function is called.
  /// stte_stop_cb() will invoke this function.
  /// @post This function invokes stte_foreach_result_time_cb().
  /// @see stte_start_cb()
  /// @see stte_set_recording_data_cb()
  /// @see stte_stop_cb()
  /// @see stte_foreach_result_time_cb()
  int stte_send_result(
    int event,
    ffi.Pointer<ffi.Char> type,
    ffi.Pointer<ffi.Pointer<ffi.Char>> result,
    int result_count,
    ffi.Pointer<ffi.Char> msg,
    ffi.Pointer<ffi.Void> time_info,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _stte_send_result(
      event,
      type,
      result,
      result_count,
      msg,
      time_info,
      user_data,
    );
  }

  late final _stte_send_resultPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Int,
              ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Void>,
              ffi.Pointer<ffi.Void>)>>('stte_send_result');
  late final _stte_send_result = _stte_send_resultPtr.asFunction<
      int Function(
          int,
          ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Pointer<ffi.Char>>,
          int,
          ffi.Pointer<ffi.Char>,
          ffi.Pointer<ffi.Void>,
          ffi.Pointer<ffi.Void>)>();

  /// @brief Sends the error to the engine service user.
  /// @details The following error codes can be delivered.
  /// #STTE_ERROR_NONE,
  /// #STTE_ERROR_OUT_OF_MEMORY,
  /// #STTE_ERROR_IO_ERROR,
  /// #STTE_ERROR_INVALID_PARAMETER,
  /// #STTE_ERROR_NETWORK_DOWN,
  /// #STTE_ERROR_INVALID_STATE,
  /// #STTE_ERROR_INVALID_LANGUAGE,
  /// #STTE_ERROR_OPERATION_FAILED,
  /// #STTE_ERROR_NOT_SUPPORTED_FEATURE,
  /// #STTE_ERROR_NOT_SUPPORTED,
  /// #STTE_ERROR_PERMISSION_DENIED,
  /// #STTE_ERROR_RECORDING_TIMED_OUT.
  /// @since_tizen 3.0
  /// @param[in] error The error reason
  /// @param[in] msg The error message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STTE_ERROR_NONE Successful
  /// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STTE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #STTE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
  /// @pre The stte_main() function should be invoked before this function is called.
  int stte_send_error(
    int error,
    ffi.Pointer<ffi.Char> msg,
  ) {
    return _stte_send_error(
      error,
      msg,
    );
  }

  late final _stte_send_errorPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Char>)>>('stte_send_error');
  late final _stte_send_error = _stte_send_errorPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sends the speech status to the engine service user when STT engine notifies the change of the speech status.
  /// @since_tizen 3.0
  /// @remarks This API is invoked when STT engine wants to notify the change of the speech status anytime.
  /// NOTE that this API can be invoked for recognizing the speech.
  /// @param[in] status The status of speech (e.g. STTE_SPEECH_STATUS_START_POINT_DETECTED or STTE_SPEECH_STATUS_END_POINT_DETECTED)
  /// @param[in] user_data The user data passed from the start function.
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STTE_ERROR_NONE Successful
  /// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STTE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #STTE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
  /// @pre The stte_main() function should be invoked before this function is called.
  /// stte_start_cb() and stte_set_recording_data_cb() will invoke this function.
  /// @see stte_start_cb()
  /// @see stte_set_recording_data_cb()
  int stte_send_speech_status(
    int status,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _stte_send_speech_status(
      status,
      user_data,
    );
  }

  late final _stte_send_speech_statusPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Void>)>>('stte_send_speech_status');
  late final _stte_send_speech_status = _stte_send_speech_statusPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Void>)>();

  /// @brief Sets a callback function for setting the private data.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks The stte_private_data_set_cb() function is called when the engine service user sends the private data.
  /// @param[in] callback_func stte_private_data_set event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STTE_ERROR_NONE Successful
  /// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STTE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #STTE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
  /// @pre The stte_main() function should be invoked before this function is called.
  /// @see stte_private_data_set_cb()
  int stte_set_private_data_set_cb(
    stte_private_data_set_cb callback_func,
  ) {
    return _stte_set_private_data_set_cb(
      callback_func,
    );
  }

  late final _stte_set_private_data_set_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(stte_private_data_set_cb)>>(
          'stte_set_private_data_set_cb');
  late final _stte_set_private_data_set_cb = _stte_set_private_data_set_cbPtr
      .asFunction<int Function(stte_private_data_set_cb)>();

  /// @brief Sets a callback function for requesting the private data.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks The stte_private_data_requested_cb() function is called when the engine service user gets the private data from STT engine.
  /// @param[in] callback_func stte_private_data_requested event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #STTE_ERROR_NONE Successful
  /// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #STTE_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #STTE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
  /// @pre The stte_main() function should be invoked before this function is called.
  /// @see stte_private_data_requested_cb()
  int stte_set_private_data_requested_cb(
    stte_private_data_requested_cb callback_func,
  ) {
    return _stte_set_private_data_requested_cb(
      callback_func,
    );
  }

  late final _stte_set_private_data_requested_cbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(stte_private_data_requested_cb)>>(
      'stte_set_private_data_requested_cb');
  late final _stte_set_private_data_requested_cb =
      _stte_set_private_data_requested_cbPtr
          .asFunction<int Function(stte_private_data_requested_cb)>();

  /// @brief Creates a handle for TTS.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If the function succeeds, @a tts handle must be released with tts_destroy().
  /// @param[out] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_ENGINE_NOT_FOUND Engine not found
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @post If this function is called, the TTS state will be #TTS_STATE_CREATED.
  /// @see tts_destroy()
  int tts_create(
    ffi.Pointer<tts_h> tts,
  ) {
    return _tts_create(
      tts,
    );
  }

  late final _tts_createPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<tts_h>)>>(
          'tts_create');
  late final _tts_create =
      _tts_createPtr.asFunction<int Function(ffi.Pointer<tts_h>)>();

  /// @brief Destroys the handle and disconnects the daemon.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @see tts_create()
  int tts_destroy(
    tts_h tts,
  ) {
    return _tts_destroy(
      tts,
    );
  }

  late final _tts_destroyPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>('tts_destroy');
  late final _tts_destroy = _tts_destroyPtr.asFunction<int Function(tts_h)>();

  /// @brief Sets the TTS mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[in] mode The mode
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_get_mode()
  int tts_set_mode(
    tts_h tts,
    int mode,
  ) {
    return _tts_set_mode(
      tts,
      mode,
    );
  }

  late final _tts_set_modePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h, ffi.Int32)>>(
          'tts_set_mode');
  late final _tts_set_mode =
      _tts_set_modePtr.asFunction<int Function(tts_h, int)>();

  /// @brief Gets the TTS mode.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[out] mode The mode
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_set_mode()
  int tts_get_mode(
    tts_h tts,
    ffi.Pointer<ffi.Int32> mode,
  ) {
    return _tts_get_mode(
      tts,
      mode,
    );
  }

  late final _tts_get_modePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(tts_h, ffi.Pointer<ffi.Int32>)>>(
      'tts_get_mode');
  late final _tts_get_mode = _tts_get_modePtr
      .asFunction<int Function(tts_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Sets the app credential.
  /// @details Using this API, the application can set a credential.
  /// The credential is a key to verify the authorization about using the engine.
  /// If the application sets the credential, it will be able to use functions of the engine entirely.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @remarks The necessity of the credential depends on the engine. In case of the engine which is basically embedded in Tizen, the credential is not necessary so far.
  /// However, if the user wants to apply the 3rd party's engine, the credential may be necessary. In that case, please follow the policy provided by the corresponding engine.
  /// @param[in] tts The TTS handle
  /// @param[in] credential The app credential
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Success
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED or #TTS_STATE_READY.
  /// @see tts_play()
  int tts_set_credential(
    tts_h tts,
    ffi.Pointer<ffi.Char> credential,
  ) {
    return _tts_set_credential(
      tts,
      credential,
    );
  }

  late final _tts_set_credentialPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(tts_h, ffi.Pointer<ffi.Char>)>>(
      'tts_set_credential');
  late final _tts_set_credential = _tts_set_credentialPtr
      .asFunction<int Function(tts_h, ffi.Pointer<ffi.Char>)>();

  /// @brief Connects the daemon asynchronously.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @post If this function is successful, the TTS state will be #TTS_STATE_READY.
  /// If this function is failed, the error callback is called. (e.g. #TTS_ERROR_ENGINE_NOT_FOUND)
  /// @see tts_unprepare()
  int tts_prepare(
    tts_h tts,
  ) {
    return _tts_prepare(
      tts,
    );
  }

  late final _tts_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>('tts_prepare');
  late final _tts_prepare = _tts_preparePtr.asFunction<int Function(tts_h)>();

  /// @brief Disconnects the daemon.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_READY.
  /// @post If this function is called, the TTS state will be #TTS_STATE_CREATED.
  /// @see tts_prepare()
  int tts_unprepare(
    tts_h tts,
  ) {
    return _tts_unprepare(
      tts,
    );
  }

  late final _tts_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>('tts_unprepare');
  late final _tts_unprepare =
      _tts_unpreparePtr.asFunction<int Function(tts_h)>();

  /// @brief Retrieves all supported voices of the current engine using callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[in] callback The callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_ENGINE_NOT_FOUND Engine not found
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @post This function invokes tts_supported_voice_cb() repeatedly for getting voices.
  /// @see tts_get_default_voice()
  int tts_foreach_supported_voices(
    tts_h tts,
    tts_supported_voice_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _tts_foreach_supported_voices(
      tts,
      callback,
      user_data,
    );
  }

  late final _tts_foreach_supported_voicesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, tts_supported_voice_cb,
              ffi.Pointer<ffi.Void>)>>('tts_foreach_supported_voices');
  late final _tts_foreach_supported_voices =
      _tts_foreach_supported_voicesPtr.asFunction<
          int Function(tts_h, tts_supported_voice_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets the default voice set by the user.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks If the function succeeds, @a language must be released with free().
  /// @param[in] tts The TTS handle
  /// @param[out] language Language specified as an ISO 3166 alpha-2 two letter country-code followed by ISO 639-1 for the two-letter language code (for example, "ko_KR" for Korean, "en_US" for American English)
  /// @param[out] voice_type The voice type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_ENGINE_NOT_FOUND Engine not found
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @see tts_foreach_supported_voices()
  int tts_get_default_voice(
    tts_h tts,
    ffi.Pointer<ffi.Pointer<ffi.Char>> language,
    ffi.Pointer<ffi.Int> voice_type,
  ) {
    return _tts_get_default_voice(
      tts,
      language,
      voice_type,
    );
  }

  late final _tts_get_default_voicePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ffi.Int>)>>('tts_get_default_voice');
  late final _tts_get_default_voice = _tts_get_default_voicePtr.asFunction<
      int Function(
          tts_h, ffi.Pointer<ffi.Pointer<ffi.Char>>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sets the private data to tts engine.
  /// @details The private data is the setting parameter for applying keys provided by the engine.
  /// Using this API, the application can set the private data and use the corresponding key of the engine.
  /// For example, if the engine provides 'girl's voice' as a voice type, the application can set the private data as the following.
  /// int ret = tts_set_private_data(tts_h, "voice_type", "GIRL");
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @remarks If the engine is replaced with the other engine, the key may be ignored.
  /// @param[in] tts The TTS handle
  /// @param[in] key The field name of private data
  /// @param[in] data The data for set
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_ENGINE_NOT_FOUND Engine not found
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_READY.
  /// @see tts_get_private_data()
  int tts_set_private_data(
    tts_h tts,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Char> data,
  ) {
    return _tts_set_private_data(
      tts,
      key,
      data,
    );
  }

  late final _tts_set_private_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Char>)>>('tts_set_private_data');
  late final _tts_set_private_data = _tts_set_private_dataPtr.asFunction<
      int Function(tts_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>();

  /// @brief Gets the private data from tts engine.
  /// @details The private data is the information provided by the engine.
  /// Using this API, the application can get the private data which corresponds to the key from the engine.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @remarks The @a data must be released using free() when it is no longer required.
  /// If the engine is replaced with the other engine, the key may be ignored.
  /// @param[in] tts The TTS handle
  /// @param[in] key The field name of private data
  /// @param[out] data The data field of private data
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_ENGINE_NOT_FOUND Engine not found
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_READY.
  /// @see tts_set_private_data()
  int tts_get_private_data(
    tts_h tts,
    ffi.Pointer<ffi.Char> key,
    ffi.Pointer<ffi.Pointer<ffi.Char>> data,
  ) {
    return _tts_get_private_data(
      tts,
      key,
      data,
    );
  }

  late final _tts_get_private_dataPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, ffi.Pointer<ffi.Char>,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('tts_get_private_data');
  late final _tts_get_private_data = _tts_get_private_dataPtr.asFunction<
      int Function(
          tts_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets the maximum byte size for text.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[out] size The maximum byte size for text
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_READY.
  /// @see tts_add_text()
  int tts_get_max_text_size(
    tts_h tts,
    ffi.Pointer<ffi.UnsignedInt> size,
  ) {
    return _tts_get_max_text_size(
      tts,
      size,
    );
  }

  late final _tts_get_max_text_sizePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              tts_h, ffi.Pointer<ffi.UnsignedInt>)>>('tts_get_max_text_size');
  late final _tts_get_max_text_size = _tts_get_max_text_sizePtr
      .asFunction<int Function(tts_h, ffi.Pointer<ffi.UnsignedInt>)>();

  /// @brief Gets the current state of TTS.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[out] state The current state of TTS
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @see tts_play()
  /// @see tts_stop()
  /// @see tts_pause()
  int tts_get_state(
    tts_h tts,
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _tts_get_state(
      tts,
      state,
    );
  }

  late final _tts_get_statePtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(tts_h, ffi.Pointer<ffi.Int32>)>>(
      'tts_get_state');
  late final _tts_get_state = _tts_get_statePtr
      .asFunction<int Function(tts_h, ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the speed range.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[out] min The minimum speed value
  /// @param[out] normal The normal speed value
  /// @param[out] max The maximum speed value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_add_text()
  int tts_get_speed_range(
    tts_h tts,
    ffi.Pointer<ffi.Int> min,
    ffi.Pointer<ffi.Int> normal,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _tts_get_speed_range(
      tts,
      min,
      normal,
      max,
    );
  }

  late final _tts_get_speed_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('tts_get_speed_range');
  late final _tts_get_speed_range = _tts_get_speed_rangePtr.asFunction<
      int Function(tts_h, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>,
          ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the current error message.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @remarks This function should be called from a tts error callback. Calling in any other context will result in an Operation failed error.
  /// A successful call will allocate @a err_msg, which must be released by calling free() when it is no longer required.
  /// @param[in] tts The TTS handle
  /// @param[out] err_msg The current error message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @see tts_set_error_cb()
  /// @see tts_unset_error_cb()
  int tts_get_error_message(
    tts_h tts,
    ffi.Pointer<ffi.Pointer<ffi.Char>> err_msg,
  ) {
    return _tts_get_error_message(
      tts,
      err_msg,
    );
  }

  late final _tts_get_error_messagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h,
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('tts_get_error_message');
  late final _tts_get_error_message = _tts_get_error_messagePtr
      .asFunction<int Function(tts_h, ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Adds a text to the queue.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @remarks Locale(e.g. setlocale()) MUST be set for utf8 text validation check.
  /// @param[in] tts The TTS handle
  /// @param[in] text An input text based utf8
  /// @param[in] language The language selected from the tts_foreach_supported_voices() (e.g. 'NULL'(Automatic), 'en_US')
  /// @param[in] voice_type The voice type selected from the tts_foreach_supported_voices() (e.g. #TTS_VOICE_TYPE_AUTO, #TTS_VOICE_TYPE_FEMALE)
  /// @param[in] speed A speaking speed (e.g. #TTS_SPEED_AUTO or the value from tts_get_speed_range())
  /// @param[out] utt_id The utterance ID passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_INVALID_VOICE Invalid voice about language, voice type
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @retval #TTS_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The state should be #TTS_STATE_READY, #TTS_STATE_PLAYING or #TTS_STATE_PAUSED.
  /// @see tts_get_max_text_size()
  /// @see tts_set_credential()
  int tts_add_text(
    tts_h tts,
    ffi.Pointer<ffi.Char> text,
    ffi.Pointer<ffi.Char> language,
    int voice_type,
    int speed,
    ffi.Pointer<ffi.Int> utt_id,
  ) {
    return _tts_add_text(
      tts,
      text,
      language,
      voice_type,
      speed,
      utt_id,
    );
  }

  late final _tts_add_textPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Int, ffi.Int, ffi.Pointer<ffi.Int>)>>('tts_add_text');
  late final _tts_add_text = _tts_add_textPtr.asFunction<
      int Function(tts_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, int,
          int, ffi.Pointer<ffi.Int>)>();

  /// @brief Starts synthesizing voice from the text and plays the synthesized audio data.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_OUT_OF_NETWORK Out of network
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @retval #TTS_ERROR_PERMISSION_DENIED Permission denied
  /// @pre The current state should be #TTS_STATE_READY or #TTS_STATE_PAUSED.
  /// @post If this function succeeds, the TTS state will be #TTS_STATE_PLAYING.
  /// @see tts_add_text()
  /// @see tts_pause()
  /// @see tts_stop()
  /// @see tts_utterance_started_cb()
  /// @see tts_utterance_completed_cb()
  /// @see tts_error_cb()
  /// @see tts_set_credential()
  int tts_play(
    tts_h tts,
  ) {
    return _tts_play(
      tts,
    );
  }

  late final _tts_playPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>('tts_play');
  late final _tts_play = _tts_playPtr.asFunction<int Function(tts_h)>();

  /// @brief Stops playing the utterance and clears the queue.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The TTS state should be #TTS_STATE_READY or #TTS_STATE_PLAYING or #TTS_STATE_PAUSED.
  /// @post If this function succeeds, the TTS state will be #TTS_STATE_READY.
  /// This function will remove all text via tts_add_text() and synthesized sound data.
  /// @see tts_play()
  /// @see tts_pause()
  int tts_stop(
    tts_h tts,
  ) {
    return _tts_stop(
      tts,
    );
  }

  late final _tts_stopPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>('tts_stop');
  late final _tts_stop = _tts_stopPtr.asFunction<int Function(tts_h)>();

  /// @brief Pauses the currently playing utterance.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The TTS state should be #TTS_STATE_PLAYING.
  /// @post If this function succeeds, the TTS state will be #TTS_STATE_PAUSED.
  /// @see tts_play()
  /// @see tts_stop()
  /// @see tts_error_cb()
  /// @see tts_interrupted_cb()
  int tts_pause(
    tts_h tts,
  ) {
    return _tts_pause(
      tts,
    );
  }

  late final _tts_pausePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>('tts_pause');
  late final _tts_pause = _tts_pausePtr.asFunction<int Function(tts_h)>();

  /// @brief Registers a callback function to be called when the TTS state changes.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_state_changed_cb()
  /// @see tts_unset_state_changed_cb()
  int tts_set_state_changed_cb(
    tts_h tts,
    tts_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _tts_set_state_changed_cb(
      tts,
      callback,
      user_data,
    );
  }

  late final _tts_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, tts_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('tts_set_state_changed_cb');
  late final _tts_set_state_changed_cb =
      _tts_set_state_changed_cbPtr.asFunction<
          int Function(tts_h, tts_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_set_state_changed_cb()
  int tts_unset_state_changed_cb(
    tts_h tts,
  ) {
    return _tts_unset_state_changed_cb(
      tts,
    );
  }

  late final _tts_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>(
          'tts_unset_state_changed_cb');
  late final _tts_unset_state_changed_cb =
      _tts_unset_state_changed_cbPtr.asFunction<int Function(tts_h)>();

  /// @brief Registers a callback function to detect utterance start.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_utterance_started_cb()
  /// @see tts_unset_utterance_started_cb()
  int tts_set_utterance_started_cb(
    tts_h tts,
    tts_utterance_started_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _tts_set_utterance_started_cb(
      tts,
      callback,
      user_data,
    );
  }

  late final _tts_set_utterance_started_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, tts_utterance_started_cb,
              ffi.Pointer<ffi.Void>)>>('tts_set_utterance_started_cb');
  late final _tts_set_utterance_started_cb =
      _tts_set_utterance_started_cbPtr.asFunction<
          int Function(
              tts_h, tts_utterance_started_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_set_utterance_started_cb()
  int tts_unset_utterance_started_cb(
    tts_h tts,
  ) {
    return _tts_unset_utterance_started_cb(
      tts,
    );
  }

  late final _tts_unset_utterance_started_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>(
          'tts_unset_utterance_started_cb');
  late final _tts_unset_utterance_started_cb =
      _tts_unset_utterance_started_cbPtr.asFunction<int Function(tts_h)>();

  /// @brief Registers a callback function to detect utterance completion.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_utterance_completed_cb()
  /// @see tts_unset_utterance_completed_cb()
  int tts_set_utterance_completed_cb(
    tts_h tts,
    tts_utterance_completed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _tts_set_utterance_completed_cb(
      tts,
      callback,
      user_data,
    );
  }

  late final _tts_set_utterance_completed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, tts_utterance_completed_cb,
              ffi.Pointer<ffi.Void>)>>('tts_set_utterance_completed_cb');
  late final _tts_set_utterance_completed_cb =
      _tts_set_utterance_completed_cbPtr.asFunction<
          int Function(
              tts_h, tts_utterance_completed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_set_utterance_completed_cb()
  int tts_unset_utterance_completed_cb(
    tts_h tts,
  ) {
    return _tts_unset_utterance_completed_cb(
      tts,
    );
  }

  late final _tts_unset_utterance_completed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>(
          'tts_unset_utterance_completed_cb');
  late final _tts_unset_utterance_completed_cb =
      _tts_unset_utterance_completed_cbPtr.asFunction<int Function(tts_h)>();

  /// @brief Registers a callback function to detect errors.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_error_cb()
  /// @see tts_unset_error_cb()
  int tts_set_error_cb(
    tts_h tts,
    tts_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _tts_set_error_cb(
      tts,
      callback,
      user_data,
    );
  }

  late final _tts_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              tts_h, tts_error_cb, ffi.Pointer<ffi.Void>)>>('tts_set_error_cb');
  late final _tts_set_error_cb = _tts_set_error_cbPtr
      .asFunction<int Function(tts_h, tts_error_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_set_error_cb()
  int tts_unset_error_cb(
    tts_h tts,
  ) {
    return _tts_unset_error_cb(
      tts,
    );
  }

  late final _tts_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>(
          'tts_unset_error_cb');
  late final _tts_unset_error_cb =
      _tts_unset_error_cbPtr.asFunction<int Function(tts_h)>();

  /// @brief Registers a callback function to detect default voice change.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_default_voice_changed_cb()
  /// @see tts_unset_default_voice_changed_cb()
  int tts_set_default_voice_changed_cb(
    tts_h tts,
    tts_default_voice_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _tts_set_default_voice_changed_cb(
      tts,
      callback,
      user_data,
    );
  }

  late final _tts_set_default_voice_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, tts_default_voice_changed_cb,
              ffi.Pointer<ffi.Void>)>>('tts_set_default_voice_changed_cb');
  late final _tts_set_default_voice_changed_cb =
      _tts_set_default_voice_changed_cbPtr.asFunction<
          int Function(
              tts_h, tts_default_voice_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_set_default_voice_changed_cb()
  int tts_unset_default_voice_changed_cb(
    tts_h tts,
  ) {
    return _tts_unset_default_voice_changed_cb(
      tts,
    );
  }

  late final _tts_unset_default_voice_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>(
          'tts_unset_default_voice_changed_cb');
  late final _tts_unset_default_voice_changed_cb =
      _tts_unset_default_voice_changed_cbPtr.asFunction<int Function(tts_h)>();

  /// @brief Registers a callback function to detect the engine change.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @param[in] tts The TTS handle
  /// @param[in] callback The callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_engine_changed_cb()
  /// @see tts_unset_engine_changed_cb()
  int tts_set_engine_changed_cb(
    tts_h tts,
    tts_engine_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _tts_set_engine_changed_cb(
      tts,
      callback,
      user_data,
    );
  }

  late final _tts_set_engine_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(tts_h, tts_engine_changed_cb,
              ffi.Pointer<ffi.Void>)>>('tts_set_engine_changed_cb');
  late final _tts_set_engine_changed_cb =
      _tts_set_engine_changed_cbPtr.asFunction<
          int Function(tts_h, tts_engine_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
  /// @param[in] tts The TTS handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTS_ERROR_NONE Successful
  /// @retval #TTS_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTS_ERROR_INVALID_STATE Invalid state
  /// @retval #TTS_ERROR_NOT_SUPPORTED TTS NOT supported
  /// @pre The state should be #TTS_STATE_CREATED.
  /// @see tts_set_engine_changed_cb()
  int tts_unset_engine_changed_cb(
    tts_h tts,
  ) {
    return _tts_unset_engine_changed_cb(
      tts,
    );
  }

  late final _tts_unset_engine_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(tts_h)>>(
          'tts_unset_engine_changed_cb');
  late final _tts_unset_engine_changed_cb =
      _tts_unset_engine_changed_cbPtr.asFunction<int Function(tts_h)>();

  /// @brief Main function for Text-To-Speech (TTS) engine.
  /// @details This function is the main function for operating TTS engine.
  /// @since_tizen 3.0
  /// @remarks The service_app_main() should be used for working the engine after this function.
  /// @param[in] argc The argument count(original)
  /// @param[in] argv The argument(original)
  /// @param[in] callback The structure of engine request callback function
  /// @return This function returns zero on success,
  /// or negative with error code on failure
  /// @retval #TTSE_ERROR_NONE Successful
  /// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
  /// @retval #TTSE_ERROR_NOT_SUPPORTED Not supported
  /// @see ttse_request_callback_s
  /// @code
  /// #include <ttse.h>
  ///
  /// // Required callback functions - MUST BE IMPLEMENTED
  /// static int ttsengine_get_info_cb(char** engine_uuid, char** engine_name, char** engine_setting, bool* use_network);
  /// static int ttsengine_initialize_cb(void);
  /// static int ttsengine_deinitialize_cb(void);
  /// static int ttsengine_is_valid_voice_cb(const char* language, int type, bool* is_valid);
  /// static int ttsengine_foreach_supported_voices_cb(ttse_supported_voice_cb callback, void* user_data);
  /// static int ttsengine_set_pitch_cb(int pitch);
  /// static int ttsengine_load_voice_cb(const char* language, int type);
  /// static int ttsengine_unload_voice_cb(const char* language, int type);
  /// static int ttsengine_start_synthesis_cb(const char* language, int type, const char* text, int speed, void* user_data);
  /// static int ttsengine_cancel_synthesis_cb(void);
  /// static int ttsengine_check_app_agreed_cb(const char* appid, bool* is_agreed);
  /// static bool ttsengine_need_app_credential_cb(void);
  ///
  /// // Optional callback function
  /// static int ttsengine_private_data_set_cb(const char* key, const char* data);
  ///
  /// int main(int argc, char* argv[])
  /// {
  /// // 1. Create a structure 'ttse_request_callback_s'
  /// ttse_request_callback_s engine_callback = { 0, };
  ///
  /// engine_callback.size = sizeof(ttse_request_callback_s);
  /// engine_callback.version = 1;
  /// engine_callback.get_info = ttsengine_get_info_cb;
  /// engine_callback.initialize = ttsengine_initialize_cb;
  /// engine_callback.deinitialize = ttsengine_deinitialize_cb;
  /// engine_callback.foreach_voices = ttsengine_foreach_supported_voices_cb;
  /// engine_callback.is_valid_voice = ttsengine_is_valid_voice_cb;
  /// engine_callback.set_pitch = ttsengine_set_pitch_cb;
  /// engine_callback.load_voice = ttsengine_load_voice_cb;
  /// engine_callback.unload_voice = ttsengine_unload_voice_cb;
  /// engine_callback.start_synth = ttsengine_start_synthesis_cb;
  /// engine_callback.cancel_synth = ttsengine_cancel_synthesis_cb;
  /// engine_callback.check_app_agreed = ttsengine_check_app_agreed_cb;
  /// engine_callback.need_app_credential = ttsengine_need_app_credential_cb;
  ///
  /// // 2. Run 'ttse_main()'
  /// if (0 != ttse_main(argc, argv, &engine_callback)) {
  /// return -1;
  /// }
  ///
  /// // Optional
  /// ttse_set_private_data_set_cb(ttsengine_private_data_set_cb);
  ///
  /// // 3. Set event callbacks for service app and Run 'service_app_main()'
  /// char ad[50] = { 0, };
  ///
  /// service_app_lifecycle_callback_s event_callback;
  /// app_event_handler_h handlers[5] = { NULL, };
  ///
  /// event_callback.create = service_app_create;
  /// event_callback.terminate = service_app_terminate;
  /// event_callback.app_control = service_app_control;
  ///
  /// service_app_add_event_handler(&handlers[APP_EVENT_LOW_BATTERY], APP_EVENT_LOW_BATTERY, service_app_low_battery, &ad);
  /// service_app_add_event_handler(&handlers[APP_EVENT_LOW_MEMORY], APP_EVENT_LOW_MEMORY, service_app_low_memory, &ad);
  /// service_app_add_event_handler(&handlers[APP_EVENT_LANGUAGE_CHANGED], APP_EVENT_LANGUAGE_CHANGED, service_app_lang_changed, &ad);
  /// service_app_add_event_handler(&handlers[APP_EVENT_REGION_FORMAT_CHANGED], APP_EVENT_REGION_FORMAT_CHANGED, service_app_region_changed, &ad);
  ///
  /// return service_app_main(argc, argv, &event_callback, ad);
  /// }
  ///
  /// @endcode
  int ttse_main(
    int argc,
    ffi.Pointer<ffi.Pointer<ffi.Char>> argv,
    ffi.Pointer<ttse_request_callback_s> callback,
  ) {
    return _ttse_main(
      argc,
      argv,
      callback,
    );
  }

  late final _ttse_mainPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Pointer<ffi.Char>>,
              ffi.Pointer<ttse_request_callback_s>)>>('ttse_main');
  late final _ttse_main = _ttse_mainPtr.asFunction<
      int Function(int, ffi.Pointer<ffi.Pointer<ffi.Char>>,
          ffi.Pointer<ttse_request_callback_s>)>();

  /// @brief Gets the speed range from Tizen platform.
  /// @since_tizen 3.0
  /// @remarks This API is used when TTS engine wants to get the speed range from Tizen platform.
  /// @param[out] min The minimum speed value
  /// @param[out] normal The normal speed value
  /// @param[out] max The maximum speed value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTSE_ERROR_NONE Successful
  /// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTSE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
  int ttse_get_speed_range(
    ffi.Pointer<ffi.Int> min,
    ffi.Pointer<ffi.Int> normal,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _ttse_get_speed_range(
      min,
      normal,
      max,
    );
  }

  late final _ttse_get_speed_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('ttse_get_speed_range');
  late final _ttse_get_speed_range = _ttse_get_speed_rangePtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Gets the pitch range from Tizen platform.
  /// @since_tizen 3.0
  /// @remarks This API is used when TTS engine wants to get the pitch range from Tizen platform.
  /// @param[out] min The minimum pitch value
  /// @param[out] normal The normal pitch value
  /// @param[out] max The maximum pitch value
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTSE_ERROR_NONE Successful
  /// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTSE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
  int ttse_get_pitch_range(
    ffi.Pointer<ffi.Int> min,
    ffi.Pointer<ffi.Int> normal,
    ffi.Pointer<ffi.Int> max,
  ) {
    return _ttse_get_pitch_range(
      min,
      normal,
      max,
    );
  }

  late final _ttse_get_pitch_rangePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>,
              ffi.Pointer<ffi.Int>)>>('ttse_get_pitch_range');
  late final _ttse_get_pitch_range = _ttse_get_pitch_rangePtr.asFunction<
      int Function(
          ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>();

  /// @brief Sends the synthesized result to the engine service user.
  /// @since_tizen 3.0
  /// @remarks This API is used in ttse_start_synthesis_cb(), when TTS engine sends the synthesized result to the engine service user.
  /// The synthesized result and @a user_data must be transferred to the engine service user through this function.
  /// @param[in] event The result event
  /// @param[in] data Result data
  /// @param[in] data_size Result data size
  /// @param[in] audio_type The audio type
  /// @param[in] rate The sample rate
  /// @param[in] user_data The user data passed from ttse_start_synthesis_cb()
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTSE_ERROR_NONE Successful
  /// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTSE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
  /// @pre The ttse_main() function should be invoked before this function is called.
  /// ttse_start_synthesis_cb() will invoke this function.
  /// @see ttse_start_synthesis_cb()
  int ttse_send_result(
    int event,
    ffi.Pointer<ffi.Void> data,
    int data_size,
    int audio_type,
    int rate,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _ttse_send_result(
      event,
      data,
      data_size,
      audio_type,
      rate,
      user_data,
    );
  }

  late final _ttse_send_resultPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Int32, ffi.Pointer<ffi.Void>, ffi.UnsignedInt,
              ffi.Int32, ffi.Int, ffi.Pointer<ffi.Void>)>>('ttse_send_result');
  late final _ttse_send_result = _ttse_send_resultPtr.asFunction<
      int Function(
          int, ffi.Pointer<ffi.Void>, int, int, int, ffi.Pointer<ffi.Void>)>();

  /// @brief Sends the error to the engine service user.
  /// @details The following error codes can be delivered.
  /// #TTSE_ERROR_NONE,
  /// #TTSE_ERROR_OUT_OF_MEMORY,
  /// #TTSE_ERROR_IO_ERROR,
  /// #TTSE_ERROR_INVALID_PARAMETER,
  /// #TTSE_ERROR_NETWORK_DOWN,
  /// #TTSE_ERROR_PERMISSION_DENIED,
  /// #TTSE_ERROR_INVALID_STATE,
  /// #TTSE_ERROR_INVALID_VOICE,
  /// #TTSE_ERROR_OPERATION_FAILED,
  /// #TTSE_ERROR_NOT_SUPPORTED_FEATURE,
  /// #TTSE_ERROR_NOT_SUPPORTED.
  /// @since_tizen 3.0
  /// @param[in] error The error reason
  /// @param[in] msg The error message
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTSE_ERROR_NONE Successful
  /// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTSE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
  /// @pre The ttse_main() function should be invoked before this function is called.
  int ttse_send_error(
    int error,
    ffi.Pointer<ffi.Char> msg,
  ) {
    return _ttse_send_error(
      error,
      msg,
    );
  }

  late final _ttse_send_errorPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Int32, ffi.Pointer<ffi.Char>)>>('ttse_send_error');
  late final _ttse_send_error = _ttse_send_errorPtr
      .asFunction<int Function(int, ffi.Pointer<ffi.Char>)>();

  /// @brief Sets a callback function for setting the private data.
  /// @since_tizen 3.0
  /// @remarks The ttse_private_data_set_cb() function is called when the engine service user sends the private data.
  /// @param[in] callback_func ttse_private_data_set event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTSE_ERROR_NONE Successful
  /// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTSE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
  /// @pre The ttse_main() function should be invoked before this function is called.
  /// @see ttse_private_data_set_cb()
  int ttse_set_private_data_set_cb(
    ttse_private_data_set_cb callback_func,
  ) {
    return _ttse_set_private_data_set_cb(
      callback_func,
    );
  }

  late final _ttse_set_private_data_set_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ttse_private_data_set_cb)>>(
          'ttse_set_private_data_set_cb');
  late final _ttse_set_private_data_set_cb = _ttse_set_private_data_set_cbPtr
      .asFunction<int Function(ttse_private_data_set_cb)>();

  /// @brief Sets a callback function for requesting the private data.
  /// @since_tizen 3.0
  /// @remarks The ttse_private_data_requested_cb() function is called when the engine service user gets the private data from TTS engine.
  /// @param[in] callback_func ttse_private_data_requested event callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #TTSE_ERROR_NONE Successful
  /// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #TTSE_ERROR_NOT_SUPPORTED Not supported
  /// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
  /// @pre The ttse_main() function should be invoked before this function is called.
  /// @see ttse_private_data_requested_cb()
  int ttse_set_private_data_requested_cb(
    ttse_private_data_requested_cb callback_func,
  ) {
    return _ttse_set_private_data_requested_cb(
      callback_func,
    );
  }

  late final _ttse_set_private_data_requested_cbPtr = _lookup<
          ffi.NativeFunction<ffi.Int Function(ttse_private_data_requested_cb)>>(
      'ttse_set_private_data_requested_cb');
  late final _ttse_set_private_data_requested_cb =
      _ttse_set_private_data_requested_cbPtr
          .asFunction<int Function(ttse_private_data_requested_cb)>();

  /// @brief Initializes voice control.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks If the function succeeds, @a vc must be released with vc_deinitialize().
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #VC_ERROR_OPERATION_FAILED Operation failure
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @post If this function is called, the state will be #VC_STATE_INITIALIZED.
  /// @see vc_deinitialize()
  int vc_initialize() {
    return _vc_initialize();
  }

  late final _vc_initializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('vc_initialize');
  late final _vc_initialize = _vc_initializePtr.asFunction<int Function()>();

  /// @brief Deinitializes voice control.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_OPERATION_FAILED Operation failure
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @see vc_deinitialize()
  int vc_deinitialize() {
    return _vc_deinitialize();
  }

  late final _vc_deinitializePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('vc_deinitialize');
  late final _vc_deinitialize =
      _vc_deinitializePtr.asFunction<int Function()>();

  /// @brief Connects the voice control service.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_OPERATION_FAILED Operation failure
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @post If this function is called, the state will be #VC_STATE_READY.
  /// @see vc_unprepare()
  int vc_prepare() {
    return _vc_prepare();
  }

  late final _vc_preparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('vc_prepare');
  late final _vc_prepare = _vc_preparePtr.asFunction<int Function()>();

  /// @brief Disconnects the voice control service.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_READY.
  /// @post If this function is called, the state will be #VC_STATE_INITIALIZED.
  /// @see vc_prepare()
  int vc_unprepare() {
    return _vc_unprepare();
  }

  late final _vc_unpreparePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('vc_unprepare');
  late final _vc_unprepare = _vc_unpreparePtr.asFunction<int Function()>();

  /// @brief Retrieves all supported languages using callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] callback Callback function to invoke
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_OPERATION_FAILED Operation failure
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED or #VC_STATE_READY.
  /// @post This function invokes vc_supported_language_cb() repeatedly for getting languages.
  /// @see vc_supported_language_cb()
  /// @see vc_get_current_language()
  int vc_foreach_supported_languages(
    vc_supported_language_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _vc_foreach_supported_languages(
      callback,
      user_data,
    );
  }

  late final _vc_foreach_supported_languagesPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(vc_supported_language_cb,
              ffi.Pointer<ffi.Void>)>>('vc_foreach_supported_languages');
  late final _vc_foreach_supported_languages =
      _vc_foreach_supported_languagesPtr.asFunction<
          int Function(vc_supported_language_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Gets current language.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remark If the function succeeds, @a language must be released with free() by you when you no longer need it.
  /// @param[out] language A language is specified as an ISO 3166 alpha-2 two letter country-code
  /// followed by ISO 639-1 for the two-letter language code.
  /// For example, "ko_KR" for Korean, "en_US" for American English
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_OUT_OF_MEMORY Out of memory
  /// @retval #VC_ERROR_OPERATION_FAILED Operation failure
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED or #VC_STATE_READY.
  /// @see vc_foreach_supported_languages()
  int vc_get_current_language(
    ffi.Pointer<ffi.Pointer<ffi.Char>> language,
  ) {
    return _vc_get_current_language(
      language,
    );
  }

  late final _vc_get_current_languagePtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              ffi.Pointer<ffi.Pointer<ffi.Char>>)>>('vc_get_current_language');
  late final _vc_get_current_language = _vc_get_current_languagePtr
      .asFunction<int Function(ffi.Pointer<ffi.Pointer<ffi.Char>>)>();

  /// @brief Gets current state of voice control client.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[out] state The current state
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @see vc_state_changed_cb()
  /// @see vc_set_state_changed_cb()
  int vc_get_state(
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _vc_get_state(
      state,
    );
  }

  late final _vc_get_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'vc_get_state');
  late final _vc_get_state =
      _vc_get_statePtr.asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets current state of voice control service.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[out] state The current state
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_READY.
  /// @see vc_request_start()
  /// @see vc_request_stop()
  /// @see vc_request_cancel()
  /// @see vc_set_service_state_changed_cb()
  /// @see vc_unset_service_state_changed_cb()
  int vc_get_service_state(
    ffi.Pointer<ffi.Int32> state,
  ) {
    return _vc_get_service_state(
      state,
    );
  }

  late final _vc_get_service_statePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Int32>)>>(
          'vc_get_service_state');
  late final _vc_get_service_state = _vc_get_service_statePtr
      .asFunction<int Function(ffi.Pointer<ffi.Int32>)>();

  /// @brief Gets the system command list.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks In the system command list, there are system commands predefined by product manufacturers. Those commands have the highest priority.
  /// Therefore, the user can not set any commands same with the system commands.
  /// The @a vc_sys_cmd_list must be released using free() when it is no longer required.
  /// @param[out] vc_sys_cmd_list System command list handle
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The service state should be #VC_SERVICE_STATE_READY.
  /// @see vc_unset_command_list()
  int vc_get_system_command_list(
    ffi.Pointer<vc_cmd_list_h> vc_sys_cmd_list,
  ) {
    return _vc_get_system_command_list(
      vc_sys_cmd_list,
    );
  }

  late final _vc_get_system_command_listPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<vc_cmd_list_h>)>>(
          'vc_get_system_command_list');
  late final _vc_get_system_command_list = _vc_get_system_command_listPtr
      .asFunction<int Function(ffi.Pointer<vc_cmd_list_h>)>();

  /// @brief Sets the invocation name.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks Invocation name is used to activate background commands. The invocation name can be the same as the application name or any other phrase.
  /// For example, an application "Tizen Sample" has a background command, "Play music", and the invocation name of the application is set to "Tizen Sample".
  /// In order to activate the background command, users can say "Tizen Sample, Play music".
  /// The invocation name is dependent on the current language. For example, if the current language is "en_US"(English), the invocation name is also "en_US".
  /// If the current language is "ja_JP"(Japanese) and the invocation name is "en_US", the invocation name will not be recognized.
  /// This function should be called before vc_set_command_list().
  /// @param[in] name Invocation name that an application wants to be invoked by
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_READY.
  /// @see vc_set_command_list()
  int vc_set_invocation_name(
    ffi.Pointer<ffi.Char> name,
  ) {
    return _vc_set_invocation_name(
      name,
    );
  }

  late final _vc_set_invocation_namePtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>)>>(
          'vc_set_invocation_name');
  late final _vc_set_invocation_name = _vc_set_invocation_namePtr
      .asFunction<int Function(ffi.Pointer<ffi.Char>)>();

  /// @brief Requests to start the dialogue.
  /// @details Using this function, the developer can request starting the dialogue to the framework.
  /// When the developer requests the dialogue, two types of texts, @a disp_text and @a utt_text, can be sent by this function.
  /// @a disp_text is a text for displaying, and @a utt_text is that for uttering.
  /// For example, if @a disp_text is "October 10th" and @a utt_text is "Today is October 10th.", "October 10th" will be displayed on the screen and "Today is October 10th." will be spoken.
  /// Also, the developer can set whether the dialogue starts automatically or not, using @a auto_start.
  /// If the developer sets @a auto_start as @c true, the framework will start to record next speech and continue the dialogue.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks If @a auto_start is @c true, the recognition will start again. In this case, it can be restarted up to 4 times.
  /// @param[in] disp_text Text to be displayed on the screen
  /// @param[in] utt_text Text to be spoken
  /// @param[in] auto_start A variable for setting whether the dialog session will be restarted automatically or not
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The service state should be #VC_SERVICE_STATE_READY.
  int vc_request_dialog(
    ffi.Pointer<ffi.Char> disp_text,
    ffi.Pointer<ffi.Char> utt_text,
    bool auto_start,
  ) {
    return _vc_request_dialog(
      disp_text,
      utt_text,
      auto_start,
    );
  }

  late final _vc_request_dialogPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
              ffi.Bool)>>('vc_request_dialog');
  late final _vc_request_dialog = _vc_request_dialogPtr.asFunction<
      int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, bool)>();

  /// @brief Sets command list.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @remarks The command type is valid for #VC_COMMAND_TYPE_FOREGROUND or #VC_COMMAND_TYPE_BACKGROUND.
  /// The matched commands of command list should be set and they should include type and command text at least.
  /// @param[in] vc_cmd_list Command list handle
  /// @param[in] type Command type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_READY.
  /// @see vc_unset_command_list()
  int vc_set_command_list(
    vc_cmd_list_h vc_cmd_list,
    int type,
  ) {
    return _vc_set_command_list(
      vc_cmd_list,
      type,
    );
  }

  late final _vc_set_command_listPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(vc_cmd_list_h, ffi.Int)>>(
          'vc_set_command_list');
  late final _vc_set_command_list =
      _vc_set_command_listPtr.asFunction<int Function(vc_cmd_list_h, int)>();

  /// @brief Unsets command list.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] type Command type
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_READY.
  /// @see vc_set_command_list()
  int vc_unset_command_list(
    int type,
  ) {
    return _vc_unset_command_list(
      type,
    );
  }

  late final _vc_unset_command_listPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>(
          'vc_unset_command_list');
  late final _vc_unset_command_list =
      _vc_unset_command_listPtr.asFunction<int Function(int)>();

  /// @brief Gets the recognition result.
  /// @since_tizen 3.0
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] callback Callback function to get recognition result
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_READY.
  /// @see vc_result_cb()
  int vc_get_result(
    vc_result_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _vc_get_result(
      callback,
      user_data,
    );
  }

  late final _vc_get_resultPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              vc_result_cb, ffi.Pointer<ffi.Void>)>>('vc_get_result');
  late final _vc_get_result = _vc_get_resultPtr
      .asFunction<int Function(vc_result_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Registers a callback function for getting recognition result.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] callback Callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @see vc_result_cb()
  /// @see vc_unset_result_cb()
  int vc_set_result_cb(
    vc_result_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _vc_set_result_cb(
      callback,
      user_data,
    );
  }

  late final _vc_set_result_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              vc_result_cb, ffi.Pointer<ffi.Void>)>>('vc_set_result_cb');
  late final _vc_set_result_cb = _vc_set_result_cbPtr
      .asFunction<int Function(vc_result_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @see vc_set_result_cb()
  int vc_unset_result_cb() {
    return _vc_unset_result_cb();
  }

  late final _vc_unset_result_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('vc_unset_result_cb');
  late final _vc_unset_result_cb =
      _vc_unset_result_cbPtr.asFunction<int Function()>();

  /// @brief Registers a callback function to be called when state is changed.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] callback Callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @see vc_service_state_changed_cb()
  /// @see vc_unset_service_state_changed_cb()
  int vc_set_service_state_changed_cb(
    vc_service_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _vc_set_service_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _vc_set_service_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(vc_service_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('vc_set_service_state_changed_cb');
  late final _vc_set_service_state_changed_cb =
      _vc_set_service_state_changed_cbPtr.asFunction<
          int Function(vc_service_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @see vc_set_service_state_changed_cb()
  int vc_unset_service_state_changed_cb() {
    return _vc_unset_service_state_changed_cb();
  }

  late final _vc_unset_service_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'vc_unset_service_state_changed_cb');
  late final _vc_unset_service_state_changed_cb =
      _vc_unset_service_state_changed_cbPtr.asFunction<int Function()>();

  /// @brief Registers a callback function to be called when state is changed.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] callback Callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @see vc_state_changed_cb()
  /// @see vc_unset_state_changed_cb()
  int vc_set_state_changed_cb(
    vc_state_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _vc_set_state_changed_cb(
      callback,
      user_data,
    );
  }

  late final _vc_set_state_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(vc_state_changed_cb,
              ffi.Pointer<ffi.Void>)>>('vc_set_state_changed_cb');
  late final _vc_set_state_changed_cb = _vc_set_state_changed_cbPtr
      .asFunction<int Function(vc_state_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @see vc_set_state_changed_cb()
  int vc_unset_state_changed_cb() {
    return _vc_unset_state_changed_cb();
  }

  late final _vc_unset_state_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'vc_unset_state_changed_cb');
  late final _vc_unset_state_changed_cb =
      _vc_unset_state_changed_cbPtr.asFunction<int Function()>();

  /// @brief Registers a callback function to be called when current language is changed.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] callback Callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @see vc_current_language_changed_cb()
  /// @see vc_unset_current_language_changed_cb()
  int vc_set_current_language_changed_cb(
    vc_current_language_changed_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _vc_set_current_language_changed_cb(
      callback,
      user_data,
    );
  }

  late final _vc_set_current_language_changed_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(vc_current_language_changed_cb,
              ffi.Pointer<ffi.Void>)>>('vc_set_current_language_changed_cb');
  late final _vc_set_current_language_changed_cb =
      _vc_set_current_language_changed_cbPtr.asFunction<
          int Function(
              vc_current_language_changed_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @see vc_set_current_language_changed_cb()
  int vc_unset_current_language_changed_cb() {
    return _vc_unset_current_language_changed_cb();
  }

  late final _vc_unset_current_language_changed_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>(
          'vc_unset_current_language_changed_cb');
  late final _vc_unset_current_language_changed_cb =
      _vc_unset_current_language_changed_cbPtr.asFunction<int Function()>();

  /// @brief Registers a callback function to be called when an error occurred.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @param[in] callback Callback function to register
  /// @param[in] user_data The user data to be passed to the callback function
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_PARAMETER Invalid parameter
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @see vc_error_cb()
  /// @see vc_unset_error_cb()
  int vc_set_error_cb(
    vc_error_cb callback,
    ffi.Pointer<ffi.Void> user_data,
  ) {
    return _vc_set_error_cb(
      callback,
      user_data,
    );
  }

  late final _vc_set_error_cbPtr = _lookup<
      ffi.NativeFunction<
          ffi.Int Function(
              vc_error_cb, ffi.Pointer<ffi.Void>)>>('vc_set_error_cb');
  late final _vc_set_error_cb = _vc_set_error_cbPtr
      .asFunction<int Function(vc_error_cb, ffi.Pointer<ffi.Void>)>();

  /// @brief Unregisters the callback function.
  /// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  /// @privlevel public
  /// @privilege %http://tizen.org/privilege/recorder
  /// @return @c 0 on success,
  /// otherwise a negative error value
  /// @retval #VC_ERROR_NONE Successful
  /// @retval #VC_ERROR_INVALID_STATE Invalid state
  /// @retval #VC_ERROR_PERMISSION_DENIED Permission denied
  /// @retval #VC_ERROR_NOT_SUPPORTED Not supported
  /// @pre The state should be #VC_STATE_INITIALIZED.
  /// @see vc_set_error_cb()
  int vc_unset_error_cb() {
    return _vc_unset_error_cb();
  }

  late final _vc_unset_error_cbPtr =
      _lookup<ffi.NativeFunction<ffi.Int Function()>>('vc_unset_error_cb');
  late final _vc_unset_error_cb =
      _vc_unset_error_cbPtr.asFunction<int Function()>();
}

/// @brief Enumeration for tizen errors.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class tizen_error_e {
  /// < Successful
  static const int TIZEN_ERROR_NONE = 0;

  /// < Operation not permitted
  static const int TIZEN_ERROR_NOT_PERMITTED = -1;

  /// < No such file or directory
  static const int TIZEN_ERROR_NO_SUCH_FILE = -2;

  /// < No such process
  static const int TIZEN_ERROR_NO_SUCH_PROCESS = -3;

  /// < Interrupted system call
  static const int TIZEN_ERROR_INTERRUPTED_SYS_CALL = -4;

  /// < I/O error
  static const int TIZEN_ERROR_IO_ERROR = -5;

  /// < No such device or address
  static const int TIZEN_ERROR_NO_SUCH_DEVICE = -6;

  /// < Argument list too long
  static const int TIZEN_ERROR_ARGUMENT_LIST_TOO_LONG = -7;

  /// < Exec format error
  static const int TIZEN_ERROR_EXEC_FORMAT_ERROR = -8;

  /// < Bad file number
  static const int TIZEN_ERROR_BAD_FILE_NUMBER = -9;

  /// < Try again
  static const int TIZEN_ERROR_TRY_AGAIN = -11;

  /// < Out of memory
  static const int TIZEN_ERROR_OUT_OF_MEMORY = -12;

  /// < Permission denied
  static const int TIZEN_ERROR_PERMISSION_DENIED = -13;

  /// < Bad address
  static const int TIZEN_ERROR_BAD_ADDRESS = -14;

  /// < Block device required
  static const int TIZEN_ERROR_BLOCK_DEVICE_REQUIRED = -15;

  /// < Device or resource busy
  static const int TIZEN_ERROR_RESOURCE_BUSY = -16;

  /// < File exists
  static const int TIZEN_ERROR_FILE_EXISTS = -17;

  /// < Cross-device link
  static const int TIZEN_ERROR_CROSS_DEVICE_LINK = -18;

  /// < Not a directory
  static const int TIZEN_ERROR_NOT_A_DIRECTORY = -20;

  /// < Is a directory
  static const int TIZEN_ERROR_IS_A_DIRECTORY = -21;

  /// < Invalid function parameter
  static const int TIZEN_ERROR_INVALID_PARAMETER = -22;

  /// < File table overflow
  static const int TIZEN_ERROR_FILE_TABLE_OVERFLOW = -23;

  /// < Too many open files
  static const int TIZEN_ERROR_TOO_MANY_OPEN_FILES = -24;

  /// < Not a terminal
  static const int TIZEN_ERROR_TOO_NOT_A_TERMINAL = -25;

  /// < Not a terminal
  static const int TIZEN_ERROR_TOO_TEXT_FILE_BUSY = -26;

  /// < File too large
  static const int TIZEN_ERROR_FILE_TOO_LARGE = -27;

  /// < No space left on device
  static const int TIZEN_ERROR_FILE_NO_SPACE_ON_DEVICE = -28;

  /// < Illegal seek
  static const int TIZEN_ERROR_ILLEGAL_SEEK = -29;

  /// < Read-only file system
  static const int TIZEN_ERROR_READ_ONLY_FILESYSTEM = -30;

  /// < No data available
  static const int TIZEN_ERROR_NO_DATA = -61;

  /// < Too many links
  static const int TIZEN_ERROR_TOO_MANY_LINKS = -31;

  /// < Broken pipe
  static const int TIZEN_ERROR_BROKEN_PIPE = -32;

  /// < Math argument out of domain of func
  static const int TIZEN_ERROR_ARGUMENT_OUT_OF_DOMAIN = -33;

  /// < Math result not representable
  static const int TIZEN_ERROR_RESULT_OUT_OF_RANGE = -34;

  /// < Resource deadlock would occur
  static const int TIZEN_ERROR_WOULD_CAUSE_DEADLOCK = -35;

  /// < File name too long
  static const int TIZEN_ERROR_FILE_NAME_TOO_LONG = -36;

  /// < No record locks available
  static const int TIZEN_ERROR_FILE_NO_LOCKS_AVAILABLE = -37;

  /// < Function not implemented
  static const int TIZEN_ERROR_INVALID_OPERATION = -38;

  /// < Directory not empty
  static const int TIZEN_ERROR_DIR_NOT_EMPTY = -39;

  /// < Too many symbolic links encountered
  static const int TIZEN_ERROR_TOO_MANY_SYMBOLIC_LINKS = -40;

  /// < Operation would block
  static const int TIZEN_ERROR_WOULD_BLOCK = -11;

  /// < Accessing a corrupted shared library
  static const int TIZEN_ERROR_CORRUPTED_SHARED_LIB = -80;

  /// < .lib section in a.out corrupted
  static const int TIZEN_ERROR_LIB_SECTION_CORRUPTED = -81;

  /// < Attempting to link in too many shared libraries
  static const int TIZEN_ERROR_LINK_TOO_MANY_SHARED_LIB = -82;

  /// < Cannot exec a shared library directly
  static const int TIZEN_ERROR_SHARED_LIB_EXEC = -83;

  /// < Illegal byte sequence
  static const int TIZEN_ERROR_ILLEGAL_BYTE_SEQ = -84;

  /// < Interrupted system call should be restarted
  static const int TIZEN_ERROR_SYSTEM_CALL_RESTART = -85;

  /// < Streams pipe error
  static const int TIZEN_ERROR_STREAMS_PIPE = -86;

  /// < Too many users
  static const int TIZEN_ERROR_TOO_MANY_USERS = -87;

  /// < Socket operation on non-socket
  static const int TIZEN_ERROR_NON_SOCKET = -88;

  /// < Destination address required
  static const int TIZEN_ERROR_NO_DEST_ADDRESS = -89;

  /// < Message too long
  static const int TIZEN_ERROR_MSG_TOO_LONG = -90;

  /// < Protocol wrong type for socket
  static const int TIZEN_ERROR_PROTOCOL_WRONG_TYPE = -91;

  /// < Protocol not available
  static const int TIZEN_ERROR_PROTOCOL_NOT_AVALIABLE = -92;

  /// < Protocol not supported
  static const int TIZEN_ERROR_PROTOCOL_NOT_SUPPORTED = -93;

  /// < Socket type not supported
  static const int TIZEN_ERROR_SOCKET_TYPE_NOT_SUPPORTED = -94;

  /// < Operation not supported on transport endpoint
  static const int TIZEN_ERROR_ENDPOINT_OPERATIN_NOT_SUPPORTED = -95;

  /// < Protocol family not supported
  static const int TIZEN_ERROR_PROTOCOL_FAMILY_NOT_SUPPORTED = -96;

  /// < Address family not supported by protocol
  static const int TIZEN_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED = -97;

  /// < Address already in use
  static const int TIZEN_ERROR_ADDRES_IN_USE = -98;

  /// < Cannot assign requested address
  static const int TIZEN_ERROR_CANNOT_ASSIGN_ADDRESS = -99;

  /// < Network is down
  static const int TIZEN_ERROR_NETWORK_DOWN = -100;

  /// < Network is unreachable
  static const int TIZEN_ERROR_NETWORK_UNREACHABLE = -101;

  /// < Network dropped connection because of reset
  static const int TIZEN_ERROR_NETWORK_RESET = -102;

  /// < Software caused connection abort
  static const int TIZEN_ERROR_CONNECTION_ABORTED = -103;

  /// < Connection reset by peer
  static const int TIZEN_ERROR_CONNECTION_RESET_BY_PEER = -104;

  /// < No buffer space available
  static const int TIZEN_ERROR_BUFFER_SPACE = -105;

  /// < Transport endpoint is already connected
  static const int TIZEN_ERROR_ENDPOINT_CONNECTED = -106;

  /// < Transport endpoint is not connected
  static const int TIZEN_ERROR_ENDPOINT_NOT_CONNECTED = -107;

  /// < Cannot send after transport endpoint shutdown
  static const int TIZEN_ERROR_ENDPOINT_SHUTDOWN = -108;

  /// < Too many references: cannot splice
  static const int TIZEN_ERROR_TOO_MANY_REFERENCES = -109;

  /// < Connection timed out
  static const int TIZEN_ERROR_CONNECTION_TIME_OUT = -110;

  /// < Connection refused
  static const int TIZEN_ERROR_CONNECTION_REFUSED = -111;

  /// < Host is down
  static const int TIZEN_ERROR_HOST_DOWN = -112;

  /// < No route to host
  static const int TIZEN_ERROR_NO_ROUTE_TO_HOST = -113;

  /// < Operation already in progress
  static const int TIZEN_ERROR_ALREADY_IN_PROGRESS = -114;

  /// < Operation now in progress
  static const int TIZEN_ERROR_NOW_IN_PROGRESS = -115;

  /// < Stale NFS file handle
  static const int TIZEN_ERROR_STALE_NFS_FILE_HANDLE = -116;

  /// < Structure needs cleaning
  static const int TIZEN_ERROR_STRUCTURE_UNCLEAN = -117;

  /// < Not a XENIX named type file
  static const int TIZEN_ERROR_NOT_XENIX_NAMED_TYPE_FILE = -118;

  /// < No XENIX semaphores available
  static const int TIZEN_ERROR_NO_XENIX_SEMAPHORES_AVAILABLE = -119;

  /// < Is a named type file
  static const int TIZEN_ERROR_IS_NAMED_TYPE_FILE = -120;

  /// < Remote I/O error
  static const int TIZEN_ERROR_REMOTE_IO = -121;

  /// < Quota exceeded
  static const int TIZEN_ERROR_QUOTA_EXCEEDED = -122;

  /// < No medium found
  static const int TIZEN_ERROR_NO_MEDIUM = -123;

  /// < Wrong medium type
  static const int TIZEN_ERROR_WRONG_MEDIUM_TYPE = -124;

  /// < Operation Canceled
  static const int TIZEN_ERROR_CANCELED = -125;

  /// < Required key not available
  static const int TIZEN_ERROR_KEY_NOT_AVAILABLE = -126;

  /// < Key has expired
  static const int TIZEN_ERROR_KEY_EXPIRED = -127;

  /// < Key has been revoked
  static const int TIZEN_ERROR_KEY_REVOKED = -128;

  /// < Key was rejected by service
  static const int TIZEN_ERROR_KEY_REJECTED = -129;

  /// < Owner died (for robust mutexes)
  static const int TIZEN_ERROR_OWNER_DEAD = -130;

  /// < Unknown error
  static const int TIZEN_ERROR_UNKNOWN = -1073741824;

  /// < Time out
  static const int TIZEN_ERROR_TIMED_OUT = -1073741823;

  /// < Not supported
  static const int TIZEN_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Not Consented
  static const int TIZEN_ERROR_USER_NOT_CONSENTED = -1073741821;

  /// < Restriction by Device Policy
  static const int TIZEN_ERROR_DEVICE_POLICY_RESTRICTION = -1073741820;
  static const int TIZEN_ERROR_END_OF_COLLECTION = -1073741819;
}

class _bundle_t extends ffi.Opaque {}

class app_control_s extends ffi.Opaque {}

/// @brief Enumeration for the application control error.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class app_control_error_e {
  /// < Successful
  static const int APP_CONTROL_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int APP_CONTROL_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int APP_CONTROL_ERROR_OUT_OF_MEMORY = -12;

  /// < The application is not found
  static const int APP_CONTROL_ERROR_APP_NOT_FOUND = -17825759;

  /// < Specified key is not found
  static const int APP_CONTROL_ERROR_KEY_NOT_FOUND = -126;

  /// < Key is not available
  static const int APP_CONTROL_ERROR_KEY_REJECTED = -129;

  /// < Invalid data type
  static const int APP_CONTROL_ERROR_INVALID_DATA_TYPE = -17825758;

  /// < The application cannot be launched now
  static const int APP_CONTROL_ERROR_LAUNCH_REJECTED = -17825757;

  /// < Permission denied
  static const int APP_CONTROL_ERROR_PERMISSION_DENIED = -13;

  /// < Internal launch error
  static const int APP_CONTROL_ERROR_LAUNCH_FAILED = -17825756;

  /// < Time out
  static const int APP_CONTROL_ERROR_TIMED_OUT = -1073741823;

  /// < IO error
  static const int APP_CONTROL_ERROR_IO_ERROR = -5;
}

/// @brief Enumeration for the application control result.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see app_control_enable_app_started_result_event()
abstract class app_control_result_e {
  /// < Callee application launched actually (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int APP_CONTROL_RESULT_APP_STARTED = 1;

  /// < Operation succeeded
  static const int APP_CONTROL_RESULT_SUCCEEDED = 0;

  /// < Operation failed by the callee
  static const int APP_CONTROL_RESULT_FAILED = -1;

  /// < Operation canceled by the platform
  static const int APP_CONTROL_RESULT_CANCELED = -2;
}

/// @brief Enumeration for the application control launch mode.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class app_control_launch_mode_e {
  /// < Prefer to launch an application as single mode
  static const int APP_CONTROL_LAUNCH_MODE_SINGLE = 0;

  /// < Prefer to launch an application as group mode
  static const int APP_CONTROL_LAUNCH_MODE_GROUP = 1;
}

/// @brief The application control handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef app_control_h = ffi.Pointer<app_control_s>;

/// @brief Called to retrieve the extra data contained in the app_control.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks The @a key must not be deallocated by the application.
/// @param[in] app_control The app_control handle
/// @param[in] key The key of the value contained in the app_control
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre app_control_foreach_extra_data() will invoke this callback.
/// @see app_control_foreach_extra_data()
typedef app_control_extra_data_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            app_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called once for each matched application that can be launched to handle the given app_control request.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] app_control The app_control handle
/// @param[in] package The package name of the application that can handle the launch request of the given app_control
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre app_control_foreach_app_matched() will invoke this callback.
/// @see app_control_foreach_app_matched()
typedef app_control_app_matched_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            app_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the reply of the launch request is delivered.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks The @a request and @a reply must not be deallocated by the application.
/// @param[in] request The app_control handle of the launch request that has been sent
/// @param[in] reply The app_control handle in which the results of the callee are contained
/// @param[in] result The result code of the launch request
/// @param[in] user_data The user data passed from the callback registration function
/// @pre When the callee replies to the launch request, this callback will be invoked.
/// @pre Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, if #APP_CONTROL_RESULT_APP_STARTED event is enabled,
/// this callback will also be invoked when the callee application actually launched.
/// @see app_control_send_launch_request()
/// @see app_control_reply_to_launch_request()
/// @see app_control_enable_app_started_result_event()
/// @see #APP_CONTROL_RESULT_APP_STARTED
typedef app_control_reply_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            app_control_h, app_control_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for application error.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class app_error_e {
  /// < Successful
  static const int APP_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int APP_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int APP_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid application context
  static const int APP_ERROR_INVALID_CONTEXT = -17825791;

  /// < No such file or directory
  static const int APP_ERROR_NO_SUCH_FILE = -2;

  /// < Not supported (Since 4.0)
  static const int APP_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Application is already running
  static const int APP_ERROR_ALREADY_RUNNING = -114;

  /// < Permission denied @if MOBILE (Since 2.3.1) @endif
  static const int APP_ERROR_PERMISSION_DENIED = -13;
}

/// @brief Enumeration for system events.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class app_event_type_e {
  /// < The low memory event
  static const int APP_EVENT_LOW_MEMORY = 0;

  /// < The low battery event
  static const int APP_EVENT_LOW_BATTERY = 1;

  /// < The system language changed event
  static const int APP_EVENT_LANGUAGE_CHANGED = 2;

  /// < The device orientation changed event
  static const int APP_EVENT_DEVICE_ORIENTATION_CHANGED = 3;

  /// < The region format changed event
  static const int APP_EVENT_REGION_FORMAT_CHANGED = 4;

  /// < The suspended state changed event of the application (since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  /// @see app_event_get_suspended_state
  static const int APP_EVENT_SUSPENDED_STATE_CHANGED = 5;

  /// < The update requested event (Since 3.0)
  /// This event can occur when an app needs to be updated.
  /// It is dependent on target devices.
  static const int APP_EVENT_UPDATE_REQUESTED = 6;
}

/// @brief Enumeration for device orientation.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class app_device_orientation_e {
  /// < The device is oriented in a natural position
  static const int APP_DEVICE_ORIENTATION_0 = 0;

  /// < The device's left side is at the top
  static const int APP_DEVICE_ORIENTATION_90 = 90;

  /// < The device is upside down
  static const int APP_DEVICE_ORIENTATION_180 = 180;

  /// < The device's right side is at the top
  static const int APP_DEVICE_ORIENTATION_270 = 270;
}

/// @brief Enumeration for low memory status.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class app_event_low_memory_status_e {
  /// < Normal status
  static const int APP_EVENT_LOW_MEMORY_NORMAL = 1;

  /// < Soft warning status
  static const int APP_EVENT_LOW_MEMORY_SOFT_WARNING = 2;

  /// < Hard warning status
  static const int APP_EVENT_LOW_MEMORY_HARD_WARNING = 4;
}

/// @brief Enumeration for battery status.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class app_event_low_battery_status_e {
  /// < The battery status is under 1%
  static const int APP_EVENT_LOW_BATTERY_POWER_OFF = 1;

  /// < The battery status is under 5%
  static const int APP_EVENT_LOW_BATTERY_CRITICAL_LOW = 2;
}

/// @brief Enumeration for suspended state.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class app_suspended_state_e {
  /// < Application will enter the suspended state
  static const int APP_SUSPENDED_STATE_WILL_ENTER = 0;

  /// < Application did exit from the suspended state
  static const int APP_SUSPENDED_STATE_DID_EXIT = 1;
}

class app_event_handler extends ffi.Opaque {}

class app_event_info extends ffi.Opaque {}

/// @brief The system event information handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see app_event_get_low_memory_status
/// @see app_event_get_low_battery_status
/// @see app_event_get_language
/// @see app_event_get_region_format
/// @see app_event_get_device_orientation
/// @see app_event_get_suspended_state
typedef app_event_info_h = ffi.Pointer<app_event_info>;

/// @brief The structure type containing the set of callback functions for handling application lifecycle events.
/// @details It is one of the input parameters of the ui_app_main() function.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see ui_app_main()
/// @see app_create_cb()
/// @see app_pause_cb()
/// @see app_resume_cb()
/// @see app_terminate_cb()
/// @see app_control_cb()
class ui_app_lifecycle_callback_s extends ffi.Struct {
  /// < This callback function is called at the start of the application.
  external app_create_cb create;

  /// < This callback function is called once after the main loop of the application exits.
  external app_terminate_cb terminate;

  /// < This callback function is called each time the application is completely obscured by another application and becomes invisible to the user.
  external app_pause_cb pause;

  /// < This callback function is called each time the application becomes visible to the user.
  external app_resume_cb resume;

  /// < This callback function is called when another application sends the launch request to the application.
  external app_control_cb app_control;
}

/// @brief Called when the application starts.
/// @details The callback function is called before the main loop of the application starts.
/// In this callback, you can initialize application resources like window creation, data structure, and so on.
/// After this callback function returns @c true, the main loop starts up and app_control_cb() is subsequently called.
/// If this callback function returns @c false, the main loop doesn't start and app_terminate_cb() is subsequently called.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] user_data	The user data passed from the callback registration function
/// @return @c true on success,
/// otherwise @c false
/// @pre	ui_app_main() will invoke this callback function.
/// @see ui_app_main()
/// @see #ui_app_lifecycle_callback_s
typedef app_create_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Bool Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the application's main loop exits.
/// @details You should release the application's resources in this function.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] user_data	The user data passed from the callback registration function
/// @see	ui_app_main()
/// @see #ui_app_lifecycle_callback_s
typedef app_terminate_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the application is completely obscured by another application and becomes invisible.
/// @details The application is not terminated and still running in the paused state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] user_data	The user data passed from the callback registration function
/// @see	ui_app_main()
/// @see	#ui_app_lifecycle_callback_s
typedef app_pause_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the application becomes visible.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] user_data	The user data passed from the callback registration function
/// @see	ui_app_main()
/// @see #ui_app_lifecycle_callback_s
typedef app_resume_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when another application sends a launch request to the application.
/// @details When the application is launched, this callback function is called after the main loop of the application starts up.
/// The passed app_control handle describes the launch request and contains the information about why the application is launched.
/// If the launch request is sent to the application in the running or pause state,
/// this callback function can be called again to notify that the application has been asked to launch.
/// The application could be explicitly launched by the user from the application launcher or be launched to perform the specific operation by another application.
/// The application is responsible for handling each launch request and responding appropriately.
/// Using the App Control API, the application can get information about what is to be performed.
/// If the application is launched from the application launcher or explicitly launched by another application,
/// the passed app_control handle may include only the default operation (#APP_CONTROL_OPERATION_DEFAULT) without any data.
/// For more information, see The @ref CAPI_APP_CONTROL_MODULE API description.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks After this callback returns, the handle of the app_control is freed.
/// Therefore, if you want to use the handle after returning this callback, you MUST copy it by using app_control_clone() API.
/// @param[in] app_control The handle to the app_control
/// @param[in] user_data	The user data passed from the callback registration function
/// @see ui_app_main()
/// @see #ui_app_lifecycle_callback_s
/// @see @ref CAPI_APP_CONTROL_MODULE API
typedef app_control_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(app_control_h, ffi.Pointer<ffi.Void>)>>;

/// @brief The event handler that returned from add event handler function to handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see app_event_type_e
/// @see app_add_event_handler
/// @see app_remove_event_handler
/// @see app_event_info_h
typedef app_event_handler_h = ffi.Pointer<app_event_handler>;

/// @brief The system event callback function.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] event_info The system event information
/// @param[in] user_data The user data passed from the add event handler function
/// @see app_add_event_handler
/// @see app_event_info_h
/// @remarks If the given @a event_info has #APP_SUSPENDED_STATE_WILL_ENTER value,
/// the application should not call any asynchronous operations in this callback.
/// After the callback returns, process of the application will be changed to suspended
/// state immediately. Thus, asynchronous operations may work incorrectly. (since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
typedef app_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(app_event_info_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for error codes of Bundle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class bundle_error_e {
  /// < Successful
  static const int BUNDLE_ERROR_NONE = 0;

  /// < Out of memory
  static const int BUNDLE_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int BUNDLE_ERROR_INVALID_PARAMETER = -22;

  /// < Required key not available
  static const int BUNDLE_ERROR_KEY_NOT_AVAILABLE = -126;

  /// < Key exists
  static const int BUNDLE_ERROR_KEY_EXISTS = -18350079;
}

/// @brief Enumeration for key-value pair types.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class bundle_type_property {
  /// < Array type
  static const int BUNDLE_TYPE_ARRAY = 256;

  /// < Primitive type
  static const int BUNDLE_TYPE_PRIMITIVE = 512;

  /// < Measurable type
  static const int BUNDLE_TYPE_MEASURABLE = 1024;
}

/// @brief Enumeration for bundle types.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class bundle_type {
  /// < None
  static const int BUNDLE_TYPE_NONE = -1;

  /// < Any type
  static const int BUNDLE_TYPE_ANY = 0;

  /// < String type (Default)
  static const int BUNDLE_TYPE_STR = 1025;

  /// < String array type
  static const int BUNDLE_TYPE_STR_ARRAY = 1281;

  /// < Byte type
  static const int BUNDLE_TYPE_BYTE = 2;

  /// < Byte array type
  static const int BUNDLE_TYPE_BYTE_ARRAY = 258;
}

class keyval_t extends ffi.Opaque {}

/// @brief The bundle handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef bundle = _bundle_t;

/// @brief Called for every key-value pair.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see bundle_foreach()
typedef bundle_iterator_t = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Int,
            ffi.Pointer<bundle_keyval_t>, ffi.Pointer<ffi.Void>)>>;

/// @brief The key-value pair handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see bundle_iterator_t
typedef bundle_keyval_t = keyval_t;

/// @brief The encoded data type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see bundle_encode()
/// @see bundle_decode()
typedef bundle_raw = ffi.UnsignedChar;

/// @brief Enumeration for notification errors.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_error {
  /// < Success
  static const int NOTIFICATION_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int NOTIFICATION_ERROR_INVALID_PARAMETER = -22;

  /// < out of memory
  static const int NOTIFICATION_ERROR_OUT_OF_MEMORY = -12;

  /// < I/O error
  static const int NOTIFICATION_ERROR_IO_ERROR = -5;

  /// < Permission denied
  static const int NOTIFICATION_ERROR_PERMISSION_DENIED = -13;

  /// < Function not implemented (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int NOTIFICATION_ERROR_INVALID_OPERATION = -38;

  /// < Error from DB query
  static const int NOTIFICATION_ERROR_FROM_DB = -18087935;

  /// < Already exist private ID
  static const int NOTIFICATION_ERROR_ALREADY_EXIST_ID = -18087934;

  /// < Error from DBus
  static const int NOTIFICATION_ERROR_FROM_DBUS = -18087933;

  /// < Not exist private ID
  static const int NOTIFICATION_ERROR_NOT_EXIST_ID = -18087932;

  /// < No response from notification service
  static const int NOTIFICATION_ERROR_SERVICE_NOT_READY = -18087931;

  /// < Max notification count exceeded (@b Since: 3.0)
  static const int NOTIFICATION_ERROR_MAX_EXCEEDED = -18087930;
}

/// @brief Enumeration for notification layout type.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_ly_type {
  /// < Default
  static const int NOTIFICATION_LY_NONE = 0;

  /// < Layout for notification. Used to inform single event
  static const int NOTIFICATION_LY_NOTI_EVENT_SINGLE = 1;

  /// < Layout for notification. Used to inform multiple event
  static const int NOTIFICATION_LY_NOTI_EVENT_MULTIPLE = 2;

  /// < Layout for notification. Used to display images
  static const int NOTIFICATION_LY_NOTI_THUMBNAIL = 3;

  /// < Layout for ongoing notification. Used to display text message.
  /// notifications with NOTIFICATION_LY_ONGOING_EVENT can not be protected from
  /// removing by user since tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
  static const int NOTIFICATION_LY_ONGOING_EVENT = 4;

  /// < Layout for ongoing notification. Used to display progress
  static const int NOTIFICATION_LY_ONGOING_PROGRESS = 5;

  /// < Layout for extended notification (Since 4.0)
  static const int NOTIFICATION_LY_EXTENSION = 6;
}

/// @brief Enumeration for notification lauch option type.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_launch_option_type {
  static const int NOTIFICATION_LAUNCH_OPTION_APP_CONTROL = 1;
}

/// @brief Enumeration for event type on notification.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class notification_event_type {
  /// < Event type : Click on button 1
  static const int NOTIFICATION_EVENT_TYPE_CLICK_ON_BUTTON_1 = 0;

  /// < Event type : Click on button 2
  static const int NOTIFICATION_EVENT_TYPE_CLICK_ON_BUTTON_2 = 1;

  /// < Event type : Click on button 3
  static const int NOTIFICATION_EVENT_TYPE_CLICK_ON_BUTTON_3 = 2;

  /// < Event type : Click on button 4
  static const int NOTIFICATION_EVENT_TYPE_CLICK_ON_BUTTON_4 = 3;

  /// < Event type : Click on button 5
  static const int NOTIFICATION_EVENT_TYPE_CLICK_ON_BUTTON_5 = 4;

  /// < Event type : Click on button 6
  static const int NOTIFICATION_EVENT_TYPE_CLICK_ON_BUTTON_6 = 5;

  /// < Event type : Click on icon
  static const int NOTIFICATION_EVENT_TYPE_CLICK_ON_ICON = 6;

  /// < Event type : Click on thumbnail
  static const int NOTIFICATION_EVENT_TYPE_CLICK_ON_THUMBNAIL = 7;

  /// < Event type : Click on text_input button(Since 3.0)
  static const int NOTIFICATION_EVENT_TYPE_CLICK_ON_TEXT_INPUT_BUTTON = 8;
}

/// @brief Enumeration for notification sound type.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_sound_type {
  /// < Default value. no sound
  static const int NOTIFICATION_SOUND_TYPE_NONE = -1;

  /// < Default sound
  static const int NOTIFICATION_SOUND_TYPE_DEFAULT = 0;

  /// < User sound data
  static const int NOTIFICATION_SOUND_TYPE_USER_DATA = 1;
}

/// @brief Enumeration for notification vibration type.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_vibration_type {
  /// < Default value. No vibration
  static const int NOTIFICATION_VIBRATION_TYPE_NONE = -1;

  /// < Default vibrate pattern
  static const int NOTIFICATION_VIBRATION_TYPE_DEFAULT = 0;

  /// < User vibration data
  static const int NOTIFICATION_VIBRATION_TYPE_USER_DATA = 1;
}

/// @brief Enumeration for notification LED operation.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_led_op {
  /// < Default value. Disable the LED notification
  static const int NOTIFICATION_LED_OP_OFF = -1;

  /// < Turn on the LED with default color
  static const int NOTIFICATION_LED_OP_ON = 0;

  /// < Turn on the LED with custom color
  static const int NOTIFICATION_LED_OP_ON_CUSTOM_COLOR = 1;
}

/// @deprecated Deprecated since 2.3.1
/// @brief Enumeration for setting display type of count.
/// @since_tizen 2.3
abstract class notification_count_display_type {
  static const int NOTIFICATION_COUNT_DISPLAY_TYPE_NONE = -1;

  /// < The number is placed to left
  static const int NOTIFICATION_COUNT_DISPLAY_TYPE_LEFT = 0;

  /// < The number is placed to center
  static const int NOTIFICATION_COUNT_DISPLAY_TYPE_IN = 1;

  /// < The number is placed to right
  static const int NOTIFICATION_COUNT_DISPLAY_TYPE_RIGHT = 2;
}

/// @brief Enumeration for button.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class notification_button_index {
  /// < button 1
  static const int NOTIFICATION_BUTTON_1 = 1;

  /// < button 2
  static const int NOTIFICATION_BUTTON_2 = 2;

  /// < button 3
  static const int NOTIFICATION_BUTTON_3 = 3;

  /// < button 4
  static const int NOTIFICATION_BUTTON_4 = 4;

  /// < button 5
  static const int NOTIFICATION_BUTTON_5 = 5;

  /// < button 6
  static const int NOTIFICATION_BUTTON_6 = 6;
}

/// @brief Enumeration for notification text type.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_text_type {
  static const int NOTIFICATION_TEXT_TYPE_NONE = -1;

  /// < Title
  static const int NOTIFICATION_TEXT_TYPE_TITLE = 0;

  /// < Content
  static const int NOTIFICATION_TEXT_TYPE_CONTENT = 1;

  /// < Content for content display option is off of the Settings
  static const int NOTIFICATION_TEXT_TYPE_CONTENT_FOR_DISPLAY_OPTION_IS_OFF = 2;

  /// < Text to display event count
  static const int NOTIFICATION_TEXT_TYPE_EVENT_COUNT = 3;

  /// < Box contents 1
  static const int NOTIFICATION_TEXT_TYPE_INFO_1 = 4;

  /// < Box contents 1-1
  static const int NOTIFICATION_TEXT_TYPE_INFO_SUB_1 = 5;

  /// < Box contents 2
  static const int NOTIFICATION_TEXT_TYPE_INFO_2 = 6;

  /// < Box contents 2-1
  static const int NOTIFICATION_TEXT_TYPE_INFO_SUB_2 = 7;

  /// < Box contents 3
  static const int NOTIFICATION_TEXT_TYPE_INFO_3 = 8;

  /// < Box contents 3-1
  static const int NOTIFICATION_TEXT_TYPE_INFO_SUB_3 = 9;

  /// < Group title
  static const int NOTIFICATION_TEXT_TYPE_GROUP_TITLE = 10;

  /// < Group content
  static const int NOTIFICATION_TEXT_TYPE_GROUP_CONTENT = 11;

  /// < Group content for content display option is off of the Settings
  static const int
      NOTIFICATION_TEXT_TYPE_GROUP_CONTENT_FOR_DISPLAY_OPTION_IS_OFF = 12;

  /// < Text on button 1
  static const int NOTIFICATION_TEXT_TYPE_BUTTON_1 = 13;

  /// < Text on button 2
  static const int NOTIFICATION_TEXT_TYPE_BUTTON_2 = 14;

  /// < Text on button 3
  static const int NOTIFICATION_TEXT_TYPE_BUTTON_3 = 15;

  /// < Text on button 4
  static const int NOTIFICATION_TEXT_TYPE_BUTTON_4 = 16;

  /// < Text on button 5
  static const int NOTIFICATION_TEXT_TYPE_BUTTON_5 = 17;

  /// < Text on button 6
  static const int NOTIFICATION_TEXT_TYPE_BUTTON_6 = 18;

  /// < Guide text on the message reply box(Since 3.0)
  static const int NOTIFICATION_TEXT_TYPE_TEXT_INPUT_PLACEHOLDER = 19;

  /// < Text on button the on message reply box(Since 3.0)
  static const int NOTIFICATION_TEXT_TYPE_TEXT_INPUT_BUTTON = 20;

  /// < Content for extended notification (Since 4.0)
  static const int NOTIFICATION_TEXT_TYPE_CONTENT_EXTENSION = 21;
}

/// @brief Enumeration for image type.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_image_type {
  static const int NOTIFICATION_IMAGE_TYPE_NONE = -1;

  /// < Icon
  static const int NOTIFICATION_IMAGE_TYPE_ICON = 0;

  /// < Indicator icon
  static const int NOTIFICATION_IMAGE_TYPE_ICON_FOR_INDICATOR = 1;

  /// < Lock screen icon
  static const int NOTIFICATION_IMAGE_TYPE_ICON_FOR_LOCK = 2;

  /// < Thumbnail
  static const int NOTIFICATION_IMAGE_TYPE_THUMBNAIL = 3;

  /// < Lock screen thumbnail
  static const int NOTIFICATION_IMAGE_TYPE_THUMBNAIL_FOR_LOCK = 4;

  /// < Icon
  static const int NOTIFICATION_IMAGE_TYPE_ICON_SUB = 5;

  /// < image displayed on background
  static const int NOTIFICATION_IMAGE_TYPE_BACKGROUND = 6;

  /// < Image for thumbnail list
  static const int NOTIFICATION_IMAGE_TYPE_LIST_1 = 7;

  /// < Image for thumbnail list
  static const int NOTIFICATION_IMAGE_TYPE_LIST_2 = 8;

  /// < Image for thumbnail list
  static const int NOTIFICATION_IMAGE_TYPE_LIST_3 = 9;

  /// < Image for thumbnail list
  static const int NOTIFICATION_IMAGE_TYPE_LIST_4 = 10;

  /// < Image for thumbnail list
  static const int NOTIFICATION_IMAGE_TYPE_LIST_5 = 11;

  /// < Image for button 1
  static const int NOTIFICATION_IMAGE_TYPE_BUTTON_1 = 12;

  /// < Image for button 2
  static const int NOTIFICATION_IMAGE_TYPE_BUTTON_2 = 13;

  /// < Image for button 3
  static const int NOTIFICATION_IMAGE_TYPE_BUTTON_3 = 14;

  /// < Image for button 4
  static const int NOTIFICATION_IMAGE_TYPE_BUTTON_4 = 15;

  /// < Image for button 5
  static const int NOTIFICATION_IMAGE_TYPE_BUTTON_5 = 16;

  /// < Image for button 6
  static const int NOTIFICATION_IMAGE_TYPE_BUTTON_6 = 17;

  /// < Image for message reply(Since 3.0)
  static const int NOTIFICATION_IMAGE_TYPE_TEXT_INPUT_BUTTON = 18;

  /// < Image for extended notification (Since 4.0)
  static const int NOTIFICATION_IMAGE_TYPE_EXTENSION = 19;
}

/// @brief Enumeration for application execution type.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_execute_type {
  /// < No operation
  static const int NOTIFICATION_EXECUTE_TYPE_NONE = -1;

  /// < Responding action
  static const int NOTIFICATION_EXECUTE_TYPE_RESPONDING = 0;

  /// < Launching when notification data is single
  static const int NOTIFICATION_EXECUTE_TYPE_SINGLE_LAUNCH = 1;

  /// < Launching when notification data is grouping(multi)
  static const int NOTIFICATION_EXECUTE_TYPE_MULTI_LAUNCH = 2;
}

/// @brief Enumeration for notification type.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_type {
  /// < None
  static const int NOTIFICATION_TYPE_NONE = -1;

  /// < Notification type
  static const int NOTIFICATION_TYPE_NOTI = 0;

  /// < Ongoing type
  static const int NOTIFICATION_TYPE_ONGOING = 1;
}

/// @brief Enumeration for Group ID.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_group_id {
  /// < Not Grouping
  static const int NOTIFICATION_GROUP_ID_NONE = -1;

  /// < Notification that has same title is grouping
  static const int NOTIFICATION_GROUP_ID_DEFAULT = 0;
}

/// @brief Enumeration for Private ID.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_priv_id {
  /// < Internally set priv_id
  static const int NOTIFICATION_PRIV_ID_NONE = -1;
}

/// @brief Enumeration for notification property.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_property {
  /// < Display only SIM card inserted
  static const int NOTIFICATION_PROP_DISPLAY_ONLY_SIMMODE = 1;

  /// < Disable application launch when it selected
  static const int NOTIFICATION_PROP_DISABLE_APP_LAUNCH = 2;

  /// < Disable auto delete when it selected
  static const int NOTIFICATION_PROP_DISABLE_AUTO_DELETE = 4;

  /// < Notification Tray should launch application using appsvc API (Deprecated since 2.3.1)
  static const int NOTIFICATION_PROP_LAUNCH_UG = 8;

  /// < Use notification_set_display_applist API (Deprecated since 2.3.1)
  static const int NOTIFICATION_PROP_DISABLE_TICKERNOTI = 16;

  /// < The notification will not be removed (Deprecated since 2.3.1)
  static const int NOTIFICATION_PROP_PERMANENT_DISPLAY = 32;

  /// < Disable update when it inserted.
  static const int NOTIFICATION_PROP_DISABLE_UPDATE_ON_INSERT = 64;

  /// < Disable update when it deleted.
  static const int NOTIFICATION_PROP_DISABLE_UPDATE_ON_DELETE = 128;

  /// < Deleted when device is rebooted eventhough NOTIFICATION_TYPE_NOTI type
  static const int NOTIFICATION_PROP_VOLATILE_DISPLAY = 256;
}

/// @brief Enumeration for display application list.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_display_applist {
  /// < Notification Tray(Quickpanel)
  static const int NOTIFICATION_DISPLAY_APP_NOTIFICATION_TRAY = 1;

  /// < Ticker notification
  static const int NOTIFICATION_DISPLAY_APP_TICKER = 2;

  /// < Lock screen
  static const int NOTIFICATION_DISPLAY_APP_LOCK = 4;

  /// < Indicator
  static const int NOTIFICATION_DISPLAY_APP_INDICATOR = 8;

  /// < Active notification
  static const int NOTIFICATION_DISPLAY_APP_ACTIVE = 16;

  /// < All display application except active notification
  static const int NOTIFICATION_DISPLAY_APP_ALL = 15;
}

/// @brief Enumeration for notification operation code.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_op_type {
  /// < Default
  static const int NOTIFICATION_OP_NONE = 0;

  /// < Notification inserted
  static const int NOTIFICATION_OP_INSERT = 1;

  /// < Notification updated
  static const int NOTIFICATION_OP_UPDATE = 2;

  /// < Notification deleted
  static const int NOTIFICATION_OP_DELETE = 3;

  /// < Notifications deleted
  static const int NOTIFICATION_OP_DELETE_ALL = 4;

  /// < (Deprecated Since 2.3.1)
  static const int NOTIFICATION_OP_REFRESH = 5;

  /// < Notification service is ready
  static const int NOTIFICATION_OP_SERVICE_READY = 6;
}

/// @brief Enumeration for notification operation data code.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_op_data_type {
  /// < Default
  static const int NOTIFICATION_OP_DATA_MIN = 0;

  /// < Operation type
  static const int NOTIFICATION_OP_DATA_TYPE = 1;

  /// < Private ID
  static const int NOTIFICATION_OP_DATA_PRIV_ID = 2;

  /// < Notification handler
  static const int NOTIFICATION_OP_DATA_NOTI = 3;

  /// < Reserved
  static const int NOTIFICATION_OP_DATA_EXTRA_INFO_1 = 4;

  /// < Reserved
  static const int NOTIFICATION_OP_DATA_EXTRA_INFO_2 = 5;
}

/// @brief Enumeration for notification count position in the text.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notifcation_count_pos_type {
  /// < Count data is not displaying in the text
  static const int NOTIFICATION_COUNT_POS_NONE = -1;

  /// < Count data is displaying at the left of the text
  static const int NOTIFICATION_COUNT_POS_LEFT = 0;

  /// < Count data is displaying in the text
  static const int NOTIFICATION_COUNT_POS_IN = 1;

  /// < Count data is displaying at the right of the text
  static const int NOTIFICATION_COUNT_POS_RIGHT = 2;
}

/// @brief Enumeration for notification variable parameter type.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class notification_variable_type {
  /// < Variable parameter type is NONE
  static const int NOTIFICATION_VARIABLE_TYPE_NONE = -1;

  /// < Variable parameter type is int
  static const int NOTIFICATION_VARIABLE_TYPE_INT = 0;

  /// < Variable parameter type is double
  static const int NOTIFICATION_VARIABLE_TYPE_DOUBLE = 1;

  /// < Variable parameter type is string
  static const int NOTIFICATION_VARIABLE_TYPE_STRING = 2;

  /// < Variable parameter type is count
  static const int NOTIFICATION_VARIABLE_TYPE_COUNT = 3;
}

class _notification extends ffi.Opaque {}

/// @brief The structure for notification operation.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
class _notification_op extends ffi.Struct {
  /// < Notification operation type
  @ffi.Int32()
  external int type;

  /// < private ID
  @ffi.Int()
  external int priv_id;

  /// < Reserved
  @ffi.Int()
  external int extra_info_1;

  /// < Reserved
  @ffi.Int()
  external int extra_info_2;

  /// < Notification handler
  external notification_h noti;
}

/// @brief Notification handle.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
typedef notification_h = ffi.Pointer<_notification>;

/// @brief Enumeration for permission.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class notification_permission_type {
  static const int NOTIFICATION_PERMISSION_TYPE_NONE = 0;
  static const int NOTIFICATION_PERMISSION_TYPE_DELETE = 1;
  static const int NOTIFICATION_PERMISSION_TYPE_UPDATE = 2;
}

/// @brief Enumeration for notification block state.
/// @since_tizen 3.0
abstract class notification_block_state {
  /// < The app is allowed to post notifications
  static const int NOTIFICATION_BLOCK_STATE_ALLOWED = 0;

  /// < The app is not allowed to post any notifications
  static const int NOTIFICATION_BLOCK_STATE_BLOCKED = 1;

  /// < User set do not disturb mode
  static const int NOTIFICATION_BLOCK_STATE_DO_NOT_DISTURB = 2;
}

typedef time_t = __time_t;
typedef __time_t = ffi.Long;

/// @brief Enumeration for Alarm Error.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class alarm_error_e {
  /// < Successful
  static const int ALARM_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int ALARM_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid time
  static const int ALARM_ERROR_INVALID_TIME = -17825787;

  /// < Invalid date
  static const int ALARM_ERROR_INVALID_DATE = -17825786;

  /// < The alarm service connection failed
  static const int ALARM_ERROR_CONNECTION_FAIL = -17825785;

  /// < Application is not permitted. (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int ALARM_ERROR_NOT_PERMITTED_APP = -17825784;

  /// < Out of memory
  static const int ALARM_ERROR_OUT_OF_MEMORY = -12;

  /// < Permission denied
  static const int ALARM_ERROR_PERMISSION_DENIED = -13;
}

/// @brief Enumeration for Alarm Week Flag, the days of the week.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class alarm_week_flag_e {
  /// < Sunday
  static const int ALARM_WEEK_FLAG_SUNDAY = 1;

  /// < Monday
  static const int ALARM_WEEK_FLAG_MONDAY = 2;

  /// < Tuesday
  static const int ALARM_WEEK_FLAG_TUESDAY = 4;

  /// < Wednesday
  static const int ALARM_WEEK_FLAG_WEDNESDAY = 8;

  /// < Thursday
  static const int ALARM_WEEK_FLAG_THURSDAY = 16;

  /// < Friday
  static const int ALARM_WEEK_FLAG_FRIDAY = 32;

  /// < Saturday
  static const int ALARM_WEEK_FLAG_SATURDAY = 64;
}

class tm extends ffi.Opaque {}

/// @brief Called once for each scheduled alarm to get the alarm ID.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] alarm_id The alarm ID returned when the alarm is scheduled
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre   alarm_foreach_registered_alarm() will invoke this callback to get all the registered alarm IDs.
/// @see   alarm_foreach_registered_alarm()
typedef alarm_registered_alarm_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

class event_handler extends ffi.Opaque {}

/// @brief Enumeration for Event Error.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class event_error_e {
  /// < Successful
  static const int EVENT_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int EVENT_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int EVENT_ERROR_OUT_OF_MEMORY = -12;

  /// < Time out
  static const int EVENT_ERROR_TIMED_OUT = -1073741823;

  /// < IO error
  static const int EVENT_ERROR_IO_ERROR = -5;

  /// < Permisiion denied
  static const int EVENT_ERROR_PERMISSION_DENIED = -13;
}

/// @brief Event callback.
///
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] event_name The interested event name
/// @param[in] event_data The data of interested event
/// @param[in] user_data The user data set by event_add_event_handler()
/// @see event_add_event_handler
typedef event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<bundle>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Event handle.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef event_handler_h = ffi.Pointer<event_handler>;

/// @brief Enumeration for Preference Error.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class preference_error_e {
  /// < Successful
  static const int PREFERENCE_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int PREFERENCE_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int PREFERENCE_ERROR_OUT_OF_MEMORY = -12;

  /// < Required key not available
  static const int PREFERENCE_ERROR_NO_KEY = -17825744;

  /// < Internal I/O Error
  static const int PREFERENCE_ERROR_IO_ERROR = -5;
}

/// @brief Called when the given key's value in the preference changes.
/// @details When the @a key is added or removed, this callback function is skipped(only update can be handled).
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] key The name of the key in the preference
/// @param[in] user_data The user data passed from the callback registration function
/// @pre This function is invoked when the value of the key is overwritten after you register this callback using preference_set_changed_cb().
/// @see preference_set_changed_cb()
/// @see preference_unset_changed_cb()
/// @see	preference_set_boolean()
/// @see preference_set_int()
/// @see preference_set_string()
/// @see preference_set_double()
typedef preference_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get key string, once for each key-value pair in the preference.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks You should not free the @a key returned by this function.
/// @param[in] key The key of the value added to the preference
/// @param[in] value The value associated with the key
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre	preference_foreach_item() will invoke this callback function.
/// @see	preference_foreach_item()
typedef preference_item_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for Resource Types
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class app_resource_e {
  /// <Image
  static const int APP_RESOURCE_TYPE_IMAGE = 0;

  /// <Edje
  static const int APP_RESOURCE_TYPE_LAYOUT = 1;

  /// <Sound
  static const int APP_RESOURCE_TYPE_SOUND = 2;

  /// <Bin
  static const int APP_RESOURCE_TYPE_BIN = 3;
  static const int APP_RESOURCE_TYPE_MIN = 0;
  static const int APP_RESOURCE_TYPE_MAX = 3;
}

/// @brief Enumeration for App Resource Manager Error.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class app_resource_error_e {
  /// < Successful
  static const int APP_RESOURCE_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int APP_RESOURCE_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int APP_RESOURCE_ERROR_OUT_OF_MEMORY = -12;

  /// < I/O error
  static const int APP_RESOURCE_ERROR_IO_ERROR = -5;
}

class app_context_s extends ffi.Opaque {}

/// @brief  Enumeration for Application Context Event.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class app_context_event_e {
  /// < The application is launched
  static const int APP_CONTEXT_EVENT_LAUNCHED = 0;

  /// < The application is terminated
  static const int APP_CONTEXT_EVENT_TERMINATED = 1;
}

/// @brief Enumeration for the application state
/// @since_tizen 3.0
abstract class app_state_e {
  /// < The undefined state
  static const int APP_STATE_UNDEFINED = 0;

  /// < The UI application is running in the foreground.
  static const int APP_STATE_FOREGROUND = 1;

  /// < The UI application is running in the background.
  static const int APP_STATE_BACKGROUND = 2;

  /// < The Service application is running.
  static const int APP_STATE_SERVICE = 3;

  /// < The application is terminated.
  static const int APP_STATE_TERMINATED = 4;
}

/// @brief  Application context handle.
/// @since_tizen  @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef app_context_h = ffi.Pointer<app_context_s>;
typedef pid_t = __pid_t;
typedef __pid_t = ffi.Int;

/// @brief Enumeration for application component type.
/// @since_tizen 4.0
/// @details A component is an application considered as a part of a package.
/// The application component type indicates what type of
/// a component an application is in a package.
/// @see PACKAGE_INFO_PROP_APP_COMPONENT_TYPE
/// @see app_info_get_app_component_type()
abstract class app_info_app_component_type_e {
  /// < UI application
  static const int APP_INFO_APP_COMPONENT_TYPE_UI_APP = 0;

  /// < Service application
  static const int APP_INFO_APP_COMPONENT_TYPE_SERVICE_APP = 1;

  /// < Widget application
  static const int APP_INFO_APP_COMPONENT_TYPE_WIDGET_APP = 2;

  /// < Watch application
  static const int APP_INFO_APP_COMPONENT_TYPE_WATCH_APP = 3;
}

class app_info_s extends ffi.Opaque {}

class app_info_filter_s extends ffi.Opaque {}

class app_info_metadata_filter_s extends ffi.Opaque {}

/// @brief Application information handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef app_info_h = ffi.Pointer<app_info_s>;

/// @brief  Called to get application metadata in app_info_foreach_metadata().
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in]   metadata_name   The name of the metadata
/// @param[in]   metadata_value  The value of the metadata
/// @param[in]   user_data       The user data passed to app_info_foreach_metadata()
/// @return      @c true to continue with the next iteration of the loop, \n
/// otherwise @c false to break out of the loop
/// @pre app_info_foreach_metadata() will invoke this callback.
/// @see app_info_foreach_metadata()
typedef app_info_metadata_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief  Called for each application category in app_info_foreach_category().
/// @since_tizen 4.0
/// @remarks     @a category will be freed when the application information handle is destroyed
/// using app_info_destroy()
/// @param[in]   category        The name of the category
/// @param[in]   user_data       The user data passed to app_info_foreach_category()
/// @return      @c true to continue with the next iteration of the loop, \n
/// otherwise @c false to break out of the loop
/// @pre app_info_foreach_category() will invoke this callback.
/// @see app_info_foreach_category()
typedef app_info_category_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Application filter handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef app_info_filter_h = ffi.Pointer<app_info_filter_s>;

/// @brief  Called to get the application information once for each installed application.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in]   app_info   The application information of each installed application
/// @param[in]   user_data  The user data passed from the foreach function
/// @return      @c true to continue with the next iteration of the loop, \n
/// otherwise @c false to break out of the loop
/// @pre app_manager_foreach_app_info() will invoke this callback.
/// @see app_manager_foreach_app_info()
typedef app_info_filter_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(app_info_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Application metadata filter handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef app_info_metadata_filter_h = ffi.Pointer<app_info_metadata_filter_s>;

/// @brief Enumerations for Application Manager Error .
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class app_manager_error_e {
  /// < Successful
  static const int APP_MANAGER_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int APP_MANAGER_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int APP_MANAGER_ERROR_OUT_OF_MEMORY = -12;

  /// < Internal I/O error
  static const int APP_MANAGER_ERROR_IO_ERROR = -5;

  /// < No such application
  static const int APP_MANAGER_ERROR_NO_SUCH_APP = -17891327;

  /// < Database error
  static const int APP_MANAGER_ERROR_DB_FAILED = -17891325;

  /// < Invalid package name
  static const int APP_MANAGER_ERROR_INVALID_PACKAGE = -17891324;

  /// < App is not running
  static const int APP_MANAGER_ERROR_APP_NO_RUNNING = -17891323;

  /// < Internal aul request error
  static const int APP_MANAGER_ERROR_REQUEST_FAILED = -17891322;

  /// < Permission denied
  static const int APP_MANAGER_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported (Since 3.0)
  static const int APP_MANAGER_ERROR_NOT_SUPPORTED = -1073741822;
}

/// @brief  Enumeration for app manager status type.
/// @since_tizen 3.0
abstract class app_manager_event_status_type_e {
  /// < All Status
  static const int APP_MANAGER_EVENT_STATUS_TYPE_ALL = 0;

  /// < Application enable status
  static const int APP_MANAGER_EVENT_STATUS_TYPE_ENABLE = 1;

  /// < Application disable status
  static const int APP_MANAGER_EVENT_STATUS_TYPE_DISABLE = 2;
}

/// @brief Enumeration for app manager event type.
/// @since_tizen 3.0
abstract class app_manager_event_type_e {
  /// < Application enable event
  static const int APP_MANAGER_EVENT_ENABLE_APP = 0;

  /// < Application disable event.
  static const int APP_MANAGER_EVENT_DISABLE_APP = 1;
}

/// @brief Enumeration for app manager event state.
/// @since_tizen 3.0
abstract class app_manager_event_state_e {
  /// < Started event state
  static const int APP_MANAGER_EVENT_STATE_STARTED = 0;

  /// < Completed event state
  static const int APP_MANAGER_EVENT_STATE_COMPLETED = 1;

  /// < Failed event state
  static const int APP_MANAGER_EVENT_STATE_FAILED = 2;
}

class app_manager_event_s extends ffi.Opaque {}

/// @brief  Called when an application is launched or terminated.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in]   app_context  The application context of the application launched or terminated
/// @param[in]   event        The application context event
/// @param[in]   user_data    The user data passed from the foreach function
/// @pre  This function is called when an application gets launched or terminated, after you register this callback using app_manager_set_app_context_event_cb().
/// @see app_manager_set_app_context_event_cb()
/// @see app_manager_unset_app_context_event_cb()
typedef app_manager_app_context_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(app_context_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief  Called to get the application context once for each running application.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in]   app_context  The application context of each running application
/// @param[in]   user_data    The user data passed from the foreach function
/// @return      @c true to continue with the next iteration of the loop, \n
/// otherwise @c false to break out of the loop
/// @pre app_manager_foreach_app_context() will invoke this callback.
/// @see app_manager_foreach_app_context()
typedef app_manager_app_context_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(app_context_h, ffi.Pointer<ffi.Void>)>>;

/// @brief  Called to get the application information once for each installed application.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in]   app_info   The application information of each installed application
/// @param[in]   user_data  The user data passed from the foreach function
/// @return      @c true to continue with the next iteration of the loop, \n
/// otherwise @c false to break out of the loop
/// @pre app_manager_foreach_app_info() will invoke this callback.
/// @see app_manager_foreach_app_info()
typedef app_manager_app_info_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(app_info_h, ffi.Pointer<ffi.Void>)>>;

/// @brief  App manager event handle.
/// @since_tizen 3.0
typedef app_manager_event_h = ffi.Pointer<app_manager_event_s>;

/// @brief Called when the application is enabled or disabled.
/// @since_tizen 3.0
///
/// @param[in] type        The type of the app to be enabled or disabled
/// @param[in] app_id     The app id to be enabled or disabled
/// @param[in] event_type  The event type of the app
/// @param[in] event_state The current event state of the app
/// @param[in] handle       The app manager event handle
/// @param[in] user_data   The user data passed from app_manager_set_event_cb()
/// @pre  This function is called when an application being disabled or enabled, after you register this callback using app_manager_set_event_cb().
///
/// @see app_manager_set_event_cb()
/// @see app_manager_unset_event_cb()
typedef app_manager_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Int32, ffi.Int32, app_manager_event_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for Badge Error
abstract class badge_error_e {
  /// < Success
  static const int BADGE_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int BADGE_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int BADGE_ERROR_OUT_OF_MEMORY = -12;

  /// < Permission denied
  static const int BADGE_ERROR_PERMISSION_DENIED = -13;

  /// < Error from I/O
  static const int BADGE_ERROR_IO_ERROR = -5;

  /// < Not supported (Since 4.0)
  static const int BADGE_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Error from DB
  static const int BADGE_ERROR_FROM_DB = -17956863;

  /// < Already exist
  static const int BADGE_ERROR_ALREADY_EXIST = -17956862;

  /// < Error from DBus
  static const int BADGE_ERROR_FROM_DBUS = -17956861;

  /// < Not exist
  static const int BADGE_ERROR_NOT_EXIST = -17956860;

  /// < Error service not ready
  static const int BADGE_ERROR_SERVICE_NOT_READY = -17956859;

  /// < The caller application is not signed with the certificate of the badge owner
  static const int BADGE_ERROR_INVALID_PACKAGE = -17956858;
}

/// @brief Callback function for getting result of badge_foreach.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] app_id The id of the application
/// @param[in] count The count of the badge
/// @param[in] user_data The user data passed from the badge_foreach function
/// @return true to continue with the next iteration of the loop, false to break out of the loop
/// @pre badge_foreach() will invoke this callback.
/// @see badge_foreach()
typedef badge_foreach_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            ffi.Pointer<ffi.Char>, ffi.UnsignedInt, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for Badge Action.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class badge_action {
  /// < Badge created
  static const int BADGE_ACTION_CREATE = 0;

  /// < Badge removed
  static const int BADGE_ACTION_REMOVE = 1;

  /// < Badge updated
  static const int BADGE_ACTION_UPDATE = 2;

  /// < The display option of the badge changed
  static const int BADGE_ACTION_CHANGED_DISPLAY = 3;

  /// < The badge service is ready
  static const int BADGE_ACTION_SERVICE_READY = 4;
}

/// @brief Called when the badge information is changed.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] action The type of the change. Refer #badge_action
/// @param[in] app_id The name of the application
/// @param[in] count The count of the badge
/// @param[in] user_data The user data passed from the callback register function
/// @pre badge_register_changed_cb() will invoke this callback.
/// @see badge_unregister_changed_cb()
typedef badge_change_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.UnsignedInt, ffi.Pointer<ffi.Char>,
            ffi.UnsignedInt, ffi.Pointer<ffi.Void>)>>;

class data_control_bulk_data_s extends ffi.Opaque {}

class data_control_bulk_result_data_s extends ffi.Opaque {}

class data_control_s extends ffi.Opaque {}

/// @brief Enumeration for different types of columns in a SQL table.
/// @since_tizen 2.3
abstract class data_control_sql_column_type_e {
  /// < undefined type
  static const int DATA_CONTROL_SQL_COLUMN_TYPE_UNDEFINED = 0;

  /// < integer type
  static const int DATA_CONTROL_SQL_COLUMN_TYPE_INT64 = 1;

  /// < double type
  static const int DATA_CONTROL_SQL_COLUMN_TYPE_DOUBLE = 2;

  /// < text type
  static const int DATA_CONTROL_SQL_COLUMN_TYPE_TEXT = 3;

  /// < blob type
  static const int DATA_CONTROL_SQL_COLUMN_TYPE_BLOB = 4;

  /// < null value
  static const int DATA_CONTROL_SQL_COLUMN_TYPE_NULL = 5;
}

/// @brief Enumeration for the various error codes an API can return.
/// @since_tizen 2.3
abstract class data_control_error_e {
  /// < Successful
  static const int DATA_CONTROL_ERROR_NONE = 0;

  /// < Out of memory
  static const int DATA_CONTROL_ERROR_OUT_OF_MEMORY = -12;

  /// < I/O error
  static const int DATA_CONTROL_ERROR_IO_ERROR = -5;

  /// < Invalid parameter
  static const int DATA_CONTROL_ERROR_INVALID_PARAMETER = -22;

  /// < Permission denied
  static const int DATA_CONTROL_ERROR_PERMISSION_DENIED = -13;

  /// < Too long argument
  static const int DATA_CONTROL_ERROR_MAX_EXCEEDED = -18415615;
}

/// @brief Enumeration for the various data changed notification types.
/// @since_tizen 3.0
abstract class data_control_data_change_type_e {
  /// < Update notification
  static const int DATA_CONTROL_DATA_CHANGE_SQL_UPDATE = 0;

  /// < Insert notification
  static const int DATA_CONTROL_DATA_CHANGE_SQL_INSERT = 1;

  /// < Delete notification
  static const int DATA_CONTROL_DATA_CHANGE_SQL_DELETE = 2;

  /// < Set notification
  static const int DATA_CONTROL_DATA_CHANGE_MAP_SET = 3;

  /// < Add notification
  static const int DATA_CONTROL_DATA_CHANGE_MAP_ADD = 4;

  /// < Remove notification
  static const int DATA_CONTROL_DATA_CHANGE_MAP_REMOVE = 5;
}

class result_set_s extends ffi.Opaque {}

/// @brief The structure type to represent a SQL result set.
/// @details This type can be used to enumerate through the result set of an SQL query.
/// @since_tizen 2.3
typedef result_set_cursor = ffi.Pointer<result_set_s>;

/// @brief The bulk data handle.
/// @since_tizen 3.0
typedef data_control_bulk_data_h = ffi.Pointer<data_control_bulk_data_s>;

/// @brief The bulk result data handle.
/// @since_tizen 3.0
typedef data_control_bulk_result_data_h
    = ffi.Pointer<data_control_bulk_result_data_s>;

/// @brief The structure type to contain the set of callback functions for handling the response events of the SQL-friendly interface based data control.
/// @since_tizen 2.3
///
/// @see data_control_sql_select_response_cb()
/// @see data_control_sql_insert_response_cb()
/// @see data_control_sql_update_response_cb()
/// @see data_control_sql_delete_response_cb()
class data_control_sql_response_cb extends ffi.Struct {
  /// < This callback function is called when a response is received for an select operation from an application using the SQL-friendly interface based data control.
  external data_control_sql_select_response_cb select_cb;

  /// < This callback function is called when a response is received for an insert operation from an application using the SQL-friendly interface based data control.
  external data_control_sql_insert_response_cb insert_cb;

  /// < This callback function is called when a response is received for an update operation from an application using the SQL-friendly interface based data control.
  external data_control_sql_update_response_cb update_cb;

  /// < This callback function is called when a response is received for a delete operation from an application using the SQL-friendly interface based data control.
  external data_control_sql_delete_response_cb delete_cb;
}

/// @brief Called when a response is received for a select operation from an application using the SQL-friendly interface based data control.
/// @since_tizen 2.3
///
/// @remarks @a enumerator will be removed after the execution of this callback.
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be destroyed
/// @param[in] enumerator The enumerator for navigating the result of data control select request
/// @param[in] provider_result Set to @c true if the data control provider successfully processed, \n
/// otherwise set to @c false
/// @param[in] error The error message from the data control provider
/// @param[in] user_data The user data passed from the register function
typedef data_control_sql_select_response_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, result_set_cursor, ffi.Bool,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief The structure type for the provider handle.
/// @since_tizen 2.3
typedef data_control_h = ffi.Pointer<data_control_s>;

/// @brief Called when a response is received for an insert operation from an application using the SQL-friendly interface based data control.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be destroyed
/// @param[in] inserted_row_id The inserted row ID set by the data control
/// @param[in] provider_result Set to @c true if the data control provider successfully processed, \n
/// otherwise set to @c false
/// @param[in] error The error message from the data control provider
/// @param[in] user_data The user data passed from the register function
typedef data_control_sql_insert_response_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.LongLong, ffi.Bool,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when a response is received for an update operation from an application using the SQL-friendly interface based data control.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be destroyed
/// @param[in] provider_result Set to @c true if the data control provider successfully processed, \n
/// otherwise set to @c false
/// @param[in] error The error message from the data control provider
/// @param[in] user_data The user data passed from the register function
typedef data_control_sql_update_response_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Bool,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when a response is received for a delete operation from an application using the SQL-friendly interface based data control.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID that identifies the data control
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be destroyed
/// @param[in] provider_result Set to @c true if the data control provider successfully processed, \n
/// otherwise set to @c false
/// @param[in] error The error message from the data control provider
/// @param[in] user_data The user data passed from the register function
typedef data_control_sql_delete_response_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Bool,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief  Called when a response is received for a bulk operation from a provider application.
/// @since_tizen 3.0
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be destroyed.
/// @param[in] bulk_results The result data for each insert request. @a bulk_results is valid only inside this function. \n
/// @a bulk_results should not be freed.
/// @param[in] provider_result Set to @c true if the data control provider successfully processed, \n
/// otherwise set to @c false
/// @param[in] error The error message from the data control provider. @a error is valid only inside this function. \n
/// @a error should not be freed.
/// @param[in] user_data The user data passed from the register function
/// @see data_control_sql_register_insert_bulk_data_response_cb()
/// @see data_control_map_register_add_bulk_data_response_cb()
typedef data_control_bulk_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int,
            data_control_h,
            data_control_bulk_result_data_h,
            ffi.Bool,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief  The structure type to contain the set of callback functions for handling the response events
/// of the key-value structured data control.
/// @since_tizen 2.3
/// @see data_control_map_get_response_cb()
/// @see data_control_map_set_response_cb()
/// @see data_control_map_add_response_cb()
/// @see data_control_map_remove_response_cb()
class data_control_map_response_cb extends ffi.Struct {
  /// < This callback function is called when the response is received for a getting value from the key-value structured data control provider.
  external data_control_map_get_response_cb get_cb;

  /// < This callback function is called when the response is received for a setting value from the key-value structured data control provider.
  external data_control_map_set_response_cb set_cb;

  /// < This callback function is called when the response is received for an adding value from the key-value structured data control provider.
  external data_control_map_add_response_cb add_cb;

  /// < This callback function is called when the response is for a removing value received from the key-value structured data control provider.
  external data_control_map_remove_response_cb remove_cb;
}

/// @brief Called when the result value list is received from the key-value structured data control provider.
/// @since_tizen 2.3
/// @remarks You must release @a result_value_list using free() after it is used. Note that @a result_value list is an array of char *. Its length is @a result_value_count. You should release all the elements in the @a result_value_list array and @a result_value_list itself like the following code.
///
/// @code
///
/// int i;
/// for (i = 0; i < resule_value_count; i++)
/// free(result_value_list[i]);
/// free(result_value_list);
///
/// @endcode
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be destroyed.
/// @param[in] result_value_list The result value list of the data control request that gets the matching values
/// @param[in] result_value_count The number of the values
/// @param[in] provider_result Set to @c true if the data control provider is successfully processed, \n
/// otherwise set to @c false
/// @param[in] error The error message from the data control provider
/// @param[in] user_data The user data passed from the register function
typedef data_control_map_get_response_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int,
            data_control_h,
            ffi.Pointer<ffi.Pointer<ffi.Char>>,
            ffi.Int,
            ffi.Bool,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the response is received for a set operation from the key-value structured data control provider.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID that identifies the data control
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be destroyed.
/// @param[in] provider_result Set to @c true if the data control provider successfully processed, \n
/// otherwise @c false
/// @param[in] error The error message from the data control provider
/// @param[in] user_data The user data passed from the register function
typedef data_control_map_set_response_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Bool,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the response is received for an add operation from the key-value structured data control provider.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID that identifies the data control
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be destroyed.
/// @param[in] provider_result Set to @c true if the data control provider successfully processed, \n
/// otherwise set to @c false
/// @param[in] error The error message from the data control provider
/// @param[in] user_data The user data passed from the register function
typedef data_control_map_add_response_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Bool,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the response is received for a remove operation from the key-value structured data control provider.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID that identifies the data control
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be destroyed.
/// @param[in] provider_result Set to @c true if the data control provider successfully processed, \n
/// otherwise set to @c false
/// @param[in] error The error message from the data control provider
/// @param[in] user_data The user data passed from the register function
typedef data_control_map_remove_response_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Bool,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief  The structure type to contain the set of callback functions for handling the request events
/// of SQL-friendly interface based data control.
/// @since_tizen 2.3
///
/// @see data_control_provider_sql_select_request_cb()
/// @see data_control_provider_sql_insert_request_cb()
/// @see data_control_provider_sql_update_request_cb()
/// @see data_control_provider_sql_delete_request_cb()
class data_control_provider_sql_cb extends ffi.Struct {
  /// < This callback function is called when a request for insert operation is received from other application.
  external data_control_provider_sql_insert_request_cb insert_cb;

  /// < This callback function is called when a request for select operation is received from other application.
  external data_control_provider_sql_select_request_cb select_cb;

  /// < This callback function is called when a request for update operation is received from other application.
  external data_control_provider_sql_update_request_cb update_cb;

  /// < This callback function is called when a request for delete operation is received from other application.
  external data_control_provider_sql_delete_request_cb delete_cb;
}

/// @brief Called when the insert request is received from an application using SQL-friendly interface based data control.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be freed
/// @param[in] insert_data The column-value pairs to insert \n
/// If the value is a string, the value must be wrapped in single quotes,
/// otherwise it does not need to be wrapped in single quotes. \n
/// To use outside the callback, make a copy by using bundle_dup().
/// @a insert_data should not be freed.
/// @param[in] user_data The user data passed from the register function
typedef data_control_provider_sql_insert_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Pointer<bundle>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the select request is received from an application using SQL-friendly interface based data control.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be freed
/// @param[in] column_list The column list to query
/// @param[in] column_count The total number of columns to be queried
/// @param[in] where A filter to select the desired rows \n
/// It is an SQL 'WHERE' clause excluding the 'WHERE' itself such as column1 = 'stringValue' and column2 = numericValue
/// @param[in] order The sorting order of the rows to query \n
/// It is an SQL 'ORDER BY' clause excluding the 'ORDER BY' itself
/// @param[in] user_data The user data passed from the register function
typedef data_control_provider_sql_select_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int,
            data_control_h,
            ffi.Pointer<ffi.Pointer<ffi.Char>>,
            ffi.Int,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the update request is received from an application using SQL-friendly interface based data control.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be freed
/// @param[in] update_data The column-value pairs to update \n
/// If the value is a string, the value must be wrapped in single quotes,
/// otherwise it does not need to be wrapped in single quotes. \n
/// To use outside the callback, make a copy by using bundle_dup().
/// @a update_data should not be freed.
/// @param[in] where A filter to select the desired rows to update \n
/// It is an SQL 'WHERE' clause excluding the 'WHERE' itself such as column1 = 'stringValue' and column2 = numericValue
/// @param[in] user_data The user data passed from the register function
typedef data_control_provider_sql_update_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Pointer<bundle>,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the delete request is received from an application using SQL-friendly interface based data control.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be freed
/// @param[in] where A filter to select the desired rows to delete \n
/// It is an SQL 'WHERE' clause excluding the 'WHERE' itself such as column1 = 'stringValue' and column2 = numericValue
/// @param[in] user_data The user data passed from the register function
typedef data_control_provider_sql_delete_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief  The structure type to contain the set of callback functions for handling the request events
/// from the key-value structured data control consumer.
/// @since_tizen 2.3
///
/// @see data_control_provider_map_get_value_request_cb()
/// @see data_control_provider_map_set_value_request_cb()
/// @see data_control_provider_map_add_value_request_cb()
/// @see data_control_provider_map_remove_value_request_cb()
class data_control_provider_map_cb extends ffi.Struct {
  /// < This callback function is called when a request for getting value is received from other application.
  external data_control_provider_map_get_value_request_cb get_cb;

  /// < This callback function is called when a request for setting value is received from other application.
  external data_control_provider_map_set_value_request_cb set_cb;

  /// < This callback function is called when a request for adding value is received from other application.
  external data_control_provider_map_add_value_request_cb add_cb;

  /// < This callback function is called when a request for removing value is received from other application.
  external data_control_provider_map_remove_value_request_cb remove_cb;
}

/// @brief Called when the request for obtaining the value list is received from the key-value structured data control consumer.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be freed
/// @param[in] key The key of the value list to obtain
/// @param[in] user_data The user data passed from the register function
typedef data_control_provider_map_get_value_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the request for replacing the value is received from the key-value structured data control consumer.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be freed
/// @param[in] key The key of the value to replace
/// @param[in] old_value The value to replace
/// @param[in] new_value The new value that replaces the existing value
/// @param[in] user_data The user data passed from the register function
typedef data_control_provider_map_set_value_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int,
            data_control_h,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the request for adding the value is received from the key-value structured data control consumer.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be freed
/// @param[in] key The key of the value to add
/// @param[in] value The value to add
/// @param[in] user_data The user data passed from the register function
typedef data_control_provider_map_add_value_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the request for removing the value is received from the key-value structured data control consumer.
/// @since_tizen 2.3
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be freed
/// @param[in] key The key of the value to remove
/// @param[in] value The value to remove
/// @param[in] user_data The user data passed from the register function
typedef data_control_provider_map_remove_value_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when a consumer requests a data change callback addition.
/// @details The callback decides - through the return value - whether a consumer application should be allowed to add a data change callback. \n
/// If it returns true, it means the application should be allowed to do so, if it returns false, it means it should be denied.
///
/// @since_tizen 3.0
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be freed
/// @param[in] consumer_appid The id of the consumer application which requested to add the callback. @a consumer_appid is valid only inside this function. \n
/// To use outside the callback, make a copy. @a consumer_appid should not be freed
/// @param[in] user_data The user data.
/// @return A boolean value indicating whether the consumer application should be allowed to add data change callbacks.
/// @c true let the application add a data change callback,
/// otherwise @c false application not allowed to add data change callback
///
/// @pre The callback must be registered using data_control_provider_add_data_change_consumer_filter_cb(). \n
/// data_control_add_data_change_cb() must be called to invoke this callback.
///
/// @see data_control_provider_add_data_change_consumer_filter_cb()
/// @see data_control_provider_remove_data_change_consumer_filter_cb()
typedef data_control_provider_data_change_consumer_filter_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            data_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called for each application which successfully added a data change callback.
/// @since_tizen 3.0
///
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be freed
/// @param[in] consumer_appid The id of the consumer application. @a consumer_appid is valid only inside this function \n
/// To use outside the callback, make a copy. @a consumer_appid should not be freed
/// @param[in] user_data The user data
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre data_control_provider_foreach_data_change_consumer() must be called to invoke this callback.
/// @see data_control_provider_foreach_data_change_consumer()
typedef data_control_provider_data_change_consumer_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            data_control_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the bulk data request is received from an consumer application.
/// @since_tizen 3.0
///
/// @param[in] request_id The request ID
/// @param[in] provider The provider handle. @a provider is valid only inside this function. \n
/// @a provider should not be freed
/// @param[in] bulk_data The bulk data handle which contains data to be inserted or added
/// @param[in] user_data The user data passed from the register function
///
/// @see data_control_provider_sql_register_insert_bulk_data_request_cb()
/// @see data_control_provider_map_register_add_bulk_data_request_cb()
/// @see data_control_sql_insert_bulk_data()
/// @see data_control_map_add_bulk_data()
/// @see data_control_bulk_data_add()
typedef data_control_provider_bulk_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, data_control_h, data_control_bulk_data_h,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when received data changed notification from provider application.
/// @since_tizen 3.0
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be destroyed.
/// @param[in] type Changed data type
/// @param[in] data Data from provider, intended to contain information about changed data \n
/// @a data is valid only inside this function \n
/// To use outside the callback, make a copy. @a data should not be freed
/// @param[in] user_data	The user data passed from the add function
/// @pre The callback must be registered using data_control_add_data_change_cb(). \n
/// data_control_provider_send_data_change_noti() must be called to invoke this callback.
/// @see data_control_add_data_change_cb()
/// @see	data_control_provider_send_data_change_noti()
typedef data_control_data_change_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(data_control_h, ffi.Int32, ffi.Pointer<bundle>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the consumer receives the result of the data change callback adding operation.
/// @details The following error codes can be delivered: \n
/// #DATA_CONTROL_ERROR_NONE, \n
/// #DATA_CONTROL_ERROR_OUT_OF_MEMORY, \n
/// #DATA_CONTROL_ERROR_IO_ERROR, \n
/// #DATA_CONTROL_ERROR_PERMISSION_DENIED, \n
/// #DATA_CONTROL_ERROR_MAX_EXCEEDED
/// @since_tizen 3.0
/// @remarks DATA_CONTROL_ERROR_PERMISSION_DENIED will be returned when the provider denies to add the callback.
/// @param[in] provider The provider handle. @a provider is valid only inside this function \n
/// @a provider should not be destroyed.
/// @param[in] result Add data change callback result
/// @param[in] callback_id Added callback ID
/// @param[in] user_data The user data passed from the add function
/// @pre The callback must be registered using data_control_add_data_change_cb().
/// @see data_control_add_data_change_cb()
typedef data_control_add_callback_result_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            data_control_h, ffi.Int32, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for error codes of a message port.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class message_port_error_e {
  /// < Successful
  static const int MESSAGE_PORT_ERROR_NONE = 0;

  /// < Internal I/O error
  static const int MESSAGE_PORT_ERROR_IO_ERROR = -5;

  /// < Out of memory
  static const int MESSAGE_PORT_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int MESSAGE_PORT_ERROR_INVALID_PARAMETER = -22;

  /// < The message port of the remote application is not found
  static const int MESSAGE_PORT_ERROR_PORT_NOT_FOUND = -18022399;

  /// < The remote application is not signed with the same certificate
  static const int MESSAGE_PORT_ERROR_CERTIFICATE_NOT_MATCH = -18022398;

  /// < The size of the message has exceeded the maximum limit
  static const int MESSAGE_PORT_ERROR_MAX_EXCEEDED = -18022397;

  /// < Resource is temporarily unavailable
  static const int MESSAGE_PORT_ERROR_RESOURCE_UNAVAILABLE = -18022396;
}

/// @brief Called when a message is received.
/// @details The function is called when a message is received from the remote application.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks @a message is automatically freed by framework when callback returned, you can keep @a message using bundle_dup() @n
/// @a remote_port will be set only if the remote application sends a message with its port information using message_port_send_message_with_local_port(), otherwise it is @c NULL @n
/// When message is sent from remote application by message_port_send_message_with_local_port() in bidirectional communication, trusted_remote_port is used to check whether remote port is trusted port or not
/// This callback is called only in the main thread.
/// @param[in] local_port_id	The local message port ID returned by message_port_register_local_port()
/// @param[in] remote_app_id	The ID of the remote application that sent this message
/// @param[in] remote_port The name of the remote message port
/// @param[in] trusted_remote_port If @c true, the remote port is a trusted port; otherwise if @c false, it is not
/// @param[in] message The message passed from the remote application
/// @param[in] user_data The user data passed from the register function
/// @pre Either message_port_send_message() or message_port_send_message_with_local_port() from the remote application will invoke this function if you register it using message_port_register_local_port()
/// @see message_port_register_local_port()
/// @see message_port_unregister_local_port()
/// @see message_port_send_message()
/// @see message_port_send_message_with_local_port()
typedef message_port_message_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Bool, ffi.Pointer<bundle>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when a trusted message is received.
/// @details This function is called when a trusted message is received from the remote application.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks You can keep @a message using bundle_dup(). @n
/// @a remote_port will be set only if the remote application sends a message with its port information using message_port_send_trusted_message_with_local_port(), otherwise it is @c NULL. @n
/// When message is sent from remote application by message_port_send_trusted_message_with_local_port() in bidirectional communication, trusted_remote_port is used to check whether remote port is trusted port or not.
/// This callback is called only in the main thread.
/// @param[in] trusted_local_port_id	The message port ID returned by message_port_register_trusted_local_port()
/// @param[in] remote_app_id	The ID of the remote application that sent this message
/// @param[in] remote_port The name of the remote message port
/// @param[in] trusted_remote_port If @c true, the remote port is a trusted port; otherwise if @c false, it is not
/// @param[in] message The message passed from the remote application
/// @param[in] user_data	The user data passed from the register function
/// @pre Either message_port_send_trusted_message() or message_port_send_trusted_message_with_local_port() from the remote application will invoke this function if you register it using message_port_register_trusted_local_port().
/// @see message_port_register_trusted_local_port()
/// @see message_port_unregister_trusted_local_port()
/// @see message_port_send_trusted_message()
/// @see message_port_send_trusted_message_with_local_port()
typedef message_port_trusted_message_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Bool, ffi.Pointer<bundle>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when a remote port is registered or unregistered.
/// @details The function is called when a remote port is registered or unregistered
/// from the remote application.
/// @since_tizen 4.0
/// @remarks @a remote_app_id and @a remote_port can be used until
/// message_port_remove_registration_event_cb() is called for the watcher which reported
/// the event.
/// @param[in] remote_app_id        The ID of the remote application that sent this message
/// @param[in] remote_port          The name of the remote message port
/// @param[in] trusted_remote_port  Indicates whether remote port is trusted
/// @param[in] user_data            The user data passed from the register function
/// @pre Called when a remote port is registered or unregistered if you add it using
/// message_port_add_registered_cb() or message_port_add_unregistered_cb() respectively.
/// @see message_port_add_registered_cb()
/// @see message_port_add_unregistered_cb()
/// @see message_port_remove_registration_event_cb()
typedef message_port_registration_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Bool, ffi.Pointer<ffi.Void>)>>;

class package_info_s extends ffi.Opaque {}

class package_updateinfo_s extends ffi.Opaque {}

/// @brief Enumeration for storage type.
/// @since_tizen 2.3
abstract class package_info_installed_storage_type_e {
  /// < Internal storage
  static const int PACKAGE_INFO_INTERNAL_STORAGE = 0;

  /// < External storage
  static const int PACKAGE_INFO_EXTERNAL_STORAGE = 1;
}

/// @brief Enumeration for app component type.
/// @since_tizen 2.3
abstract class package_info_app_component_type_e {
  /// < All application
  static const int PACKAGE_INFO_ALLAPP = 0;

  /// < UI application
  static const int PACKAGE_INFO_UIAPP = 1;

  /// < Service application
  static const int PACKAGE_INFO_SERVICEAPP = 2;

  /// < Widget application (Since 4.0)
  static const int PACKAGE_INFO_WIDGETAPP = 3;

  /// < Watch application (Since 4.0)
  static const int PACKAGE_INFO_WATCHAPP = 4;
}

/// @brief Enumeration for certification type.
/// @since_tizen 2.3
abstract class package_cert_type_e {
  /// < Author Root Certificate
  static const int PACKAGE_INFO_AUTHOR_ROOT_CERT = 0;

  /// < Author Intermediate Certificate
  static const int PACKAGE_INFO_AUTHOR_INTERMEDIATE_CERT = 1;

  /// < Author Signer Certificate
  static const int PACKAGE_INFO_AUTHOR_SIGNER_CERT = 2;

  /// < Distributor Root Certificate
  static const int PACKAGE_INFO_DISTRIBUTOR_ROOT_CERT = 3;

  /// < Distributor Intermediate Certificate
  static const int PACKAGE_INFO_DISTRIBUTOR_INTERMEDIATE_CERT = 4;

  /// < Distributor Signer Certificate
  static const int PACKAGE_INFO_DISTRIBUTOR_SIGNER_CERT = 5;

  /// < Distributor2 Root Certificate
  static const int PACKAGE_INFO_DISTRIBUTOR2_ROOT_CERT = 6;

  /// < Distributor2 Intermediate Certificate
  static const int PACKAGE_INFO_DISTRIBUTOR2_INTERMEDIATE_CERT = 7;

  /// < Distributor2 Signer Certificate
  static const int PACKAGE_INFO_DISTRIBUTOR2_SIGNER_CERT = 8;
}

/// @brief Enumeration for package update info type.
/// @since_tizen 4.0
abstract class package_updateinfo_type_e {
  /// < None type
  static const int PACKAGE_UPDATEINFO_TYPE_NONE = 0;

  /// < Force type
  static const int PACKAGE_UPDATEINFO_TYPE_FORCE = 1;

  /// < Optional type
  static const int PACKAGE_UPDATEINFO_TYPE_OPTIONAL = 2;
}

/// @brief The package information handle.
/// @since_tizen 2.3
typedef package_info_h = ffi.Pointer<package_info_s>;

/// @brief Called to get the application ID once for each installed package.
/// @since_tizen 2.3
/// @param[in] comp_type The Application Component type
/// @param[in] callback  The callback function to be invoked
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre package_info_foreach_app_from_package() will invoke this callback.
/// @see package_info_foreach_app_from_package()
typedef package_info_app_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            ffi.Int32, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get the certification information.
/// @since_tizen 2.3
/// @param[in] package_info The package info handle
/// @param[in] cert_type    The certificate type
/// @param[in] cert_value   The certificate value of corresponding certificate key \n
/// This value is base64 encoded data.
/// @param[in] user_data    The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre package_info_foreach_cert_info() will invoke this callback.
/// @see package_info_foreach_cert_info()
typedef package_info_cert_info_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(package_info_h, ffi.Int32, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get the privilege information.
/// @since_tizen 2.3
/// @param[in] privilege_name the name of the privilege
/// @param[in] user_data    The user data passed from the foreach function
/// @return  @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre package_info_foreach_privilege_info() will invoke this callback.
/// @see package_info_foreach_privilege_info()
typedef package_info_privilege_info_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief The package update information handle.
/// @since_tizen 4.0
typedef package_updateinfo_h = ffi.Pointer<package_updateinfo_s>;

/// @brief Called for each update information of all packages.
/// @since_tizen 4.0
/// @remarks @a info should not be freed and can be used only in the callback.
/// @param[in] info       The package update information handle
/// @param[in] user_data  The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre package_info_updateinfo_foreach_updateinfo() will invoke this callback.
/// @see package_info_updateinfo_foreach_updateinfo()
typedef package_info_updateinfo_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(package_updateinfo_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for error code.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class package_manager_error_e {
  /// < Successful
  static const int PACKAGE_MANAGER_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int PACKAGE_MANAGER_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int PACKAGE_MANAGER_ERROR_OUT_OF_MEMORY = -12;

  /// < Internal I/O error
  static const int PACKAGE_MANAGER_ERROR_IO_ERROR = -5;

  /// < No such package
  static const int PACKAGE_MANAGER_ERROR_NO_SUCH_PACKAGE = -18153359;

  /// < Severe system error
  static const int PACKAGE_MANAGER_ERROR_SYSTEM_ERROR = -18153358;

  /// < Permission denied
  static const int PACKAGE_MANAGER_ERROR_PERMISSION_DENIED = -13;
}

/// @brief Enumeration for event type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class package_manager_event_type_e {
  /// < Install event type
  static const int PACKAGE_MANAGER_EVENT_TYPE_INSTALL = 0;

  /// < Uninstall event type
  static const int PACKAGE_MANAGER_EVENT_TYPE_UNINSTALL = 1;

  /// < Update event type
  static const int PACKAGE_MANAGER_EVENT_TYPE_UPDATE = 2;

  /// < Move event type (Since 3.0)
  static const int PACKAGE_MANAGER_EVENT_TYPE_MOVE = 3;

  /// < Clear event type (Since 3.0)
  static const int PACKAGE_MANAGER_EVENT_TYPE_CLEAR = 4;
  static const int PACAKGE_MANAGER_EVENT_TYPE_INSTALL = 0;
  static const int PACAKGE_MANAGER_EVENT_TYPE_UNINSTALL = 1;
  static const int PACAKGE_MANAGER_EVENT_TYPE_UPDATE = 2;
}

/// @brief Enumeration for event state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class package_manager_event_state_e {
  /// < Started event state
  static const int PACKAGE_MANAGER_EVENT_STATE_STARTED = 0;

  /// < Processing event state
  static const int PACKAGE_MANAGER_EVENT_STATE_PROCESSING = 1;

  /// < Completed event state
  static const int PACKAGE_MANAGER_EVENT_STATE_COMPLETED = 2;

  /// < Failed event state
  static const int PACKAGE_MANAGER_EVENT_STATE_FAILED = 3;
  static const int PACAKGE_MANAGER_EVENT_STATE_STARTED = 0;
  static const int PACAKGE_MANAGER_EVENT_STATE_PROCESSING = 1;
  static const int PACAKGE_MANAGER_EVENT_STATE_COMPLETED = 2;
  static const int PACAKGE_MANAGER_EVENT_STATE_FAILED = 3;
}

/// @brief Enumeration for move type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class package_manager_move_type_e {
  /// < Internal type
  static const int PACKAGE_MANAGER_REQUEST_MOVE_TO_INTERNAL = 0;

  /// < External type
  static const int PACKAGE_MANAGER_REQUEST_MOVE_TO_EXTERNAL = 1;
  static const int PACAKGE_MANAGER_REQUEST_MOVE_TO_INTERNAL = 0;
  static const int PACAKGE_MANAGER_REQUEST_MOVE_TO_EXTERNAL = 1;
}

/// @brief Enumeration for certification compare type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class package_manager_compare_result_type_e {
  /// < Matching certification
  static const int PACKAGE_MANAGER_COMPARE_MATCH = 0;

  /// < Mismatching certification
  static const int PACKAGE_MANAGER_COMPARE_MISMATCH = 1;

  /// < First package has no certification
  static const int PACKAGE_MANAGER_COMPARE_LHS_NO_CERT = 2;

  /// < Second package has no certification
  static const int PACKAGE_MANAGER_COMPARE_RHS_NO_CERT = 3;

  /// < Both have no certification
  static const int PACKAGE_MANAGER_COMPARE_BOTH_NO_CERT = 4;
  static const int PACAKGE_MANAGER_COMPARE_MATCH = 0;
  static const int PACAKGE_MANAGER_COMPARE_MISMATCH = 1;
  static const int PACAKGE_MANAGER_COMPARE_LHS_NO_CERT = 2;
  static const int PACAKGE_MANAGER_COMPARE_RHS_NO_CERT = 3;
  static const int PACAKGE_MANAGER_COMPARE_BOTH_NO_CERT = 4;
}

/// @brief Enumeration for permission type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class package_manager_permission_type_e {
  /// < Normal permission
  static const int PACKAGE_MANAGER_PERMISSION_NORMAL = 0;

  /// < Signature permission
  static const int PACKAGE_MANAGER_PERMISSION_SIGNATURE = 1;

  /// < Privilege permission
  static const int PACKAGE_MANAGER_PERMISSION_PRIVILEGE = 2;
}

/// @brief Enumeration for status type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class package_manager_status_type_e {
  /// < All status
  static const int PACKAGE_MANAGER_STATUS_TYPE_ALL = 0;

  /// < Install package status
  static const int PACKAGE_MANAGER_STATUS_TYPE_INSTALL = 1;

  /// < Uninstall package status
  static const int PACKAGE_MANAGER_STATUS_TYPE_UNINSTALL = 2;

  /// < Upgrade package status
  static const int PACKAGE_MANAGER_STATUS_TYPE_UPGRADE = 4;

  /// < Move package status
  static const int PACKAGE_MANAGER_STATUS_TYPE_MOVE = 8;

  /// < Clear data status
  static const int PACKAGE_MANAGER_STATUS_TYPE_CLEAR_DATA = 16;

  /// < Install progress status
  static const int PACKAGE_MANAGER_STATUS_TYPE_INSTALL_PROGRESS = 32;

  /// < Get size status
  static const int PACKAGE_MANAGER_STATUS_TYPE_GET_SIZE = 64;
}

class package_updateinfo_request_s extends ffi.Opaque {}

class package_manager_s extends ffi.Opaque {}

class package_manager_filter_s extends ffi.Opaque {}

/// @brief The Package manager handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef package_manager_h = ffi.Pointer<package_manager_s>;

/// @brief Called when the package is installed, uninstalled, or updated, and the progress of the request to the package manager changes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] type The type of the package to be installed, uninstalled, or updated
/// @param[in] package The name of the package to be installed, uninstalled, or updated
/// @param[in] event_type The type of the request to the package manager
/// @param[in] event_state The current state of the request to the package manager
/// @param[in] progress    The progress for the request that is being processed by the package manager \n
/// The range of progress is from @c 0 to @c 100
/// @param[in] error       The error code when the package manager failed to process the request
/// @param[in] user_data   The user data passed from package_manager_set_event_cb()
/// @see package_manager_set_event_cb()
/// @see package_manager_unset_event_cb()
typedef package_manager_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Int32, ffi.Int32, ffi.Int, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to retrieve all packages.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] package_info The package information
/// @param[in] user_data    The user data passed from the foreach function
/// @return  @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @see package_manager_foreach_package_info()
typedef package_manager_package_info_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(package_info_h, ffi.Pointer<ffi.Void>)>>;

class package_size_info extends ffi.Opaque {}

/// @brief Called when the package size information is obtained.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] package_id  The package ID
/// @param[in] size_info   The pointer to the structure including the package size information
/// @param[in] user_data   The user data to be passed to the callback function
typedef package_manager_size_info_receive_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, package_size_info_h,
            ffi.Pointer<ffi.Void>)>>;

/// @brief The package size information handle.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef package_size_info_h = ffi.Pointer<package_size_info>;

/// @platform
/// @brief Called when the total package size information is obtained.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] size_info  The pointer to the structure including the package size information
/// @param[in] user_data  The user data to be passed to the callback function
typedef package_manager_total_size_info_receive_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(package_size_info_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Package manager filter handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef package_manager_filter_h = ffi.Pointer<package_manager_filter_s>;

/// @platform
/// @brief Enumeration for request mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class package_manager_request_mode_e {
  /// < @platform Default request mode
  static const int PACKAGE_MANAGER_REQUEST_MODE_DEFAULT = 0;

  /// < @platform Quiet request mode
  static const int PACKAGE_MANAGER_REQUEST_MODE_QUIET = 1;
  static const int PACAKGE_MANAGER_REQUEST_MODE_DEFAULT = 0;
  static const int PACAKGE_MANAGER_REQUEST_MODE_QUIET = 1;
}

class package_manager_request_s extends ffi.Opaque {}

/// @platform
/// @brief The Package manager request handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef package_manager_request_h = ffi.Pointer<package_manager_request_s>;

/// @platform
/// @brief Called when the progress of the request to the package manager changes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] id          The ID of the request to the package manager
/// @param[in] type        The type of the package to install, uninstall or update
/// @param[in] package     The name of the package to install, uninstall or update
/// @param[in] event_type  The type of the request to the package manager
/// @param[in] event_state The current state of the request to the package manager
/// @param[in] progress    The progress for the request that is being processed by the package manager \n
/// The range of progress is from @c 0 to @c 100.
/// @param[in] error       The error code when the package manager failed to process the request
/// @param[in] user_data   The user data passed from package_manager_request_set_event_cb()
/// @see package_manager_request_set_event_cb()
/// @see package_manager_request_unset_event_cb()
typedef package_manager_request_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Int32, ffi.Int32, ffi.Int, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief The Package manager update info request handle.
/// @since_tizen 4.0
typedef package_updateinfo_request_h
    = ffi.Pointer<package_updateinfo_request_s>;

class package_archive_info_s extends ffi.Opaque {}

/// @brief The package archive information handle.
/// @since_tizen 4.0
typedef package_archive_info_h = ffi.Pointer<package_archive_info_s>;

/// @brief The structure type containing the set of callback functions for handling application events.
/// @details It is one of the input parameters of the service_app_efl_main() function.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see service_app_main()
/// @see service_app_create_cb()
/// @see service_app_terminate_cb()
/// @see service_app_control_cb()
class service_app_lifecycle_callback_s extends ffi.Struct {
  /// < This callback function is called at the start of the application.
  external service_app_create_cb create;

  /// < This callback function is called once after the main loop of the application exits.
  external service_app_terminate_cb terminate;

  /// < This callback function is called when another application sends the launch request to the application.
  external service_app_control_cb app_control;
}

/// @brief Called at the start of the agent application.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] user_data	The user data passed from the callback registration function
/// @return @c true on success,
/// otherwise @c false
/// @pre	service_app_main() will invoke this callback function.
/// @see service_app_main()
/// @see #service_app_lifecycle_callback_s
typedef service_app_create_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Bool Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called once after the main loop of the agent application exits.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] user_data	The user data passed from the callback registration function
/// @see	service_app_main()
/// @see #service_app_lifecycle_callback_s
typedef service_app_terminate_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when another application sends the launch request to the agent application.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] app_control The handle to the app_control
/// @param[in] user_data The user data passed from the callback registration function
/// @see service_app_main()
/// @see #service_app_lifecycle_callback_s
/// @see @ref CAPI_APP_CONTROL_MODULE API
typedef service_app_control_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(app_control_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for values of shortcut response types.
/// @since_tizen 2.3
abstract class shortcut_error_e {
  /// < Successful
  static const int SHORTCUT_ERROR_NONE = 0;

  /// < Invalid function parameter
  static const int SHORTCUT_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int SHORTCUT_ERROR_OUT_OF_MEMORY = -12;

  /// < I/O Error
  static const int SHORTCUT_ERROR_IO_ERROR = -5;

  /// < Permission denied
  static const int SHORTCUT_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int SHORTCUT_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Device or resource busy
  static const int SHORTCUT_ERROR_RESOURCE_BUSY = -16;

  /// < There is no space to add a new shortcut
  static const int SHORTCUT_ERROR_NO_SPACE = -18219007;

  /// < Shortcut is already added
  static const int SHORTCUT_ERROR_EXIST = -18219006;

  /// < Unrecoverable error
  static const int SHORTCUT_ERROR_FAULT = -18219004;

  /// < Not exist shortcut(@b Since: 3.0)
  static const int SHORTCUT_ERROR_NOT_EXIST = -18219000;

  /// < Connection not established or communication problem
  static const int SHORTCUT_ERROR_COMM = -18218944;
}

/// @brief Enumeration for shortcut types.
/// @details Basically, two types of shortcuts are defined.
/// Every homescreen developer should support these types of shortcuts.
/// Or return, a proper errno to figure out why the application failed to add a shortcut.
/// #LAUNCH_BY_APP is used for adding a package itself as a shortcut.
/// #LAUNCH_BY_URI is used for adding a shortcut for "uri" data.
/// @since_tizen 2.3
abstract class shortcut_type {
  /// < Launch the application itself
  static const int LAUNCH_BY_APP = 0;

  /// < Launch the application with the given data(URI)
  static const int LAUNCH_BY_URI = 1;
}

/// @brief Enumeration for sizes of shortcut widget.
/// @since_tizen 2.4
abstract class shortcut_widget_size {
  static const int WIDGET_SIZE_DEFAULT = 268435456;

  /// < 1x1
  static const int WIDGET_SIZE_1x1 = 268500992;

  /// < 2x1
  static const int WIDGET_SIZE_2x1 = 268566528;

  /// < 2x2
  static const int WIDGET_SIZE_2x2 = 268697600;

  /// < 4x1
  static const int WIDGET_SIZE_4x1 = 268959744;

  /// < 4x2
  static const int WIDGET_SIZE_4x2 = 269484032;

  /// < 4x3
  static const int WIDGET_SIZE_4x3 = 270532608;

  /// < 4x4
  static const int WIDGET_SIZE_4x4 = 272629760;

  /// < 4x5
  static const int WIDGET_SIZE_4x5 = 285212672;

  /// < 4x6
  static const int WIDGET_SIZE_4x6 = 301989888;
  static const int WIDGET_SIZE_EASY_DEFAULT = 805306368;

  /// < Easy mode 1x1
  static const int WIDGET_SIZE_EASY_1x1 = 805371904;

  /// < Easy mode 3x2
  static const int WIDGET_SIZE_EASY_3x1 = 805437440;

  /// < Easy mode 3x3
  static const int WIDGET_SIZE_EASY_3x3 = 805568512;
}

/// @brief Called to receive the result of shortcut_add_to_home().
/// @since_tizen 2.3
/// @param[in] ret The result value, it could be @c 0 if it succeeds to add a shortcut,
/// otherwise it returns an errno
/// @param[in] data The callback data
/// @return int @c 0 if there is no error,
/// otherwise errno
/// @see shortcut_add_to_home()
typedef result_cb_t = ffi.Pointer<
    ffi.NativeFunction<ffi.Int Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to receive the result of shortcut_get_list().
/// @since_tizen 2.4
/// @param[in] package_name The name of package
/// @param[in] icon The absolute path of an icon file for this shortcut
/// @param[in] name The name of the created shortcut icon
/// @param[in] extra_key The user data. A property of shortcut element in manifest file
/// @param[in] extra_data The user data. A property of shortcut element in manifest file
/// @param[in] user_data The callback user data
/// @return SHORTCUT_ERROR_NONE to continue with the next iteration of the loop, other error values to break out of the loop
/// @see shortcut_get_list()
typedef shortcut_list_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called to the add_to_home request.
/// @details The homescreen should define a callback as this type and implement the service code
/// for adding a new application shortcut.
/// @since_tizen 2.4
/// @param[in] package_name The name of package
/// @param[in] name The name of the created shortcut icon
/// @param[in] type One of the three defined types
/// @param[in] content_info The specific information for creating a new shortcut
/// @param[in] icon The absolute path of an icon file for this shortcut
/// @param[in] pid The process ID of who request add_to_home
/// @param[in] allow_duplicate @c 1 if the shortcut can be duplicated,
/// otherwise a shourtcut should exist only once
/// @param[in] data The callback data
/// @return The result of handling a shortcut creation request\n
/// This returns @c 0 if the add_to_home request is handled successfully,
/// otherwise it returns a proper errno
/// @see shortcut_set_request_cb()
typedef shortcut_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Int,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Int,
            ffi.Double,
            ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called to the shortcut_remove_from_home request.
/// @since_tizen 3.0
/// @param[in] package_name The name of package
/// @param[in] name The name of the created shortcut icon
/// @param[in] sender_pid The process ID of who request shortcut_remove_from_home
/// @param[in] user_data  The user data passed from the callback register function
/// @return The result of handling a shortcut remove request\n
/// This returns @c 0 if the remove_from_home request is handled successfully,
/// otherwise it returns a proper errno.
/// @see shortcut_set_remove_cb()
typedef shortcut_remove_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for error codes of URL download.
/// @since_tizen 2.3
abstract class download_error_e {
  /// < Successful
  static const int DOWNLOAD_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int DOWNLOAD_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int DOWNLOAD_ERROR_OUT_OF_MEMORY = -12;

  /// < Network is unreachable
  static const int DOWNLOAD_ERROR_NETWORK_UNREACHABLE = -101;

  /// < HTTP session time-out
  static const int DOWNLOAD_ERROR_CONNECTION_TIMED_OUT = -110;

  /// < No space left on device
  static const int DOWNLOAD_ERROR_NO_SPACE = -28;

  /// < Permission denied
  static const int DOWNLOAD_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int DOWNLOAD_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Invalid state
  static const int DOWNLOAD_ERROR_INVALID_STATE = -44040159;

  /// < Connection failed
  static const int DOWNLOAD_ERROR_CONNECTION_FAILED = -44040158;

  /// < Invalid URL
  static const int DOWNLOAD_ERROR_INVALID_URL = -44040156;

  /// < Invalid destination
  static const int DOWNLOAD_ERROR_INVALID_DESTINATION = -44040155;

  /// < Too many simultaneous downloads
  static const int DOWNLOAD_ERROR_TOO_MANY_DOWNLOADS = -44040154;

  /// < Download server queue is full
  static const int DOWNLOAD_ERROR_QUEUE_FULL = -44040153;

  /// < The download is already completed
  static const int DOWNLOAD_ERROR_ALREADY_COMPLETED = -44040152;

  /// < Failed to rename the downloaded file
  static const int DOWNLOAD_ERROR_FILE_ALREADY_EXISTS = -44040151;

  /// < Cannot resume
  static const int DOWNLOAD_ERROR_CANNOT_RESUME = -44040150;

  /// < Specified field not found
  static const int DOWNLOAD_ERROR_FIELD_NOT_FOUND = -44040149;

  /// < Too many redirects from HTTP response header
  static const int DOWNLOAD_ERROR_TOO_MANY_REDIRECTS = -44040144;

  /// < The download cannot handle the HTTP status value
  static const int DOWNLOAD_ERROR_UNHANDLED_HTTP_CODE = -44040143;

  /// < No action after client creates a download ID
  static const int DOWNLOAD_ERROR_REQUEST_TIMEOUT = -44040142;

  /// < No call to start API for some time although the download is created
  static const int DOWNLOAD_ERROR_RESPONSE_TIMEOUT = -44040141;

  /// < No response from client after rebooting download daemon
  static const int DOWNLOAD_ERROR_SYSTEM_DOWN = -44040140;

  /// < Download ID does not exist in download service module
  static const int DOWNLOAD_ERROR_ID_NOT_FOUND = -44040139;

  /// < Network bonding is set but network type is not set as DOWNLOAD_NETWORK_ALL
  static const int DOWNLOAD_ERROR_INVALID_NETWORK_TYPE = -44040138;

  /// < No data because the set API is not called
  static const int DOWNLOAD_ERROR_NO_DATA = -61;

  /// < Internal I/O error
  static const int DOWNLOAD_ERROR_IO_ERROR = -5;
}

/// @brief Enumeration for download states.
/// @since_tizen 2.3
abstract class download_state_e {
  /// < Unhandled exception
  static const int DOWNLOAD_STATE_NONE = 0;

  /// < Ready to download
  static const int DOWNLOAD_STATE_READY = 1;

  /// < Queued to start downloading
  static const int DOWNLOAD_STATE_QUEUED = 2;

  /// < Currently downloading
  static const int DOWNLOAD_STATE_DOWNLOADING = 3;

  /// < The download is waiting to resume
  static const int DOWNLOAD_STATE_PAUSED = 4;

  /// < The download is completed
  static const int DOWNLOAD_STATE_COMPLETED = 5;

  /// < The download failed
  static const int DOWNLOAD_STATE_FAILED = 6;

  /// < User canceled the download item
  static const int DOWNLOAD_STATE_CANCELED = 7;
}

/// @brief Enumeration for network type for downloading.
/// @since_tizen 2.3
abstract class download_network_type_e {
  /// < Download is available through data network
  static const int DOWNLOAD_NETWORK_DATA_NETWORK = 0;

  /// < Download is available through WiFi
  static const int DOWNLOAD_NETWORK_WIFI = 1;

  /// < Download is available through WiFi-Direct
  static const int DOWNLOAD_NETWORK_WIFI_DIRECT = 2;

  /// < Download is available through either data network or WiFi
  static const int DOWNLOAD_NETWORK_ALL = 3;
}

/// @brief Enumeration for notification types when a client wants to register.
/// @since_tizen 2.3
///
/// @see download_set_notification_type()
/// @see download_get_notification_type()
abstract class download_notification_type_e {
  /// < Do not register notification
  static const int DOWNLOAD_NOTIFICATION_TYPE_NONE = 0;

  /// < Completion notification for success state and failed state
  static const int DOWNLOAD_NOTIFICATION_TYPE_COMPLETE_ONLY = 1;

  /// < All download notifications for ongoing state, success state and failed state
  static const int DOWNLOAD_NOTIFICATION_TYPE_ALL = 2;
}

/// @brief Enumeration for the type of notification app control action which the client wants to set when registering notification.
/// @since_tizen 2.3
///
/// @see download_set_notification_app_control()
/// @see download_get_notification_app_control()
abstract class download_notification_app_control_type_e {
  /// < App control action for failed and ongoing notification
  static const int DOWNLOAD_NOTIFICATION_APP_CONTROL_TYPE_ONGOING = 0;

  /// < App control action for completed notification
  static const int DOWNLOAD_NOTIFICATION_APP_CONTROL_TYPE_COMPLETE = 1;

  /// < App control action for failed notification
  static const int DOWNLOAD_NOTIFICATION_APP_CONTROL_TYPE_FAILED = 2;
}

/// @brief Called when a download state is changed.
///
/// @since_tizen 2.3
///
/// @param[in] download_id  The download ID
/// @param[in] state        The state of download
/// @param[in] user_data    The user data passed from download_set_state_changed_cb()
///
/// @pre download_start() will invoke this callback if you register this callback using download_set_state_changed_cb().
///
/// @see download_set_state_changed_cb()
/// @see download_unset_state_changed_cb()
typedef download_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the progress of download changes.
///
/// @since_tizen 2.3
///
/// @remarks This callback function is only invoked in the downloading state.
///
/// @param[in] download_id  The download ID
/// @param[in] received     The size of the data received in bytes
/// @param[in] user_data    The user data passed from download_set_progress_cb()
///
/// @pre This callback function is invoked if you register this callback using download_set_progress_cb().
///
/// @see download_cancel()
/// @see download_set_progress_cb()
/// @see download_unset_progress_cb()
typedef download_progress_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.UnsignedLongLong, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration of error code.
abstract class mime_type_error_e {
  /// < Successful
  static const int MIME_TYPE_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int MIME_TYPE_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int MIME_TYPE_ERROR_OUT_OF_MEMORY = -12;

  /// < Internal I/O error
  static const int MIME_TYPE_ERROR_IO_ERROR = -5;

  /// < No access for the file (Since 4.0)
  static const int MIME_TYPE_ERROR_PERMISSION_DENIED = -13;
}

/// @ingroup CAPI_MEDIA_CONTENT_MODULE
/// @brief Enumeration for the media file format.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks Since 4.0, #MEDIA_CONTENT_TYPE_OTHERS is related to the following feature:\n
/// %http://tizen.org/feature/content.scanning.others\n
/// If this feature is not suppported on the device, MEDIA_CONTENT_TYPE_OTHERS type file is not scanned.
abstract class media_content_type_e {
  /// <The type of an image
  static const int MEDIA_CONTENT_TYPE_IMAGE = 0;

  /// <The type of a video
  static const int MEDIA_CONTENT_TYPE_VIDEO = 1;

  /// <The type of sound
  static const int MEDIA_CONTENT_TYPE_SOUND = 2;

  /// <The type of music
  static const int MEDIA_CONTENT_TYPE_MUSIC = 3;

  /// <The type of other
  static const int MEDIA_CONTENT_TYPE_OTHERS = 4;
}

/// @ingroup CAPI_CONTENT_MEDIA_CONTENT_MODULE
/// @brief Enumeration for the storage type.
/// @details This information is used to establish where the folder is.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_content_storage_e {
  /// < The device's internal storage
  static const int MEDIA_CONTENT_STORAGE_INTERNAL = 0;

  /// < The device's external storage like sd card
  static const int MEDIA_CONTENT_STORAGE_EXTERNAL = 1;

  /// < The external USB storage (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_CONTENT_STORAGE_EXTERNAL_USB = 2;

  /// < The Cloud storage (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif, Deprecated since 4.0)
  static const int MEDIA_CONTENT_STORAGE_CLOUD = 100;
}

/// @ingroup CAPI_MEDIA_CONTENT_MODULE
/// @brief Enumeration for media content DB update items.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_content_db_update_item_type_e {
  /// < File type, an item updated to DB
  static const int MEDIA_ITEM_FILE = 0;

  /// < Directory type, an item updated to DB
  static const int MEDIA_ITEM_DIRECTORY = 1;
}

/// @ingroup CAPI_MEDIA_CONTENT_MODULE
/// @brief Enumeration for media content DB update types.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_content_db_update_type_e {
  /// < Insert, the type of DB update
  static const int MEDIA_CONTENT_INSERT = 0;

  /// < Delete, The type of DB update
  static const int MEDIA_CONTENT_DELETE = 1;

  /// < Update, The type of DB update
  static const int MEDIA_CONTENT_UPDATE = 2;
}

/// @ingroup CAPI_CONTENT_MEDIA_INFO_MODULE
/// @brief Enumeration for orientation types.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_content_orientation_e {
  /// < Not available
  static const int MEDIA_CONTENT_ORIENTATION_NOT_AVAILABLE = 0;

  /// < Normal
  static const int MEDIA_CONTENT_ORIENTATION_NORMAL = 1;

  /// < Flip horizontal
  static const int MEDIA_CONTENT_ORIENTATION_HFLIP = 2;

  /// < Rotate 180 degrees
  static const int MEDIA_CONTENT_ORIENTATION_ROT_180 = 3;

  /// < Flip vertical
  static const int MEDIA_CONTENT_ORIENTATION_VFLIP = 4;

  /// < Transpose
  static const int MEDIA_CONTENT_ORIENTATION_TRANSPOSE = 5;

  /// < Rotate 90 degrees
  static const int MEDIA_CONTENT_ORIENTATION_ROT_90 = 6;

  /// < Transverse
  static const int MEDIA_CONTENT_ORIENTATION_TRANSVERSE = 7;

  /// < Rotate 270 degrees
  static const int MEDIA_CONTENT_ORIENTATION_ROT_270 = 8;
}

/// @ingroup CAPI_MEDIA_CONTENT_MODULE
/// @brief Enumeration for ordering.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_content_order_e {
  /// < Ascending order
  static const int MEDIA_CONTENT_ORDER_ASC = 0;

  /// < Descending order
  static const int MEDIA_CONTENT_ORDER_DESC = 1;
  static const int MEDIA_CONTENT_ORDER_OTHER = 2;
}

/// @ingroup CAPI_MEDIA_CONTENT_MODULE
/// @brief Enumeration for collations.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_content_collation_e {
  /// < Default collation BINARY
  static const int MEDIA_CONTENT_COLLATE_DEFAULT = 0;

  /// < Collation NOCASE, not case sensitive
  static const int MEDIA_CONTENT_COLLATE_NOCASE = 1;

  /// < Collation RTRIM, trailing space characters are ignored
  static const int MEDIA_CONTENT_COLLATE_RTRIM = 2;

  /// < Collation LOCALIZATION, NOCASE also applied
  static const int MEDIA_CONTENT_COLLATE_LOCALIZED = 3;
}

/// @ingroup CAPI_MEDIA_CONTENT_MODULE
/// @brief Enumeration for a media content error.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_content_error_e {
  /// < Successful
  static const int MEDIA_CONTENT_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int MEDIA_CONTENT_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int MEDIA_CONTENT_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid Operation
  static const int MEDIA_CONTENT_ERROR_INVALID_OPERATION = -38;

  /// < No space left on device
  static const int MEDIA_CONTENT_FILE_NO_SPACE_ON_DEVICE = -28;

  /// < Permission denied
  static const int MEDIA_CONTENT_ERROR_PERMISSION_DENIED = -13;

  /// < DB operation failed
  static const int MEDIA_CONTENT_ERROR_DB_FAILED = -23134207;

  /// < DB operation BUSY
  static const int MEDIA_CONTENT_ERROR_DB_BUSY = -23134206;

  /// < Network Fail
  static const int MEDIA_CONTENT_ERROR_NETWORK = -23134205;

  /// < Unsupported Content
  static const int MEDIA_CONTENT_ERROR_UNSUPPORTED_CONTENT = -23134204;

  /// < Not supported
  static const int MEDIA_CONTENT_ERROR_NOT_SUPPORTED = -1073741822;
}

/// @ingroup CAPI_MEDIA_CONTENT_MODULE
/// @brief Enumeration for a media group.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_group_e {
  /// < Media group ID for display name
  static const int MEDIA_CONTENT_GROUP_DISPLAY_NAME = 0;

  /// < Media group ID for a media type
  static const int MEDIA_CONTENT_GROUP_TYPE = 1;

  /// < Media group ID for a mime type
  static const int MEDIA_CONTENT_GROUP_MIME_TYPE = 2;

  /// < Media group ID for content size
  static const int MEDIA_CONTENT_GROUP_SIZE = 3;

  /// < Media group ID for the added time
  static const int MEDIA_CONTENT_GROUP_ADDED_TIME = 4;

  /// < Media group ID for the modified time
  static const int MEDIA_CONTENT_GROUP_MODIFIED_TIME = 5;

  /// < Media group ID for a content title
  static const int MEDIA_CONTENT_GROUP_TITLE = 6;

  /// < Media group ID for an artist
  static const int MEDIA_CONTENT_GROUP_ARTIST = 7;

  /// < Media group ID for an album artist
  static const int MEDIA_CONTENT_GROUP_ALBUM_ARTIST = 8;

  /// < Media group ID for a genre
  static const int MEDIA_CONTENT_GROUP_GENRE = 9;

  /// < Media group ID for a composer
  static const int MEDIA_CONTENT_GROUP_COMPOSER = 10;

  /// < Media group ID for a year
  static const int MEDIA_CONTENT_GROUP_YEAR = 11;

  /// < Media group ID for the recorded date
  static const int MEDIA_CONTENT_GROUP_RECORDED_DATE = 12;

  /// < Media group ID for the copyright
  static const int MEDIA_CONTENT_GROUP_COPYRIGHT = 13;

  /// < Media group ID for a track number
  static const int MEDIA_CONTENT_GROUP_TRACK_NUM = 14;

  /// < Media group ID for a description
  static const int MEDIA_CONTENT_GROUP_DESCRIPTION = 15;

  /// < Media group ID for the longitude
  static const int MEDIA_CONTENT_GROUP_LONGITUDE = 16;

  /// < Media group ID for the latitude
  static const int MEDIA_CONTENT_GROUP_LATITUDE = 17;

  /// < Media group ID for the altitude
  static const int MEDIA_CONTENT_GROUP_ALTITUDE = 18;

  /// < Media group ID for the burst shot (Deprecated since 4.0)
  static const int MEDIA_CONTENT_GROUP_BURST_IMAGE = 19;

  /// < Media group ID for a rating
  static const int MEDIA_CONTENT_GROUP_RATING = 20;

  /// < Media group ID for an author (Deprecated since 4.0)
  static const int MEDIA_CONTENT_GROUP_AUTHOR = 21;

  /// < Media group ID for a provider (Deprecated since 4.0)
  static const int MEDIA_CONTENT_GROUP_PROVIDER = 22;

  /// < Media group ID for the content name (Deprecated since 4.0)
  static const int MEDIA_CONTENT_GROUP_CONTENT_NAME = 23;

  /// < Media group ID for a category (Deprecated since 4.0)
  static const int MEDIA_CONTENT_GROUP_CATEGORY = 24;

  /// < Media group ID for a location tag (Deprecated since 4.0)
  static const int MEDIA_CONTENT_GROUP_LOCATION_TAG = 25;

  /// < Media group ID for an age rating (Deprecated since 4.0)
  static const int MEDIA_CONTENT_GROUP_AGE_RATING = 26;

  /// < Media group ID for a keyword (Deprecated since 4.0)
  static const int MEDIA_CONTENT_GROUP_KEYWORD = 27;

  /// < Media group ID for the weather (Deprecated since 4.0)
  static const int MEDIA_CONTENT_GROUP_WEATHER = 28;

  /// < Invalid media group ID
  static const int MEDIA_CONTENT_GROUP_MAX = 29;
}

class media_info_s extends ffi.Opaque {}

class media_folder_s extends ffi.Opaque {}

class media_playlist_s extends ffi.Opaque {}

class media_tag_s extends ffi.Opaque {}

class media_bookmark_s extends ffi.Opaque {}

class media_album_s extends ffi.Opaque {}

class image_meta_s extends ffi.Opaque {}

class video_meta_s extends ffi.Opaque {}

class audio_meta_s extends ffi.Opaque {}

class filter_s extends ffi.Opaque {}

/// @ingroup CAPI_CONTENT_MEDIA_AUDIO_META_MODULE
/// @brief The structure type for the Audio metadata handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef audio_meta_h = ffi.Pointer<audio_meta_s>;

/// @ingroup CAPI_CONTENT_MEDIA_FILTER_MODULE
/// @brief The structure type for the Media filter handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef filter_h = ffi.Pointer<filter_s>;

/// @ingroup CAPI_CONTENT_MEDIA_FOLDER_MODULE
/// @brief Called for every available media folder.
/// @details Iterates over a list of folders.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks To use the @a folder outside this function, copy the handle with the media_folder_clone() function. \n
/// The callback is called in the main loop.
///
/// @param[in] folder    The handle to the media folder
/// @param[in] user_data The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre media_folder_foreach_folder_from_db() will invoke this function.
/// @see media_folder_clone()
/// @see media_folder_foreach_folder_from_db()
typedef media_folder_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(media_folder_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_FOLDER_MODULE
/// @brief The structure type for the Media folder handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef media_folder_h = ffi.Pointer<media_folder_s>;

/// @ingroup CAPI_CONTENT_MEDIA_INFO_MODULE
/// @brief Called for every available media info.
/// @details Iterates over a list of media info.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks To use the @a media outside this function, copy the handle with media_info_clone() function. \n
/// The callback is called in the main loop.
///
/// @param[in] media     The handle to the media info
/// @param[in] user_data The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre media_tag_foreach_media_from_db(), media_playlist_foreach_media_from_db(), media_genre_foreach_media_from_db(),
/// media_info_foreach_media_from_db(), media_folder_foreach_media_from_db() will invoke this function.
///
/// @see media_info_clone()
/// @see media_album_foreach_media_from_db()
/// @see media_playlist_foreach_media_from_db()
/// @see media_tag_foreach_media_from_db()
/// @see media_info_foreach_media_from_db()
/// @see media_folder_foreach_media_from_db()
typedef media_info_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(media_info_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_INFO_MODULE
/// @brief The structure type for the Media info handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef media_info_h = ffi.Pointer<media_info_s>;

/// @ingroup CAPI_CONTENT_MEDIA_IMAGE_MODULE
/// @brief The structure type for the Image metadata handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef image_meta_h = ffi.Pointer<image_meta_s>;

/// @ingroup CAPI_CONTENT_MEDIA_INFO_MODULE
/// @brief Called when media items are inserted completely.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks The callback is called in a separate thread(not in the main loop).
///
/// @param[in] media     The handle to the media info
/// @param[in] user_data The user data passed from the foreach function
///
/// @pre media_info_insert_batch_to_db()
/// @see media_info_insert_batch_to_db()
typedef media_insert_completed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 4.0.
/// @ingroup CAPI_CONTENT_MEDIA_INFO_MODULE
/// @brief Called when the burst shot is inserted completely.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks The callback is called in a separate thread(not in the main loop).
///
/// @param[in] media     The handle to the media info
/// @param[in] user_data The user data passed from the foreach function
///
/// @pre media_info_insert_burst_shot_to_db()
/// @see media_info_insert_burst_shot_to_db()
typedef media_insert_burst_shot_completed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_TAG_MODULE
/// @brief Called for every tag in the obtained list of tags.
/// @details Iterates over a list of tags.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks To use the @a tag outside this function, copy the handle with the media_tag_clone() function. \n
/// The callback is called in the main loop.
///
/// @param[in] tag       The handle to the media tag
/// @param[in] user_data The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre media_tag_foreach_tag_from_db(), media_info_foreach_tag_from_db() will invoke this function.
///
/// @see media_tag_clone()
/// @see media_tag_foreach_tag_from_db()
/// @see media_info_foreach_tag_from_db()
typedef media_tag_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(media_tag_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_TAG_MODULE
/// @brief The structure type for the Media tag handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef media_tag_h = ffi.Pointer<media_tag_s>;

/// @ingroup CAPI_CONTENT_MEDIA_BOOKMARK_MODULE
/// @brief Called for every bookmark in the obtained list of bookmarks.
/// @details Iterates over a bookmark list.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks To use the @a bookmark outside this function, copy the handle with the media_bookmark_clone() function. \n
/// The callback is called in the main loop.
///
/// @param[in] bookmark  The handle to the video bookmark
/// @param[in] user_data The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre media_info_foreach_bookmark_from_db() will invoke this function.
/// @see media_info_foreach_bookmark_from_db()
typedef media_bookmark_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(media_bookmark_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_BOOKMARK_MODULE
/// @brief The structure type for the Media bookmark handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef media_bookmark_h = ffi.Pointer<media_bookmark_s>;

/// @ingroup CAPI_CONTENT_MEDIA_FACE_MODULE
/// @brief Called for every face in the obtained list of face.
/// @details Iterates over a media face list.
///
/// @since_tizen 3.0
///
/// @remarks You should not destroy @a face returned by this function. \n
/// The callback is called in the main loop.
///
/// @param[in] face     The handle of the media face
/// @param[in] user_data  The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre media_info_foreach_face_from_db() will invoke this function.
/// @see media_info_foreach_face_from_db()
typedef media_face_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(media_face_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_FACE_MODULE
/// @brief The structure type for the Media face handle.
/// @since_tizen 3.0
typedef media_face_h = ffi.Pointer<ffi.Void>;

/// @ingroup CAPI_CONTENT_MEDIA_VIDEO_META_MODULE
/// @brief The structure type for the Video metadata handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef video_meta_h = ffi.Pointer<video_meta_s>;

/// @ingroup CAPI_CONTENT_MEDIA_INFO_MODULE
/// @brief Called when creating a thumbnail image.
/// @details This callback is called for completion of generating the thumbnail image.
/// The following error codes can be delivered. \n
/// #MEDIA_CONTENT_ERROR_NONE, \n
/// #MEDIA_CONTENT_ERROR_INVALID_PARAMETER, \n
/// #MEDIA_CONTENT_ERROR_INVALID_OPERATION, \n
/// #MEDIA_CONTENT_ERROR_PERMISSION_DENIED, \n
/// #MEDIA_CONTENT_ERROR_DB_FAILED, \n
/// #MEDIA_CONTENT_ERROR_UNSUPPORTED_CONTENT
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks The callback is called in a separate thread(not in the main loop).
///
/// @param[in] error     The error code
/// @param[in] path      The path of the thumbnail which is generated
/// @param[in] user_data The user data passed from the foreach function
///
/// @pre media_info_create_thumbnail()
/// @see media_info_create_thumbnail()
typedef media_thumbnail_completed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_FACE_DETECTION_MODULE
/// @brief Called when face detection on the image is completed.
///
/// @details The following error codes can be delivered. \n
/// #MEDIA_CONTENT_ERROR_NONE, \n
/// #MEDIA_CONTENT_ERROR_OUT_OF_MEMORY, \n
/// #MEDIA_CONTENT_ERROR_INVALID_OPERATION, \n
/// #MEDIA_CONTENT_ERROR_DB_FAILED, \n
/// #MEDIA_CONTENT_ERROR_DB_BUSY, \n
/// #MEDIA_CONTENT_ERROR_UNSUPPORTED_CONTENT
///
/// @since_tizen 3.0
///
/// @remarks The callback is called in a separate thread(not in the main loop).
///
/// @param[in] error     The error code
/// @param[in] face_count      The number of all detected faces
/// @param[in] user_data The user data passed from the foreach function
///
/// @pre media_info_start_face_detection()
/// @see media_info_start_face_detection()
typedef media_face_detection_completed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_ALBUM_MODULE
/// @brief Called for every album in the obtained list of groups.
/// @details Iterates over an album list.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks To use the @a album outside this function, copy the handle with the media_album_clone() function. \n
/// The callback is called in the main loop.
///
/// @param[in] album     The handle to the media album
/// @param[in] user_data The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre media_album_foreach_album_from_db() will invoke this function.
///
/// @see media_album_clone()
/// @see media_album_foreach_album_from_db()
typedef media_album_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(media_album_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_ALBUM_MODULE
/// @brief The structure type for the Media album handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef media_album_h = ffi.Pointer<media_album_s>;

/// @ingroup CAPI_CONTENT_MEDIA_GROUP_MODULE
/// @brief Called for every group in the obtained list of groups.
/// @details Iterates over a media group list.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks You should not free @a group_name returned by this function. \n
/// The callback is called in the main loop.
///
/// @param[in] group_name The name of the media group
/// @param[in] user_data  The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre media_group_foreach_group_from_db() will invoke this function.
/// @see media_group_foreach_group_from_db()
typedef media_group_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_PLAYLIST_MODULE
/// @brief Called for every playlist in the obtained list of playlists.
/// @details Iterates over a playlist list.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks To use the @a playlist outside this function, copy the handle with the media_playlist_clone() function. \n
/// The callback is called in the main loop.
///
/// @param[in] playlist  The handle to the media playlist
/// @param[in] user_data The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre media_playlist_foreach_playlist_from_db() will invoke this function.
///
/// @see media_playlist_clone()
/// @see media_playlist_foreach_playlist_from_db()
typedef media_playlist_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(media_playlist_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_PLAYLIST_MODULE
/// @brief The structure type for the Media playlist handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef media_playlist_h = ffi.Pointer<media_playlist_s>;

/// @ingroup CAPI_CONTENT_MEDIA_PLAYLIST_MODULE
/// @brief Called for every media info with playlist member ID in the obtained list of media info.
/// @details Iterates over playlist members.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks To use the @a media outside this function, copy the handle with the media_info_clone() function. \n
/// The callback is called in the main loop.
///
/// @param[in] playlist_member_id The ID to member of the playlist
/// @param[in] media              The handle to the media info
/// @param[in] user_data          The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre media_playlist_foreach_media_from_db() will invoke this function.
///
/// @see media_info_clone()
/// @see media_playlist_foreach_media_from_db()
typedef playlist_member_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, media_info_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_STORAGE_MODULE
/// @brief The structure type for the Media storage handle.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef media_storage_h = ffi.Pointer<ffi.Void>;

/// @ingroup CAPI_CONTENT_MEDIA_STORAGE_MODULE
/// @brief Called for every storage in the obtained list of storages.
/// @details Iterates over a media storage list.
///
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @remarks You should not destroy @a storage returned by this function. \n
/// The callback is called in the main loop.
///
/// @param[in] storage     The handle of the media storage
/// @param[in] user_data  The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre media_storage_foreach_storage_from_db() will invoke this function.
/// @see media_storage_foreach_storage_from_db()
typedef media_storage_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(media_storage_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_MEDIA_CONTENT_MODULE
/// @brief Called when the media scanning is finished.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks The callback is called in a separate thread(not in the main loop).
///
/// @param[in] error     The error code
/// @param[in] user_data The user data passed from the foreach function
///
/// @pre media_content_scan_folder().
/// @see media_content_scan_folder()
typedef media_scan_completed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_MEDIA_CONTENT_MODULE
/// @brief Called when the notification of the media DB change is subscribed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks The callback is called in a separate thread(not in the main loop).
///
/// @param[in] error       The error code
/// @param[in] pid         The PID which publishes notification
/// @param[in] update_item The update item of notification
/// @param[in] update_type The update type of notification
/// @param[in] media_type  The type of the media content (#media_content_type_e)
/// @param[in] uuid        The UUID of media or directory, which is updated
/// @param[in] path        The path of the media or directory
/// @param[in] mime_type   The mime type of the media info
/// @param[in] user_data   The user data passed from the foreach function
///
/// @pre media_content_db_update_subscribe().
/// @see media_content_db_update_subscribe()
typedef media_content_db_update_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32,
            ffi.Int,
            ffi.Int32,
            ffi.Int32,
            ffi.Int32,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_CONTENT_MEDIA_CONTENT_MODULE
/// @brief The structure type for the Media content noti handle.
/// @since_tizen 3.0
typedef media_content_noti_h = ffi.Pointer<ffi.Void>;

class email_s extends ffi.Opaque {}

/// @brief Enumeration for the result values of email transport.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class email_sending_e {
  /// < Email sending failed
  static const int EMAIL_SENDING_FAILED = -1;

  /// < Email sending succeeded
  static const int EMAIL_SENDING_SUCCEEDED = 0;
}

/// @brief Enumeration for the email recipient types.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class email_recipient_type_e {
  /// < Normal recipient
  static const int EMAIL_RECIPIENT_TYPE_TO = 1;

  /// < CC(carbon copy) recipient
  static const int EMAIL_RECIPIENT_TYPE_CC = 2;

  /// < BCC(blind carbon copy) recipient
  static const int EMAIL_RECIPIENT_TYPE_BCC = 3;
}

/// @brief Enumeration for error codes for email API.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class email_error_e {
  /// < Successful
  static const int EMAILS_ERROR_NONE = 0;

  /// < Memory cannot be allocated
  static const int EMAILS_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int EMAILS_ERROR_INVALID_PARAMETER = -22;

  /// < Server not ready
  static const int EMAILS_ERROR_SERVER_NOT_READY = -24116736;

  /// < Communication with server failed
  static const int EMAILS_ERROR_COMMUNICATION_WITH_SERVER_FAILED = -24116735;

  /// < Operation failed
  static const int EMAILS_ERROR_OPERATION_FAILED = -24116734;

  /// < Email account not found
  static const int EMAILS_ERROR_ACCOUNT_NOT_FOUND = -24116733;

  /// < Email database failed
  static const int EMAILS_ERROR_DB_FAILED = -24116732;

  /// < Permission denied
  static const int EMAILS_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported (Since 3.0)
  static const int EMAILS_ERROR_NOT_SUPPORTED = -1073741822;
}

/// @brief The email message handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
typedef email_h = ffi.Pointer<email_s>;

/// @brief Called when the process of sending an email finishes.
/// @details You can check whether sending an email succeeds using this function.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
/// @param[in] email The handle to the email message
/// @param[in] result The result of email message sending \n
/// #EMAIL_SENDING_FAILED or #EMAIL_SENDING_SUCCEEDED
/// @param[in] user_data The user data passed from the callback registration function
/// @pre email_send_message() will invoke this callback if you register this callback using email_set_message_sent_cb().
/// @see email_send_message()
/// @see email_set_message_sent_cb()
/// @see email_unset_message_sent_cb()
typedef email_message_sent_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(email_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

class messages_service_s extends ffi.Opaque {}

class messages_message_s extends ffi.Opaque {}

/// @brief Enumeration for the message box type.
/// @since_tizen 2.3
abstract class messages_message_box_e {
  /// < All message box type
  static const int MESSAGES_MBOX_ALL = 0;

  /// < Inbox type
  static const int MESSAGES_MBOX_INBOX = 1;

  /// < Outbox type
  static const int MESSAGES_MBOX_OUTBOX = 2;

  /// < Sentbox type
  static const int MESSAGES_MBOX_SENTBOX = 3;

  /// < Draft type
  static const int MESSAGES_MBOX_DRAFT = 4;
}

/// @brief Enumeration for the message type.
/// @since_tizen 2.3
abstract class messages_message_type_e {
  /// < Unknown type
  static const int MESSAGES_TYPE_UNKNOWN = 0;

  /// < SMS type
  static const int MESSAGES_TYPE_SMS = 1;

  /// < MMS type
  static const int MESSAGES_TYPE_MMS = 2;

  /// < CB(Cell Broadcast) Type
  static const int MESSAGES_TYPE_SMS_CB = 17;

  /// < WAP Push Type
  static const int MESSAGES_TYPE_SMS_PUSH = 161;

  /// < ETWS(Earthquake and Tsunami Warning System) Primary Type
  static const int MESSAGES_TYPE_SMS_ETWS_PRIMARY = 337;

  /// < ETWS(Earthquake and Tsunami Warning System) Secondary Type
  static const int MESSAGES_TYPE_SMS_ETWS_SECONDARY = 353;
}

/// @brief Enumeration for the attachment type for MMS messaging.
/// @since_tizen 2.3
abstract class messages_media_type_e {
  /// < Unknown
  static const int MESSAGES_MEDIA_UNKNOWN = 0;

  /// < The image
  static const int MESSAGES_MEDIA_IMAGE = 1;

  /// < The audio
  static const int MESSAGES_MEDIA_AUDIO = 2;

  /// < The video
  static const int MESSAGES_MEDIA_VIDEO = 3;
}

/// @brief Enumeration for the recipient type of a message.
/// @since_tizen 2.3
abstract class messages_recipient_type_e {
  /// < Unknown
  static const int MESSAGES_RECIPIENT_UNKNOWN = 0;

  /// < The 'To' recipient
  static const int MESSAGES_RECIPIENT_TO = 1;

  /// < The 'Cc' (carbon copy) recipient
  static const int MESSAGES_RECIPIENT_CC = 2;

  /// < The 'Bcc' (blind carbon copy) recipient
  static const int MESSAGES_RECIPIENT_BCC = 3;
}

/// @brief Enumeration for the result of sending a message.
/// @since_tizen 2.3
abstract class messages_sending_result_e {
  /// < Message sending failed
  static const int MESSAGES_SENDING_FAILED = -1;

  /// < Message sending succeeded
  static const int MESSAGES_SENDING_SUCCEEDED = 0;
}

/// @brief Enumeration for the SIM index of a message.
/// @since_tizen 2.3
abstract class messages_sim_index_e {
  /// < Unknown SIM Index
  static const int MESSAGES_SIM_INDEX_UNKNOWN = 0;

  /// < SIM Index 1
  static const int MESSAGES_SIM_INDEX_1 = 1;

  /// < SIM Index 2
  static const int MESSAGES_SIM_INDEX_2 = 2;
}

/// @brief Enumeration for Messaging of error code.
abstract class messages_error_e {
  /// < Successful
  static const int MESSAGES_ERROR_NONE = 0;

  /// < Out of memory
  static const int MESSAGES_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int MESSAGES_ERROR_INVALID_PARAMETER = -22;

  /// < Server is not read
  static const int MESSAGES_ERROR_SERVER_NOT_READY = -24181503;

  /// < Communication with server failed
  static const int MESSAGES_ERROR_COMMUNICATION_WITH_SERVER_FAILED = -24181502;

  /// < Index out of range
  static const int MESSAGES_ERROR_OUT_OF_RANGE = -24181501;

  /// < Sending a message failed
  static const int MESSAGES_ERROR_SENDING_FAILED = -24181500;

  /// < Messaging operation failed
  static const int MESSAGES_ERROR_OPERATION_FAILED = -24181499;

  /// < No SIM Card
  static const int MESSAGES_ERROR_NO_SIM_CARD = -24181498;

  /// < No data available
  static const int MESSAGES_ERROR_NO_DATA = -24181497;

  /// < Permission denied
  static const int MESSAGES_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int MESSAGES_ERROR_NOT_SUPPORTED = -1073741822;
}

/// @brief The messaging service handle.
/// @since_tizen 2.3
typedef messages_service_h = ffi.Pointer<messages_service_s>;

/// @brief The message handle.
/// @since_tizen 2.3
typedef messages_message_h = ffi.Pointer<messages_message_s>;

/// @brief Called when the process of sending a message to all recipients finishes.
/// @since_tizen 2.3
/// @param[in] result The result of message sending
/// @param[in] user_data The user data passed from the callback registration function
/// @pre messages_send_message() will invoke this callback function.
/// @see messages_send_message()
typedef messages_sent_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when a message is retrieved from a search request.
/// @since_tizen 2.3
/// @remarks You should not call messages_destroy_message() with @a msg.
/// @param[in] msg The message handle \n
/// It can be @c NULL if nothing is found
/// @param[in] user_data The user data passed from the foreach function
/// @param[in] index The index of a message from the messages that have been retrieved as a search result
/// @param[in] result_count The count of the messages that have been retrieved as a result applying @a limit and @a offset \n
/// If the search has a @a limit, then this value is always equal or less than the limit
/// @param[in] total_count The count of the messages that have been retrieved as a result without applying @a limit and @a offset \n
/// The value can be used to calculate the total number of page views for the searched messages. \n
/// For example, if the count of message search is @c 50 and the limit is @c 20, then using this value, you can notice the total page is @c 3
/// @return @c true to continue with the next iteration of the loop,
/// otherwise return @c false to break out of the loop
/// @pre messages_foreach_message() will invoke this callback function.
/// @see messages_foreach_message()
typedef messages_search_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(messages_message_h, ffi.Int, ffi.Int, ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an incoming message is received.
/// @since_tizen 2.3
/// @param[in] incoming_msg The incoming message
/// @param[in] user_data The user data passed from the callback registration function
/// @pre You register this callback using messages_set_message_incoming_cb() for getting an incoming message.
/// @see messages_set_message_incoming_cb()
/// @see messages_unset_message_incoming_cb()
typedef messages_incoming_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(messages_message_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an incoming push message is received.
/// @since_tizen 2.3
/// @param[in] header The header of the push message
/// @param[in] body The body of the push message \n
/// It is not a null-terminated string
/// @param[in] body_length The length of @a body
/// @param[in] user_data The user data to be passed to the callback function
/// @pre You register this callback using messages_push_set_incoming_cb() for getting an incoming message.
/// @see messages_push_set_incoming_cb()
/// @see messages_push_unset_incoming_cb()
typedef messages_push_incoming_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>, ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for sound manager's error codes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_manager_error_e {
  /// < Successful
  static const int SOUND_MANAGER_ERROR_NONE = 0;

  /// < Out of memory
  static const int SOUND_MANAGER_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int SOUND_MANAGER_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid operation
  static const int SOUND_MANAGER_ERROR_INVALID_OPERATION = -38;

  /// < Permission denied
  static const int SOUND_MANAGER_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int SOUND_MANAGER_ERROR_NOT_SUPPORTED = -1073741822;

  /// < No data
  static const int SOUND_MANAGER_ERROR_NO_DATA = -61;

  /// < Internal error inside the sound system
  static const int SOUND_MANAGER_ERROR_INTERNAL = -26607615;

  /// < Noncompliance with the sound system policy
  static const int SOUND_MANAGER_ERROR_POLICY = -26607614;

  /// < No playing sound
  static const int SOUND_MANAGER_ERROR_NO_PLAYING_SOUND = -26607613;

  /// < Invalid state (Since 3.0)
  static const int SOUND_MANAGER_ERROR_INVALID_STATE = -26607612;
}

/// @brief Enumeration for sound type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_type_e {
  /// < Sound type for system
  static const int SOUND_TYPE_SYSTEM = 0;

  /// < Sound type for notifications
  static const int SOUND_TYPE_NOTIFICATION = 1;

  /// < Sound type for alarm
  static const int SOUND_TYPE_ALARM = 2;

  /// < Sound type for ringtones (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int SOUND_TYPE_RINGTONE = 3;

  /// < Sound type for media
  static const int SOUND_TYPE_MEDIA = 4;

  /// < Sound type for call (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int SOUND_TYPE_CALL = 5;

  /// < Sound type for voip (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int SOUND_TYPE_VOIP = 6;

  /// < Sound type for voice
  static const int SOUND_TYPE_VOICE = 7;
}

class sound_stream_info_s extends ffi.Opaque {}

/// @brief Enumeration for sound stream type.
/// @since_tizen 3.0
abstract class sound_stream_type_e {
  /// < Sound stream type for media
  static const int SOUND_STREAM_TYPE_MEDIA = 0;

  /// < Sound stream type for system
  static const int SOUND_STREAM_TYPE_SYSTEM = 1;

  /// < Sound stream type for alarm
  static const int SOUND_STREAM_TYPE_ALARM = 2;

  /// < Sound stream type for notification
  static const int SOUND_STREAM_TYPE_NOTIFICATION = 3;

  /// < Sound stream type for emergency
  static const int SOUND_STREAM_TYPE_EMERGENCY = 4;

  /// < Sound stream type for voice information
  static const int SOUND_STREAM_TYPE_VOICE_INFORMATION = 5;

  /// < Sound stream type for voice recognition
  static const int SOUND_STREAM_TYPE_VOICE_RECOGNITION = 6;

  /// < Sound stream type for ringtone for VoIP
  static const int SOUND_STREAM_TYPE_RINGTONE_VOIP = 7;

  /// < Sound stream type for VoIP
  static const int SOUND_STREAM_TYPE_VOIP = 8;

  /// < Sound stream type for media only for external devices
  static const int SOUND_STREAM_TYPE_MEDIA_EXTERNAL_ONLY = 9;
}

/// @brief Enumeration for change reason of sound stream focus state.
/// @since_tizen 3.0
abstract class sound_stream_focus_change_reason_e {
  /// < Changed by the stream type for media
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_MEDIA = 0;

  /// < Changed by the stream type for system
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_SYSTEM = 1;

  /// < Changed by the stream type for alarm
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_ALARM = 2;

  /// < Changed by the stream type for notification
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_NOTIFICATION = 3;

  /// < Changed by the stream type for emergency
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_EMERGENCY = 4;

  /// < Changed by the stream type for voice information
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_VOICE_INFORMATION = 5;

  /// < Changed by the stream type for voice recognition
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_VOICE_RECOGNITION = 6;

  /// < Changed by the stream type for ringtone
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_RINGTONE = 7;

  /// < Changed by the stream type for VoIP
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_VOIP = 8;

  /// < Changed by the stream type for voice-call or video-call
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_CALL = 9;

  /// < Changed by the stream type for media only for external devices
  static const int SOUND_STREAM_FOCUS_CHANGED_BY_MEDIA_EXTERNAL_ONLY = 10;
}

/// @brief Enumeration for sound stream focus mask.
/// @since_tizen 3.0
abstract class sound_stream_focus_mask_e {
  /// < Mask for playback focus
  static const int SOUND_STREAM_FOCUS_FOR_PLAYBACK = 1;

  /// < Mask for recording focus
  static const int SOUND_STREAM_FOCUS_FOR_RECORDING = 2;

  /// < Mask for both playback and recording focus
  static const int SOUND_STREAM_FOCUS_FOR_BOTH = 3;
}

/// @brief Enumeration for sound stream focus state.
/// @since_tizen 3.0
abstract class sound_stream_focus_state_e {
  /// < Focus state for release
  static const int SOUND_STREAM_FOCUS_STATE_RELEASED = 0;

  /// < Focus state for acquisition
  static const int SOUND_STREAM_FOCUS_STATE_ACQUIRED = 1;
}

/// @brief Enumeration for sound behavior.
/// @since_tizen 3.0
/// @remarks These values can be combined with bitwise 'or'.
/// @see sound_manager_get_current_playback_focus()
/// @see sound_manager_get_current_recording_focus()
abstract class sound_behavior_e {
  /// < None (default)
  static const int SOUND_BEHAVIOR_NONE = 0;

  /// < No resumption
  static const int SOUND_BEHAVIOR_NO_RESUME = 1;

  /// < Fading effect
  static const int SOUND_BEHAVIOR_FADING = 2;
}

/// @deprecated Deprecated since 3.0. Use sound_manager_create_stream_information() and sound_stream_type_e instead.
/// @brief Enumeration for session type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_session_type_e {
  /// < Media type
  static const int SOUND_SESSION_TYPE_MEDIA = 0;

  /// < Alarm type
  static const int SOUND_SESSION_TYPE_ALARM = 1;

  /// < Notification type
  static const int SOUND_SESSION_TYPE_NOTIFICATION = 2;

  /// < Emergency type
  static const int SOUND_SESSION_TYPE_EMERGENCY = 3;

  /// < VoIP type
  static const int SOUND_SESSION_TYPE_VOIP = 4;
}

/// @deprecated Deprecated since 3.0. Use sound_manager_acquire_focus() or not instead.
/// @brief Enumeration for session option for starting.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_session_option_for_starting_e {
  /// < This session will be mixed with others when starting (default)
  static const int SOUND_SESSION_OPTION_MIX_WITH_OTHERS_WHEN_START = 0;

  /// < This session will interrupt other sessions when starting
  static const int SOUND_SESSION_OPTION_PAUSE_OTHERS_WHEN_START = 1;
}

/// @deprecated Deprecated since 3.0. In sound_stream_focus_state_changed_cb, you can choose to stop playing or not.
/// @brief Enumeration for session option during play.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_session_option_for_during_play_e {
  /// < This session will be interrupted by other sessions during play (default)
  static const int SOUND_SESSION_OPTION_INTERRUPTIBLE_DURING_PLAY = 0;

  /// < This session will not be interrupted by other media sessions
  static const int SOUND_SESSION_OPTION_UNINTERRUPTIBLE_DURING_PLAY = 1;
}

/// @deprecated Deprecated since 3.0. In sound_stream_focus_state_changed_cb, you can choose to resume playing or not.
/// @brief Enumeration for session option for resumption.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_session_option_for_resumption_e {
  /// < This session will be resumed according to system policy (default)
  static const int SOUND_SESSION_OPTION_RESUMPTION_BY_SYSTEM = 0;

  /// < This session will be resumed according to system policy and when the media session which interrupted this session is paused
  static const int SOUND_SESSION_OPTION_RESUMPTION_BY_SYSTEM_OR_MEDIA_PAUSED =
      1;
}

/// @deprecated Deprecated since 3.0. Use sound_manager_apply_stream_routing() instead.
/// @brief Enumeration for voip session mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_session_voip_mode_e {
  /// < voip mode for ringtone
  static const int SOUND_SESSION_VOIP_MODE_RINGTONE = 0;

  /// < voip mode for during call with built-in receiver
  static const int SOUND_SESSION_VOIP_MODE_VOICE_WITH_BUILTIN_RECEIVER = 1;

  /// < voip mode for during call with built-in speaker
  static const int SOUND_SESSION_VOIP_MODE_VOICE_WITH_BUILTIN_SPEAKER = 2;

  /// < voip mode for during call with audio jack
  static const int SOUND_SESSION_VOIP_MODE_VOICE_WITH_AUDIO_JACK = 3;

  /// < voip mode for during call with bluetooth
  static const int SOUND_SESSION_VOIP_MODE_VOICE_WITH_BLUETOOTH = 4;
}

/// @deprecated Deprecated since 3.0. Use sound_stream_focus_state_changed_cb instead.
/// @brief Enumeration for sound session interrupted type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_session_interrupted_code_e {
  /// < Interrupt completed
  static const int SOUND_SESSION_INTERRUPTED_COMPLETED = 0;

  /// < Interrupted by media application
  static const int SOUND_SESSION_INTERRUPTED_BY_MEDIA = 1;

  /// < Interrupted by an incoming call
  static const int SOUND_SESSION_INTERRUPTED_BY_CALL = 2;

  /// < Interrupted by unplugging headphones
  static const int SOUND_SESSION_INTERRUPTED_BY_EARJACK_UNPLUG = 3;

  /// < Interrupted by a resource conflict
  static const int SOUND_SESSION_INTERRUPTED_BY_RESOURCE_CONFLICT = 4;

  /// < Interrupted by an alarm
  static const int SOUND_SESSION_INTERRUPTED_BY_ALARM = 5;

  /// < Interrupted by an emergency
  static const int SOUND_SESSION_INTERRUPTED_BY_EMERGENCY = 6;

  /// < Interrupted by a notification
  static const int SOUND_SESSION_INTERRUPTED_BY_NOTIFICATION = 7;
}

/// @brief Enumeration for sound device type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_device_type_e {
  /// < Built-in speaker
  static const int SOUND_DEVICE_BUILTIN_SPEAKER = 0;

  /// < Built-in receiver
  static const int SOUND_DEVICE_BUILTIN_RECEIVER = 1;

  /// < Built-in mic
  static const int SOUND_DEVICE_BUILTIN_MIC = 2;

  /// < Audio jack that can be connected to wired accessory such as headphone, headset, and so on
  static const int SOUND_DEVICE_AUDIO_JACK = 3;

  /// < Bluetooth (Deprecated since 3.0)
  static const int SOUND_DEVICE_BLUETOOTH = 4;

  /// < Bluetooth device representing media (A2DP) profile (Since 3.0)
  static const int SOUND_DEVICE_BLUETOOTH_MEDIA = 4;

  /// < HDMI
  static const int SOUND_DEVICE_HDMI = 5;

  /// < MIRRORING (Deprecated since 3.0)
  static const int SOUND_DEVICE_MIRRORING = 6;

  /// < Device for forwarding (Since 3.0)
  static const int SOUND_DEVICE_FORWARDING = 6;

  /// < USB Audio
  static const int SOUND_DEVICE_USB_AUDIO = 7;

  /// < Bluetooth device representing voice (SCO) profile (Since 3.0)
  static const int SOUND_DEVICE_BLUETOOTH_VOICE = 8;
}

/// @brief Enumeration for sound device direction.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_device_io_direction_e {
  /// < Input device
  static const int SOUND_DEVICE_IO_DIRECTION_IN = 0;

  /// < Output device
  static const int SOUND_DEVICE_IO_DIRECTION_OUT = 1;

  /// < Input/output device (both directions are available)
  static const int SOUND_DEVICE_IO_DIRECTION_BOTH = 2;
}

/// @deprecated Deprecated since 4.0.
/// @brief Enumeration for sound device state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_device_state_e {
  /// < Deactivated state
  static const int SOUND_DEVICE_STATE_DEACTIVATED = 0;

  /// < Activated state
  static const int SOUND_DEVICE_STATE_ACTIVATED = 1;
}

/// @brief Enumeration for sound device mask.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_device_mask_e {
  /// < Mask for input devices
  static const int SOUND_DEVICE_IO_DIRECTION_IN_MASK = 1;

  /// < Mask for output devices
  static const int SOUND_DEVICE_IO_DIRECTION_OUT_MASK = 2;

  /// < Mask for input/output devices (both directions are available)
  static const int SOUND_DEVICE_IO_DIRECTION_BOTH_MASK = 4;

  /// < Mask for built-in devices
  static const int SOUND_DEVICE_TYPE_INTERNAL_MASK = 16;

  /// < Mask for external devices
  static const int SOUND_DEVICE_TYPE_EXTERNAL_MASK = 32;

  /// < Mask for deactivated devices
  static const int SOUND_DEVICE_STATE_DEACTIVATED_MASK = 4096;

  /// < Mask for activated devices
  static const int SOUND_DEVICE_STATE_ACTIVATED_MASK = 8192;

  /// < Mask for all devices
  static const int SOUND_DEVICE_ALL_MASK = 65535;
}

/// @deprecated Deprecated since 3.0. Use sound_manager_add_device_state_changed_cb() instead.
/// @brief Enumeration for changed information of sound device.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sound_device_changed_info_e {
  /// < State of the device was changed
  static const int SOUND_DEVICE_CHANGED_INFO_STATE = 0;

  /// < IO direction of the device was changed
  static const int SOUND_DEVICE_CHANGED_INFO_IO_DIRECTION = 1;
}

/// @brief Called when the system volume has changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in]   type	The sound type of the changed volume
/// @param[in]   volume	The new volume value
/// @param[in]   user_data	The user data passed from the callback registration function
/// @pre sound_manager_set_volume() will invoke this callback if you register it using sound_manager_set_volume_changed_cb().
/// @see sound_manager_set_volume_changed_cb()
/// @see sound_manager_unset_volume_changed_cb()
typedef sound_manager_volume_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.UnsignedInt, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the state of focus that belongs to the stream_info is changed.
/// @since_tizen 3.0
///
/// @remarks	This function is issued in the internal thread of the sound manager.\n
/// Therefore it is recommended not to call UI update function in this function.
///
/// @param[in]   stream_info	The handle of stream information
/// @param[in]   focus_mask	The changed focus mask
/// @param[in]   focus_state	The changed focus state
/// @param[in]   reason		The reason for state change of the focus
/// @param[in]   sound_behavior	The requested sound behavior that should be followed, values of #sound_behavior_e combined with bitwise 'or'
/// @param[in]   extra_info	The extra information
/// @param[in]   user_data	The user data passed from the callback registration function
/// @pre You should register this callback using sound_manager_create_stream_information().
/// @see sound_manager_create_stream_information()
/// @see sound_manager_destroy_stream_information()
/// @see sound_manager_get_focus_state()
typedef sound_stream_focus_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(sound_stream_info_h, ffi.Int32, ffi.Int32, ffi.Int32,
            ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Sound stream information handle.
/// @since_tizen 3.0
typedef sound_stream_info_h = ffi.Pointer<sound_stream_info_s>;

/// @brief Sound device handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef sound_device_h = ffi.Pointer<ffi.Void>;

/// @brief Called when the focus state for each sound stream type is changed regardless of the process.
/// @since_tizen 3.0
///
/// @remarks	This function is invoked by the internal thread of the sound manager.\n
/// Therefore it is recommended not to call functions which update the UI from this callback.
///
/// @param[in]   id		The focus state change watch cb id
/// @param[in]   focus_mask	The changed focus mask
/// @param[in]   focus_state	The changed focus state
/// @param[in]   reason		The reason for state change of the focus
/// @param[in]   extra_info	The extra information
/// @param[in]   user_data	The user data passed from the callback registration function
/// @pre You should register this callback using sound_manager_add_focus_state_watch_cb().
/// @see sound_manager_add_focus_state_watch_cb()
/// @see sound_manager_remove_focus_state_watch_cb()
typedef sound_stream_focus_state_watch_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Int32, ffi.Int32, ffi.Int32,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 3.0. Use sound_stream_focus_state_changed_cb instead.
/// @brief Called when the playing sound session is interrupted.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in]   code	The interrupted code
/// @param[in]   user_data	The user data passed from the callback registration function
/// @pre You should register this callback using sound_manager_set_session_interrupted_cb().
/// @see sound_manager_set_session_interrupted_cb()
/// @see sound_manager_unset_session_interrupted_cb()
typedef sound_session_interrupted_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Sound device list handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef sound_device_list_h = ffi.Pointer<ffi.Void>;

/// @deprecated Deprecated since 3.0. Use sound_device_connection_changed_cb() instead.
/// @brief Called when the state of connection of a sound device was changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in]   sound_device_h	The sound_device
/// @param[in]   is_connected	The state of device connection: (@c true = connected, @c false = disconnected)
/// @param[in]   user_data	The user data passed from the callback registration function
/// @pre You should register this callback using sound_manager_set_device_connected_cb().
/// @see sound_manager_set_device_connected_cb()
/// @see sound_manager_unset_device_connected_cb()
typedef sound_device_connected_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(sound_device_h, ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the connection state of a sound device was changed.
/// @since_tizen 3.0
/// @param[in]   device	The sound_device
/// @param[in]   is_connected	The state of device connection: @c true = connected, @c false = disconnected
/// @param[in]   user_data	The user data passed from the callback registration function
/// @pre You should add this callback using sound_manager_add_device_connection_changed_cb().
/// @see sound_manager_add_device_connection_changed_cb()
/// @see sound_manager_remove_device_connection_changed_cb()
typedef sound_device_connection_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(sound_device_h, ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 3.0.
/// @brief Called when the information of a sound device was changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in]   sound_device_h	The sound_device
/// @param[in]   changed_info	The entry of sound device information
/// @param[in]   user_data	The user data passed from the callback registration function
/// @pre You should register this callback using sound_manager_set_device_information_changed_cb().
/// @see sound_manager_set_device_information_changed_cb()
/// @see sound_manager_unset_device_information_changed_cb()
typedef sound_device_information_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(sound_device_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 4.0.
/// @brief Called when the state of a sound device was changed.
/// @since_tizen 3.0
/// @param[in]   device	The sound_device
/// @param[in]   state	The state of the device
/// @param[in]   user_data	The user data passed from the callback registration function
/// @pre You should add this callback using sound_manager_add_device_state_changed_cb().
/// @see sound_manager_add_device_state_changed_cb()
/// @see sound_manager_remove_device_state_changed_cb()
typedef sound_device_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(sound_device_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

class audio_io_s extends ffi.Opaque {}

/// @brief Enumeration for audio sample type with bit depth.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class audio_sample_type_e {
  /// < Unsigned 8-bit audio samples
  static const int AUDIO_SAMPLE_TYPE_U8 = 112;

  /// < Signed 16-bit audio samples
  static const int AUDIO_SAMPLE_TYPE_S16_LE = 113;
}

/// @brief Enumeration for audio channel.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class audio_channel_e {
  /// < 1 channel, mono
  static const int AUDIO_CHANNEL_MONO = 128;

  /// < 2 channel, stereo
  static const int AUDIO_CHANNEL_STEREO = 129;
}

/// @brief Enumeration for audio input and output state.
/// @since_tizen 3.0
abstract class audio_io_state_e {
  /// < Audio-io handle is created, but not prepared
  static const int AUDIO_IO_STATE_IDLE = 0;

  /// < Audio-io handle is ready and the stream is running
  static const int AUDIO_IO_STATE_RUNNING = 1;

  /// < Audio-io handle is ready and the stream is paused
  static const int AUDIO_IO_STATE_PAUSED = 2;
}

/// @brief Enumeration for audio input and output error.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class audio_io_error_e {
  /// < Successful
  static const int AUDIO_IO_ERROR_NONE = 0;

  /// < Out of memory
  static const int AUDIO_IO_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int AUDIO_IO_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid operation
  static const int AUDIO_IO_ERROR_INVALID_OPERATION = -38;

  /// < Device open error by security
  static const int AUDIO_IO_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int AUDIO_IO_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Device policy restriction (Since 3.0)
  static const int AUDIO_IO_ERROR_DEVICE_POLICY_RESTRICTION = -1073741820;

  /// < Device open error
  static const int AUDIO_IO_ERROR_DEVICE_NOT_OPENED = -26214399;

  /// < Device close error
  static const int AUDIO_IO_ERROR_DEVICE_NOT_CLOSED = -26214398;

  /// < Invalid buffer pointer
  static const int AUDIO_IO_ERROR_INVALID_BUFFER = -26214397;

  /// < Sound policy error
  static const int AUDIO_IO_ERROR_SOUND_POLICY = -26214396;

  /// < Invalid state (Since 3.0)
  static const int AUDIO_IO_ERROR_INVALID_STATE = -26214395;

  /// < Not supported stream type (Since 3.0)
  static const int AUDIO_IO_ERROR_NOT_SUPPORTED_TYPE = -26214394;
}

/// @deprecated Deprecated since 3.0
/// @brief Enumeration for audio IO interrupted messages.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class audio_io_interrupted_code_e {
  /// < Interrupt completed
  static const int AUDIO_IO_INTERRUPTED_COMPLETED = 0;

  /// < Interrupted by a media application
  static const int AUDIO_IO_INTERRUPTED_BY_MEDIA = 1;

  /// < Interrupted by an incoming call
  static const int AUDIO_IO_INTERRUPTED_BY_CALL = 2;

  /// < Interrupted by unplugging headphones
  static const int AUDIO_IO_INTERRUPTED_BY_EARJACK_UNPLUG = 3;

  /// < Interrupted by a resource conflict
  static const int AUDIO_IO_INTERRUPTED_BY_RESOURCE_CONFLICT = 4;

  /// < Interrupted by an alarm
  static const int AUDIO_IO_INTERRUPTED_BY_ALARM = 5;

  /// < Interrupted by an emergency
  static const int AUDIO_IO_INTERRUPTED_BY_EMERGENCY = 6;

  /// < Interrupted by a notification
  static const int AUDIO_IO_INTERRUPTED_BY_NOTIFICATION = 7;
}

/// @brief The audio input handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef audio_in_h = ffi.Pointer<audio_io_s>;

/// @deprecated Deprecated since 3.0. Use sound_stream_focus_state_changed_cb instead.
/// @brief Called when audio input or output is interrupted.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] error_code The interrupted error code
/// @param[in] user_data The user data passed from the callback registration function
///
/// @see audio_in_set_interrupted_cb()
/// @see audio_out_set_interrupted_cb()
/// @see audio_in_unset_interrupted_cb()
/// @see audio_out_unset_interrupted_cb()
typedef audio_io_interrupted_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when audio input data is available in asynchronous(event) mode.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks @a use audio_in_peek() to get audio in data inside callback, use audio_in_drop() after use of peeked data.
///
/// @param[in] handle The handle to the audio input
/// @param[in] nbytes The amount of available audio in data which can be peeked.
/// @param[in] user_data The user data passed from the callback registration function
///
/// @see audio_in_set_stream_cb()
typedef audio_in_stream_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(audio_in_h, ffi.Size, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the state of audio input is changed.
///
/// @since_tizen 3.0
///
/// @param[in] handle The handle of the audio input
/// @param[in] previous The previous state of the audio input
/// @param[in] current The current state of the audio input
/// @param[in] by_policy @c true if the state is changed by policy, otherwise @c false if the state is not changed by policy
/// @param[in] user_data The user data passed from the callback registration function
///
/// @see audio_in_set_state_changed_cb()
/// @see audio_in_unset_state_changed_cb()
typedef audio_in_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(audio_in_h, ffi.Int32, ffi.Int32, ffi.Bool,
            ffi.Pointer<ffi.Void>)>>;

/// @brief The audio output handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef audio_out_h = ffi.Pointer<audio_io_s>;

/// @brief Called when audio out data can be written in asynchronous(event) mode.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks @a use audio_out_write() to write pcm data inside this callback.
/// @param[in] handle The handle to the audio output
/// @param[in] nbytes The amount of audio in data which can be written.
/// @param[in] user_data The user data passed from the callback registration function
///
/// @see audio_out_set_stream_cb()
typedef audio_out_stream_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(audio_out_h, ffi.Size, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the state of audio output is changed.
///
/// @since_tizen 3.0
///
/// @param[in] handle The handle of the audio output
/// @param[in] previous The previous state of the audio output
/// @param[in] current The current state of the audio output
/// @param[in] by_policy @c true if the state is changed by policy, otherwise @c false if the state is not changed by policy
/// @param[in] user_data The user data passed from the callback registration function
///
/// @see audio_out_set_state_changed_cb()
/// @see audio_out_unset_state_changed_cb()
typedef audio_out_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(audio_out_h, ffi.Int32, ffi.Int32, ffi.Bool,
            ffi.Pointer<ffi.Void>)>>;

class media_format_s extends ffi.Opaque {}

/// @brief Enumerations of  media format error.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_format_error_e {
  /// < Successful
  static const int MEDIA_FORMAT_ERROR_NONE = 0;

  /// < Out of memory
  static const int MEDIA_FORMAT_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int MEDIA_FORMAT_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid operation
  static const int MEDIA_FORMAT_ERROR_INVALID_OPERATION = -38;

  /// < No space left on device
  static const int MEDIA_FORMAT_ERROR_FILE_NO_SPACE_ON_DEVICE = -28;
}

/// @brief Enumeration for media format type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_format_type_e {
  /// < media format type is NONE
  static const int MEDIA_FORMAT_NONE = 0;

  /// < media format type is AUDIO
  static const int MEDIA_FORMAT_AUDIO = 16777216;

  /// < media format type is VIDEO
  static const int MEDIA_FORMAT_VIDEO = 33554432;

  /// < media format type is TEXT
  static const int MEDIA_FORMAT_TEXT = 50331648;

  /// < media format type is CONTAINER
  static const int MEDIA_FORMAT_CONTAINER = 67108864;

  /// < media format type is UNKNOWN
  static const int MEDIA_FORMAT_UNKNOWN = 134217728;
}

/// @brief Enumeration for media format data type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_format_data_type_e {
  /// < media format data type is encoded type
  static const int MEDIA_FORMAT_ENCODED = 268435456;

  /// < media format data type is raw type
  static const int MEDIA_FORMAT_RAW = 536870912;
}

/// @brief Enumeration for media format MIME type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_format_mimetype_e {
  /// < media format mime type is L16, AUDIO
  static const int MEDIA_FORMAT_L16 = 285216784;

  /// < media format mime type is ALAW, AUDIO
  static const int MEDIA_FORMAT_ALAW = 285216800;

  /// < media format mime type is ULAW,  AUDIO
  static const int MEDIA_FORMAT_ULAW = 285216816;

  /// < media format mime type is AMR,  AUDIO,  indicates MEDIA_FORMAT_AMR_NB (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_AMR = 285216832;

  /// < media format mime type is AMR_NB,  AUDIO , (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_AMR_NB = 285216832;

  /// < media format mime type is AMR_WB,  AUDIO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_AMR_WB = 285216833;

  /// < media format mime type is G729,  AUDIO
  static const int MEDIA_FORMAT_G729 = 285216848;

  /// < media format mime type is AAC,  AUDIO, indicates MEDIA_FORMAT_AAC_LC (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_AAC = 285216864;

  /// < media format mime type is AAC_LC,  AUDIO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_AAC_LC = 285216864;

  /// < media format mime type is AAC_HE,  AUDIO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_AAC_HE = 285216865;

  /// < media format mime type is AAC_HE_PS,  AUDIO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_AAC_HE_PS = 285216866;

  /// < media format mime type is MP3,  AUDIO
  static const int MEDIA_FORMAT_MP3 = 285216880;

  /// < media format mime type is MP23, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_MP2 = 285216881;

  /// < media format mime type is VORBIS,  AUDIO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_VORBIS = 285216896;

  /// < media format mime type is FLAC,  AUDIO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_FLAC = 285216912;

  /// < media format mime type is WMAV1,  AUDIO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_WMAV1 = 285216928;

  /// < media format mime type is WMAV2,  AUDIO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_WMAV2 = 285216929;

  /// < media format mime type is WMAVPRO,  AUDIO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_WMAPRO = 285216930;

  /// < media format mime type is WMAVLSL,  AUDIO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_WMALSL = 285216931;

  /// < media format mime type is AC3, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_AC3 = 285216945;

  /// < media format mime type is EAC3, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_EAC3 = 285216946;

  /// < media format mime type is DTS, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_DTS = 285216961;

  /// < media format mime type is OPUS, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_OPUS = 285216977;

  /// < media format mime type is PCM, AUDIO, indicates MEDIA_FORMAT_PCM_S16LE (Since 3.0)
  static const int MEDIA_FORMAT_PCM = 553653520;

  /// < media format mime type is PCM signed 16-bit little-endian, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_PCM_S16LE = 553653520;

  /// < media format mime type is PCM signed 24-bit little-endian, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_PCM_S24LE = 553653521;

  /// < media format mime type is PCM signed 32-bit little-endian, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_PCM_S32LE = 553653522;

  /// < media format mime type is PCM signed 16-bit big-endian, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_PCM_S16BE = 553653523;

  /// < media format mime type is PCM signed 24-bit big-endian, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_PCM_S24BE = 553653524;

  /// < media format mime type is PCM signed 32-bit big-endian, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_PCM_S32BE = 553653525;

  /// < media format mime type is PCM 32-bit floating point little-endian, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_PCM_F32LE = 553653526;

  /// < media format mime type is PCM 32-bit floating point big-endian, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_PCM_F32BE = 553653527;

  /// < media format mime type is PCM unsigned 16-bit little-endian, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_PCM_U16LE = 553653528;

  /// < media format mime type is PCM unsigned 24-bit little-endian, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_PCM_U24LE = 553653529;

  /// < media format mime type is PCM unsigned 32-bit little-endian, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_PCM_U32LE = 553653530;

  /// < media format mime type is PCM unsigned 16-bit big-endian, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_PCM_U16BE = 553653531;

  /// < media format mime type is PCM unsigned 24-bit big-endian, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_PCM_U24BE = 553653532;

  /// < media format mime type is PCM unsigned 32-bit big-endian, AUDIO, (Since 4.0)
  static const int MEDIA_FORMAT_PCM_U32BE = 553653533;

  /// < media format mime type is PCM A-law, AUDIO
  static const int MEDIA_FORMAT_PCMA = 553653536;

  /// < media format mime type is PCM U-law, AUDIO
  static const int MEDIA_FORMAT_PCMU = 553653552;

  /// < media format mime type is H261, VIDEO
  static const int MEDIA_FORMAT_H261 = 301998096;

  /// < media format mime type is H263, VIDEO
  static const int MEDIA_FORMAT_H263 = 301998112;

  /// < media format mime type is H263P, VIDEO
  static const int MEDIA_FORMAT_H263P = 301998113;

  /// < media format mime type is H263 Baseline Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_H263_BLP = 301998114;

  /// < media format mime type is H263 H.320 Coding Efficiency Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_H263_H320_CEP = 301998115;

  /// < media format mime type is H263 Backward-Compatibility Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_H263_BCP = 301998116;

  /// < media format mime type is H263 Interactive and Streaming Wireless Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_H263_ISW2P = 301998117;

  /// < media format mime type is H263 Interactive and Streaming Wireless Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_H263_ISW3P = 301998118;

  /// < media format mime type is H263 Conversation High Compression Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_H263_CHCP = 301998119;

  /// < media format mime type is H263 Conversational Internet Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_H263_C_INTERNETP = 301998120;

  /// < media format mime type is H263 Conversational Interlace Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_H263_C_INTERLACEP = 301998121;

  /// < media format mime type is H263 High Latency Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_H263_HLP = 301998122;

  /// < media format mime type is H264 baseline profile, VIDEO
  static const int MEDIA_FORMAT_H264_SP = 301998128;

  /// < media format mime type is H264 main profile, VIDEO
  static const int MEDIA_FORMAT_H264_MP = 301998129;

  /// < media format mime type is H264 high profile, VIDEO
  static const int MEDIA_FORMAT_H264_HP = 301998130;

  /// < media format mime type is H264 Extended Profile, VIDEO (Since 3.0)
  static const int MEDIA_FORMAT_H264_EXTP = 301998131;

  /// < media format mime type is H264 High10 Profile, VIDEO (Since 3.0)
  static const int MEDIA_FORMAT_H264_H10P = 301998132;

  /// < media format mime type is H264 High422 Profile, VIDEO (Since 3.0)
  static const int MEDIA_FORMAT_H264_H422P = 301998133;

  /// < media format mime type is H264 High444 Profile, VIDEO (Since 3.0)
  static const int MEDIA_FORMAT_H264_H444P = 301998134;

  /// < media format mime type is H264 CAVLC444 Profile, VIDEO (Since 3.0)
  static const int MEDIA_FORMAT_H264_C444P = 301998135;

  /// < media format mime type is MJPEG, VIDEO
  static const int MEDIA_FORMAT_MJPEG = 301998144;

  /// < media format mime type is MPEG1, VIDEO
  static const int MEDIA_FORMAT_MPEG1 = 301998160;

  /// < media format mime type is MPEG2 simple profile, VIDEO
  static const int MEDIA_FORMAT_MPEG2_SP = 301998176;

  /// < media format mime type is MPEG2 main profile, VIDEO
  static const int MEDIA_FORMAT_MPEG2_MP = 301998177;

  /// < media format mime type is MPEG2 high profile, VIDEO
  static const int MEDIA_FORMAT_MPEG2_HP = 301998178;

  /// < media format mime type is MPEG4 simple profile, VIDEO
  static const int MEDIA_FORMAT_MPEG4_SP = 301998192;

  /// < media format mime type is MPEG4 advanced simple profile, VIDEO
  static const int MEDIA_FORMAT_MPEG4_ASP = 301998193;

  /// < media format mime type is HEVC, VIDEO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_HEVC = 301998208;

  /// < media format mime type is HEVC Main Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_HEVC_MP = 301998209;

  /// < media format mime type is HEVC Main10 Profile, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_HEVC_M10P = 301998210;

  /// < media format mime type is VP8, VIDEO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_VP8 = 301998224;

  /// < media format mime type is VP9, VIDEO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_VP9 = 301998240;

  /// < media format mime type is VC1, VIDEO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_VC1 = 301998256;

  /// < media format mime type is DIVX4, VIDEO, (Since 4.0)
  static const int MEDIA_FORMAT_DIVX4 = 301998276;

  /// < media format mime type is DIVX5, VIDEO, (Since 4.0)
  static const int MEDIA_FORMAT_DIVX5 = 301998277;

  /// < media format mime type is XVID, VIDEO, (Since 4.0)
  static const int MEDIA_FORMAT_XVID = 301998288;

  /// < media format mime type is I420, VIDEO
  static const int MEDIA_FORMAT_I420 = 570434832;

  /// < media format mime type is NV12, VIDEO
  static const int MEDIA_FORMAT_NV12 = 570434848;

  /// < media format mime type is NV12T, VIDEO
  static const int MEDIA_FORMAT_NV12T = 570434864;

  /// < media format mime type is YV12, VIDEO
  static const int MEDIA_FORMAT_YV12 = 570434880;

  /// < media format mime type is NV21, VIDEO
  static const int MEDIA_FORMAT_NV21 = 570434896;

  /// < media format mime type is NV16, VIDEO
  static const int MEDIA_FORMAT_NV16 = 570434912;

  /// < media format mime type is YUYV, VIDEO
  static const int MEDIA_FORMAT_YUYV = 570434928;

  /// < media format mime type is UYVY, VIDEO
  static const int MEDIA_FORMAT_UYVY = 570434944;

  /// < media format mime type is 422P, VIDEO
  static const int MEDIA_FORMAT_422P = 570434960;

  /// < media format mime type is RGB565, VIDEO
  static const int MEDIA_FORMAT_RGB565 = 570434976;

  /// < media format mime type is RGB888, VIDEO
  static const int MEDIA_FORMAT_RGB888 = 570434992;

  /// < media format mime type is RGBA, VIDEO
  static const int MEDIA_FORMAT_RGBA = 570435008;

  /// < media format mime type is ARGB, VIDEO
  static const int MEDIA_FORMAT_ARGB = 570435024;

  /// < media format mime type is BGRA, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_BGRA = 570435040;

  /// < media format mime type is MP4 container, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_MP4 = 67121168;

  /// < media format mime type is AVI container, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_AVI = 67121184;

  /// < media format mime type is MPEG2TS container, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_MPEG2TS = 67121200;

  /// < media format mime type is MPEG2PS container, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_MPEG2PS = 67121216;

  /// < media format mime type is MATROSKA container, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_MATROSKA = 67121232;

  /// < media format mime type is WEBM container, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_WEBM = 67121248;

  /// < media format mime type is 3GP container, VIDEO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_3GP = 67121264;

  /// < media format mime type is WAV container, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_WAV = 67125264;

  /// < media format mime type is OGG container, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_OGG = 67125280;

  /// < media format mime type is AAC_ADTS container, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_AAC_ADTS = 67125296;

  /// < media format mime type is AAC_ADIF container, AUDIO, (Since 3.0)
  static const int MEDIA_FORMAT_CONTAINER_AAC_ADIF = 67125297;

  /// < media format mime type is HW dependent, VIDEO, (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIA_FORMAT_NATIVE_VIDEO = 570454016;

  /// < media format mime type is MP4, TEXT, (Since 3.0)
  static const int MEDIA_FORMAT_TEXT_MP4 = 318799888;

  /// < media format mime type is 3GP, TEXT, (Since 3.0)
  static const int MEDIA_FORMAT_TEXT_3GP = 318799904;

  /// < media format mime type is MEDIA_FORMAT_MAX, Do not use
  static const int MEDIA_FORMAT_MAX = 318799905;
}

/// @brief Enumeration for media color model.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_format_color_model_e {
  /// < media format color model is NONE
  static const int MEDIA_COLOR_MODEL_NONE = 0;

  /// < media format color model is RGB
  static const int MEDIA_COLOR_MODEL_RGB = 1;

  /// < media format color model is YUV
  static const int MEDIA_COLOR_MODEL_YUV = 2;
}

/// @brief Enumeration for media format aac header type.
/// @since_tizen 3.0
abstract class media_format_aac_header_type_e {
  /// < media format aac header type is RAW, no header
  static const int MEDIA_FORMAT_AAC_HEADER_NONE = 0;

  /// < media format aac header type is ADTS header
  static const int MEDIA_FORMAT_AAC_HEADER_ADTS = 1;

  /// < media format aac header type is ADIF header
  static const int MEDIA_FORMAT_AAC_HEADER_ADIF = 2;

  /// < media format aac header type is UNKNOWN
  static const int MEDIA_FORMAT_AAC_HEADER_UNKNOWN = 3;
}

/// @brief Enumeration for media format text type.
/// @since_tizen 3.0
abstract class media_format_text_type_e {
  /// < media format text type is none
  static const int MEDIA_FORMAT_TEXT_TYPE_NONE = 0;

  /// < media format text type is MPEG-4 Timed Text
  static const int MEDIA_FORMAT_TEXT_TYPE_TIMED_TEXT_MP4 = 1;

  /// < media format text type is 3GPP Timed Text
  static const int MEDIA_FORMAT_TEXT_TYPE_TIMED_TEXT_3GPP = 2;

  /// < media format text type is unknown
  static const int MEDIA_FORMAT_TEXT_TYPE_UNKNOWN = 3;
}

/// @brief Media Format handle type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef media_format_h = ffi.Pointer<media_format_s>;

/// @brief Enumeration for tbm_surface error type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class tbm_surface_error_e {
  /// < Successful
  static const int TBM_SURFACE_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int TBM_SURFACE_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid Operation
  static const int TBM_SURFACE_ERROR_INVALID_OPERATION = -38;
}

/// @brief Definition for the TBM plane struct.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
class _tbm_surface_plane extends ffi.Struct {
  /// < Plane pointer
  external ffi.Pointer<ffi.UnsignedChar> ptr;

  /// < Plane size
  @ffi.Uint32()
  external int size;

  /// < Plane offset
  @ffi.Uint32()
  external int offset;

  /// < Plane stride
  @ffi.Uint32()
  external int stride;

  /// < Reserved pointer1
  external ffi.Pointer<ffi.Void> reserved1;

  /// < Reserved pointer2
  external ffi.Pointer<ffi.Void> reserved2;

  /// < Reserved pointer3
  external ffi.Pointer<ffi.Void> reserved3;
}

/// @brief Definition for the TBM surface information struct.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
class _tbm_surface_info extends ffi.Struct {
  /// < TBM surface width
  @ffi.Uint32()
  external int width;

  /// < TBM surface height
  @ffi.Uint32()
  external int height;

  /// < TBM surface format
  @tbm_format()
  external int format;

  /// < TBM surface bbp
  @ffi.Uint32()
  external int bpp;

  /// < TBM surface size
  @ffi.Uint32()
  external int size;

  /// < The number of planes
  @ffi.Uint32()
  external int num_planes;

  @ffi.Array.multi([4])
  external ffi.Array<tbm_surface_plane_s> planes;

  /// < Reserved pointer4
  external ffi.Pointer<ffi.Void> reserved4;

  /// < Reserved pointer5
  external ffi.Pointer<ffi.Void> reserved5;

  /// < Reserved pointer6
  external ffi.Pointer<ffi.Void> reserved6;
}

/// @brief Definition for the Tizen buffer surface format.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef tbm_format = ffi.Uint32;

/// @brief Definition for the TBM plane struct.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef tbm_surface_plane_s = _tbm_surface_plane;

/// @brief Definition for the Tizen buffer surface.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef tbm_surface_h = ffi.Pointer<_tbm_surface>;

class _tbm_surface extends ffi.Opaque {}

/// @brief Definition for the TBM surface information struct.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef tbm_surface_info_s = _tbm_surface_info;

class media_packet_s extends ffi.Opaque {}

/// @brief Enumeration for media packet error.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_packet_error_e {
  /// < Successful
  static const int MEDIA_PACKET_ERROR_NONE = 0;

  /// < Out of memory
  static const int MEDIA_PACKET_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int MEDIA_PACKET_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid operation
  static const int MEDIA_PACKET_ERROR_INVALID_OPERATION = -38;

  /// < No space left on device
  static const int MEDIA_PACKET_ERROR_FILE_NO_SPACE_ON_DEVICE = -28;

  /// < No Available packet, (Since 3.0)
  static const int MEDIA_PACKET_ERROR_NO_AVAILABLE_PACKET = -27394047;
}

/// @brief Enumeration for media buffer flag.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_buffer_flags_e {
  /// < The buffer marked as such contains codec initialization/codec specific data instead of media data
  static const int MEDIA_PACKET_CODEC_CONFIG = 1;

  /// < The end of stream
  static const int MEDIA_PACKET_END_OF_STREAM = 2;

  /// < The buffer marked as such contains the data for a sync frame
  static const int MEDIA_PACKET_SYNC_FRAME = 4;
}

/// @brief Enumeration for the return values of media packet finalize call back functions.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see media_packet_finalize_cb()
abstract class finalize_cb_ret {
  /// < Packet handle is not destroyed
  static const int MEDIA_PACKET_REUSE = 0;

  /// < Destroy packet handle
  static const int MEDIA_PACKET_FINALIZE = 1;
}

/// @brief   Called when the media packet is destroyed.
/// @details It will be invoked when media_packet_destroy() is called.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @param[in] packet        The media packet handle
/// @param[in] error_code    The error code of #media_packet_error_e
/// @param[in] user_data  The user data passed from the callback registration function
///
/// @pre It will be invoked when media packet is destroyed.
///
/// @retval #MEDIA_PACKET_REUSE     Packet handle is not destroyed, the handle will be reused.
/// @retval #MEDIA_PACKET_FINALIZE  Destroy media packet handle, the handle will not be reused.
///
/// @see media_packet_destroy()
/// @see media_packet_create_alloc()
/// @see media_packet_create()
/// @see media_packet_copy()
/// @see media_packet_create_from_tbm_surface()
typedef media_packet_finalize_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(media_packet_h, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief  The Media Packet handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef media_packet_h = ffi.Pointer<media_packet_s>;

/// @brief Enumeration for the error codes of Camera.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_error_e {
  /// < Successful
  static const int CAMERA_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int CAMERA_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid state
  static const int CAMERA_ERROR_INVALID_STATE = -26279934;

  /// < Out of memory
  static const int CAMERA_ERROR_OUT_OF_MEMORY = -12;

  /// < Device error
  static const int CAMERA_ERROR_DEVICE = -26279932;

  /// < Internal error
  static const int CAMERA_ERROR_INVALID_OPERATION = -38;

  /// < Blocked by Audio Session Manager (Deprecated since 3.0)
  static const int CAMERA_ERROR_SOUND_POLICY = -26279930;

  /// < Restricted by security system policy
  static const int CAMERA_ERROR_SECURITY_RESTRICTED = -26279929;

  /// < The device is using another application or working on some operation
  static const int CAMERA_ERROR_DEVICE_BUSY = -26279928;

  /// < No camera device
  static const int CAMERA_ERROR_DEVICE_NOT_FOUND = -26279927;

  /// < Blocked by Audio Session Manager - CALL (Deprecated since 3.0)
  static const int CAMERA_ERROR_SOUND_POLICY_BY_CALL = -26279926;

  /// < Blocked by Audio Session Manager - ALARM (Deprecated since 3.0)
  static const int CAMERA_ERROR_SOUND_POLICY_BY_ALARM = -26279925;

  /// < ESD situation
  static const int CAMERA_ERROR_ESD = -26279924;

  /// < The access to the resources can not be granted
  static const int CAMERA_ERROR_PERMISSION_DENIED = -13;

  /// < The feature is not supported
  static const int CAMERA_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Blocked by resource conflict (Since 3.0)
  static const int CAMERA_ERROR_RESOURCE_CONFLICT = -26279923;

  /// < Socket connection lost (Since 3.0)
  static const int CAMERA_ERROR_SERVICE_DISCONNECTED = -26279922;
}

/// @brief Enumeration for the camera state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_state_e {
  /// < Before creating
  static const int CAMERA_STATE_NONE = 0;

  /// < Created, but not initialized yet
  static const int CAMERA_STATE_CREATED = 1;

  /// < Preview
  static const int CAMERA_STATE_PREVIEW = 2;

  /// < While capturing
  static const int CAMERA_STATE_CAPTURING = 3;

  /// < After capturing
  static const int CAMERA_STATE_CAPTURED = 4;
}

/// @brief Enumeration for the camera device state.
/// @since_tizen 3.0
abstract class camera_device_state_e {
  /// < Not opened
  static const int CAMERA_DEVICE_STATE_NULL = 0;

  /// < Opened
  static const int CAMERA_DEVICE_STATE_OPENED = 1;

  /// < Now previewing or capturing or is being used for video recording
  static const int CAMERA_DEVICE_STATE_WORKING = 2;
}

/// @brief Enumeration for the camera device.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_device_e {
  /// < Primary camera
  static const int CAMERA_DEVICE_CAMERA0 = 0;

  /// < Secondary camera
  static const int CAMERA_DEVICE_CAMERA1 = 1;
}

/// @brief Enumeration for the camera pixel format.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_pixel_format_e {
  /// < Invalid pixel format
  static const int CAMERA_PIXEL_FORMAT_INVALID = -1;

  /// < NV12 pixel format
  static const int CAMERA_PIXEL_FORMAT_NV12 = 0;

  /// < NV12 Tiled pixel format
  static const int CAMERA_PIXEL_FORMAT_NV12T = 1;

  /// < NV16 pixel format
  static const int CAMERA_PIXEL_FORMAT_NV16 = 2;

  /// < NV21 pixel format
  static const int CAMERA_PIXEL_FORMAT_NV21 = 3;

  /// < YUYV(YUY2) pixel format
  static const int CAMERA_PIXEL_FORMAT_YUYV = 4;

  /// < UYVY pixel format
  static const int CAMERA_PIXEL_FORMAT_UYVY = 5;

  /// < YUV422(Y:U:V) planar pixel format
  static const int CAMERA_PIXEL_FORMAT_422P = 6;

  /// < I420 pixel format
  static const int CAMERA_PIXEL_FORMAT_I420 = 7;

  /// < YV12 pixel format
  static const int CAMERA_PIXEL_FORMAT_YV12 = 8;

  /// < RGB565 pixel format
  static const int CAMERA_PIXEL_FORMAT_RGB565 = 9;

  /// < RGB888 pixel format
  static const int CAMERA_PIXEL_FORMAT_RGB888 = 10;

  /// < RGBA pixel format
  static const int CAMERA_PIXEL_FORMAT_RGBA = 11;

  /// < ARGB pixel format
  static const int CAMERA_PIXEL_FORMAT_ARGB = 12;

  /// < Encoded pixel format
  static const int CAMERA_PIXEL_FORMAT_JPEG = 13;

  /// < Encoded pixel format : H264 (Since 3.0)
  static const int CAMERA_PIXEL_FORMAT_H264 = 15;
}

/// @brief Enumeration for the camera display type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_display_type_e {
  /// < Overlay surface display
  static const int CAMERA_DISPLAY_TYPE_OVERLAY = 0;

  /// < Evas object surface display
  static const int CAMERA_DISPLAY_TYPE_EVAS = 1;

  /// < This disposes off buffers
  static const int CAMERA_DISPLAY_TYPE_NONE = 2;
}

/// @brief Enumeration for the camera policy.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_policy_e {
  /// < None
  static const int CAMERA_POLICY_NONE = 0;

  /// < Sound policy (Deprecated since 3.0)
  static const int CAMERA_POLICY_SOUND = 1;

  /// < Sound policy by CALL (Deprecated since 3.0)
  static const int CAMERA_POLICY_SOUND_BY_CALL = 2;

  /// < Sound policy by ALARM (Deprecated since 3.0)
  static const int CAMERA_POLICY_SOUND_BY_ALARM = 3;

  /// < Security policy
  static const int CAMERA_POLICY_SECURITY = 4;

  /// < Resource conflict (Since 3.0)
  static const int CAMERA_POLICY_RESOURCE_CONFLICT = 5;
}

/// @brief Enumeration for the camera rotation type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_rotation_e {
  /// < No rotation
  static const int CAMERA_ROTATION_NONE = 0;

  /// < 90 degree rotation
  static const int CAMERA_ROTATION_90 = 1;

  /// < 180 degree rotation
  static const int CAMERA_ROTATION_180 = 2;

  /// < 270 degree rotation
  static const int CAMERA_ROTATION_270 = 3;
}

/// @brief Enumeration for the camera flip type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_flip_e {
  /// < No Flip
  static const int CAMERA_FLIP_NONE = 0;

  /// < Horizontal flip
  static const int CAMERA_FLIP_HORIZONTAL = 1;

  /// < Vertical flip
  static const int CAMERA_FLIP_VERTICAL = 2;
  static const int CAMERA_FLIP_BOTH = 3;
}

/// @brief Enumeration for the camera focus state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_focus_state_e {
  /// < Focus released
  static const int CAMERA_FOCUS_STATE_RELEASED = 0;

  /// < Focus in progress
  static const int CAMERA_FOCUS_STATE_ONGOING = 1;

  /// < Focus succeeded
  static const int CAMERA_FOCUS_STATE_FOCUSED = 2;

  /// < Focus failed
  static const int CAMERA_FOCUS_STATE_FAILED = 3;
}

/// @brief Enumeration for the facing direction of camera module
/// @since_tizen 3.0
abstract class camera_facing_direction_e {
  /// < Rear
  static const int CAMERA_FACING_DIRECTION_REAR = 0;

  /// < Front
  static const int CAMERA_FACING_DIRECTION_FRONT = 1;
}

/// @brief Enumeration for the current flash state.
/// @since_tizen 3.0
abstract class camera_flash_state_e {
  /// < Flash is not used now through camera API
  static const int CAMERA_FLASH_STATE_NOT_USED = 0;

  /// < Flash is used now through camera API
  static const int CAMERA_FLASH_STATE_USED = 1;
}

/// @brief The structure type of the image data.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
class camera_image_data_s extends ffi.Struct {
  /// < The image buffer
  external ffi.Pointer<ffi.UnsignedChar> data;

  /// < The size of the buffer
  @ffi.UnsignedInt()
  external int size;

  /// < The width of the image
  @ffi.Int()
  external int width;

  /// < The height of the image
  @ffi.Int()
  external int height;

  /// < The format of the image pixel
  @ffi.Int32()
  external int format;

  /// < The exif raw data
  external ffi.Pointer<ffi.UnsignedChar> exif;

  /// < The size of the exif data
  @ffi.UnsignedInt()
  external int exif_size;
}

/// @brief The structure type for face detection.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
class camera_detected_face_s extends ffi.Struct {
  /// < The ID of each face
  @ffi.Int()
  external int id;

  /// < The confidence level for the detection of the face
  @ffi.Int()
  external int score;

  /// < The x coordinates of the face
  @ffi.Int()
  external int x;

  /// < The y coordinates of the face
  @ffi.Int()
  external int y;

  /// < The width of the face
  @ffi.Int()
  external int width;

  /// < The height of the face
  @ffi.Int()
  external int height;
}

/// @brief The structure type to preview stream data.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
class camera_preview_data_s extends ffi.Struct {
  /// < The format of the frame pixel
  @ffi.Int32()
  external int format;

  /// < The width of the frame
  @ffi.Int()
  external int width;

  /// < The height of the frame
  @ffi.Int()
  external int height;

  /// < The number of planes
  @ffi.Int()
  external int num_of_planes;

  /// < The timestamp of the frame
  @ffi.UnsignedInt()
  external int timestamp;

  external UnnamedUnion1 data;
}

class UnnamedUnion1 extends ffi.Union {
  /// < single plane frame data
  external UnnamedStruct1 single_plane;

  /// < double plane frame data
  external UnnamedStruct2 double_plane;

  /// < triple plane frame data
  external UnnamedStruct3 triple_plane;

  external UnnamedStruct4 encoded_plane;
}

class UnnamedStruct1 extends ffi.Struct {
  /// < The yuv data pointer
  external ffi.Pointer<ffi.UnsignedChar> yuv;

  /// < The size of data
  @ffi.UnsignedInt()
  external int size;
}

class UnnamedStruct2 extends ffi.Struct {
  /// < The y data pointer
  external ffi.Pointer<ffi.UnsignedChar> y;

  /// < The uv data pointer
  external ffi.Pointer<ffi.UnsignedChar> uv;

  /// < The size of y data
  @ffi.UnsignedInt()
  external int y_size;

  /// < The size of uv data
  @ffi.UnsignedInt()
  external int uv_size;
}

class UnnamedStruct3 extends ffi.Struct {
  /// < The y data pointer
  external ffi.Pointer<ffi.UnsignedChar> y;

  /// < The u data pointer
  external ffi.Pointer<ffi.UnsignedChar> u;

  /// < The v data pointer
  external ffi.Pointer<ffi.UnsignedChar> v;

  /// < The size of y data
  @ffi.UnsignedInt()
  external int y_size;

  /// < The size of u data
  @ffi.UnsignedInt()
  external int u_size;

  /// < The size of v data
  @ffi.UnsignedInt()
  external int v_size;
}

class UnnamedStruct4 extends ffi.Struct {
  /// < The encoded data pointer
  external ffi.Pointer<ffi.UnsignedChar> data;

  /// < The size of encoded data
  @ffi.UnsignedInt()
  external int size;
}

class camera_cli_s extends ffi.Opaque {}

/// @brief Enumeration for the camera display mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_display_mode_e {
  /// < Letter box
  static const int CAMERA_DISPLAY_MODE_LETTER_BOX = 0;

  /// < Origin size
  static const int CAMERA_DISPLAY_MODE_ORIGIN_SIZE = 1;

  /// < Full screen
  static const int CAMERA_DISPLAY_MODE_FULL = 2;

  /// < Cropped full screen
  static const int CAMERA_DISPLAY_MODE_CROPPED_FULL = 3;

  /// < Original size or letter box (Since 3.0)
  static const int CAMERA_DISPLAY_MODE_ORIGIN_OR_LETTER_BOX = 4;

  /// < Custom ROI (Since 3.0)
  static const int CAMERA_DISPLAY_MODE_CUSTOM_ROI = 5;
}

/// @brief Enumeration for the color tone, which provides the impression of looking through a tinted glass.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_effect_mode_e {
  /// < None
  static const int CAMERA_ATTR_EFFECT_NONE = 0;

  /// < Mono
  static const int CAMERA_ATTR_EFFECT_MONO = 1;

  /// < Sepia
  static const int CAMERA_ATTR_EFFECT_SEPIA = 2;

  /// < Negative
  static const int CAMERA_ATTR_EFFECT_NEGATIVE = 3;

  /// < Blue
  static const int CAMERA_ATTR_EFFECT_BLUE = 4;

  /// < Green
  static const int CAMERA_ATTR_EFFECT_GREEN = 5;

  /// < Aqua
  static const int CAMERA_ATTR_EFFECT_AQUA = 6;

  /// < Violet
  static const int CAMERA_ATTR_EFFECT_VIOLET = 7;

  /// < Orange
  static const int CAMERA_ATTR_EFFECT_ORANGE = 8;

  /// < Gray
  static const int CAMERA_ATTR_EFFECT_GRAY = 9;

  /// < Red
  static const int CAMERA_ATTR_EFFECT_RED = 10;

  /// < Antique
  static const int CAMERA_ATTR_EFFECT_ANTIQUE = 11;

  /// < Warm
  static const int CAMERA_ATTR_EFFECT_WARM = 12;

  /// < Pink
  static const int CAMERA_ATTR_EFFECT_PINK = 13;

  /// < Yellow
  static const int CAMERA_ATTR_EFFECT_YELLOW = 14;

  /// < Purple
  static const int CAMERA_ATTR_EFFECT_PURPLE = 15;

  /// < Emboss
  static const int CAMERA_ATTR_EFFECT_EMBOSS = 16;

  /// < Outline
  static const int CAMERA_ATTR_EFFECT_OUTLINE = 17;

  /// < Solarization
  static const int CAMERA_ATTR_EFFECT_SOLARIZATION = 18;

  /// < Sketch
  static const int CAMERA_ATTR_EFFECT_SKETCH = 19;

  /// < Washed
  static const int CAMERA_ATTR_EFFECT_WASHED = 20;

  /// < Vintage warm
  static const int CAMERA_ATTR_EFFECT_VINTAGE_WARM = 21;

  /// < Vintage cold
  static const int CAMERA_ATTR_EFFECT_VINTAGE_COLD = 22;

  /// < Posterization
  static const int CAMERA_ATTR_EFFECT_POSTERIZATION = 23;

  /// < Cartoon
  static const int CAMERA_ATTR_EFFECT_CARTOON = 24;

  /// < Selective color - Red
  static const int CAMERA_ATTR_EFFECT_SELECTIVE_RED = 25;

  /// < Selective color - Green
  static const int CAMERA_ATTR_EFFECT_SELECTIVE_GREEN = 26;

  /// < Selective color - Blue
  static const int CAMERA_ATTR_EFFECT_SELECTIVE_BLUE = 27;

  /// < Selective color - Yellow
  static const int CAMERA_ATTR_EFFECT_SELECTIVE_YELLOW = 28;

  /// < Selective color - Red and Yellow
  static const int CAMERA_ATTR_EFFECT_SELECTIVE_RED_YELLOW = 29;

  /// < Other Graphic effects
  static const int CAMERA_ATTR_EFFECT_OTHER_GRAPHICS = 30;
}

/// @brief Enumeration for the white balance levels of the camera.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_whitebalance_e {
  /// < None
  static const int CAMERA_ATTR_WHITE_BALANCE_NONE = 0;

  /// < Automatic
  static const int CAMERA_ATTR_WHITE_BALANCE_AUTOMATIC = 1;

  /// < Daylight
  static const int CAMERA_ATTR_WHITE_BALANCE_DAYLIGHT = 2;

  /// < Cloudy
  static const int CAMERA_ATTR_WHITE_BALANCE_CLOUDY = 3;

  /// < Fluorescent
  static const int CAMERA_ATTR_WHITE_BALANCE_FLUORESCENT = 4;

  /// < Incandescent
  static const int CAMERA_ATTR_WHITE_BALANCE_INCANDESCENT = 5;

  /// < Shade
  static const int CAMERA_ATTR_WHITE_BALANCE_SHADE = 6;

  /// < Horizon
  static const int CAMERA_ATTR_WHITE_BALANCE_HORIZON = 7;

  /// < Flash
  static const int CAMERA_ATTR_WHITE_BALANCE_FLASH = 8;

  /// < Custom
  static const int CAMERA_ATTR_WHITE_BALANCE_CUSTOM = 9;
}

/// @brief Enumeration for the scene mode.
/// @details The mode of operation can be in daylight, night, or back-light.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_scene_mode_e {
  /// < Normal
  static const int CAMERA_ATTR_SCENE_MODE_NORMAL = 0;

  /// < Portrait
  static const int CAMERA_ATTR_SCENE_MODE_PORTRAIT = 1;

  /// < Landscape
  static const int CAMERA_ATTR_SCENE_MODE_LANDSCAPE = 2;

  /// < Sports
  static const int CAMERA_ATTR_SCENE_MODE_SPORTS = 3;

  /// < Party & indoor
  static const int CAMERA_ATTR_SCENE_MODE_PARTY_N_INDOOR = 4;

  /// < Beach & indoor
  static const int CAMERA_ATTR_SCENE_MODE_BEACH_N_INDOOR = 5;

  /// < Sunset
  static const int CAMERA_ATTR_SCENE_MODE_SUNSET = 6;

  /// < Dusk & dawn
  static const int CAMERA_ATTR_SCENE_MODE_DUSK_N_DAWN = 7;

  /// < Fall
  static const int CAMERA_ATTR_SCENE_MODE_FALL_COLOR = 8;

  /// < Night scene
  static const int CAMERA_ATTR_SCENE_MODE_NIGHT_SCENE = 9;

  /// < Firework
  static const int CAMERA_ATTR_SCENE_MODE_FIREWORK = 10;

  /// < Text
  static const int CAMERA_ATTR_SCENE_MODE_TEXT = 11;

  /// < Show window
  static const int CAMERA_ATTR_SCENE_MODE_SHOW_WINDOW = 12;

  /// < Candle light
  static const int CAMERA_ATTR_SCENE_MODE_CANDLE_LIGHT = 13;

  /// < Backlight
  static const int CAMERA_ATTR_SCENE_MODE_BACKLIGHT = 14;

  /// < Aqua
  static const int CAMERA_ATTR_SCENE_MODE_AQUA = 15;
}

/// @brief Enumeration for the auto focus mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_af_mode_e {
  /// < auto-focus is not set
  static const int CAMERA_ATTR_AF_NONE = 0;

  /// < auto-focus in the normal mode
  static const int CAMERA_ATTR_AF_NORMAL = 1;

  /// < auto-focus in the macro mode(close distance)
  static const int CAMERA_ATTR_AF_MACRO = 2;

  /// < auto-focus in the full mode(all range scan, limited by device spec)
  static const int CAMERA_ATTR_AF_FULL = 3;
}

/// @brief Enumeration for the ISO levels of the camera.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_iso_e {
  /// < ISO auto mode
  static const int CAMERA_ATTR_ISO_AUTO = 0;

  /// < ISO 50
  static const int CAMERA_ATTR_ISO_50 = 1;

  /// < ISO 100
  static const int CAMERA_ATTR_ISO_100 = 2;

  /// < ISO 200
  static const int CAMERA_ATTR_ISO_200 = 3;

  /// < ISO 400
  static const int CAMERA_ATTR_ISO_400 = 4;

  /// < ISO 800
  static const int CAMERA_ATTR_ISO_800 = 5;

  /// < ISO 1600
  static const int CAMERA_ATTR_ISO_1600 = 6;

  /// < ISO 3200
  static const int CAMERA_ATTR_ISO_3200 = 7;
}

/// @brief Enumeration for the camera exposure modes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_exposure_mode_e {
  /// < Off
  static const int CAMERA_ATTR_EXPOSURE_MODE_OFF = 0;

  /// < All mode
  static const int CAMERA_ATTR_EXPOSURE_MODE_ALL = 1;

  /// < Center mode
  static const int CAMERA_ATTR_EXPOSURE_MODE_CENTER = 2;

  /// < Spot mode
  static const int CAMERA_ATTR_EXPOSURE_MODE_SPOT = 3;

  /// < Custom mode
  static const int CAMERA_ATTR_EXPOSURE_MODE_CUSTOM = 4;
}

/// @brief Enumeration for the orientation values of tag.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_tag_orientation_e {
  /// < Row #0 is at the top, Column #0 is to the left
  static const int CAMERA_ATTR_TAG_ORIENTATION_TOP_LEFT = 1;

  /// < Row #0 is at the top, Column #0 is to the right (flipped)
  static const int CAMERA_ATTR_TAG_ORIENTATION_TOP_RIGHT = 2;

  /// < Row #0 is at the bottom, Column #0 is to the right
  static const int CAMERA_ATTR_TAG_ORIENTATION_BOTTOM_RIGHT = 3;

  /// < Row #0 is at the bottom, Column #0 is to the left (flipped)
  static const int CAMERA_ATTR_TAG_ORIENTATION_BOTTOM_LEFT = 4;

  /// < Row #0 is to the left, Column #0 is at the top (flipped)
  static const int CAMERA_ATTR_TAG_ORIENTATION_LEFT_TOP = 5;

  /// < Row #0 is to the right, Column #0 is at the top
  static const int CAMERA_ATTR_TAG_ORIENTATION_RIGHT_TOP = 6;

  /// < Row #0 is to the right, Column #0 is at the bottom (flipped)
  static const int CAMERA_ATTR_TAG_ORIENTATION_RIGHT_BOTTOM = 7;

  /// < Row #0 is to the left, Column #0 is at the bottom
  static const int CAMERA_ATTR_TAG_ORIENTATION_LEFT_BOTTOM = 8;
}

/// @brief Enumeration for the flash mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_flash_mode_e {
  /// < Always off
  static const int CAMERA_ATTR_FLASH_MODE_OFF = 0;

  /// < Always splashes
  static const int CAMERA_ATTR_FLASH_MODE_ON = 1;

  /// < Depending on intensity of light, strobe starts to flash
  static const int CAMERA_ATTR_FLASH_MODE_AUTO = 2;

  /// < Red eye reduction. Multiple flash before capturing
  static const int CAMERA_ATTR_FLASH_MODE_REDEYE_REDUCTION = 3;

  /// < Slow sync curtain synchronization
  static const int CAMERA_ATTR_FLASH_MODE_SLOW_SYNC = 4;

  /// < Front curtain synchronization
  static const int CAMERA_ATTR_FLASH_MODE_FRONT_CURTAIN = 5;

  /// < Rear curtain synchronization
  static const int CAMERA_ATTR_FLASH_MODE_REAR_CURTAIN = 6;

  /// < Keep turned on until turning off
  static const int CAMERA_ATTR_FLASH_MODE_PERMANENT = 7;
}

/// @brief Enumeration to preview FPS.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_fps_e {
  /// < AUTO FPS
  static const int CAMERA_ATTR_FPS_AUTO = 0;

  /// < 7 FPS
  static const int CAMERA_ATTR_FPS_7 = 7;

  /// < 8 FPS
  static const int CAMERA_ATTR_FPS_8 = 8;

  /// < 15 FPS
  static const int CAMERA_ATTR_FPS_15 = 15;

  /// < 20 FPS
  static const int CAMERA_ATTR_FPS_20 = 20;

  /// < 24 FPS
  static const int CAMERA_ATTR_FPS_24 = 24;

  /// < 25 FPS
  static const int CAMERA_ATTR_FPS_25 = 25;

  /// < 30 FPS
  static const int CAMERA_ATTR_FPS_30 = 30;

  /// < 60 FPS
  static const int CAMERA_ATTR_FPS_60 = 60;

  /// < 90 FPS
  static const int CAMERA_ATTR_FPS_90 = 90;

  /// < 120 FPS
  static const int CAMERA_ATTR_FPS_120 = 120;
}

/// @brief Enumeration for the theater mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_theater_mode_e {
  /// < Disable theater mode - External display shows same image as device display
  static const int CAMERA_ATTR_THEATER_MODE_DISABLE = 0;

  /// < Enable theater mode - Preview image is displayed on external display with full screen mode, but preview image is not shown on device display
  static const int CAMERA_ATTR_THEATER_MODE_ENABLE = 2;

  /// < Clone mode - Preview image is displayed on external display with full screen mode. Also preview image is shown by the UI on device display
  static const int CAMERA_ATTR_THEATER_MODE_CLONE = 1;
}

/// @brief Enumeration for HDR capture mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class camera_attr_hdr_mode_e {
  /// < Disable HDR capture
  static const int CAMERA_ATTR_HDR_MODE_DISABLE = 0;

  /// < Enable HDR capture
  static const int CAMERA_ATTR_HDR_MODE_ENABLE = 1;

  /// < Enable HDR capture and keep original image data
  static const int CAMERA_ATTR_HDR_MODE_KEEP_ORIGINAL = 2;
}

/// @brief Enumeration for PTZ(Pan Tilt Zoom) type.
/// @since_tizen 3.0
abstract class camera_attr_ptz_type_e {
  /// < Move the camera device physically
  static const int CAMERA_ATTR_PTZ_TYPE_MECHANICAL = 0;

  /// < Zoom digitally and move into portion of the image
  static const int CAMERA_ATTR_PTZ_TYPE_ELECTRONIC = 1;
}

/// @brief Enumeration for PTZ(Pan Tilt Zoom) movement type.
/// @since_tizen 3.0
abstract class camera_attr_ptz_move_type_e {
  /// < Move to a specific coordinate position
  static const int CAMERA_ATTR_PTZ_MOVE_ABSOLUTE = 0;

  /// < Move a specific distance from the current position
  static const int CAMERA_ATTR_PTZ_MOVE_RELATIVE = 1;
}

/// @brief The Camera handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see	recorder_create_videorecorder()
typedef camera_h = ffi.Pointer<camera_cli_s>;

/// @brief Called to get information about image data taken by the camera once per frame while capturing.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks This function is issued in the context of internal framework so the UI update code should not be directly invoked.
/// You must not call camera_start_preview() within this callback.
///
/// @param[in] image The image data of the captured picture
/// @param[in] postview The image data of the postview
/// @param[in] thumbnail The image data of the thumbnail (it should be @c NULL if the available thumbnail data does not exist)
/// @param[in] user_data The user data passed from the callback registration function
/// @pre	camera_start_capture() or camera_start_continuous_capture() will invoke this callback function if it is registered using camera_start_capture() or camera_start_continuous_capture().
/// @see	camera_start_capture()
/// @see	camera_start_continuous_capture()
/// @see	camera_capture_completed_cb()
typedef camera_capturing_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<camera_image_data_s>,
            ffi.Pointer<camera_image_data_s>,
            ffi.Pointer<camera_image_data_s>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the camera capturing completes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks The callback is called after camera_capturing_cb() is completed.\n
/// If you want to show the user a preview after capturing is finished, \n
/// an application can use camera_start_preview() after calling this callback.
/// @param[in] user_data The user data passed from the callback registration function
/// @pre	This callback function is invoked if it is registered using camera_start_capture() or camera_start_continuous_capture().
/// @see	camera_start_capture()
/// @see	camera_start_continuous_capture()
/// @see	camera_capturing_cb()
typedef camera_capture_completed_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief The Camera display handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef camera_display_h = ffi.Pointer<ffi.Void>;

/// @brief Called when a face is detected in the preview frame.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] faces The detected face array
/// @param[in] count The length of the array
/// @param[in] user_data The user data passed from the callback registration function
/// @see	camera_start_face_detection()
typedef camera_face_detected_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<camera_detected_face_s>, ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called once for each supported preview resolution.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] width The preview image width
/// @param[in] height The preview image height
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_foreach_supported_preview_resolution() will invoke this callback.
/// @see	camera_foreach_supported_preview_resolution()
typedef camera_supported_preview_resolution_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called once for each supported capture resolution.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] width The capture resolution width
/// @param[in] height The capture resolution height
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_foreach_supported_capture_resolution() will invoke this callback.
/// @see	camera_foreach_supported_capture_resolution()
typedef camera_supported_capture_resolution_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called once for the pixel format of each supported capture format.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] format The supported pixel format
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_foreach_supported_capture_format() will invoke this callback.
/// @see	camera_foreach_supported_capture_format()
typedef camera_supported_capture_format_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called once for the pixel format of each supported preview format.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] format The supported preview data format
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_foreach_supported_preview_format() will invoke this callback.
/// @see	camera_foreach_supported_preview_format()
typedef camera_supported_preview_format_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to register for notifications about delivering a copy of the new preview frame when every preview frame is displayed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks This function is issued in the context of internal framework so the UI update code should not be directly invoked.\n
/// If the camera is used as a recorder then this callback function won't be called.
///
/// @param[in] frame The reference pointer to preview stream data
/// @param[in] user_data The user data passed from the callback registration function
/// @pre	camera_start_preview() will invoke this callback function if you register this callback using camera_set_preview_cb().
/// @see	camera_start_preview()
/// @see	camera_set_preview_cb()
/// @see	camera_unset_preview_cb()
typedef camera_preview_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<camera_preview_data_s>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to register for notifications about delivering media packet when every preview frame is displayed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks This function is issued in the context of internal framework so the UI update code should not be directly invoked.\n
/// If the camera is used as a recorder then this callback function won't be called.\n
/// and the packet should be released by media_packet_destroy() after use.
///
/// @param[in] pkt Reference pointer to media packet
/// @param[in] user_data The user data passed from the callback registration function
/// @pre	camera_start_preview() will invoke this callback function if you register this callback using camera_set_media_packet_preview_cb().
/// @see	camera_start_preview()
/// @see	camera_set_media_packet_preview_cb()
/// @see	camera_unset_media_packet_preview_cb()
typedef camera_media_packet_preview_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(media_packet_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the camera state is changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] previous The previous state of the camera
/// @param[in] current The current state of the camera
/// @param[in] by_policy If @c true the state is changed by policy, otherwise @c false
/// @param[in] user_data The user data passed from the callback registration function
/// @pre camera_start_preview(), camera_start_capture() or camera_stop_preview()
/// will invoke this callback if you register this callback using camera_set_state_changed_cb().
/// @see	camera_set_state_changed_cb()
typedef camera_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, ffi.Int32, ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the camera is interrupted by policy.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks This callback is called after interrupt handling is completed.
/// @param[in] policy The policy that interrupted the camera
/// @param[in] previous The previous state of the camera
/// @param[in] current The current state of the camera
/// @param[in] user_data The user data passed from the callback registration function
/// @see	camera_set_interrupted_cb()
typedef camera_interrupted_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the camera interrupt is started by policy.
/// @since_tizen 4.0
/// @remarks This callback is called before interrupt handling is started.
/// @param[in] policy The policy that is interrupting the camera
/// @param[in] state The current state of the camera
/// @param[in] user_data The user data passed from the callback registration function
/// @see camera_set_interrupt_started_cb()
typedef camera_interrupt_started_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the camera focus state is changed.
/// @details When the camera auto focus completes or a change to the focus state occurs,
/// this callback is invoked. \n \n
/// Changes of focus state are as follows: \n
/// #CAMERA_FOCUS_STATE_RELEASED -> start focusing -> #CAMERA_FOCUS_STATE_ONGOING -> working ->
/// #CAMERA_FOCUS_STATE_FOCUSED or #CAMERA_FOCUS_STATE_FAILED.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @param[in] state The current state of the auto-focus
/// @param[in] user_data The user data passed from the callback registration function
/// @pre camera_start_focusing() will invoke this callback if you register it using camera_set_focus_changed_cb().
/// @see	camera_set_focus_changed_cb()
/// @see	camera_unset_focus_changed_cb()
/// @see	camera_start_focusing()
/// @see camera_cancel_focusing()
typedef camera_focus_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an error occurs.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @remarks This callback informs about a critical error situation.\n
/// When this callback is invoked, the user should release the resource and terminate the application.\n
/// In case of errors, one of these codes occur:\n
/// #CAMERA_ERROR_DEVICE,\n
/// #CAMERA_ERROR_INVALID_OPERATION,\n
/// #CAMERA_ERROR_OUT_OF_MEMORY.
/// @param[in] error The error code
/// @param[in] current_state The current state of the camera
/// @param[in] user_data	The user data passed from the callback registration function
/// @pre	This callback function is invoked if it is registered using camera_set_error_cb().
/// @see	camera_set_error_cb()
/// @see	camera_unset_error_cb()
typedef camera_error_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the camera device state is changed.
/// @since_tizen 3.0
/// @param[in] device The hardware camera type
/// @param[in] state The state of the camera device
/// @param[in] user_data The user data passed from the callback registration function
/// @see	camera_add_device_state_changed_cb()
typedef camera_device_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported FPS mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] mode The supported FPS mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_fps() will invoke this callback.
/// @see	camera_attr_foreach_supported_fps()
typedef camera_attr_supported_fps_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported auto-focus mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] mode The supported auto-focus mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_af_mode() will invoke this callback.
/// @see	camera_attr_foreach_supported_af_mode()
typedef camera_attr_supported_af_mode_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported exposure mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] mode The supported exposure mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_exposure_mode() will invoke this callback.
/// @see	camera_attr_foreach_supported_exposure_mode()
/// @see	#camera_attr_exposure_mode_e
typedef camera_attr_supported_exposure_mode_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported ISO mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] iso The supported ISO mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_iso() will invoke this callback.
/// @see	camera_attr_foreach_supported_iso()
typedef camera_attr_supported_iso_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported theater mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] mode The supported theater mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_theater_mode() will invoke this callback.
/// @see	camera_attr_foreach_supported_theater_mode()
typedef camera_attr_supported_theater_mode_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported white balance.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] wb The supported white balance mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_whitebalance() will invoke this callback.
/// @see	camera_attr_foreach_supported_whitebalance()
/// @see	#camera_attr_whitebalance_e
typedef camera_attr_supported_whitebalance_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported effect mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] effect The supported effect mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_effect() will invoke this callback.
/// @see	camera_attr_foreach_supported_effect()
typedef camera_attr_supported_effect_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported scene mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] mode The supported scene mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_scene_mode() will invoke this callback.
/// @see	camera_attr_foreach_supported_scene_mode()
/// @see	#camera_attr_scene_mode_e
typedef camera_attr_supported_scene_mode_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported flash mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] mode The supported flash mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_flash_mode() will invoke this callback.
/// @see	camera_attr_foreach_supported_flash_mode()
typedef camera_attr_supported_flash_mode_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported stream rotation mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] mode The supported stream rotation mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_stream_rotation() will invoke this callback.
/// @see	camera_attr_foreach_supported_stream_rotation()
typedef camera_attr_supported_stream_rotation_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported stream flip mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] mode The supported stream flip mode
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_stream_flip() will invoke this callback.
/// @see	camera_attr_foreach_supported_stream_flip()
typedef camera_attr_supported_stream_flip_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the HDR capture process is updated.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] percent The progress percentage of HDR capture
/// @param[in] user_data The user data passed from the callback registration function
/// @pre camera_start_capture() will invoke this callback if you register it using camera_attr_set_hdr_capture_progress_cb().
/// @see camera_attr_get_hdr_mode()
/// @see camera_attr_set_hdr_capture_progress_cb()
/// @see camera_attr_unset_hdr_capture_progress_cb()
/// @see camera_attr_is_supported_hdr_capture()
typedef camera_attr_hdr_progress_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get each supported PTZ(Pan Tilt Zoom) type.
/// @since_tizen 3.0
/// @param[in] type The supported ptz type
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n @c false to break out of the loop
/// @pre	camera_attr_foreach_supported_ptz_mode() will invoke this callback.
/// @see	camera_attr_foreach_supported_ptz_mode()
typedef camera_attr_supported_ptz_type_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

class media_packet_pool_s extends ffi.Opaque {}

/// @brief  The Media Packet Pool Handle.
/// @since_tizen 3.0
typedef media_packet_pool_h = ffi.Pointer<media_packet_pool_s>;

class mediacodec_s extends ffi.Opaque {}

/// @brief Enumeration of  media codec support  type
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks If this codec is to be used as an encoder or decoder, the codec flag must be set to #MEDIACODEC_ENCODER or
/// #MEDIACODEC_DECODER. If user doesn't set optional flag, default flags will be set to #MEDIACODEC_SUPPORT_TYPE_SW.
abstract class mediacodec_support_type_e {
  /// < This flag is for using the encoder
  static const int MEDIACODEC_ENCODER = 1;

  /// < This flag is for using the decoder
  static const int MEDIACODEC_DECODER = 2;

  /// < This is an optional flag for using the h/w codec
  static const int MEDIACODEC_SUPPORT_TYPE_HW = 4;

  /// < This is an optional flag for using the s/w codec
  static const int MEDIACODEC_SUPPORT_TYPE_SW = 8;
}

/// @brief Enumerations of  media codec type
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class mediacodec_codec_type_e {
  /// < NONE
  static const int MEDIACODEC_NONE = 0;

  /// < L16
  static const int MEDIACODEC_L16 = 4112;

  /// < ALAW
  static const int MEDIACODEC_ALAW = 4128;

  /// < ULAW
  static const int MEDIACODEC_ULAW = 4144;

  /// < MEDIACDEC_AMR indicates AMR-NB (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_AMR = 4160;

  /// < AMR-NB (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_AMR_NB = 4160;

  /// < AMR-WB (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_AMR_WB = 4161;

  /// < G729
  static const int MEDIACODEC_G729 = 4176;

  /// < MEDIACDEC_AAC indicates AAC-LC (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_AAC = 4192;

  /// < AAC-LC (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_AAC_LC = 4192;

  /// < HE-AAC (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_AAC_HE = 4193;

  /// < HE-AAC-PS (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_AAC_HE_PS = 4194;

  /// < MP3
  static const int MEDIACODEC_MP3 = 4208;

  /// < VORBIS (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_VORBIS = 4224;

  /// < FLAC (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_FLAC = 4240;

  /// < WMA version 1 (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_WMAV1 = 4256;

  /// < WMA version 2  (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_WMAV2 = 4257;

  /// < WMA Professional (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_WMAPRO = 4258;

  /// < WMA Lossless (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_WMALSL = 4259;

  /// < H.261
  static const int MEDIACODEC_H261 = 8208;

  /// < H.263
  static const int MEDIACODEC_H263 = 8224;

  /// < H.264
  static const int MEDIACODEC_H264 = 8240;

  /// < MJPEG
  static const int MEDIACODEC_MJPEG = 8256;

  /// < MPEG1
  static const int MEDIACODEC_MPEG1 = 8272;

  /// < MPEG2
  static const int MEDIACODEC_MPEG2 = 8288;

  /// < MPEG4
  static const int MEDIACODEC_MPEG4 = 8304;

  /// < HEVC (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_HEVC = 8320;

  /// < VP8 (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_VP8 = 8336;

  /// < VP9 (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_VP9 = 8352;

  /// < VC1 (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_VC1 = 8368;
}

/// @brief Enumeration of  media codec error
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class mediacodec_error_e {
  /// < Successful
  static const int MEDIACODEC_ERROR_NONE = 0;

  /// < Out of memory
  static const int MEDIACODEC_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int MEDIACODEC_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid operation
  static const int MEDIACODEC_ERROR_INVALID_OPERATION = -38;

  /// < Not supported
  static const int MEDIACODEC_ERROR_NOT_SUPPORTED_ON_DEVICE = -1073741822;

  /// < Permission denied
  static const int MEDIACODEC_ERROR_PERMISSION_DENIED = -13;

  /// < Invalid state
  static const int MEDIACODEC_ERROR_INVALID_STATE = -26935295;

  /// < Invalid input buffer
  static const int MEDIACODEC_ERROR_INVALID_INBUFFER = -26935294;

  /// < Invalid output buffer
  static const int MEDIACODEC_ERROR_INVALID_OUTBUFFER = -26935293;

  /// < Internal error
  static const int MEDIACODEC_ERROR_INTERNAL = -26935292;

  /// < Not initialized mediacodec
  static const int MEDIACODEC_ERROR_NOT_INITIALIZED = -26935291;

  /// < Invalid stream
  static const int MEDIACODEC_ERROR_INVALID_STREAM = -26935290;

  /// < Not supported format
  static const int MEDIACODEC_ERROR_CODEC_NOT_FOUND = -26935289;

  /// < Error while decoding data
  static const int MEDIACODEC_ERROR_DECODE = -26935288;

  /// < Out of storage
  static const int MEDIACODEC_ERROR_NO_FREE_SPACE = -26935287;

  /// < Cannot find stream
  static const int MEDIACODEC_ERROR_STREAM_NOT_FOUND = -26935286;

  /// < Not supported format
  static const int MEDIACODEC_ERROR_NOT_SUPPORTED_FORMAT = -26935285;

  /// < Not available buffer
  static const int MEDIACODEC_ERROR_BUFFER_NOT_AVAILABLE = -26935284;

  /// < Overflow input buffer (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_ERROR_OVERFLOW_INBUFFER = -26935283;

  /// < Exceed the instance limits (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int MEDIACODEC_ERROR_RESOURCE_OVERLOADED = -26935282;
}

/// @brief Enumeration of buffer status
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class mediacodec_status_e {
  static const int MEDIACODEC_NEED_DATA = 0;
  static const int MEDIACODEC_ENOUGH_DATA = 1;
}

/// @brief Media Codec type handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef mediacodec_h = ffi.Pointer<mediacodec_s>;

/// @brief Called when the input buffer(pkt) used up.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @details It will be invoked when mediacodec has used input buffer.
/// @param[in] pkt       The media packet handle
/// @param[in] user_data The user data passed from the callback registration function
/// @pre It will be invoked when input buffer process completed if you register this callback using mediacodec_set_input_buffer_used_cb().
/// @see mediacodec_set_input_buffer_used_cb()
/// @see mediacodec_unset_input_buffer_used_cb()
typedef mediacodec_input_buffer_used_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(media_packet_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the output buffer is available.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @details It will be invoked when mediacodec has output buffer.
/// @param[in] pkt       The media packet handle
/// @param[in] user_data The user data passed from the callback registration function
/// @pre It will be invoked when mediacodec process completed(had output buffer) if you register this callback using mediacodec_set_fill_buffer_cb().
/// @see mediacodec_set_output_buffer_available_cb()
/// @see mediacodec_unset_output_buffer_available_cb()
typedef mediacodec_output_buffer_available_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(media_packet_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the error has occured
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @details It will be invoked when the error has occured.
/// @param[in] error_code The error code
/// @param[in] user_data  The user data passed from the callback registration function
/// @pre It will be invoked when the error has occured if you register this callback using mediacodec_set_error_cb().
/// @see mediacodec_set_error_cb()
/// @see mediacodec_unset_error_cb()
typedef mediacodec_error_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when there is no data to decode/encode
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @details It will be invoked when the end-of-stream is reached.
/// @param[in] user_data The user data passed from the callback registration function
/// @pre It will be invoked when the eos event generate if you register this callback using mediacodec_set_eos_cb().
/// @see mediacodec_set_eos_cb()
/// @see mediacodec_unset_eos_cb()
typedef mediacodec_eos_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the mediacodec needs more data or has enough data.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @details It is recommended that the application stops calling mediacodec_process_input() when MEDIACODEC_ENOUGH_DATA
/// is invoked.
/// @param[in] user_data The user data passed from the callback registration function
/// @see mediacodec_set_buffer_status_cb()
/// @see mediacodec_unset_buffer_status_cb()
typedef mediacodec_buffer_status_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called once for each supported codec types.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] codec_type  The codec type
/// @param[in] user_data   The user data passed from the foreach function
/// @return  @c true to continue with the next iteration of the loop, @c false to break out of the loop.
/// @pre mediacodec_foreach_supported_codec() will invoke this callback.
/// @see mediacodec_foreach_supported_codec()
typedef mediacodec_supported_codec_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for the media controller error.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class mc_error_e {
  /// < Successful
  static const int MEDIA_CONTROLLER_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int MEDIA_CONTROLLER_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int MEDIA_CONTROLLER_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid Operation
  static const int MEDIA_CONTROLLER_ERROR_INVALID_OPERATION = -38;

  /// < No space left on device
  static const int MEDIA_CONTROLLER_ERROR_FILE_NO_SPACE_ON_DEVICE = -28;

  /// < Permission denied
  static const int MEDIA_CONTROLLER_ERROR_PERMISSION_DENIED = -13;
}

/// @brief Enumeration for the media controller server state.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class mc_server_state_e {
  /// < None state
  static const int MC_SERVER_STATE_NONE = 0;

  /// < Activate state
  static const int MC_SERVER_STATE_ACTIVATE = 1;

  /// < Deactivate state
  static const int MC_SERVER_STATE_DEACTIVATE = 2;
}

/// @brief Enumeration for the media meta info.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class mc_meta_e {
  /// < Title
  static const int MC_META_MEDIA_TITLE = 0;

  /// < Artist
  static const int MC_META_MEDIA_ARTIST = 1;

  /// < Album
  static const int MC_META_MEDIA_ALBUM = 2;

  /// < Author
  static const int MC_META_MEDIA_AUTHOR = 3;

  /// < Genre
  static const int MC_META_MEDIA_GENRE = 4;

  /// < Duration
  static const int MC_META_MEDIA_DURATION = 5;

  /// < Date
  static const int MC_META_MEDIA_DATE = 6;

  /// < Copyright
  static const int MC_META_MEDIA_COPYRIGHT = 7;

  /// < Description
  static const int MC_META_MEDIA_DESCRIPTION = 8;

  /// < Track Number
  static const int MC_META_MEDIA_TRACK_NUM = 9;

  /// < Picture. Album Art
  static const int MC_META_MEDIA_PICTURE = 10;
}

/// @brief Enumeration for the media playback state.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class mc_playback_states_e {
  /// < None
  static const int MC_PLAYBACK_STATE_NONE = 0;

  /// < Play
  static const int MC_PLAYBACK_STATE_PLAYING = 1;

  /// < Pause
  static const int MC_PLAYBACK_STATE_PAUSED = 2;

  /// < Stop
  static const int MC_PLAYBACK_STATE_STOPPED = 3;

  /// < Next file
  static const int MC_PLAYBACK_STATE_NEXT_FILE = 4;

  /// < Previous file
  static const int MC_PLAYBACK_STATE_PREV_FILE = 5;

  /// < Fast forward
  static const int MC_PLAYBACK_STATE_FAST_FORWARD = 6;

  /// < Rewind
  static const int MC_PLAYBACK_STATE_REWIND = 7;
}

/// @brief Enumeration for the shuffle mode.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class mc_shuffle_mode_e {
  /// < Shuffle mode on
  static const int MC_SHUFFLE_MODE_ON = 0;

  /// < Shuffle mode off
  static const int MC_SHUFFLE_MODE_OFF = 1;
}

/// @brief Enumeration for the repeat mode.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class mc_repeat_mode_e {
  /// < Repeat mode on
  static const int MC_REPEAT_MODE_ON = 0;

  /// < Repeat mode off
  static const int MC_REPEAT_MODE_OFF = 1;
}

/// @brief Enumeration for the subscription type.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class mc_subscription_type_e {
  /// < Server state
  static const int MC_SUBSCRIPTION_TYPE_SERVER_STATE = 0;

  /// < Playback
  static const int MC_SUBSCRIPTION_TYPE_PLAYBACK = 1;

  /// < Metadata
  static const int MC_SUBSCRIPTION_TYPE_METADATA = 2;

  /// < Shuffle mode
  static const int MC_SUBSCRIPTION_TYPE_SHUFFLE_MODE = 3;

  /// < Repeat mode
  static const int MC_SUBSCRIPTION_TYPE_REPEAT_MODE = 4;
}

/// @brief The structure type for the media server handle.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef mc_server_h = ffi.Pointer<ffi.Void>;

/// @brief Called when the Server received playback state command from the client.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @details This callback is called when server received playback state recommand from client.
///
/// @remarks The callback is called in the dbus event loop.
///
/// @param[in] client_name    The app_id of the media controller client
/// @param[in] state    The received playback state
/// @param[in] user_data        The user data passed from the mc_server_set_playback_state_command_received_cb() fuction
///
/// @pre mc_server_set_playback_state_command_received_cb()
///
/// @see mc_server_set_playback_state_command_received_cb()
typedef mc_server_playback_state_command_received_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.Char>, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the Server received custom command from the client.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @details This callback is called when server received custom recommand from client.
/// If there is reply for command, call mc_server_send_command_reply() function.
///
/// @remarks The callback is called in the dbus event loop.
///
/// @param[in] client_name    The app_id of the media controller client
/// @param[in] command    The received command
/// @param[in] data    The extra data
/// @param[in] user_data        The user data passed from the mc_server_set_custom_command_received_cb() fuction
///
/// @pre mc_server_set_custom_command_received_cb()
///
/// @see mc_server_set_custom_command_received_cb()
typedef mc_server_custom_command_received_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Pointer<bundle>, ffi.Pointer<ffi.Void>)>>;

/// @brief The structure type for the media client handle.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef mc_client_h = ffi.Pointer<ffi.Void>;

/// @brief Called when updating status of the media controller server.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @remarks The callback is called in the dbus event loop.
///
/// @param[in] server_name,    The app_id of the updated media controller server
/// @param[in] state,    The state of the updated media controller server
/// @param[in] user_data        The user data passed from the mc_client_set_server_update_cb() fuction
///
/// @pre mc_client_set_server_update_cb()
///
/// @see mc_client_set_server_update_cb()
typedef mc_server_state_updated_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.Char>, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when updating the playback information of the media controller server.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @remarks The callback is called in the dbus event loop.
///
/// @param[in] server_name,    The app_id of the updated media controller server
/// @param[in] playback,        The playback information of the updated media controller server
/// @param[in] user_data        The user data passed from the mc_client_set_playback_update_cb() fuction
///
/// @pre mc_client_set_playback_update_cb()
///
/// @see mc_client_set_playback_update_cb()
typedef mc_playback_updated_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.Char>, mc_playback_h, ffi.Pointer<ffi.Void>)>>;

/// @brief The structure type for the media controller playback handle.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef mc_playback_h = ffi.Pointer<ffi.Void>;

/// @brief Called when updating the metadata of the media controller server.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @remarks The callback is called in the dbus event loop.
///
/// @param[in] server_name,    The app_id of the updated media controller server
/// @param[in] metadata,        the metadata of the updated media controller server
/// @param[in] user_data        The user data passed from the mc_client_set_metadata_update_cb() fuction
///
/// @pre mc_client_set_metadata_update_cb()
///
/// @see mc_client_set_metadata_update_cb()
typedef mc_metadata_updated_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.Char>, mc_metadata_h, ffi.Pointer<ffi.Void>)>>;

/// @brief The structure type for the media controller metadata handle.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef mc_metadata_h = ffi.Pointer<ffi.Void>;

/// @brief Called when updating the shuffle mode of the media controller server.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @remarks The callback is called in the dbus event loop.
///
/// @param[in] server_name,    The app_id of the updated media controller server
/// @param[in] mode,            The shuffle mode of the updated media controller server
/// @param[in] user_data        The user data passed from the mc_client_set_shuffle_mode_update_cb() fuction
///
/// @pre mc_client_set_shuffle_mode_update_cb()
///
/// @see mc_client_set_shuffle_mode_update_cb()
typedef mc_shuffle_mode_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.Char>, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when updating the repeat mode of the media controller server.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @remarks The callback is called in the dbus event loop.
///
/// @param[in] server_name,    The app_id of the updated media controller server
/// @param[in] mode,            The repeat mode of the updated media controller server
/// @param[in] user_data        The user data passed from the mc_client_set_repeat_mode_update_cb() fuction
///
/// @pre mc_client_set_repeat_mode_update_cb()
///
/// @see mc_client_set_repeat_mode_update_cb()
typedef mc_repeat_mode_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.Char>, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when requesting the list of subscribed servers.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @remarks The callback is called in the dbus event loop.
///
/// @param[in] server_name,    The app_id of the subscribed media controller server
/// @param[in] user_data        The user data passed from the mc_client_foreach_server_subscribed() fuction
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre mc_client_foreach_server_subscribed()
///
/// @see mc_client_foreach_server_subscribed()
typedef mc_subscribed_server_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when requesting the list of activated servers.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @remarks The callback is called in the dbus event loop.
///
/// @param[in] server_name,    The app_id of the activated media controller server
/// @param[in] user_data        The user data passed from the mc_client_foreach_server() fuction
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre mc_client_foreach_server()
///
/// @see mc_client_foreach_server()
typedef mc_activated_server_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when receiving the command processing result from the server.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @remarks The callback is called in the dbus event loop.
///
/// @param[in] server_name    The app_id of the updated media controller server
/// @param[in] result_code    The result code of custom command
/// @param[in] data The extra data
/// @param[in] user_data        The user data passed from the mc_client_send_custom_command() fuction
///
/// @pre mc_client_send_custom_command()
///
/// @see mc_client_send_custom_command()
typedef mc_command_reply_received_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Int, ffi.Pointer<bundle>,
            ffi.Pointer<ffi.Void>)>>;

class mediademuxer_s extends ffi.Opaque {}

/// @brief Enumeration for media demuxer state
/// @since_tizen 3.0
abstract class mediademuxer_state {
  /// < The mediademuxer is not created
  static const int MEDIADEMUXER_STATE_NONE = 0;

  /// < The mediademuxer is created, but not prepared
  static const int MEDIADEMUXER_STATE_IDLE = 1;

  /// < The mediademuxer is ready to demux media
  static const int MEDIADEMUXER_STATE_READY = 2;

  /// < The mediademuxer is demuxing media
  static const int MEDIADEMUXER_STATE_DEMUXING = 3;
}

/// @brief Enumeration for media demuxer error.
/// @since_tizen 3.0
abstract class mediademuxer_error_e {
  /// < Successful
  static const int MEDIADEMUXER_ERROR_NONE = 0;

  /// < Out of memory
  static const int MEDIADEMUXER_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int MEDIADEMUXER_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid operation
  static const int MEDIADEMUXER_ERROR_INVALID_OPERATION = -38;

  /// < Not supported
  static const int MEDIADEMUXER_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Permission denied
  static const int MEDIADEMUXER_ERROR_PERMISSION_DENIED = -13;

  /// < Invalid state
  static const int MEDIADEMUXER_ERROR_INVALID_STATE = -27131903;

  /// < Invalid path
  static const int MEDIADEMUXER_ERROR_INVALID_PATH = -27131902;

  /// < Resource limit
  static const int MEDIADEMUXER_ERROR_RESOURCE_LIMIT = -27131901;

  /// < Seek operation failure
  static const int MEDIADEMUXER_ERROR_SEEK_FAILED = -27131900;

  /// < Not permitted format
  static const int MEDIADEMUXER_ERROR_DRM_NOT_PERMITTED = -27131899;
}

/// @brief Media Demuxer handle type.
/// @since_tizen 3.0
typedef mediademuxer_h = ffi.Pointer<mediademuxer_s>;

/// @brief Called when error occurs in media demuxer.
/// @details Following error codes can be delivered.
/// #MEDIADEMUXER_ERROR_INVALID_OPERATION,
/// #MEDIADEMUXER_ERROR_NOT_SUPPORTED,
/// #MEDIADEMUXER_ERROR_INVALID_PATH,
/// #MEDIADEMUXER_ERROR_RESOURCE_LIMIT,
/// #MEDIADEMUXER_ERROR_SEEK_FAILED,
/// #MEDIADEMUXER_ERROR_DRM_NOT_PERMITTED
/// @since_tizen 3.0
/// @param[in] error  The error that occurred in media demuxer
/// @param[in] user_data   The user data passed from the code where
/// mediademuxer_set_error_cb() was invoked
/// This data will be accessible from mediademuxer_error_cb()
/// @pre Create media demuxer handle by calling mediademuxer_create() function.
/// @see mediademuxer_set_error_cb()
/// @see mediademuxer_unset_error_cb()
typedef mediademuxer_error_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when end of stream occurs in media demuxer.
/// @since_tizen 3.0
/// @param[in] track_num  The track_num which indicate eos for which track number occured
/// @param[in] user_data   The user data passed from the code where
/// mediademuxer_set_eos_cb() was invoked
/// This data will be accessible from mediademuxer_eos_cb()
/// @pre Create media demuxer handle by calling mediademuxer_create() function.
/// @see mediademuxer_set_eos_cb()
/// @see mediademuxer_unset_eos_cb()
typedef mediademuxer_eos_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

class mediamuxer_s extends ffi.Opaque {}

/// @brief Enumeration for media muxer state
/// @since_tizen 3.0
abstract class mediamuxer_state_e {
  /// < The mediamuxer is not created
  static const int MEDIAMUXER_STATE_NONE = 0;

  /// < The mediamuxer is created, but not prepared
  static const int MEDIAMUXER_STATE_IDLE = 1;

  /// < The mediamuxer is ready to mux media
  static const int MEDIAMUXER_STATE_READY = 2;

  /// < The mediamuxer is muxing media
  static const int MEDIAMUXER_STATE_MUXING = 3;

  /// < The mediamuxer is paused while muxing media
  static const int MEDIAMUXER_STATE_PAUSED = 4;
}

/// @brief Enumeration for media muxer error
/// @since_tizen 3.0
abstract class mediamuxer_error_e {
  /// < Successful
  static const int MEDIAMUXER_ERROR_NONE = 0;

  /// < Out of memory
  static const int MEDIAMUXER_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int MEDIAMUXER_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid operation
  static const int MEDIAMUXER_ERROR_INVALID_OPERATION = -38;

  /// < Not supported
  static const int MEDIAMUXER_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Permission denied
  static const int MEDIAMUXER_ERROR_PERMISSION_DENIED = -13;

  /// < Invalid state
  static const int MEDIAMUXER_ERROR_INVALID_STATE = -27197439;

  /// < Invalid path
  static const int MEDIAMUXER_ERROR_INVALID_PATH = -27197438;

  /// < Resource limit
  static const int MEDIAMUXER_ERROR_RESOURCE_LIMIT = -27197437;
}

/// @brief Enumeration for media muxer output format
/// @since_tizen 3.0
abstract class mediamuxer_output_format_e {
  /// < The mediamuxer output format is MP4 container
  static const int MEDIAMUXER_CONTAINER_FORMAT_MP4 = 67121168;

  /// < The mediamuxer output format is 3GP container
  static const int MEDIAMUXER_CONTAINER_FORMAT_3GP = 67121264;

  /// < The mediamuxer output format is WAV container
  static const int MEDIAMUXER_CONTAINER_FORMAT_WAV = 67125264;

  /// < The mediamuxer output format is ARM_NB container
  static const int MEDIAMUXER_CONTAINER_FORMAT_AMR_NB = 285216832;

  /// < The mediamuxer output format is AMR_WB container
  static const int MEDIAMUXER_CONTAINER_FORMAT_AMR_WB = 285216833;

  /// < The mediamuxer output format is AAC_ADTS container
  static const int MEDIAMUXER_CONTAINER_FORMAT_AAC_ADTS = 67125296;
}

/// @brief Media Muxer handle type
/// @since_tizen 3.0
typedef mediamuxer_h = ffi.Pointer<mediamuxer_s>;

/// @brief Called when error occurs in media muxer.
/// @details Following error codes can be delivered.
/// #MEDIAMUXER_ERROR_INVALID_OPERATION,
/// #MEDIAMUXER_ERROR_NOT_SUPPORTED,
/// #MEDIAMUXER_ERROR_INVALID_PATH,
/// #MEDIAMUXER_ERROR_RESOURCE_LIMIT
/// @since_tizen 3.0
/// @param[in] error        The error that occurred in media muxer
/// @param[in] user_data    The user data passed from the code where
/// mediamuxer_set_error_cb() was invoked
/// This data will be accessible from @a mediamuxer_error_cb
/// @pre Create media muxer handle by calling mediamuxer_create() function.
/// @see mediamuxer_set_error_cb()
/// @see mediamuxer_unset_error_cb()
typedef mediamuxer_error_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when end of stream occurs in media muxer.
/// @since_tizen 4.0
/// @param[in] user_data    The user data passed from the code where
/// mediamuxer_set_eos_cb() was invoked;\n
/// this data will be accessible from mediamuxer_eos_cb()
/// @pre Create media muxer handle by calling mediamuxer_create() function.
/// @see mediamuxer_set_eos_cb()
/// @see mediamuxer_unset_eos_cb()
typedef mediamuxer_eos_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for media streamer node type.
///
/// @since_tizen 3.0
abstract class media_streamer_node_type_e {
  /// <  Not defined type
  static const int MEDIA_STREAMER_NODE_TYPE_NONE = 0;

  /// <  Src node type. Not available for media_streamer_node_create(). Use media_streamer_node_create_src()
  static const int MEDIA_STREAMER_NODE_TYPE_SRC = 1;

  /// <  Sink node type. Not available for media_streamer_node_create(). Use media_streamer_node_create_sink()
  static const int MEDIA_STREAMER_NODE_TYPE_SINK = 2;

  /// <  Video encoder node type
  static const int MEDIA_STREAMER_NODE_TYPE_VIDEO_ENCODER = 3;

  /// <  Video decoder node type
  static const int MEDIA_STREAMER_NODE_TYPE_VIDEO_DECODER = 4;

  /// <  Audio encoder node type
  static const int MEDIA_STREAMER_NODE_TYPE_AUDIO_ENCODER = 5;

  /// <  Audio decoder node type
  static const int MEDIA_STREAMER_NODE_TYPE_AUDIO_DECODER = 6;

  /// <  Video converter node type
  static const int MEDIA_STREAMER_NODE_TYPE_VIDEO_CONVERTER = 7;

  /// <  Audio converter node type
  static const int MEDIA_STREAMER_NODE_TYPE_AUDIO_CONVERTER = 8;

  /// <  Audio resample node type
  static const int MEDIA_STREAMER_NODE_TYPE_AUDIO_RESAMPLE = 9;

  /// <  Rtp video payloader
  static const int MEDIA_STREAMER_NODE_TYPE_VIDEO_PAY = 10;

  /// <  Rtp audio payloader
  static const int MEDIA_STREAMER_NODE_TYPE_AUDIO_PAY = 11;

  /// <  Rtp video depayloader
  static const int MEDIA_STREAMER_NODE_TYPE_VIDEO_DEPAY = 12;

  /// <  Rtp audio depayloader
  static const int MEDIA_STREAMER_NODE_TYPE_AUDIO_DEPAY = 13;

  /// <  Rate node type
  static const int MEDIA_STREAMER_NODE_TYPE_VIDEO_RATE = 14;

  /// <  Scale node type
  static const int MEDIA_STREAMER_NODE_TYPE_VIDEO_SCALE = 15;

  /// <  Overlay node type
  static const int MEDIA_STREAMER_NODE_TYPE_TEXT_OVERLAY = 16;

  /// <  Parser node type
  static const int MEDIA_STREAMER_NODE_TYPE_PARSER = 17;

  /// <  Filter node type, to limit formats of data
  static const int MEDIA_STREAMER_NODE_TYPE_FILTER = 18;

  /// <  Tee node type, splits data to multiple path
  static const int MEDIA_STREAMER_NODE_TYPE_TEE = 19;

  /// <  Queue node type
  static const int MEDIA_STREAMER_NODE_TYPE_QUEUE = 20;

  /// <  Multiple data queue node type
  static const int MEDIA_STREAMER_NODE_TYPE_MQUEUE = 21;

  /// <  Muxer node type
  static const int MEDIA_STREAMER_NODE_TYPE_MUXER = 22;

  /// <  Demuxer node type
  static const int MEDIA_STREAMER_NODE_TYPE_DEMUXER = 23;

  /// <  Rtp component to send and receive data
  static const int MEDIA_STREAMER_NODE_TYPE_RTP = 24;

  /// <  N-to-1 input stream selector
  static const int MEDIA_STREAMER_NODE_TYPE_INPUT_SELECTOR = 25;

  /// <  1-to-N output stream selector
  static const int MEDIA_STREAMER_NODE_TYPE_OUTPUT_SELECTOR = 26;

  /// <  Folds many mono channel into one interleaved audio stream
  static const int MEDIA_STREAMER_NODE_TYPE_INTERLEAVE = 27;

  /// <  Splits multi channel audio into many mono audio
  static const int MEDIA_STREAMER_NODE_TYPE_DEINTERLEAVE = 28;
}

/// @brief Enumeration for media streamer source node type.
///
/// @since_tizen 3.0
abstract class media_streamer_node_src_type_e {
  /// <  Not defined src type
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_NONE = 0;

  /// <  Local file src type
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_FILE = 1;

  /// <  Http src type, Network internet feature is required
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_HTTP = 2;

  /// <  Rtsp src type, Network internet feature is required
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_RTSP = 3;

  /// <  Camera src type, Camera feature is required
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_CAMERA = 4;

  /// <  Audio capture src type, Microphone feature is required
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_AUDIO_CAPTURE = 5;

  /// <  Video capture src type, Camera feature is required
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_VIDEO_CAPTURE = 6;

  /// <  Audio test src type
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_AUDIO_TEST = 7;

  /// <  Video test src type
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_VIDEO_TEST = 8;

  /// <  Custom src type
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_CUSTOM = 9;

  /// <  Adaptive src type, Network internet feature is required
  static const int MEDIA_STREAMER_NODE_SRC_TYPE_ADAPTIVE = 10;
}

/// @brief Enumeration for media streamer sink node type.
///
/// @since_tizen 3.0
abstract class media_streamer_node_sink_type_e {
  /// <  Not defined sink type
  static const int MEDIA_STREAMER_NODE_SINK_TYPE_NONE = 0;

  /// <  Local file sink type
  static const int MEDIA_STREAMER_NODE_SINK_TYPE_FILE = 1;

  /// <  Rtsp sink type, Network internet feature is required
  static const int MEDIA_STREAMER_NODE_SINK_TYPE_RTSP = 2;

  /// <  Http sink type, Network internet feature is required
  static const int MEDIA_STREAMER_NODE_SINK_TYPE_HTTP = 3;

  /// <  Audio sink type
  static const int MEDIA_STREAMER_NODE_SINK_TYPE_AUDIO = 4;

  /// <  Overlay sink type
  static const int MEDIA_STREAMER_NODE_SINK_TYPE_OVERLAY = 5;

  /// <  Fake sink type
  static const int MEDIA_STREAMER_NODE_SINK_TYPE_FAKE = 6;

  /// <  Custom sink type
  static const int MEDIA_STREAMER_NODE_SINK_TYPE_CUSTOM = 7;

  /// <  Adaptive sink type to generate fragmented files
  static const int MEDIA_STREAMER_NODE_SINK_TYPE_ADAPTIVE = 8;
}

/// @brief Enumeration for media streamer state.
///
/// @since_tizen 3.0
abstract class media_streamer_state_e {
  /// <  Streamer is not created
  static const int MEDIA_STREAMER_STATE_NONE = 0;

  /// <  Streamer is created but not prepared
  static const int MEDIA_STREAMER_STATE_IDLE = 1;

  /// <  Streamer is ready to play
  static const int MEDIA_STREAMER_STATE_READY = 2;

  /// <  Streamer is playing
  static const int MEDIA_STREAMER_STATE_PLAYING = 3;

  /// <  Streamer is paused
  static const int MEDIA_STREAMER_STATE_PAUSED = 4;

  /// <  Seek is under operation
  static const int MEDIA_STREAMER_STATE_SEEKING = 5;
}

/// @brief Enumeration for media streamer error.
///
/// @since_tizen 3.0
abstract class media_streamer_error_e {
  /// < Successful
  static const int MEDIA_STREAMER_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int MEDIA_STREAMER_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid operation
  static const int MEDIA_STREAMER_ERROR_INVALID_OPERATION = -38;

  /// < No space left on the device
  static const int MEDIA_STREAMER_ERROR_FILE_NO_SPACE_ON_DEVICE = -28;

  /// < The feature is not supported
  static const int MEDIA_STREAMER_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Permission denied
  static const int MEDIA_STREAMER_ERROR_PERMISSION_DENIED = -13;

  /// < Invalid state
  static const int MEDIA_STREAMER_ERROR_INVALID_STATE = -27262975;

  /// < Connection failed
  static const int MEDIA_STREAMER_ERROR_CONNECTION_FAILED = -27262974;

  /// < Resource conflict
  static const int MEDIA_STREAMER_ERROR_RESOURCE_CONFLICT = -27262973;

  /// < Seek operation failure
  static const int MEDIA_STREAMER_ERROR_SEEK_FAILED = -27262972;
}

/// @brief Enumeration of media streamer buffer status of custom src
///
/// @since_tizen 3.0
abstract class media_streamer_custom_buffer_status_e {
  /// < Buffer underrun of custom src
  static const int MEDIA_STREAMER_CUSTOM_BUFFER_UNDERRUN = 0;

  /// < Buffer overflow of custom src
  static const int MEDIA_STREAMER_CUSTOM_BUFFER_OVERFLOW = 1;
}

/// @brief Enumeration for media streamer's interruption type.
///
/// @since_tizen 3.0
abstract class media_streamer_interrupted_code_e {
  /// < Interrupted by a resource conflict
  static const int MEDIA_STREAMER_INTERRUPTED_BY_RESOURCE_CONFLICT = 0;

  /// < Interrupted by a security policy
  static const int MEDIA_STREAMER_INTERRUPTED_BY_SECURITY = 1;
}

/// @brief Media Streamer handle type.
///
/// @since_tizen 3.0
typedef media_streamer_h = ffi.Pointer<ffi.Void>;

/// @brief Called when error occurs in media streamer.
/// @details Following error codes can be delivered.
/// #MEDIA_STREAMER_ERROR_INVALID_OPERATION,
/// #MEDIA_STREAMER_ERROR_FILE_NO_SPACE_ON_DEVICE,
/// #MEDIA_STREAMER_ERROR_NOT_SUPPORTED,
/// #MEDIA_STREAMER_ERROR_CONNECTION_FAILED,
/// #MEDIA_STREAMER_ERROR_RESOURCE_CONFLICT
/// @since_tizen 3.0
/// @param [in] streamer    Media streamer handle
/// @param [in] error       The error that occurred in media steamer
/// @param [in] user_data   The user data passed from the code where
/// media_streamer_set_error_cb() was invoked
/// This data will be accessible from @a media_streamer_error_cb
/// @pre Create media streamer handle by calling media_streamer_create() function
/// @see media_streamer_set_error_cb()
/// @see media_streamer_unset_error_cb()
typedef media_streamer_error_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(media_streamer_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when media streamer state is changed.
/// @since_tizen 3.0
/// @param [in] streamer            Media streamer handle
/// @param [in] previous_state      The previous state of the media streamer
/// @param [in] current_state       The current state of media streamer
/// @param [in] user_data           The user data passed from the code where
/// media_streamer_set_state_changed_cb() was invoked
/// This data will be accessible from @a media_streamer_state_changed_cb
/// @pre Create media streamer handle by calling media_streamer_create() function
/// @see media_streamer_set_state_change_cb()
/// @see media_streamer_unset_state_change_cb()
typedef media_streamer_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            media_streamer_h, ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the media streamer is interrupted.
/// @since_tizen 3.0
/// @param[in]	error_code	The interrupted error code
/// @param[in]	user_data	The user data passed from the callback registration function
/// @see media_streamer_set_interrupted_cb()
/// @see media_streamer_unset_interrupted_cb()
typedef media_streamer_interrupted_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Media Streamer node handle type.
///
/// @since_tizen 3.0
typedef media_streamer_node_h = ffi.Pointer<ffi.Void>;

/// @brief Called when the custom source needs more data or has enough data.
/// @details This callback will be invoked when the buffer level drops below the threshold of max size
/// or no free space in custom source buffer.
/// @since_tizen 3.0
/// @remarks Callback can be applied only for MEDIA_STREAMER_NODE_SRC_TYPE_CUSTOM source type
/// @param [in] node      Media streamer source node handle
/// @param [in] user_data The user data passed from the callback registration function
/// @see media_streamer_src_set_buffer_status_cb()
/// @see media_streamer_node_get_param()
/// @see media_streamer_node_set_param()
typedef media_streamer_custom_buffer_status_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            media_streamer_node_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when new data is available from custom sink.
/// @details This callback can be applied only to MEDIA_STREAMER_NODE_SINK_TYPE_CUSTOM sink type
/// @since_tizen 3.0
/// @param [in] node      Media streamer sink node handle
/// @param [in] user_data The user data passed from the code where
/// media_streamer_sink_set_data_ready_cb() was invoked
/// This data will be accessible from @a media_streamer_sink_data_ready_cb
/// @pre media_streamer_sink_set_data_ready_cb()
/// @see MEDIA_STREAMER_NODE_SINK_TYPE_CUSTOM
/// @see media_streamer_sink_set_data_ready_cb()
/// @see media_streamer_sink_unset_data_ready_cb()
typedef media_streamer_sink_data_ready_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(media_streamer_node_h, ffi.Pointer<ffi.Void>)>>;

/// @brief  Called when the end-of-stream has been reached.
/// @details This callback can be applied only to MEDIA_STREAMER_NODE_SINK_TYPE_CUSTOM sink type
/// @since_tizen 3.0
/// @param [in] node      Media streamer sink node handle
/// @param [in] user_data The user data passed from the code where
/// media_streamer_sink_set_eos_cb() was invoked
/// This data will be accessible from @a media_streamer_sink_eos_cb
/// @pre media_streamer_sink_set_eos_cb()
/// @see MEDIA_STREAMER_NODE_SINK_TYPE_CUSTOM
/// @see media_streamer_sink_set_eos_cb()
/// @see media_streamer_sink_unset_eos_cb()
typedef media_streamer_sink_eos_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(media_streamer_node_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the seek operation is completed.
/// @since_tizen 3.0
/// @param[in] user_data     The user data passed from the callback registration function
/// @see media_streamer_set_play_position()
typedef media_streamer_position_changed_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Point in 2D space.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
class mv_point_s extends ffi.Struct {
  /// < X-axis coordinate of the point in 2D space
  @ffi.Int()
  external int x;

  /// < Y-axis coordinate of the point in 2D space
  @ffi.Int()
  external int y;
}

/// @brief Location of the object bounded by quadrangle defined by four 2D points.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
class mv_quadrangle_s extends ffi.Struct {
  @ffi.Array.multi([4])
  external ffi.Array<mv_point_s> points;
}

/// @brief Location of the object bounded by rectangle defined by
/// coordinates of top left corner, width and height.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
class mv_rectangle_s extends ffi.Struct {
  /// < Top left corner of rectangle coordinates
  external mv_point_s point;

  /// < Width of the bounding rectangle
  @ffi.Int()
  external int width;

  /// < Height of the bounding rectangle
  @ffi.Int()
  external int height;
}

/// @brief Enumeration for Media Vision error.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class mv_error_e {
  static const int MEDIA_VISION_ERROR_NONE = 0;
  static const int MEDIA_VISION_ERROR_NOT_SUPPORTED = -1073741822;
  static const int MEDIA_VISION_ERROR_MSG_TOO_LONG = -90;
  static const int MEDIA_VISION_ERROR_NO_DATA = -61;
  static const int MEDIA_VISION_ERROR_KEY_NOT_AVAILABLE = -126;
  static const int MEDIA_VISION_ERROR_OUT_OF_MEMORY = -12;
  static const int MEDIA_VISION_ERROR_INVALID_PARAMETER = -22;
  static const int MEDIA_VISION_ERROR_INVALID_OPERATION = -38;
  static const int MEDIA_VISION_ERROR_PERMISSION_DENIED = -1;
  static const int MEDIA_VISION_ERROR_NOT_SUPPORTED_FORMAT = -27066367;
  static const int MEDIA_VISION_ERROR_INTERNAL = -27066366;
  static const int MEDIA_VISION_ERROR_INVALID_DATA = -27066365;
  static const int MEDIA_VISION_ERROR_INVALID_PATH = -27066364;
}

/// @brief Enumeration for Media Vision @ref mv_engine_config_h handle attribute
/// type.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class mv_config_attribute_type_e {
  /// < Double attribute type
  static const int MV_ENGINE_CONFIG_ATTR_TYPE_DOUBLE = 0;

  /// < Integer attribute type
  static const int MV_ENGINE_CONFIG_ATTR_TYPE_INTEGER = 1;

  /// < Boolean attribute type
  static const int MV_ENGINE_CONFIG_ATTR_TYPE_BOOLEAN = 2;

  /// < String attribute type
  static const int MV_ENGINE_CONFIG_ATTR_TYPE_STRING = 3;
}

/// @brief Enumeration for Media Vision colorspace.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class mv_colorspace_e {
  /// < The colorspace type is invalid
  static const int MEDIA_VISION_COLORSPACE_INVALID = 0;

  /// < The colorspace type is Y800
  static const int MEDIA_VISION_COLORSPACE_Y800 = 1;

  /// < The colorspace type is I420
  static const int MEDIA_VISION_COLORSPACE_I420 = 2;

  /// < The colorspace type is NV12
  static const int MEDIA_VISION_COLORSPACE_NV12 = 3;

  /// < The colorspace type is YV12
  static const int MEDIA_VISION_COLORSPACE_YV12 = 4;

  /// < The colorspace type is NV21
  static const int MEDIA_VISION_COLORSPACE_NV21 = 5;

  /// < The colorspace type is YUYV
  static const int MEDIA_VISION_COLORSPACE_YUYV = 6;

  /// < The colorspace type is UYVY
  static const int MEDIA_VISION_COLORSPACE_UYVY = 7;

  /// < The colorspace type is 422P
  static const int MEDIA_VISION_COLORSPACE_422P = 8;

  /// < The colorspace type is RGB565
  static const int MEDIA_VISION_COLORSPACE_RGB565 = 9;

  /// < The colorspace type is RGB888
  static const int MEDIA_VISION_COLORSPACE_RGB888 = 10;

  /// < The colorspace type is RGBA
  static const int MEDIA_VISION_COLORSPACE_RGBA = 11;
}

/// @brief The handle to the source.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
typedef mv_source_h = ffi.Pointer<ffi.Void>;

/// @brief The handle to the Media Vision API engine algorithms configuration.
/// @details Configuration is a dictionary consists of key and value pairs to
/// collect engine-specific settings and allow Media Vision module to
/// access them internally. Engine configuration provides developer by
/// the possibility to make computer vision algorithms work better
/// in particular conditions of API usage. To create engine
/// configuration handle @ref mv_create_engine_config() function has to
/// be used. When configuration is not needed any more, it is required to
/// destroy it and release resources by @ref mv_destroy_engine_config()
/// function.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @see mv_create_engine_config()
/// @see mv_destroy_engine_config()
typedef mv_engine_config_h = ffi.Pointer<ffi.Void>;

/// @brief Called to get information (type and name) once for each supported
/// attribute.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
/// @param [in] attribute_type    The supported attribute type
/// @param [in] attribute_name    The supported attribute name
/// @param [in] user_data         The user data passed from the
/// @ref mv_engine_config_foreach_supported_attribute()
/// function
/// @return @c true to continue with the next iteration of the loop, \n
/// otherwise @c false to break out of the loop
///
/// @pre mv_engine_config_foreach_supported_attribute() will invoke this callback
/// @see mv_engine_config_foreach_supported_attribute()
typedef mv_supported_attribute_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            ffi.Int32, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for supported barcode types.
/// @details QR codes (versions 1 to 40) and set of 1D barcodes are supported
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class mv_barcode_type_e {
  /// < 2D barcode - Quick Response code
  static const int MV_BARCODE_QR = 0;

  /// < 1D barcode - Universal Product Code with 12-digit
  static const int MV_BARCODE_UPC_A = 1;

  /// < 1D barcode - Universal Product Code with 6-digit
  static const int MV_BARCODE_UPC_E = 2;

  /// < 1D barcode - International Article Number with 8-digit
  static const int MV_BARCODE_EAN_8 = 3;

  /// < 1D barcode - International Article Number with 13-digit
  static const int MV_BARCODE_EAN_13 = 4;

  /// < 1D barcode - Code 128
  static const int MV_BARCODE_CODE128 = 5;

  /// < 1D barcode - Code 39
  static const int MV_BARCODE_CODE39 = 6;

  /// < 1D barcode - Interleaved Two of Five
  static const int MV_BARCODE_I2_5 = 7;

  /// < Undefined
  static const int MV_BARCODE_UNDEFINED = 8;
}

/// @brief Enumeration for supported QR code error correction level.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
/// @remarks This is unavailable for 1D barcodes
abstract class mv_barcode_qr_ecc_e {
  /// < Recovery up to  7% losses
  static const int MV_BARCODE_QR_ECC_LOW = 0;

  /// < Recovery up to 15% losses
  static const int MV_BARCODE_QR_ECC_MEDIUM = 1;

  /// < Recovery up to 25% losses
  static const int MV_BARCODE_QR_ECC_QUARTILE = 2;

  /// < Recovery up to 30% losses
  static const int MV_BARCODE_QR_ECC_HIGH = 3;

  /// < Unavailable
  static const int MV_BARCODE_QR_ECC_UNAVAILABLE = 4;
}

/// @brief Enumeration for supported QR code encoding mode.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
/// @remarks This is unavailable for 1D barcodes
abstract class mv_barcode_qr_mode_e {
  /// < Numeric digits
  static const int MV_BARCODE_QR_MODE_NUMERIC = 0;

  /// < Alphanumeric characters
  static const int MV_BARCODE_QR_MODE_ALPHANUMERIC = 1;

  /// < Raw 8-bit bytes
  static const int MV_BARCODE_QR_MODE_BYTE = 2;

  /// < UTF-8 character encoding
  static const int MV_BARCODE_QR_MODE_UTF8 = 3;

  /// < Unavailable
  static const int MV_BARCODE_QR_MODE_UNAVAILABLE = 4;
}

/// @brief Enumeration for supported image formats for the barcode generating.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class mv_barcode_image_format_e {
  static const int MV_BARCODE_IMAGE_FORMAT_UNAVAILABLE = -1;

  /// < BMP image format
  static const int MV_BARCODE_IMAGE_FORMAT_BMP = 0;

  /// < JPEG image format
  static const int MV_BARCODE_IMAGE_FORMAT_JPG = 1;

  /// < PNG image format
  static const int MV_BARCODE_IMAGE_FORMAT_PNG = 2;

  /// < The number of supported image format
  static const int MV_BARCODE_IMAGE_FORMAT_NUM = 3;
}

/// @brief Enumeration to target attribute
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class mv_barcode_detect_attr_target_e {
  /// < 1D and 2D
  static const int MV_BARCODE_DETECT_ATTR_TARGET_ALL = 0;

  /// < 1D barcode only
  static const int MV_BARCODE_DETECT_ATTR_TARGET_1D_BARCODE = 1;

  /// < 2D barcode only
  static const int MV_BARCODE_DETECT_ATTR_TARGET_2D_BARCODE = 2;
}

/// @brief Called when barcode detection is completed.
/// @details If no barcode is detected then the method will be called, barcodes
/// and states will be equal to NULL, and @a number_of_barcodes - 0.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
/// @param [in] source               The handle to the media source
/// @param [in] engine_cfg           The handle to the configuration of the engine
/// @param [in] barcode_locations    The quadrangle locations of detected barcodes
/// @param [in] messages             The decoded messages of barcodes
/// @param [in] types                The types of detected barcodes
/// @param [in] number_of_barcodes   The number of detected barcodes
/// @param [in] user_data            The user data passed from
/// the mv_barcode_detect() function
///
/// @pre mv_barcode_detect() invokes this callback
///
/// @see mv_barcode_detect()
typedef mv_barcode_detected_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            mv_source_h,
            mv_engine_config_h,
            ffi.Pointer<mv_quadrangle_s>,
            ffi.Pointer<ffi.Pointer<ffi.Char>>,
            ffi.Pointer<ffi.Int32>,
            ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration to text attribute
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class mv_barcode_generate_attr_text_e {
  /// < Invisible
  static const int MV_BARCODE_GENERATE_ATTR_TEXT_INVISIBLE = 0;

  /// < Visible
  static const int MV_BARCODE_GENERATE_ATTR_TEXT_VISIBLE = 1;
}

/// @brief Enumeration for eyes state type.
///
/// @since_tizen 3.0
///
/// @see mv_face_eye_condition_recognize()
abstract class mv_face_eye_condition_e {
  /// < Eyes are open
  static const int MV_FACE_EYES_OPEN = 0;

  /// < Eyes are closed
  static const int MV_FACE_EYES_CLOSED = 1;

  /// < The eyes condition wasn't determined
  static const int MV_FACE_EYES_NOT_FOUND = 2;
}

/// @brief Enumeration for expression types can be determined for faces.
///
/// @since_tizen 3.0
///
/// @see mv_face_facial_expression_recognize()
abstract class mv_face_facial_expression_e {
  /// < Unknown face expression
  static const int MV_FACE_UNKNOWN = 0;

  /// < Face expression is neutral
  static const int MV_FACE_NEUTRAL = 1;

  /// < Face expression is smiling
  static const int MV_FACE_SMILE = 2;

  /// < Face expression is sadness
  static const int MV_FACE_SADNESS = 3;

  /// < Face expression is surprise
  static const int MV_FACE_SURPRISE = 4;

  /// < Face expression is anger
  static const int MV_FACE_ANGER = 5;

  /// < Face expression is fear
  static const int MV_FACE_FEAR = 6;

  /// < Face expression is disgust
  static const int MV_FACE_DISGUST = 7;
}

/// @brief Called when faces are detected for the @a source.
/// @details This type callback can be invoked each time when
/// @ref mv_face_detect() is called to process the results of face
/// detecting.
///
/// @since_tizen 3.0
/// @remarks If no face is detected then the callback will be invoked, but
/// @a faces_locations array will be NULL, and @a number_of_faces will
/// be equal to 0.
/// @param [in] source             The handle to the source of the media where
/// faces were detected
/// @param [in] engine_cfg         The handle to the configuration of engine was
/// used for face detecting, or NULL if default
/// settings were applied
/// @param [in] faces_locations    Rectangular locations of detected faces
/// @param [in] number_of_faces    Number of detected faces
/// @param [in] user_data          The user data passed from callback invoking code
///
/// @pre Call @ref mv_face_detect() function to perform detection of the face for
/// the face image and invoke this callback as a result
///
/// @see mv_face_detect()
typedef mv_face_detected_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(mv_source_h, mv_engine_config_h,
            ffi.Pointer<mv_rectangle_s>, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief The handle to the model aggregating recognition face features.
/// @details This handle can be used for faces recognizing with
/// @ref mv_face_recognize() function. Handle has to be created by
/// @ref mv_face_recognition_model_create() and destroyed by
/// @ref mv_face_recognition_model_destroy() functions. To use
/// recognition models effectively learning process has to be performed
/// before recognition. In other words, appropriate set of the face
/// image examples has to be collected with
/// @ref mv_face_recognition_model_add() function before
/// @ref mv_face_recognition_model_learn() function call, then
/// recognition can be performed with @ref mv_face_recognize().
///
/// @since_tizen 3.0
///
/// @see mv_face_recognition_model_create()
/// @see mv_face_recognition_model_destroy()
/// @see mv_face_recognition_model_learn()
typedef mv_face_recognition_model_h = ffi.Pointer<ffi.Void>;

/// @brief Called each time when face is recognized by @ref mv_face_recognize()
/// function.
///
/// @since_tizen 3.0
/// @param [in] source              The handle to the image source for which
/// face has been recognized/not recognized
/// @param [in] recognition_model   The handle to the recognition model has been
/// used for recognition
/// @param [in] engine_cfg          The handle to the configuration of engine was
/// used for recognition, or NULL if default
/// settings were applied
/// @param [in] face_location       The pointer to the location of the face
/// recognized on @a source. If face wasn't
/// recognized, then pointer is NULL
/// @param [in] face_label          The label that identifies face which was
/// recognized in the @a source. NULL if
/// recognition was performed, but no faces
/// were recognized in the @a source
/// @param [in] confidence          The confidence of the @a recognition_model
/// that face has been recognized correctly
/// (value from 0.0 to 1.0). No faces were
/// recognized if @a confidence was 0.0.
/// When model has been learned on large amount
/// of examples, threshold for this value
/// can be high (0.85-0.95). If model
/// was learned for small amount of examples,
/// then threshold can be reduced (0.5-0.85)
/// @param [in] user_data           The user data passed from callback invoking
/// code
///
/// @pre Call @ref mv_face_recognize() function to perform recognition of the
/// face for the face image and invoke this callback as a result
///
/// @see mv_face_recognize()
typedef mv_face_recognized_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            mv_source_h,
            mv_face_recognition_model_h,
            mv_engine_config_h,
            ffi.Pointer<mv_rectangle_s>,
            ffi.Pointer<ffi.Int>,
            ffi.Double,
            ffi.Pointer<ffi.Void>)>>;

/// @brief The handle to the model aggregating tracking face features.
/// @details This model can be used for face tracking with @ref mv_face_track()
/// function. Handle has to be created by
/// @ref mv_face_tracking_model_create() and destroyed by
/// @ref mv_face_tracking_model_destroy() function. Tracking model can
/// be improved during tracking task and allows to track face more
/// accurately. So, you can create several tracking models independently
/// by default, then apply tracking task for each of them. After some
/// tracking these models will be different and each of them will be
/// more efficient for tracking of face for which was created.
///
/// @since_tizen 3.0
/// @remarks Create each tracking model for single face.
///
/// @see mv_face_tracking_model_create()
/// @see mv_face_tracking_model_destroy()
typedef mv_face_tracking_model_h = ffi.Pointer<ffi.Void>;

/// @brief Called when face determined by @a tracking_model is tracked.
/// @details This type callback can be invoked each time when
/// @ref mv_face_track() is called to process the results of face
/// tracking.
///
/// @since_tizen 3.0
/// @param [in] source           The handle to the video frame or image from
/// sequence for which face was tracked
/// @param [in] tracking_model   The handle to the model that was used for
/// tracking
/// @param [in] engine_cfg       The handle to the configuration of engine was
/// used for tracking, or NULL if default settings
/// were applied.
/// @param [in] location         The pointer to the quadrangle-shaped location
/// which determines new position of the tracked
/// face on the @a source. If NULL, then face was
/// lost by tracking algorithm during last iteration
/// @param [in] confidence       The confidence of the @a tracking_model
/// that new location of the face was determined
/// correctly (value from 0.0 to 1.0).
/// If no location was determined during last track
/// iteration, then value is 0.0
/// @param [in] user_data        The user data passed from callback invoking code
///
/// @pre Call @ref mv_face_track() function to perform track iteration for
/// the video frame or the image from sequence and invoke this callback as
/// a result
///
/// @see mv_face_track()
typedef mv_face_tracked_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            mv_source_h,
            mv_face_tracking_model_h,
            mv_engine_config_h,
            ffi.Pointer<mv_quadrangle_s>,
            ffi.Double,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when eye blink condition is recognized.
/// @details This type callback can be invoked each time when
/// mv_face_eye_condition_recognize() is called for @a face_location to
/// recognize eye-blink condition for the face at the @a source.\n
/// Usage example for this callback can be found in
/// mv_face_eye_condition_recognize() documentation.
///
/// @since_tizen 3.0
/// @param [in] source           The handle to the source of the media for which
/// eye-blink condition was recognized
/// @param [in] engine_cfg       The handle to the configuration of engine was
/// used for eye-blink condition recognition, or
/// NULL if default settings were applied.
/// @param [in] face_location    The location bounding the face at the @a source
/// @param [in] eye_condition    The type of eye-blink condition recognized for
/// face bounded by @a face_location
/// @param [in] user_data        The user data passed from callback invoking code
///
///
/// @pre Call @ref mv_face_eye_condition_recognize() function to perform
/// eye-blink condition recognition and invoke this callback as a result
///
/// @see mv_face_eye_condition_recognize()
typedef mv_face_eye_condition_recognized_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(mv_source_h, mv_engine_config_h, mv_rectangle_s,
            ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when facial expression is recognized
/// @details This type callback can be invoked each time when
/// mv_face_facial_expression_recognize() is called for @a face_location to
/// recognize facial expression for the face at the @a source.\n
/// Usage example for this callback can be found in
/// mv_face_facial_expression_recognize() documentation.
///
/// @since_tizen 3.0
/// @param [in] source               The handle to the source of the media for
/// which facial expression was recognized
/// @param [in] engine_cfg           The handle to the configuration of engine was
/// used for expression recognition
/// @param [in] face_location        The location bounding the face at the @a source
/// @param [in] facial_expression    The type of facial expression recognized
/// for face bounded by @a face_location
/// @param [in] user_data            The user data passed from callback invoking code
///
/// @pre Create a source handle by calling mv_create_source()
/// @pre Create a face engine configuration handle by calling mv_create_engine_config()
///
/// @see mv_face_facial_expression_recognize()
typedef mv_face_facial_expression_recognized_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(mv_source_h, mv_engine_config_h, mv_rectangle_s,
            ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief The image object's type handle.
///
/// @since_tizen 3.0
typedef mv_image_object_h = ffi.Pointer<ffi.Void>;

/// @brief Called when image recognition results are received from @ref mv_image_recognize()
/// @details This type of callback will be called after @ref mv_image_recognize()
/// in order to process recognition result.
///
/// @since_tizen 3.0
/// @remarks Values @a source, @a engine_cfg, @a image_objects, and @a number_of_objects
/// are the same as values of input parameters of @ref mv_image_recognize().
/// @remarks @a locations are valid only inside callback.
/// @param [in] source              The handle to the source image on which the
/// recognition was carried out
/// @param [in] engine_cfg          The handle to the configuration of engine
/// that was used for image recognition, or NULL
/// if default settings were applied
/// @param [in] image_objects       The set of handles to the image objects which
/// have been processed as targets of recognition
/// @param [in] locations           The locations of image objects on the source
/// image. This array corresponding to an array
/// of image objects and each element contains a
/// location of corresponding object on the
/// @a source image or NULL if object is not
/// recognized
/// @param [in] number_of_objects   The number of image objects and corresponding
/// locations
/// @param [in] user_data           The user data passed from the
/// @ref mv_image_recognize() function
///
/// @pre Call @ref mv_image_recognize() function to perform recognition of the
/// image objects on the source image and invoke this callback as a result
///
/// @see mv_image_recognize()
/// @see mv_source_h
/// @see mv_image_object_h
/// @see mv_engine_config_h
/// @see mv_quadrangle_s
typedef mv_image_recognized_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            mv_source_h,
            mv_engine_config_h,
            ffi.Pointer<mv_image_object_h>,
            ffi.Pointer<ffi.Pointer<mv_quadrangle_s>>,
            ffi.UnsignedInt,
            ffi.Pointer<ffi.Void>)>>;

/// @brief The image tracking model's type handle.
///
/// @since_tizen 3.0
typedef mv_image_tracking_model_h = ffi.Pointer<ffi.Void>;

/// @brief Called when image tracking result received from @ref mv_image_track()
/// @details Image tracking on a sequence of frames assumes calling
/// @ref mv_image_track() function for each frame in the correct order.
/// This type of callback will be called after each @ref mv_image_track()
/// call for processing result data.
///
/// @since_tizen 3.0
/// @remarks If image object is not tracked then the callback will be invoked,
/// but @a location will be NULL.
/// @remarks Handles @a image_tracking_model, @a source and @a engine_cfg the
/// same as input parameters of @ref mv_image_track().
/// @remarks @a location pointer is valid only inside callback
/// @param [in] source                 The handle to the source image on which
/// the tracking was carried out
/// @param [in] image_tracking_model   The handle to the image tracking model
/// which processed as target of tracking
/// @param [in] engine_cfg             The handle to the configuration of engine
/// that was used to image tracking, or
/// NULL if default settings were applied
/// @param [in] location               The image object location on the source
/// image or NULL if objects is not tracked
/// @param [in] user_data              The user data passed from the
/// @ref mv_image_track() function
///
/// @pre Call @ref mv_image_track() function to perform tracking of the image
/// object on the current image from the sequence and invoke this callback
/// as a result
///
/// @see mv_image_track()
/// @see mv_source_h
/// @see image_tracking_model_h
/// @see mv_engine_config_h
/// @see mv_quadrangle_s
typedef mv_image_tracked_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            mv_source_h,
            mv_image_tracking_model_h,
            mv_engine_config_h,
            ffi.Pointer<mv_quadrangle_s>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief The handle to event trigger.
///
/// @since_tizen 3.0
/// @remarks See supported event types and their descriptions in
/// @ref CAPI_MEDIA_VISION_SURVEILLANCE_EVENT_TYPES documentation
/// section.
/// Also the list of supported events can be obtained using
/// @ref mv_surveillance_foreach_supported_event_type() function
typedef mv_surveillance_event_trigger_h = ffi.Pointer<ffi.Void>;

/// @brief Called when event trigger activation has been detected.
///
/// @since_tizen 3.0
/// @remarks Handle @a event_result is valid only inside callback
/// @param [in] trigger            The event trigger handle
/// @param [in] source             The handle to the media source
/// @param [in] video_stream_id    The identifier of the video source where event
/// has been detected
/// @param [in] event_result       The event result passed from the
/// @ref mv_surveillance_subscribe_event_trigger()
/// @param [in] user_data          The user data passed from the
/// @ref mv_surveillance_subscribe_event_trigger()
/// function
///
/// @pre Callback can be invoked only after
/// @ref mv_surveillance_subscribe_event_trigger()
/// was called for particular event trigger.
///
/// @see mv_surveillance_subscribe_event_trigger()
/// @see mv_surveillance_unsubscribe_event_trigger()
typedef mv_surveillance_event_occurred_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(mv_surveillance_event_trigger_h, mv_source_h, ffi.Int,
            mv_surveillance_result_h, ffi.Pointer<ffi.Void>)>>;

/// @brief The handle to event trigger activation result.
/// @details Result is a handle to the output values which are specific for each event.
/// See the output values names in the event types descriptions located
/// in @ref CAPI_MEDIA_VISION_SURVEILLANCE_EVENT_TYPES documentation
/// section.
/// Result values can be gotten by @ref mv_surveillance_get_result_value()
/// function one by one in order specified in the event description (
/// the same order of event value names is supported by
/// @ref mv_surveillance_foreach_event_result_name() function).
/// This pointer will be destroyed when
/// @ref mv_surveillance_event_occurred_cb passed.
///
/// @since_tizen 3.0
typedef mv_surveillance_result_h = ffi.Pointer<ffi.Void>;

/// @brief Called to get the information once for each supported event type.
///
/// @since_tizen 3.0
/// @remarks Don't release memory of @a event_type
/// @param [in] event_type    Character string containing name of the event type
/// @param [in] user_data     The user data passed from the
/// @ref mv_surveillance_foreach_supported_event_type()
/// function
/// @return @c true to continue with the next iteration of the loop, \n
/// otherwise @c false to break out of the loop
///
/// @pre mv_surveillance_foreach_supported_event_type() will invoke this callback
/// @see mv_surveillance_foreach_supported_event_type()
typedef mv_surveillance_event_type_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get the result name from the triggered event.
///
/// @since_tizen 3.0
/// @remarks Don't release memory of @a value_name
/// @param [in] name         Character string containing the name of value that
/// can be obtained from @ref mv_surveillance_result_h
/// handle by @ref mv_surveillance_get_result_value()
/// function
/// @param [in] user_data    The user data passed from the
/// @ref mv_surveillance_foreach_event_result_name()
/// function
/// @return @c true to continue with the next iteration of the loop, \n
/// otherwise @c false to break out of the loop
///
/// @pre mv_surveillance_foreach_event_result_name() will invoke this
/// callback
/// @see mv_surveillance_foreach_event_result_name()
typedef mv_surveillance_event_result_name_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_MEDIA_METADATA_EDITOR_MODULE
/// @brief The enumerations of media metadata error
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class metadata_editor_error_e {
  /// < Successful
  static const int METADATA_EDITOR_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int METADATA_EDITOR_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int METADATA_EDITOR_ERROR_OUT_OF_MEMORY = -12;

  /// < File not exist
  static const int METADATA_EDITOR_ERROR_FILE_EXISTS = -17;

  /// < Permission denied
  static const int METADATA_EDITOR_ERROR_PERMISSION_DENIED = -13;

  /// < Unsupported type
  static const int METADATA_EDITOR_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Invalid internal operation
  static const int METADATA_EDITOR_ERROR_OPERATION_FAILED = -27000831;
}

/// @ingroup CAPI_MEDIA_METADATA_EDITOR_MODULE
/// @brief The enumerations of attribute
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class metadata_editor_attr_e {
  /// < Artist
  static const int METADATA_EDITOR_ATTR_ARTIST = 0;

  /// < Title
  static const int METADATA_EDITOR_ATTR_TITLE = 1;

  /// < Album
  static const int METADATA_EDITOR_ATTR_ALBUM = 2;

  /// < Genre
  static const int METADATA_EDITOR_ATTR_GENRE = 3;

  /// < Author
  static const int METADATA_EDITOR_ATTR_AUTHOR = 4;

  /// < Copyright
  static const int METADATA_EDITOR_ATTR_COPYRIGHT = 5;

  /// < Date
  static const int METADATA_EDITOR_ATTR_DATE = 6;

  /// < Description
  static const int METADATA_EDITOR_ATTR_DESCRIPTION = 7;

  /// < Comment
  static const int METADATA_EDITOR_ATTR_COMMENT = 8;

  /// < Track number info
  static const int METADATA_EDITOR_ATTR_TRACK_NUM = 9;

  /// < Picture number
  static const int METADATA_EDITOR_ATTR_PICTURE_NUM = 10;

  /// < Conductor
  static const int METADATA_EDITOR_ATTR_CONDUCTOR = 11;

  /// < Unsynchronized lyric
  static const int METADATA_EDITOR_ATTR_UNSYNCLYRICS = 12;
}

/// @ingroup CAPI_MEDIA_METADATA_EDITOR_MODULE
/// @brief The handle of media metadata
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef metadata_editor_h = ffi.Pointer<ffi.Void>;

/// @ingroup CAPI_METADATA_EXTRACTOR_MODULE
/// @brief Enumeration for metadata extractor error.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class metadata_extractor_error_e {
  /// < Successful
  static const int METADATA_EXTRACTOR_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int METADATA_EXTRACTOR_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int METADATA_EXTRACTOR_ERROR_OUT_OF_MEMORY = -12;

  /// < File does not exist
  static const int METADATA_EXTRACTOR_ERROR_FILE_EXISTS = -17;

  /// < Permission denied
  static const int METADATA_EXTRACTOR_ERROR_PERMISSION_DENIED = -13;

  /// < Invalid internal operation
  static const int METADATA_EXTRACTOR_ERROR_OPERATION_FAILED = -26411007;
}

/// @ingroup CAPI_METADATA_EXTRACTOR_MODULE
/// @brief Enumeration for attribute.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class metadata_extractor_attr_e {
  /// < Duration
  static const int METADATA_DURATION = 0;

  /// < Video Bitrate
  static const int METADATA_VIDEO_BITRATE = 1;

  /// < Video FPS
  static const int METADATA_VIDEO_FPS = 2;

  /// < Video Width
  static const int METADATA_VIDEO_WIDTH = 3;

  /// < Video Height
  static const int METADATA_VIDEO_HEIGHT = 4;

  /// < Video stream count
  static const int METADATA_HAS_VIDEO = 5;

  /// < Audio Bitrate
  static const int METADATA_AUDIO_BITRATE = 6;

  /// < Audio Channels
  static const int METADATA_AUDIO_CHANNELS = 7;

  /// < Audio Samplerate
  static const int METADATA_AUDIO_SAMPLERATE = 8;

  /// < Audio bit per sample
  static const int METADATA_AUDIO_BITPERSAMPLE = 9;

  /// < Audio stream count
  static const int METADATA_HAS_AUDIO = 10;

  /// < Artist
  static const int METADATA_ARTIST = 11;

  /// < Title
  static const int METADATA_TITLE = 12;

  /// < Album
  static const int METADATA_ALBUM = 13;

  /// < Album_Artist
  static const int METADATA_ALBUM_ARTIST = 14;

  /// < Genre
  static const int METADATA_GENRE = 15;

  /// < Author (Deprecated since 4.0. Use METADATA_COMPOSER instead)
  static const int METADATA_AUTHOR = 16;

  /// < Composer
  static const int METADATA_COMPOSER = 16;

  /// < Copyright
  static const int METADATA_COPYRIGHT = 17;

  /// < Date
  static const int METADATA_DATE = 18;

  /// < Description
  static const int METADATA_DESCRIPTION = 19;

  /// < Comment
  static const int METADATA_COMMENT = 20;

  /// < Track number info
  static const int METADATA_TRACK_NUM = 21;

  /// < Classification
  static const int METADATA_CLASSIFICATION = 22;

  /// < Rating
  static const int METADATA_RATING = 23;

  /// < Longitude
  static const int METADATA_LONGITUDE = 24;

  /// < Latitude
  static const int METADATA_LATITUDE = 25;

  /// < Altitude
  static const int METADATA_ALTITUDE = 26;

  /// < Conductor
  static const int METADATA_CONDUCTOR = 27;

  /// < Unsynchronized lyric
  static const int METADATA_UNSYNCLYRICS = 28;

  /// < Synchronized lyric (time/lyric set) number
  static const int METADATA_SYNCLYRICS_NUM = 29;

  /// < Recording date
  static const int METADATA_RECDATE = 30;

  /// < Rotate(Orientation) Information
  static const int METADATA_ROTATE = 31;

  /// < Video Codec (Since 3.0)
  static const int METADATA_VIDEO_CODEC = 32;

  /// < Audio Codec (Since 3.0)
  static const int METADATA_AUDIO_CODEC = 33;

  /// < Flag indicating if the video is a spherical video (Since 3.0)
  static const int METADATA_360 = 34;
}

class metadata_extractor_s extends ffi.Opaque {}

/// @ingroup CAPI_METADATA_EXTRACTOR_MODULE
/// @brief The metadata extractor handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef metadata_extractor_h = ffi.Pointer<metadata_extractor_s>;

class player_s extends ffi.Opaque {}

/// @brief Enumeration for media player state.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class player_state_e {
  /// < Player is not created
  static const int PLAYER_STATE_NONE = 0;

  /// < Player is created, but not prepared
  static const int PLAYER_STATE_IDLE = 1;

  /// < Player is ready to play media
  static const int PLAYER_STATE_READY = 2;

  /// < Player is playing media
  static const int PLAYER_STATE_PLAYING = 3;

  /// < Player is paused while playing media
  static const int PLAYER_STATE_PAUSED = 4;
}

/// @brief Enumeration for media player's error codes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class player_error_e {
  /// < Successful
  static const int PLAYER_ERROR_NONE = 0;

  /// < Out of memory
  static const int PLAYER_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int PLAYER_ERROR_INVALID_PARAMETER = -22;

  /// < No such file or directory
  static const int PLAYER_ERROR_NO_SUCH_FILE = -2;

  /// < Invalid operation
  static const int PLAYER_ERROR_INVALID_OPERATION = -38;

  /// < No space left on the device
  static const int PLAYER_ERROR_FILE_NO_SPACE_ON_DEVICE = -28;

  /// < Not supported Feature
  static const int PLAYER_ERROR_FEATURE_NOT_SUPPORTED_ON_DEVICE = -1073741822;

  /// < Seek operation failure
  static const int PLAYER_ERROR_SEEK_FAILED = -26476511;

  /// < Invalid state
  static const int PLAYER_ERROR_INVALID_STATE = -26476510;

  /// < File format not supported
  static const int PLAYER_ERROR_NOT_SUPPORTED_FILE = -26476509;

  /// < Invalid URI
  static const int PLAYER_ERROR_INVALID_URI = -26476508;

  /// < Sound policy error
  static const int PLAYER_ERROR_SOUND_POLICY = -26476507;

  /// < Streaming connection failed
  static const int PLAYER_ERROR_CONNECTION_FAILED = -26476506;

  /// < Video capture failed
  static const int PLAYER_ERROR_VIDEO_CAPTURE_FAILED = -26476505;

  /// < Expired license
  static const int PLAYER_ERROR_DRM_EXPIRED = -26476504;

  /// < No license
  static const int PLAYER_ERROR_DRM_NO_LICENSE = -26476503;

  /// < License for future use
  static const int PLAYER_ERROR_DRM_FUTURE_USE = -26476502;

  /// < Format not permitted
  static const int PLAYER_ERROR_DRM_NOT_PERMITTED = -26476501;

  /// < Resource limit
  static const int PLAYER_ERROR_RESOURCE_LIMIT = -26476500;

  /// < Permission denied
  static const int PLAYER_ERROR_PERMISSION_DENIED = -13;

  /// < Socket connection lost (Since 3.0)
  static const int PLAYER_ERROR_SERVICE_DISCONNECTED = -26476499;

  /// < No buffer space available (Since 3.0)
  static const int PLAYER_ERROR_BUFFER_SPACE = -105;

  /// < Not supported audio codec but video can be played (Since 4.0)
  static const int PLAYER_ERROR_NOT_SUPPORTED_AUDIO_CODEC = -26476498;

  /// < Not supported video codec but audio can be played (Since 4.0)
  static const int PLAYER_ERROR_NOT_SUPPORTED_VIDEO_CODEC = -26476497;

  /// < Not supported subtitle format (Since 4.0)
  static const int PLAYER_ERROR_NOT_SUPPORTED_SUBTITLE = -26476496;
}

/// @brief Enumeration for media player's interruption type.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class player_interrupted_code_e {
  /// < Interrupt completed (Deprecated since 3.0)
  static const int PLAYER_INTERRUPTED_COMPLETED = 0;

  /// < Interrupted by a non-resumable media application (Deprecated since 3.0)
  static const int PLAYER_INTERRUPTED_BY_MEDIA = 1;

  /// < Interrupted by an incoming call (Deprecated since 3.0)
  static const int PLAYER_INTERRUPTED_BY_CALL = 2;

  /// < Interrupted by unplugging headphones (Deprecated since 3.0)
  static const int PLAYER_INTERRUPTED_BY_EARJACK_UNPLUG = 3;

  /// < Interrupted by a resource conflict and the player handle will be paused or unprepared
  static const int PLAYER_INTERRUPTED_BY_RESOURCE_CONFLICT = 4;

  /// < Interrupted by an alarm (Deprecated since 3.0)
  static const int PLAYER_INTERRUPTED_BY_ALARM = 5;

  /// < Interrupted by an emergency (Deprecated since 3.0)
  static const int PLAYER_INTERRUPTED_BY_EMERGENCY = 6;

  /// < Interrupted by a notification (Deprecated since 3.0)
  static const int PLAYER_INTERRUPTED_BY_NOTIFICATION = 7;
}

/// @brief Enumeration for progressive download message type.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class player_pd_message_type_e {
  /// < Progressive download is started
  static const int PLAYER_PD_STARTED = 0;

  /// < Progressive download is completed
  static const int PLAYER_PD_COMPLETED = 1;
}

/// @brief Enumeration for display type.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class player_display_type_e {
  /// < Overlay surface display
  static const int PLAYER_DISPLAY_TYPE_OVERLAY = 0;
  static const int PLAYER_DISPLAY_TYPE_OBSOLETE_EVAS_WNONE = 1;
  static const int PLAYER_DISPLAY_TYPE_OBSOLETE_NONE_WEVAS = 2;

  /// < Evas image object surface display (Since 4.0)
  static const int PLAYER_DISPLAY_TYPE_EVAS = 3;

  /// < This disposes of buffers (Since 4.0)
  static const int PLAYER_DISPLAY_TYPE_NONE = 4;
}

/// @brief Enumeration for audio latency mode.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class audio_latency_mode_e {
  /// < Low audio latency mode
  static const int AUDIO_LATENCY_MODE_LOW = 0;

  /// < Middle audio latency mode
  static const int AUDIO_LATENCY_MODE_MID = 1;

  /// < High audio latency mode
  static const int AUDIO_LATENCY_MODE_HIGH = 2;
}

/// @brief Enumeration for stream type.
/// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
abstract class player_stream_type_e {
  /// < Container type
  static const int PLAYER_STREAM_TYPE_DEFAULT = 0;

  /// < Audio element stream type
  static const int PLAYER_STREAM_TYPE_AUDIO = 1;

  /// < Video element stream type
  static const int PLAYER_STREAM_TYPE_VIDEO = 2;

  /// < Text type
  static const int PLAYER_STREAM_TYPE_TEXT = 3;
}

/// @brief Enumeration of media stream buffer status
/// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
abstract class player_media_stream_buffer_status_e {
  static const int PLAYER_MEDIA_STREAM_BUFFER_UNDERRUN = 0;
  static const int PLAYER_MEDIA_STREAM_BUFFER_OVERFLOW = 1;
}

/// @brief Enumeration for display rotation type.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class player_display_rotation_e {
  /// < Display is not rotated
  static const int PLAYER_DISPLAY_ROTATION_NONE = 0;

  /// < Display is rotated 90 degrees
  static const int PLAYER_DISPLAY_ROTATION_90 = 1;

  /// < Display is rotated 180 degrees
  static const int PLAYER_DISPLAY_ROTATION_180 = 2;

  /// < Display is rotated 270 degrees
  static const int PLAYER_DISPLAY_ROTATION_270 = 3;
}

/// @brief Enumeration for display mode.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class player_display_mode_e {
  /// < Letter box
  static const int PLAYER_DISPLAY_MODE_LETTER_BOX = 0;

  /// < Origin size
  static const int PLAYER_DISPLAY_MODE_ORIGIN_SIZE = 1;

  /// < Full-screen
  static const int PLAYER_DISPLAY_MODE_FULL_SCREEN = 2;

  /// < Cropped full-screen
  static const int PLAYER_DISPLAY_MODE_CROPPED_FULL = 3;

  /// < Origin size (if surface size is larger than video size(width/height)) or Letter box (if video size(width/height) is larger than surface size)
  static const int PLAYER_DISPLAY_MODE_ORIGIN_OR_LETTER = 4;

  /// < Dst ROI mode
  static const int PLAYER_DISPLAY_MODE_DST_ROI = 5;
  static const int PLAYER_DISPLAY_MODE_NUM = 6;
}

/// @brief Enumeration for media stream content information.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class player_content_info_e {
  /// < Album
  static const int PLAYER_CONTENT_INFO_ALBUM = 0;

  /// < Artist
  static const int PLAYER_CONTENT_INFO_ARTIST = 1;

  /// < Author
  static const int PLAYER_CONTENT_INFO_AUTHOR = 2;

  /// < Genre
  static const int PLAYER_CONTENT_INFO_GENRE = 3;

  /// < Title
  static const int PLAYER_CONTENT_INFO_TITLE = 4;

  /// < Year
  static const int PLAYER_CONTENT_INFO_YEAR = 5;
}

/// @brief The media player's type handle.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
typedef player_h = ffi.Pointer<player_s>;

/// @brief Called when the media player is prepared.
/// @details It will be invoked when player has reached the begin of stream.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
/// @param[in]   user_data  The user data passed from the callback registration function
/// @pre player_prepare_async() will cause this callback.
/// @post The player state will be #PLAYER_STATE_READY.
/// @see player_prepare_async()
typedef player_prepared_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the seek operation is completed.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
/// @param[in]   user_data  The user data passed from the callback registration function
/// @see player_set_play_position()
typedef player_seek_completed_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief The player display handle.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
typedef player_display_h = ffi.Pointer<ffi.Void>;

/// @brief Called to register for notifications about delivering media packet when every video frame is decoded.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @remarks This function is called in the context of gstreamer so the UI update code must not be directly invoked.\n
/// The packet must be released after use by calling media_packet_destroy(). \n
/// If not, the decoder will fail due to having insufficient buffer space for the decoded frame.
///
/// @param[in] pkt Reference pointer to the media packet
/// @param[in] user_data The user data passed from the callback registration function
typedef player_media_packet_video_decoded_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(media_packet_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the buffer level drops below the threshold of max size or no free space in buffer.
/// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
/// @remarks This API is used for media stream playback only.
/// @param[in] status The buffer status
/// @param[in] user_data The user data passed from the callback registration function
/// @see player_set_media_stream_buffer_status_cb()
/// @see player_set_media_stream_buffer_max_size()
/// @see player_set_media_stream_buffer_min_threshold()
typedef player_media_stream_buffer_status_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to notify the next push-buffer offset when seeking is occurred.
/// @details The next push-buffer should produce buffers from the new offset.
/// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
/// @remarks This API is used for media stream playback only.
/// @param[in] offset The new byte position to seek
/// @param[in] user_data The user data passed from the callback registration function
typedef player_media_stream_seek_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.UnsignedLongLong, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the video is captured.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
/// @remarks The color space format of the captured image is IMAGE_UTIL_COLORSPACE_RGB888.
/// @param[in]   data	The captured image buffer
/// @param[in]   width	The width of the captured image
/// @param[in]   height  The height of the captured image
/// @param[in]   size	The size of the captured image
/// @param[in]   user_data	The user data passed from the callback registration function
/// @see player_capture_video()
typedef player_video_captured_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.UnsignedChar>, ffi.Int, ffi.Int,
            ffi.UnsignedInt, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the media player is completed.
/// @details It will be invoked when player has reached the end of the stream.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
/// @param[in]   user_data  The user data passed from the callback registration function
/// @pre It will be invoked when the playback is completed if you register this callback using player_set_completed_cb().
/// @see player_set_completed_cb()
/// @see player_unset_completed_cb()
typedef player_completed_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the media player is interrupted.
/// @details If the code is #PLAYER_INTERRUPTED_BY_RESOURCE_CONFLICT,
/// the player state will be one of #PLAYER_STATE_IDLE, #PLAYER_STATE_READY, or #PLAYER_STATE_PAUSED.
/// Application should get exact state by calling player_get_state().
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
/// @param[in] code        The interrupted error code
/// @param[in] user_data   The user data passed from the callback registration function
/// @see player_set_interrupted_cb()
/// @see player_unset_interrupted_cb()
/// @see player_get_state()
typedef player_interrupted_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an error occurs in the media player.
/// @details Following error codes can be delivered.
/// #PLAYER_ERROR_INVALID_OPERATION
/// #PLAYER_ERROR_INVALID_STATE
/// #PLAYER_ERROR_INVALID_URI
/// #PLAYER_ERROR_CONNECTION_FAILED
/// #PLAYER_ERROR_DRM_NOT_PERMITTED
/// #PLAYER_ERROR_FILE_NO_SPACE_ON_DEVICE
/// #PLAYER_ERROR_NOT_SUPPORTED_FILE
/// #PLAYER_ERROR_SEEK_FAILED
/// #PLAYER_ERROR_SERVICE_DISCONNECTED
/// #PLAYER_ERROR_NOT_SUPPORTED_AUDIO_CODEC (Since 4.0)
/// #PLAYER_ERROR_NOT_SUPPORTED_VIDEO_CODEC (Since 4.0)
/// #PLAYER_ERROR_NOT_SUPPORTED_SUBTITLE (Since 4.0)
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
/// @param[in]	error_code  The error code
/// @param[in]	user_data	The user data passed from the callback registration function
/// @see player_set_error_cb()
/// @see player_unset_error_cb()
typedef player_error_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the buffering percentage of the media playback is updated.
/// @details If the buffer is full, it will return 100%.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
/// @param[in]   percent	The percentage of buffering completed (0~100)
/// @param[in]   user_data	The user data passed from the callback registration function
/// @see player_set_buffering_cb()
/// @see player_unset_buffering_cb()
typedef player_buffering_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when progressive download is started or completed.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
/// @param[in]   type		The message type for progressive download
/// @param[in]   user_data	The user data passed from the callback registration function
/// @see player_set_progressive_download_path()
typedef player_pd_message_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief  Called when the subtitle is updated.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
/// @param[in]   duration	The duration of the updated subtitle
/// @param[in]   text		The text of the updated subtitle
/// @param[in]   user_data	The user data passed from the callback registration function
/// @see player_set_subtitle_updated_cb()
/// @see player_unset_subtitle_updated_cb()
typedef player_subtitle_updated_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.UnsignedLong, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to notify the video stream changed.
/// @details The video stream changing is detected just before rendering operation.
/// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
/// @param[in] width	The width of the captured image
/// @param[in] height The height of the captured image
/// @param[in] fps The frame per second of the video \n
/// It can be @c 0 if there is no video stream information.
/// @param[in] bit_rate The video bit rate [Hz] \n
/// It can be an invalid value if there is no video stream information.
/// @param[in] user_data The user data passed from the callback registration function
/// @see player_set_video_stream_changed_cb()
typedef player_video_stream_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Int, ffi.Int, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to notify the streaming variant information.
/// @details The adaptive streaming protocol(hls, mpeg dash) can support variant stream condition.
/// All the streaming variant information can be shared by calling player_foreach_adaptive_variant().
/// @since_tizen 4.0
/// @param[in] bandwidth The bandwidth of the stream can be supportable, this is mandatory parameter
/// @param[in] width The width of the stream, this is optional parameter
/// @param[in] height The height of the stream, this is optional parameter
/// @param[in] user_data The user data passed from the callback registration function
/// @see player_foreach_adaptive_variant()
typedef player_adaptive_variant_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Int, ffi.Int, ffi.Pointer<ffi.Void>)>>;

class recorder_s extends ffi.Opaque {}

/// @brief Enumeration for error code of the media recorder.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class recorder_error_e {
  /// < Successful
  static const int RECORDER_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int RECORDER_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid state
  static const int RECORDER_ERROR_INVALID_STATE = -26542062;

  /// < Out of memory
  static const int RECORDER_ERROR_OUT_OF_MEMORY = -12;

  /// < Device error
  static const int RECORDER_ERROR_DEVICE = -26542060;

  /// < Internal error
  static const int RECORDER_ERROR_INVALID_OPERATION = -38;

  /// < Blocked by Audio Session Manager (Deprecated since 3.0)
  static const int RECORDER_ERROR_SOUND_POLICY = -26542058;

  /// < Restricted by security system policy
  static const int RECORDER_ERROR_SECURITY_RESTRICTED = -26542057;

  /// < Blocked by Audio Session Manager - CALL (Deprecated since 3.0)
  static const int RECORDER_ERROR_SOUND_POLICY_BY_CALL = -26542056;

  /// < Blocked by Audio Session Manager - ALARM (Deprecated since 3.0)
  static const int RECORDER_ERROR_SOUND_POLICY_BY_ALARM = -26542055;

  /// < ESD situation
  static const int RECORDER_ERROR_ESD = -26542054;

  /// < Out of storage
  static const int RECORDER_ERROR_OUT_OF_STORAGE = -26542053;

  /// < The access to the resources can not be granted
  static const int RECORDER_ERROR_PERMISSION_DENIED = -13;

  /// < The feature is not supported
  static const int RECORDER_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Blocked by resource conflict (Since 3.0)
  static const int RECORDER_ERROR_RESOURCE_CONFLICT = -26542052;

  /// < Socket connection lost (Since 3.0)
  static const int RECORDER_ERROR_SERVICE_DISCONNECTED = -26542051;
}

/// @brief Enumeration for recorder states.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class recorder_state_e {
  /// < Recorder is not created
  static const int RECORDER_STATE_NONE = 0;

  /// < Recorder is created, but not prepared
  static const int RECORDER_STATE_CREATED = 1;

  /// < Recorder is ready to record \n In case of video recorder, preview display will be shown
  static const int RECORDER_STATE_READY = 2;

  /// < Recorder is recording media
  static const int RECORDER_STATE_RECORDING = 3;

  /// < Recorder is paused while recording media
  static const int RECORDER_STATE_PAUSED = 4;
}

/// @brief Enumeration for the recording limit.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class recorder_recording_limit_type_e {
  /// < Time limit (second) of recording file
  static const int RECORDER_RECORDING_LIMIT_TIME = 0;

  /// < Size limit (kilo bytes [KB]) of recording file
  static const int RECORDER_RECORDING_LIMIT_SIZE = 1;

  /// < No free space in storage
  static const int RECORDER_RECORDING_LIMIT_FREE_SPACE = 2;
}

/// @brief Enumeration for the file container format.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class recorder_file_format_e {
  /// < 3GP file format
  static const int RECORDER_FILE_FORMAT_3GP = 0;

  /// < MP4 file format
  static const int RECORDER_FILE_FORMAT_MP4 = 1;

  /// < AMR file format
  static const int RECORDER_FILE_FORMAT_AMR = 2;

  /// < ADTS file format
  static const int RECORDER_FILE_FORMAT_ADTS = 3;

  /// < WAV file format
  static const int RECORDER_FILE_FORMAT_WAV = 4;

  /// < OGG file format
  static const int RECORDER_FILE_FORMAT_OGG = 5;

  /// < MPEG2-TransportStream file format (Since 3.0)
  static const int RECORDER_FILE_FORMAT_M2TS = 6;
}

/// @brief Enumeration for the audio codec.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class recorder_audio_codec_e {
  /// < Disable audio track
  static const int RECORDER_AUDIO_CODEC_DISABLE = -1;

  /// < AMR codec
  static const int RECORDER_AUDIO_CODEC_AMR = 0;

  /// < AAC codec
  static const int RECORDER_AUDIO_CODEC_AAC = 1;

  /// < Vorbis codec
  static const int RECORDER_AUDIO_CODEC_VORBIS = 2;

  /// < PCM codec
  static const int RECORDER_AUDIO_CODEC_PCM = 3;

  /// < MP3 codec (Since 3.0)
  static const int RECORDER_AUDIO_CODEC_MP3 = 4;
}

/// @brief Enumeration for the video codec.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class recorder_video_codec_e {
  /// < H263 codec
  static const int RECORDER_VIDEO_CODEC_H263 = 0;

  /// < H264 codec
  static const int RECORDER_VIDEO_CODEC_H264 = 1;

  /// < MPEG4 codec
  static const int RECORDER_VIDEO_CODEC_MPEG4 = 2;

  /// < Theora codec
  static const int RECORDER_VIDEO_CODEC_THEORA = 3;
}

/// @brief Enumeration for audio capture devices.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class recorder_audio_device_e {
  /// < Mic device
  static const int RECORDER_AUDIO_DEVICE_MIC = 0;

  /// < Modem
  static const int RECORDER_AUDIO_DEVICE_MODEM = 1;
}

/// @brief Enumeration for the recorder rotation type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class recorder_rotation_e {
  /// < No rotation
  static const int RECORDER_ROTATION_NONE = 0;

  /// < 90 degree rotation
  static const int RECORDER_ROTATION_90 = 1;

  /// < 180 degree rotation
  static const int RECORDER_ROTATION_180 = 2;

  /// < 270 degree rotation
  static const int RECORDER_ROTATION_270 = 3;
}

/// @brief Enumeration for the recorder policy.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class recorder_policy_e {
  /// < None
  static const int RECORDER_POLICY_NONE = 0;

  /// < Sound policy (Deprecated since 3.0)
  static const int RECORDER_POLICY_SOUND = 1;

  /// < Sound policy by CALL (Deprecated since 3.0)
  static const int RECORDER_POLICY_SOUND_BY_CALL = 2;

  /// < Sound policy by ALARM (Deprecated since 3.0)
  static const int RECORDER_POLICY_SOUND_BY_ALARM = 3;

  /// < Security policy
  static const int RECORDER_POLICY_SECURITY = 4;

  /// < Resource conflict (Since 3.0)
  static const int RECORDER_POLICY_RESOURCE_CONFLICT = 5;
}

/// @brief Enumeration for the recorder type.
/// @since_tizen 3.0
abstract class recorder_type_e {
  /// < Audio only recorder
  static const int RECORDER_TYPE_AUDIO = 0;

  /// < Video recorder (audio is optional)
  static const int RECORDER_TYPE_VIDEO = 1;
}

/// @brief Enumeration for the recorder device state.
/// @since_tizen 3.0
abstract class recorder_device_state_e {
  /// < No recording in progress
  static const int RECORDER_DEVICE_STATE_IDLE = 0;

  /// < Now recording
  static const int RECORDER_DEVICE_STATE_RECORDING = 1;

  /// < All recordings are paused
  static const int RECORDER_DEVICE_STATE_PAUSED = 2;
}

/// @brief The Media recorder handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef recorder_h = ffi.Pointer<recorder_s>;

/// @brief Called iteratively to notify about the supported file formats.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] format    The format of recording files
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre recorder_foreach_supported_file_format() will invoke this callback.
/// @see	recorder_foreach_supported_file_format()
typedef recorder_supported_file_format_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called iteratively to notify about the supported audio encoders.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] codec     The codec of audio encoder
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre recorder_foreach_supported_audio_encoder() will invoke this callback.
/// @see	recorder_foreach_supported_audio_encoder()
typedef recorder_supported_audio_encoder_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called once for each supported video resolution.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] width         The video image width
/// @param[in] height        The video image height
/// @param[in] user_data     The user data passed from the foreach function
/// @return    @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	recorder_foreach_supported_video_resolution() will invoke this callback.
/// @see	recorder_foreach_supported_video_resolution()
typedef recorder_supported_video_resolution_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called iteratively to notify about the supported video encoders.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] codec     The codec of video encoder
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre recorder_foreach_supported_video_encoder() will invoke this callback.
/// @see	recorder_foreach_supported_video_encoder()
typedef recorder_supported_video_encoder_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the record state is changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] previous  The previous state of the recorder
/// @param[in] current   The current state of the recorder
/// @param[in] by_policy @c true if the state is changed by policy, otherwise @c false if the state is not changed
/// @param[in] user_data The user data passed from the callback registration function
/// @pre This function is required to register a callback using recorder_set_state_changed_cb().
/// @see	recorder_set_state_changed_cb()
/// @see	recorder_prepare()
/// @see	recorder_unprepare()
/// @see	recorder_start()
/// @see	recorder_pause()
/// @see	recorder_commit()
/// @see	recorder_cancel()
typedef recorder_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, ffi.Int32, ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the recorder is interrupted by a policy.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks This callback is called after interrupt handling is completed.
/// @param[in] policy        The policy that interrupted the recorder
/// @param[in] previous      The previous state of the recorder
/// @param[in] current       The current state of the recorder
/// @param[in] user_data     The user data passed from the callback registration function
/// @see	recorder_set_interrupted_cb()
typedef recorder_interrupted_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the recorder interrupt is started by a policy.
/// @since_tizen 4.0
/// @remarks This callback is called before interrupt handling is started.
/// @param[in] policy        The policy that is interrupting the recorder
/// @param[in] state         The current state of the recorder
/// @param[in] user_data     The user data passed from the callback registration function
/// @see	recorder_set_interrupt_started_cb()
typedef recorder_interrupt_started_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when audio stream data was being delivered just before storing in the recorded file.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks The callback function holds the same buffer that will be recorded. \n
/// So if the user changes the buffer, the result file will contain the buffer.
/// @remarks The callback is called via internal thread of Frameworks, therefore do not invoke UI API, recorder_unprepare(), recorder_commit() and recorder_cancel() in callback.
/// @param[in] stream    The audio stream data
/// @param[in] size      The size of the stream data
/// @param[in] format    The audio format
/// @param[in] channel   The number of the channel
/// @param[in] timestamp The timestamp of the stream buffer (in msec)
/// @param[in] user_data The user data passed from the callback registration function
/// @see recorder_set_audio_stream_cb()
typedef recorder_audio_stream_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Void>, ffi.Int, ffi.Int32, ffi.Int,
            ffi.UnsignedInt, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when muxed stream data is delivered just before writing to the file.
/// @since_tizen 4.0
/// @remarks This callback receives the data that will be recorded, \n
/// but any changes to this data will not affect the recorded file. \n
/// The @a stream should not be freed and it's valid only in the callback. To use outside the callback, make a copy.
/// @param[in] stream    The muxed stream data
/// @param[in] size      The size of the stream data
/// @param[in] offset    The offset of the stream data
/// @param[in] user_data The user data passed from the callback registration function
/// @see recorder_set_muxed_stream_cb()
typedef recorder_muxed_stream_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Void>, ffi.Int, ffi.UnsignedLongLong,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called to indicate the recording status.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks This callback function is repeatedly invoked during the #RECORDER_STATE_RECORDING state.
/// @param[in] elapsed_time  The time of the recording (milliseconds)
/// @param[in] file_size     The size of the recording file (KB)
/// @param[in] user_data     The user data passed from the callback registration function
/// @pre recorder_start() will invoke this callback if you register it using recorder_set_recording_status_cb().
/// @see	recorder_set_recording_status_cb()
/// @see	recorder_unset_recording_status_cb()
/// @see	recorder_start()
typedef recorder_recording_status_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.UnsignedLongLong, ffi.UnsignedLongLong,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when limitation error occurs while recording.
/// @details The callback function is possible to receive three types of limits: time, size and no-space.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks After being called, recording data is discarded and not written in the recording file. Also the state of recorder is not changed.
/// @param[in] type      The imitation type
/// @param[in] user_data The user data passed from the callback registration function
/// @pre You have to register a callback using recorder_set_recording_limit_reached_cb().
/// @see recorder_set_recording_status_cb()
/// @see recorder_set_recording_limit_reached_cb()
/// @see recorder_unset_recording_limit_reached_cb()
typedef recorder_recording_limit_reached_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the error occurred.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks This callback informs about the critical error situation. \n
/// When being invoked, user should release the resource and terminate the application. \n
/// This error code will be reported.
/// #RECORDER_ERROR_DEVICE \n
/// #RECORDER_ERROR_INVALID_OPERATION \n
/// #RECORDER_ERROR_OUT_OF_MEMORY.
/// @param[in] error          The error code
/// @param[in] current_state  The current state of the recorder
/// @param[in] user_data      The user data passed from the callback registration function
/// @pre	This callback function is invoked if you register this callback using recorder_set_error_cb().
/// @see	recorder_set_error_cb()
/// @see	recorder_unset_error_cb()
typedef recorder_error_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the recorder device state is changed.
/// @since_tizen 3.0
/// @param[in] type      The recorder type
/// @param[in] state     The state of the recorder device
/// @param[in] user_data The user data passed from the callback registration function
/// @see	recorder_add_device_state_changed_cb()
typedef recorder_device_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for Tizen Sound Pool error.
///
/// @since_tizen 4.0
abstract class sound_pool_error_e {
  static const int SOUND_POOL_ERROR_NONE = 0;
  static const int SOUND_POOL_ERROR_KEY_NOT_AVAILABLE = -126;
  static const int SOUND_POOL_ERROR_OUT_OF_MEMORY = -12;
  static const int SOUND_POOL_ERROR_INVALID_PARAMETER = -22;
  static const int SOUND_POOL_ERROR_INVALID_OPERATION = -38;
  static const int SOUND_POOL_ERROR_NOT_PERMITTED = -1;
  static const int SOUND_POOL_ERROR_NO_SUCH_FILE = -2;
}

/// @brief Enumeration of sound pool stream state.
///
/// @since_tizen 4.0
abstract class sound_pool_stream_state_e {
  /// < Stream state isn't determined
  static const int SOUND_POOL_STREAM_STATE_NONE = 0;

  /// < Stream state is playing
  static const int SOUND_POOL_STREAM_STATE_PLAYING = 1;

  /// < Stream state is paused
  static const int SOUND_POOL_STREAM_STATE_PAUSED = 2;

  /// < Stream state is stopped
  static const int SOUND_POOL_STREAM_STATE_STOPPED = 3;

  /// < Stream state is finished
  static const int SOUND_POOL_STREAM_STATE_FINISHED = 4;

  /// < Stream state is suspended
  static const int SOUND_POOL_STREAM_STATE_SUSPENDED = 5;
}

/// @brief Enumeration of sound pool stream priority policy.
///
/// @since_tizen 4.0
abstract class sound_pool_stream_priority_policy_e {
  /// < Stream priority policy is mute
  static const int SOUND_POOL_STREAM_PRIORITY_POLICY_MUTE = 0;

  /// < Stream priority policy is suspended
  static const int SOUND_POOL_STREAM_PRIORITY_POLICY_SUSPENDED = 1;
}

/// @brief Enumeration of sound pool state.
///
/// @since_tizen 4.0
abstract class sound_pool_state_e {
  /// < Sound pool active state: streams can be played
  static const int SOUND_POOL_STATE_ACTIVE = 0;

  /// < Sound pool inactive state: streams can't be played
  static const int SOUND_POOL_STATE_INACTIVE = 1;
}

/// @brief Sound pool handle type.
///
/// @since_tizen 4.0
typedef sound_pool_h = ffi.Pointer<ffi.Void>;

/// @brief Called when the sound pool state is changed.
///
/// @since_tizen 4.0
/// @remarks @a pool is the object for which the callback was set.
/// @param[in]  pool          The sound pool handle
/// @param[in]  prev_state    Previous pool state
/// @param[in]  cur_state     Current pool state
/// @param[in]  user_data     The user data passed from the code where
/// sound_pool_set_state_changed_cb() was
/// called.
///
/// @pre Create sound pool handle by calling sound_pool_create()
/// @pre Call sound_pool_set_state_changed_cb()
///
/// @see sound_pool_create()
/// @see sound_pool_set_state_changed_cb()
/// @see sound_pool_state_e
typedef sound_pool_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            sound_pool_h, ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the sound pool stream state is changed.
///
/// @since_tizen 4.0
/// @remarks @a pool is the object for which the callback was set.
/// @param[in]  pool        The sound pool handle
/// @param[in]  id          Unique stream identifier
/// @param[in]  prev_state  Previous stream state
/// @param[in]  cur_state   Current stream state
/// @param[in]  user_data   The user data passed to the callback
///
/// @pre Create sound pool handle by calling sound_pool_create()
/// @pre Load source to pool by calling sound_pool_load_source_from_file()
/// @pre Start source playback by calling sound_pool_stream_play()
///
/// @see sound_pool_create()
/// @see sound_pool_load_source_from_file()
/// @see sound_pool_stream_play()
/// @see sound_pool_stream_state_e
typedef sound_pool_stream_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(sound_pool_h, ffi.UnsignedInt, ffi.Int32, ffi.Int32,
            ffi.Pointer<ffi.Void>)>>;

class streamrecorder_s extends ffi.Opaque {}

/// @brief Enumeration for the source type.
/// @since_tizen 3.0
abstract class streamrecorder_source_e {
  /// < Video only
  static const int STREAMRECORDER_SOURCE_VIDEO = 0;

  /// < Audio only
  static const int STREAMRECORDER_SOURCE_AUDIO = 1;

  /// < Video and Audio
  static const int STREAMRECORDER_SOURCE_VIDEO_AUDIO = 2;
}

/// @brief Enumeration for the pixel format.
/// @since_tizen 3.0
abstract class streamrecorder_video_source_format_e {
  /// < Invalid pixel format
  static const int STREAMRECORDER_VIDEO_SOURCE_FORMAT_INVALID = -1;

  /// < NV12 pixel format
  static const int STREAMRECORDER_VIDEO_SOURCE_FORMAT_NV12 = 0;

  /// < NV12 pixel format
  static const int STREAMRECORDER_VIDEO_SOURCE_FORMAT_NV21 = 1;

  /// < I420 pixel format
  static const int STREAMRECORDER_VIDEO_SOURCE_FORMAT_I420 = 2;

  /// < Number of the video source format
  static const int STREAMRECORDER_VIDEO_SOURCE_FORMAT_NUM = 3;
}

/// @brief Enumeration for the file container format.
/// @since_tizen 3.0
abstract class streamrecorder_file_format_e {
  /// < 3GP file format
  static const int STREAMRECORDER_FILE_FORMAT_3GP = 0;

  /// < MP4 file format
  static const int STREAMRECORDER_FILE_FORMAT_MP4 = 1;

  /// < AMR file format
  static const int STREAMRECORDER_FILE_FORMAT_AMR = 2;

  /// < ADTS file format
  static const int STREAMRECORDER_FILE_FORMAT_ADTS = 3;

  /// < WAV file format
  static const int STREAMRECORDER_FILE_FORMAT_WAV = 4;
}

/// @brief Enumeration for the audio codec.
/// @since_tizen 3.0
abstract class streamrecorder_audio_codec_e {
  /// < AMR codec
  static const int STREAMRECORDER_AUDIO_CODEC_AMR = 0;

  /// < AAC codec
  static const int STREAMRECORDER_AUDIO_CODEC_AAC = 1;

  /// < PCM codec
  static const int STREAMRECORDER_AUDIO_CODEC_PCM = 2;
}

/// @brief Enumeration for the video codec.
/// @since_tizen 3.0
abstract class streamrecorder_video_codec_e {
  /// < H263 codec
  static const int STREAMRECORDER_VIDEO_CODEC_H263 = 0;

  /// < MPEG4 codec
  static const int STREAMRECORDER_VIDEO_CODEC_MPEG4 = 1;
}

/// @brief Enumeration for the recording limit reached.
/// @since_tizen 3.0
abstract class streamrecorder_recording_limit_type_e {
  /// < Time limit (second) of recording file
  static const int STREAMRECORDER_RECORDING_LIMIT_TYPE_TIME = 0;

  /// < Size limit (kilo bytes [KB]) of recording file
  static const int STREAMRECORDER_RECORDING_LIMIT_TYPE_SIZE = 1;
}

/// @brief Enumeration for Streamrecorder error type.
/// @since_tizen 3.0
abstract class streamrecorder_error_e {
  /// < Successful
  static const int STREAMRECORDER_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int STREAMRECORDER_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid state
  static const int STREAMRECORDER_ERROR_INVALID_STATE = -27328511;

  /// < Out of memory
  static const int STREAMRECORDER_ERROR_OUT_OF_MEMORY = -12;

  /// < Internal error
  static const int STREAMRECORDER_ERROR_INVALID_OPERATION = -38;

  /// < Out of storage
  static const int STREAMRECORDER_ERROR_OUT_OF_STORAGE = -27328510;

  /// < The access to the resources can not be granted
  static const int STREAMRECORDER_ERROR_PERMISSION_DENIED = -13;

  /// < The feature is not supported
  static const int STREAMRECORDER_ERROR_NOT_SUPPORTED = -1073741822;
}

/// @brief Enumeration for the Streamrecorder notification.
/// @since_tizen 3.0
abstract class streamrecorder_notify_e {
  /// < None
  static const int STREAMRECORDER_NOTIFY_NONE = 0;

  /// < The notification of normal state changes
  static const int STREAMRECORDER_NOTIFY_STATE_CHANGED = 1;
}

/// @brief Enumeration for Streamrecorder states.
/// @since_tizen 3.0
abstract class streamrecorder_state_e {
  /// < StreamRecorder is not created
  static const int STREAMRECORDER_STATE_NONE = 0;

  /// < StreamRecorder is created, but not prepared
  static const int STREAMRECORDER_STATE_CREATED = 1;

  /// < StreamRecorder is prepared to record
  static const int STREAMRECORDER_STATE_PREPARED = 2;

  /// < StreamRecorder is recording media
  static const int STREAMRECORDER_STATE_RECORDING = 3;

  /// < StreamRecorder is paused while recording media
  static const int STREAMRECORDER_STATE_PAUSED = 4;
}

/// @brief The Streamrecorder handle.
/// @since_tizen 3.0
typedef streamrecorder_h = ffi.Pointer<streamrecorder_s>;

/// @brief Called iteratively to notify about the supported file formats.
/// @since_tizen 3.0
/// @param[in] format   The format of recording files
/// @param[in] user_data	The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre streamrecorder_foreach_supported_file_format() will invoke this callback.
/// @see	streamrecorder_foreach_supported_file_format()
typedef streamrecorder_supported_file_format_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called iteratively to notify about the supported audio encoders.
/// @since_tizen 3.0
/// @param[in] codec	The codec of audio encoder
/// @param[in] user_data	The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre streamrecorder_foreach_supported_audio_encoder() will invoke this callback.
/// @see	streamrecorder_foreach_supported_audio_encoder()
typedef streamrecorder_supported_audio_encoder_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called iteratively to notify about the supported video encoders.
/// @since_tizen 3.0
/// @param[in] codec	The codec of video encoder
/// @param[in] user_data	The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre streamrecorder_foreach_supported_video_encoder() will invoke this callback.
/// @see	streamrecorder_foreach_supported_video_encoder()
typedef streamrecorder_supported_video_encoder_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called once for each supported video resolution.
/// @since_tizen 3.0
/// @param[in] width         The video image width
/// @param[in] height        The video image height
/// @param[in] user_data     The user data passed from the foreach function
/// @return    @c true to continue with the next iteration of the loop, \n otherwise @c false to break out of the loop
/// @pre	streamrecorder_foreach_supported_video_resolution() will invoke this callback.
/// @see	streamrecorder_foreach_supported_video_resolution()
typedef streamrecorder_supported_video_resolution_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the streamrecorder gets some nofications.
/// @since_tizen 3.0
/// @param[in] previous	The previous state of the streamrecorder
/// @param[in] current	The current state of the streamrecorder
/// @param[in] notification  The notification type of the srecorder
/// @param[in] user_data	The user data passed from the callback registration function
/// @pre This function is required to register a callback using streamrecorder_set_notify_cb().
/// @see	streamrecorder_set_notify_cb()
/// @see	streamrecorder_prepare()
/// @see	streamrecorder_unprepare()
/// @see	streamrecorder_start()
/// @see	streamrecorder_pause()
/// @see	streamrecorder_commit()
/// @see	streamrecorder_cancel()
typedef streamrecorder_notify_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to indicate the recording status.
/// @since_tizen 3.0
/// @remarks This callback function is repeatedly invoked during the #STREAMRECORDER_STATE_RECORDING state.
/// @param[in] elapsed_time  The time of the recording (milliseconds)
/// @param[in] file_size     The size of the recording file (KB)
/// @param[in] user_data     The user data passed from the callback registration function
/// @pre streamrecorder_start() will invoke this callback if you register it using streamrecorder_set_recording_status_cb().
/// @see	streamrecorder_set_recording_status_cb()
/// @see	streamrecorder_unset_recording_status_cb()
/// @see	streamrecorder_start()
typedef streamrecorder_recording_status_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.UnsignedLongLong, ffi.UnsignedLongLong,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when limitation error occurs while recording.
/// @details The callback function is possible to receive three types of limits: time and size.
/// @since_tizen 3.0
/// @remarks After being called, recording data except present recorded data will be discarded and not written in the recording file. Also the state of streamrecorder is not changed.
/// @param[in] type The imitation type
/// @param[in] user_data The user data passed from the callback registration function
/// @pre You have to register a callback using streamrecorder_set_recording_limit_reached_cb().
/// @see streamrecorder_set_recording_status_cb()
/// @see streamrecorder_set_recording_limit_reached_cb()
/// @see streamrecorder_unset_recording_limit_reached_cb()
typedef streamrecorder_recording_limit_reached_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the error occurred.
/// @since_tizen 3.0
/// @remarks This callback informs about the critical error situation. \n
/// When being invoked, user should release the resource and terminate the application. \n
/// This error code will be reported. \n
/// #STREAMRECORDER_ERROR_INVALID_OPERATION \n
/// #STREAMRECORDER_ERROR_OUT_OF_MEMORY
/// @param[in] error          The error code
/// @param[in] current_state  The current state of the streamrecorder
/// @param[in] user_data      The user data passed from the callback registration function
/// @pre	This callback function is invoked if you register this callback using streamrecorder_set_error_cb().
/// @see	streamrecorder_set_error_cb()
/// @see	streamrecorder_unset_error_cb()
typedef streamrecorder_error_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called iteratively to notify about the buffer has been consumed
/// @since_tizen 3.0
/// @remarks The user needs to release consumed buffer if buffer is allocated by user including media packet
/// @param[in] buffer  The consumed buffer that user pushed
/// @param[in] user_data	The user data passed
/// @see streamrecorder_set_buffer_consume_completed_cb() will invoke this callback.
/// @see streamrecorder_unset_buffer_consume_completed_cb()
typedef streamrecorder_consume_completed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_MEDIA_THUMBNAIL_UTIL_MODULE
/// @brief Enumeration for a thumbnail util error.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class thumbnail_util_error_e {
  /// < Successful
  static const int THUMBNAIL_UTIL_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int THUMBNAIL_UTIL_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int THUMBNAIL_UTIL_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid Operation
  static const int THUMBNAIL_UTIL_ERROR_INVALID_OPERATION = -38;

  /// < No space left on device
  static const int THUMBNAIL_UTIL_ERROR_FILE_NO_SPACE_ON_DEVICE = -28;

  /// < Permission denied
  static const int THUMBNAIL_UTIL_ERROR_PERMISSION_DENIED = -13;

  /// < Unsupported Content (Since 4.0)
  static const int THUMBNAIL_UTIL_ERROR_UNSUPPORTED_CONTENT = -49872895;
}

class thumbnail_s extends ffi.Opaque {}

/// @ingroup CAPI_MEDIA_THUMBNAIL_UTIL_MODULE
/// @brief The structure type for the thumbnail info handle.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef thumbnail_h = ffi.Pointer<thumbnail_s>;

/// @ingroup CAPI_MEDIA_THUMBNAIL_UTIL_MODULE
/// @brief Called when creating the thumbnail.
/// @details This callback is called for completion of generating the thumbnail.
///
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
///
/// @remarks Color space of the generated thumbnail is BGRA. \n
/// The callback is called in a separate thread(not in the main loop). \n
/// You must release @a thumb_data using free().
///
/// @param[in] error     The error code
/// @param[in] request_id       The generated request id by thumbnail extraction request
/// @param[in] thumb_width    The width of the thumbnail which is generated
/// @param[in] thumb_height   The height of the thumbnail which is generated
/// @param[in] thumb_data     The raw data of the thumbnail which is generated
/// @param[in] thumb_size      The size of the thumbnail which is generated
/// @param[in] user_data        The user data passed from the thumbnail_util_extract() function
///
/// @pre thumbnail_util_extract() calls this callback.
/// @see thumbnail_util_extract()
typedef thumbnail_extracted_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Char>, ffi.Int, ffi.Int,
            ffi.Pointer<ffi.UnsignedChar>, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration of error codes for tone player.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class tone_player_error_e {
  /// < Successful
  static const int TONE_PLAYER_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int TONE_PLAYER_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid operation
  static const int TONE_PLAYER_ERROR_INVALID_OPERATION = -38;

  /// < Not supported (Since 3.0)
  static const int TONE_PLAYER_ERROR_NOT_SUPPORTED_TYPE = -26673151;
}

/// @brief Enumeration of tone.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class tone_type_e {
  /// < The default tone
  static const int TONE_TYPE_DEFAULT = 0;

  /// < Predefined DTMF 0
  static const int TONE_TYPE_DTMF_0 = 0;

  /// < Predefined DTMF 1
  static const int TONE_TYPE_DTMF_1 = 1;

  /// < Predefined DTMF 2
  static const int TONE_TYPE_DTMF_2 = 2;

  /// < Predefined DTMF 3
  static const int TONE_TYPE_DTMF_3 = 3;

  /// < Predefined DTMF 4
  static const int TONE_TYPE_DTMF_4 = 4;

  /// < Predefined DTMF 5
  static const int TONE_TYPE_DTMF_5 = 5;

  /// < Predefined DTMF 6
  static const int TONE_TYPE_DTMF_6 = 6;

  /// < Predefined DTMF 7
  static const int TONE_TYPE_DTMF_7 = 7;

  /// < Predefined DTMF 8
  static const int TONE_TYPE_DTMF_8 = 8;

  /// < Predefined DTMF 9
  static const int TONE_TYPE_DTMF_9 = 9;

  /// < Predefined DTMF Star - Asterisk (*)
  static const int TONE_TYPE_DTMF_S = 10;

  /// < Predefined DTMF sharP (#)
  static const int TONE_TYPE_DTMF_P = 11;

  /// < Predefined DTMF A (A)
  static const int TONE_TYPE_DTMF_A = 12;

  /// < Predefined DTMF B (B)
  static const int TONE_TYPE_DTMF_B = 13;

  /// < Predefined DTMF C (C)
  static const int TONE_TYPE_DTMF_C = 14;

  /// < Predefined DTMF D (D)
  static const int TONE_TYPE_DTMF_D = 15;

  /// < Call supervisory tone, Dial tone: CEPT: 425Hz, continuous
  static const int TONE_TYPE_SUP_DIAL = 16;

  /// < Call supervisory tone, Dial tone: ANSI (IS-95): 350Hz+440Hz, continuous
  static const int TONE_TYPE_ANSI_DIAL = 17;

  /// < Call supervisory tone, Dial tone: JAPAN: 400Hz, continuous
  static const int TONE_TYPE_JAPAN_DIAL = 18;

  /// < Call supervisory tone, Busy: CEPT: 425Hz, 500ms ON, 500ms OFF...
  static const int TONE_TYPE_SUP_BUSY = 19;

  /// < Call supervisory tone, Busy: ANSI (IS-95): 480Hz+620Hz, 500ms ON, 500ms OFF...
  static const int TONE_TYPE_ANSI_BUSY = 20;

  /// < Call supervisory tone, Busy: JAPAN: 400Hz, 500ms ON, 500ms OFF...
  static const int TONE_TYPE_JAPAN_BUSY = 21;

  /// < Call supervisory tone, Congestion: CEPT, JAPAN: 425Hz, 200ms ON, 200ms OFF
  static const int TONE_TYPE_SUP_CONGESTION = 22;

  /// < Call supervisory tone, Congestion: ANSI (IS-95): 480Hz+620Hz, 250ms ON, 250ms OFF...
  static const int TONE_TYPE_ANSI_CONGESTION = 23;

  /// < Call supervisory tone, Radio path acknowledgment : CEPT, ANSI: 425Hz, 200ms ON
  static const int TONE_TYPE_SUP_RADIO_ACK = 24;

  /// < Call supervisory tone, Radio path acknowledgment : JAPAN: 400Hz, 1s ON, 2s OFF...
  static const int TONE_TYPE_JAPAN_RADIO_ACK = 25;

  /// < Call supervisory tone, Radio path not available: 425Hz, 200ms ON, 200 OFF 3 bursts
  static const int TONE_TYPE_SUP_RADIO_NOTAVAIL = 26;

  /// < Call supervisory tone, Error/Special info: 950Hz+1400Hz+1800Hz, 330ms ON, 1s OFF...
  static const int TONE_TYPE_SUP_ERROR = 27;

  /// < Call supervisory tone, Call Waiting: CEPT, JAPAN: 425Hz, 200ms ON, 600ms OFF, 200ms ON, 3s OFF...
  static const int TONE_TYPE_SUP_CALL_WAITING = 28;

  /// < Call supervisory tone, Call Waiting: ANSI (IS-95): 440 Hz, 300 ms ON, 9.7 s OFF, (100 ms ON, 100 ms OFF, 100 ms ON, 9.7s OFF ...)
  static const int TONE_TYPE_ANSI_CALL_WAITING = 29;

  /// < Call supervisory tone, Ring Tone: CEPT, JAPAN: 425Hz, 1s ON, 4s OFF...
  static const int TONE_TYPE_SUP_RINGTONE = 30;

  /// < Call supervisory tone, Ring Tone: ANSI (IS-95): 440Hz + 480Hz, 2s ON, 4s OFF...
  static const int TONE_TYPE_ANSI_RINGTONE = 31;

  /// < General beep: 400Hz+1200Hz, 35ms ON
  static const int TONE_TYPE_PROP_BEEP = 32;

  /// < Proprietary tone, positive acknowledgment: 1200Hz, 100ms ON, 100ms OFF 2 bursts
  static const int TONE_TYPE_PROP_ACK = 33;

  /// < Proprietary tone, negative acknowledgment: 300Hz+400Hz+500Hz, 400ms ON
  static const int TONE_TYPE_PROP_NACK = 34;

  /// < Proprietary tone, prompt tone: 400Hz+1200Hz, 200ms ON
  static const int TONE_TYPE_PROP_PROMPT = 35;

  /// < Proprietary tone, general double beep: twice 400Hz+1200Hz, 35ms ON, 200ms OFF, 35ms ON
  static const int TONE_TYPE_PROP_BEEP2 = 36;

  /// < Call supervisory tone (IS-95), intercept tone: alternating 440 Hz and 620 Hz tones, each on for 250 ms
  static const int TONE_TYPE_SUP_INTERCEPT = 37;

  /// < Call supervisory tone (IS-95), abbreviated intercept: intercept tone limited to 4 seconds
  static const int TONE_TYPE_SUP_INTERCEPT_ABBREV = 38;

  /// < Call supervisory tone (IS-95), abbreviated congestion: congestion tone limited to 4 seconds
  static const int TONE_TYPE_SUP_CONGESTION_ABBREV = 39;

  /// < Call supervisory tone (IS-95), confirm tone: a 350 Hz tone added to a 440 Hz tone repeated 3 times in a 100 ms on, 100 ms off cycle
  static const int TONE_TYPE_SUP_CONFIRM = 40;

  /// < Call supervisory tone (IS-95), pip tone: four bursts of 480 Hz tone (0.1 s on, 0.1 s off).
  static const int TONE_TYPE_SUP_PIP = 41;

  /// < 425Hz continuous
  static const int TONE_TYPE_CDMA_DIAL_TONE_LITE = 42;

  /// < CDMA USA Ringback: 440Hz+480Hz 2s ON, 4000 OFF ...
  static const int TONE_TYPE_CDMA_NETWORK_USA_RINGBACK = 43;

  /// < CDMA Intercept tone: 440Hz 250ms ON, 620Hz 250ms ON ...
  static const int TONE_TYPE_CDMA_INTERCEPT = 44;

  /// < CDMA Abbr Intercept tone: 440Hz 250ms ON, 620Hz 250ms ON
  static const int TONE_TYPE_CDMA_ABBR_INTERCEPT = 45;

  /// < CDMA Reorder tone: 480Hz+620Hz 250ms ON, 250ms OFF...
  static const int TONE_TYPE_CDMA_REORDER = 46;

  /// < CDMA Abbr Reorder tone: 480Hz+620Hz 250ms ON, 250ms OFF repeated for 8 times
  static const int TONE_TYPE_CDMA_ABBR_REORDER = 47;

  /// < CDMA Network Busy tone: 480Hz+620Hz 500ms ON, 500ms OFF continuous
  static const int TONE_TYPE_CDMA_NETWORK_BUSY = 48;

  /// < CDMA Confirm tone: 350Hz+440Hz 100ms ON, 100ms OFF repeated for 3 times
  static const int TONE_TYPE_CDMA_CONFIRM = 49;

  /// < CDMA answer tone: silent tone - definition Frequency 0, 0ms ON, 0ms OFF
  static const int TONE_TYPE_CDMA_ANSWER = 50;

  /// < CDMA Network Callwaiting tone: 440Hz 300ms ON
  static const int TONE_TYPE_CDMA_NETWORK_CALLWAITING = 51;

  /// < CDMA PIP tone: 480Hz 100ms ON, 100ms OFF repeated for 4 times
  static const int TONE_TYPE_CDMA_PIP = 52;

  /// < ISDN Call Signal Normal tone: {2091Hz 32ms ON, 2556 64ms ON} 20 times, 2091 32ms ON, 2556 48ms ON, 4s OFF
  static const int TONE_TYPE_CDMA_CALL_SIGNAL_ISDN_NORMAL = 53;

  /// < ISDN Call Signal Intergroup tone: {2091Hz 32ms ON, 2556 64ms ON} 8 times, 2091Hz 32ms ON, 400ms OFF, {2091Hz 32ms ON, 2556Hz 64ms ON} 8times, 2091Hz 32ms ON, 4s OFF.
  static const int TONE_TYPE_CDMA_CALL_SIGNAL_ISDN_INTERGROUP = 54;

  /// < ISDN Call Signal SP PRI tone:{2091Hz 32ms ON, 2556 64ms ON} 4 times 2091Hz 16ms ON, 200ms OFF, {2091Hz 32ms ON, 2556Hz 64ms ON} 4 times, 2091Hz 16ms ON, 200ms OFF
  static const int TONE_TYPE_CDMA_CALL_SIGNAL_ISDN_SP_PRI = 55;

  /// < SDN Call sign PAT3 tone: silent tone
  static const int TONE_TYPE_CDMA_CALL_SIGNAL_ISDN_PAT3 = 56;

  /// < ISDN Ping Ring tone: {2091Hz 32ms ON, 2556Hz 64ms ON} 5 times 2091Hz 20ms ON
  static const int TONE_TYPE_CDMA_CALL_SIGNAL_ISDN_PING_RING = 57;

  /// < ISDN Pat5 tone: silent tone
  static const int TONE_TYPE_CDMA_CALL_SIGNAL_ISDN_PAT5 = 58;

  /// < ISDN Pat6 tone: silent tone
  static const int TONE_TYPE_CDMA_CALL_SIGNAL_ISDN_PAT6 = 59;

  /// < ISDN Pat7 tone: silent tone
  static const int TONE_TYPE_CDMA_CALL_SIGNAL_ISDN_PAT7 = 60;

  /// < TONE_CDMA_HIGH_L tone: {3700Hz 25ms, 4000Hz 25ms} 40 times 4000ms OFF, Repeat ....
  static const int TONE_TYPE_CDMA_HIGH_L = 61;

  /// < TONE_CDMA_MED_L tone: {2600Hz 25ms, 2900Hz 25ms} 40 times 4000ms OFF, Repeat ....
  static const int TONE_TYPE_CDMA_MED_L = 62;

  /// < TONE_CDMA_LOW_L tone: {1300Hz 25ms, 1450Hz 25ms} 40 times, 4000ms OFF, Repeat ....
  static const int TONE_TYPE_CDMA_LOW_L = 63;

  /// < CDMA HIGH SS tone: {3700Hz 25ms, 4000Hz 25ms} repeat 16 times, 400ms OFF, repeat ....
  static const int TONE_TYPE_CDMA_HIGH_SS = 64;

  /// < CDMA MED SS tone: {2600Hz 25ms, 2900Hz 25ms} repeat 16 times, 400ms OFF, repeat ....
  static const int TONE_TYPE_CDMA_MED_SS = 65;

  /// < CDMA LOW SS tone: {1300z 25ms, 1450Hz 25ms} repeat 16 times, 400ms OFF, repeat ....
  static const int TONE_TYPE_CDMA_LOW_SS = 66;

  /// < CDMA HIGH SSL tone: {3700Hz 25ms, 4000Hz 25ms} 8 times, 200ms OFF, {3700Hz 25ms, 4000Hz 25ms} repeat 8 times, 200ms OFF, {3700Hz 25ms, 4000Hz 25ms} repeat 16 times, 4000ms OFF, repeat ...
  static const int TONE_TYPE_CDMA_HIGH_SSL = 67;

  /// < CDMA MED SSL tone: {2600Hz 25ms, 2900Hz 25ms} 8 times, 200ms OFF, {2600Hz 25ms, 2900Hz 25ms} repeat 8 times, 200ms OFF, {2600Hz 25ms, 2900Hz 25ms} repeat 16 times, 4000ms OFF, repeat ...
  static const int TONE_TYPE_CDMA_MED_SSL = 68;

  /// < CDMA LOW SSL tone: {1300Hz 25ms, 1450Hz 25ms} 8 times, 200ms OFF, {1300Hz 25ms, 1450Hz 25ms} repeat 8 times, 200ms OFF, {1300Hz 25ms, 1450Hz 25ms} repeat 16 times, 4000ms OFF, repeat ...
  static const int TONE_TYPE_CDMA_LOW_SSL = 69;

  /// < CDMA HIGH SS2 tone: {3700Hz 25ms, 4000Hz 25ms} 20 times, 1000ms OFF, {3700Hz 25ms, 4000Hz 25ms} 20 times, 3000ms OFF, repeat ....
  static const int TONE_TYPE_CDMA_HIGH_SS_2 = 70;

  /// < CDMA MED SS2 tone: {2600Hz 25ms, 2900Hz 25ms} 20 times, 1000ms OFF, {2600Hz 25ms, 2900Hz 25ms} 20 times, 3000ms OFF, repeat ....
  static const int TONE_TYPE_CDMA_MED_SS_2 = 71;

  /// < CDMA LOW SS2 tone: {1300Hz 25ms, 1450Hz 25ms} 20 times, 1000ms OFF, {1300Hz 25ms, 1450Hz 25ms} 20 times, 3000ms OFF, repeat ....
  static const int TONE_TYPE_CDMA_LOW_SS_2 = 72;

  /// < CDMA HIGH SLS tone: {3700Hz 25ms, 4000Hz 25ms} 10 times, 500ms OFF, {3700Hz 25ms, 4000Hz 25ms} 20 times, 500ms OFF, {3700Hz 25ms, 4000Hz 25ms} 10 times, 3000ms OFF, REPEAT
  static const int TONE_TYPE_CDMA_HIGH_SLS = 73;

  /// < CDMA MED SLS tone: {2600Hz 25ms, 2900Hz 25ms} 10 times, 500ms OFF, {2600Hz 25ms, 2900Hz 25ms} 20 times, 500ms OFF, {2600Hz 25ms, 2900Hz 25ms} 10 times, 3000ms OFF, REPEAT
  static const int TONE_TYPE_CDMA_MED_SLS = 74;

  /// < CDMA LOW SLS tone: {1300Hz 25ms, 1450Hz 25ms} 10 times, 500ms OFF, {1300Hz 25ms, 1450Hz 25ms} 20 times, 500ms OFF, {1300Hz 25ms, 1450Hz 25ms} 10 times, 3000ms OFF, REPEAT
  static const int TONE_TYPE_CDMA_LOW_SLS = 75;

  /// < CDMA HIGH S X4 tone: {3700Hz 25ms, 4000Hz 25ms} 10 times, 500ms OFF, {3700Hz 25ms, 4000Hz 25ms} 10 times, 500ms OFF, {3700Hz 25ms, 4000Hz 25ms} 10 times, 500ms OFF, {3700Hz 25ms, 4000Hz 25ms} 10 times, 2500ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_HIGH_S_X4 = 76;

  /// < CDMA MED S X4 tone: {2600Hz 25ms, 2900Hz 25ms} 10 times, 500ms OFF, {2600Hz 25ms, 2900Hz 25ms} 10 times, 500ms OFF, {2600Hz 25ms, 2900Hz 25ms} 10 times, 500ms OFF, {2600Hz 25ms, 2900Hz 25ms} 10 times, 2500ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_MED_S_X4 = 77;

  /// < CDMA LOW S X4 tone: {2600Hz 25ms, 2900Hz 25ms} 10 times, 500ms OFF, {2600Hz 25ms, 2900Hz 25ms} 10 times, 500ms OFF, {2600Hz 25ms, 2900Hz 25ms} 10 times, 500ms OFF, {2600Hz 25ms, 2900Hz 25ms} 10 times, 2500ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_LOW_S_X4 = 78;

  /// < CDMA HIGH PBX L: {3700Hz 25ms, 4000Hz 25ms}20 times, 2000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_HIGH_PBX_L = 79;

  /// < CDMA MED PBX L: {2600Hz 25ms, 2900Hz 25ms}20 times, 2000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_MED_PBX_L = 80;

  /// < CDMA LOW PBX L: {1300Hz 25ms,1450Hz 25ms}20 times, 2000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_LOW_PBX_L = 81;

  /// < CDMA HIGH PBX SS tone: {3700Hz 25ms, 4000Hz 25ms} 8 times 200 ms OFF, {3700Hz 25ms 4000Hz 25ms}8 times, 2000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_HIGH_PBX_SS = 82;

  /// < CDMA MED PBX SS tone: {2600Hz 25ms, 2900Hz 25ms} 8 times 200 ms OFF, {2600Hz 25ms 2900Hz 25ms}8 times, 2000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_MED_PBX_SS = 83;

  /// < CDMA LOW PBX SS tone: {1300Hz 25ms, 1450Hz 25ms} 8 times 200 ms OFF, {1300Hz 25ms 1450Hz 25ms}8 times, 2000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_LOW_PBX_SS = 84;

  /// < CDMA HIGH PBX SSL tone:{3700Hz 25ms, 4000Hz 25ms} 8 times 200ms OFF, {3700Hz 25ms, 4000Hz 25ms} 8 times, 200ms OFF, {3700Hz 25ms, 4000Hz 25ms} 16 times, 1000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_HIGH_PBX_SSL = 85;

  /// < CDMA MED PBX SSL tone:{2600Hz 25ms, 2900Hz 25ms} 8 times 200ms OFF, {2600Hz 25ms, 2900Hz 25ms} 8 times, 200ms OFF, {2600Hz 25ms, 2900Hz 25ms} 16 times, 1000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_MED_PBX_SSL = 86;

  /// < CDMA LOW PBX SSL tone:{1300Hz 25ms, 1450Hz 25ms} 8 times 200ms OFF, {1300Hz 25ms, 1450Hz 25ms} 8 times, 200ms OFF, {1300Hz 25ms, 1450Hz 25ms} 16 times, 1000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_LOW_PBX_SSL = 87;

  /// < CDMA HIGH PBX SLS tone:{3700Hz 25ms, 4000Hz 25ms} 8 times 200ms OFF, {3700Hz 25ms, 4000Hz 25ms} 16 times, 200ms OFF, {3700Hz 25ms, 4000Hz 25ms} 8 times, 1000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_HIGH_PBX_SLS = 88;

  /// < CDMA MED PBX SLS tone:{2600Hz 25ms, 2900Hz 25ms} 8 times 200ms OFF, {2600Hz 25ms, 2900Hz 25ms} 16 times, 200ms OFF, {2600Hz 25ms, 2900Hz 25ms} 8 times, 1000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_MED_PBX_SLS = 89;

  /// < CDMA LOW PBX SLS tone:{1300Hz 25ms, 1450Hz 25ms} 8 times 200ms OFF, {1300Hz 25ms, 1450Hz 25ms} 16 times, 200ms OFF, {1300Hz 25ms, 1450Hz 25ms} 8 times, 1000ms OFF, REPEAT....
  static const int TONE_TYPE_CDMA_LOW_PBX_SLS = 90;

  /// < CDMA HIGH PBX X S4 tone: {3700Hz 25ms 4000Hz 25ms} 8 times, 200ms OFF, {3700Hz 25ms 4000Hz 25ms} 8 times, 200ms OFF, {3700Hz 25ms 4000Hz 25ms} 8 times, 200ms OFF, {3700Hz 25ms 4000Hz 25ms} 8 times, 800ms OFF, REPEAT...
  static const int TONE_TYPE_CDMA_HIGH_PBX_S_X4 = 91;

  /// < CDMA MED PBX X S4 tone: {2600Hz 25ms 2900Hz 25ms} 8 times, 200ms OFF, {2600Hz 25ms 2900Hz 25ms} 8 times, 200ms OFF, {2600Hz 25ms 2900Hz 25ms} 8 times, 200ms OFF, {2600Hz 25ms 2900Hz 25ms} 8 times, 800ms OFF, REPEAT...
  static const int TONE_TYPE_CDMA_MED_PBX_S_X4 = 92;

  /// < CDMA LOW PBX X S4 tone: {1300Hz 25ms 1450Hz 25ms} 8 times, 200ms OFF, {1300Hz 25ms 1450Hz 25ms} 8 times, 200ms OFF, {1300Hz 25ms 1450Hz 25ms} 8 times, 200ms OFF, {1300Hz 25ms 1450Hz 25ms} 8 times, 800ms OFF, REPEAT...
  static const int TONE_TYPE_CDMA_LOW_PBX_S_X4 = 93;

  /// < CDMA Alert Network Lite tone: 1109Hz 62ms ON, 784Hz 62ms ON, 740Hz 62ms ON 622Hz 62ms ON, 1109Hz 62ms ON
  static const int TONE_TYPE_CDMA_ALERT_NETWORK_LITE = 94;

  /// < CDMA Alert Auto Redial tone: {1245Hz 62ms ON, 659Hz 62ms ON} 3 times, 1245 62ms ON
  static const int TONE_TYPE_CDMA_ALERT_AUTOREDIAL_LITE = 95;

  /// < CDMA One Min Beep tone: 1150Hz+770Hz 400ms ON
  static const int TONE_TYPE_CDMA_ONE_MIN_BEEP = 96;

  /// < CDMA KEYPAD Volume key lite tone: 941Hz+1477Hz 120ms ON
  static const int TONE_TYPE_CDMA_KEYPAD_VOLUME_KEY_LITE = 97;

  /// < CDMA PRESSHOLDKEY LITE tone: 587Hz 375ms ON, 1175Hz 125ms ON
  static const int TONE_TYPE_CDMA_PRESSHOLDKEY_LITE = 98;

  /// < CDMA ALERT INCALL LITE tone: 587Hz 62ms, 784 62ms, 831Hz 62ms, 784Hz 62ms, 1109 62ms, 784Hz 62ms, 831Hz 62ms, 784Hz 62ms
  static const int TONE_TYPE_CDMA_ALERT_INCALL_LITE = 99;

  /// < CDMA EMERGENCY RINGBACK tone: {941Hz 125ms ON, 10ms OFF} 3times 4990ms OFF, REPEAT...
  static const int TONE_TYPE_CDMA_EMERGENCY_RINGBACK = 100;

  /// < CDMA ALERT CALL GUARD tone: {1319Hz 125ms ON, 125ms OFF} 3 times
  static const int TONE_TYPE_CDMA_ALERT_CALL_GUARD = 101;

  /// < CDMA SOFT ERROR LITE tone: 1047Hz 125ms ON, 370Hz 125ms
  static const int TONE_TYPE_CDMA_SOFT_ERROR_LITE = 102;

  /// < CDMA CALLDROP LITE tone: 1480Hz 125ms, 1397Hz 125ms, 784Hz 125ms
  static const int TONE_TYPE_CDMA_CALLDROP_LITE = 103;

  /// < CDMA_NETWORK_BUSY_ONE_SHOT tone: 425Hz 500ms ON, 500ms OFF.
  static const int TONE_TYPE_CDMA_NETWORK_BUSY_ONE_SHOT = 104;

  /// < CDMA_ABBR_ALERT tone: 1150Hz+770Hz 400ms ON
  static const int TONE_TYPE_CDMA_ABBR_ALERT = 105;

  /// < CDMA_SIGNAL_OFF - silent tone
  static const int TONE_TYPE_CDMA_SIGNAL_OFF = 106;

  /// < User Defined Tone: 100Hz continuous
  static const int TONE_TYPE_USER_DEFINED_LOW_FRE = 107;

  /// < User Defined Tone: 200Hz continuous
  static const int TONE_TYPE_USER_DEFINED_MED_FRE = 108;

  /// < User Defined Tone: 300Hz continuous
  static const int TONE_TYPE_USER_DEFINED_HIGH_FRE = 109;
}

/// @ingroup CAPI_MEDIA_VIDEO_UTIL_MODULE
/// @brief Enumeration for errors of a video util.
/// @since_tizen 2.3
abstract class video_util_error_e {
  /// < Successful
  static const int VIDEO_UTIL_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int VIDEO_UTIL_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int VIDEO_UTIL_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid operation
  static const int VIDEO_UTIL_ERROR_INVALID_OPERATION = -38;

  /// < Device or resource busy
  static const int VIDEO_UTIL_ERROR_BUSY = -16;

  /// < Not supported format
  static const int VIDEO_UTIL_ERROR_NOT_SUPPORTED_FORMAT = -26738687;

  /// < Permission denied
  static const int VIDEO_UTIL_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int VIDEO_UTIL_ERROR_NOT_SUPPORTED = -1073741822;
}

/// @ingroup CAPI_MEDIA_VIDEO_UTIL_MODULE
/// @brief Enumeration for video codec.
/// @since_tizen 2.3
abstract class video_util_video_codec_e {
  /// < MPEG4
  static const int VIDEO_UTIL_VIDEO_CODEC_MPEG4 = 0;

  /// < H.263
  static const int VIDEO_UTIL_VIDEO_CODEC_H263 = 1;

  /// < H.264
  static const int VIDEO_UTIL_VIDEO_CODEC_H264 = 2;

  /// < No transcoding for video
  static const int VIDEO_UTIL_VIDEO_CODEC_NONE = 3;
}

/// @ingroup CAPI_MEDIA_VIDEO_UTIL_MODULE
/// @brief Enumeration for audio codec.
/// @since_tizen 2.3
abstract class video_util_audio_codec_e {
  /// < AAC
  static const int VIDEO_UTIL_AUDIO_CODEC_AAC = 0;

  /// < AMRNB
  static const int VIDEO_UTIL_AUDIO_CODEC_AMRNB = 1;

  /// < No transcoding for audio
  static const int VIDEO_UTIL_AUDIO_CODEC_NONE = 2;
}

/// @ingroup CAPI_MEDIA_VIDEO_UTIL_MODULE
/// @brief Enumeration for formats of a media.
/// @since_tizen 2.3
abstract class video_util_file_format_e {
  /// < 3GP
  static const int VIDEO_UTIL_FILE_FORMAT_3GP = 0;

  /// < MP4
  static const int VIDEO_UTIL_FILE_FORMAT_MP4 = 1;
  static const int VIDEO_UTIL_FILE_FORMAT_MAX = 2;
}

class video_util_s extends ffi.Opaque {}

/// @ingroup CAPI_MEDIA_VIDEO_UTIL_MODULE
/// @brief Video util handle.
/// @since_tizen 2.3
typedef video_util_h = ffi.Pointer<video_util_s>;

/// @ingroup CAPI_MEDIA_VIDEO_UTIL_MODULE
/// @brief Called regularly during the video transcoding.
/// @since_tizen 2.3
///
/// @details The interval of callback invocation depends on the framework.
///
/// @param[in] current_position The current position in milliseconds
/// @param[in] duration The duration in seconds
/// @param[in] user_data The user data passed from the callback registration function
///
/// @pre This callback function is invoked if you register this callback using video_util_set_progress_transcoding_cb().
///
/// @see video_util_start_transcoding()
typedef video_util_transcoding_progress_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.UnsignedLong, ffi.UnsignedLong, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_MEDIA_VIDEO_UTIL_MODULE
/// @brief Called when transcoding is finished just before storing in the file.
/// @since_tizen 2.3
///
/// @param[in] error_code The error code of video util
/// @param[in] user_data The user data passed from the callback registration function
///
/// @pre video_util_start_transcoding() will invoke this function.
typedef video_util_transcoding_completed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called iteratively to notify you about the supported file formats.
/// @since_tizen 2.3
///
/// @param[in] format The format of media files
/// @param[in] user_data The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre video_util_foreach_supported_file_format() will invoke this callback.
typedef video_util_supported_file_format_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called iteratively to notify you of supported video codec.
/// @since_tizen 2.3
///
/// @param[in] format The codec of video
/// @param[in] user_data The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre video_util_foreach_supported_video_codec() will invoke this callback.
typedef video_util_supported_video_encoder_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called iteratively to notify you about the supported audio codec.
/// @since_tizen 2.3
///
/// @param[in] format The codec of audio
/// @param[in] user_data The user data passed from the foreach function
///
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
///
/// @pre video_util_foreach_supported_audio_codec() will invoke this callback.
typedef video_util_supported_audio_encoder_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration of error codes for WAV player.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class wav_player_error_e {
  /// < Successful
  static const int WAV_PLAYER_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int WAV_PLAYER_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid operation
  static const int WAV_PLAYER_ERROR_INVALID_OPERATION = -38;

  /// < Format not supported
  static const int WAV_PLAYER_ERROR_FORMAT_NOT_SUPPORTED = -26804223;

  /// < Not supported (Since 3.0)
  static const int WAV_PLAYER_ERROR_NOT_SUPPORTED_TYPE = -26804222;
}

/// @brief Called when a WAV file has finished playing.
/// @details This callback is not invoked by calling wav_player_stop().
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] id	The completed wav player ID
/// @param[in] user_data	The user data passed from the callback registration function
/// @see wav_player_start()
typedef wav_player_playback_completed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief  Enumeration of PBAP fields.
/// @since_tizen 3.0
abstract class bt_pbap_field_e {
  /// < All field
  static const int BT_PBAP_FIELD_ALL = -1;

  /// < vCard Version
  static const int BT_PBAP_FIELD_VERSION = 1;

  /// < Formatted Name
  static const int BT_PBAP_FIELD_FN = 2;

  /// < Structured Presentation of Name
  static const int BT_PBAP_FIELD_N = 4;

  /// < Associated Image or Photo
  static const int BT_PBAP_FIELD_PHOTO = 8;

  /// < Birthday
  static const int BT_PBAP_FIELD_BDAY = 16;

  /// < Delivery Address
  static const int BT_PBAP_FIELD_ADR = 32;

  /// < Delivery
  static const int BT_PBAP_FIELD_LABEL = 64;

  /// < Telephone Number
  static const int BT_PBAP_FIELD_TEL = 128;

  /// < Electronic Mail Address
  static const int BT_PBAP_FIELD_EMAIL = 256;

  /// < Electronic Mail
  static const int BT_PBAP_FIELD_MAILER = 512;

  /// < Time Zone
  static const int BT_PBAP_FIELD_TZ = 1024;

  /// < Geographic Position
  static const int BT_PBAP_FIELD_GEO = 2048;

  /// < Job
  static const int BT_PBAP_FIELD_TITLE = 4096;

  /// < Role within the Organization
  static const int BT_PBAP_FIELD_ROLE = 8192;

  /// < Organization Logo
  static const int BT_PBAP_FIELD_LOGO = 16384;

  /// < vCard of Person Representing
  static const int BT_PBAP_FIELD_AGENT = 32768;

  /// < Name of Organization
  static const int BT_PBAP_FIELD_ORG = 65536;

  /// < Comments
  static const int BT_PBAP_FIELD_NOTE = 131072;

  /// < Revision
  static const int BT_PBAP_FIELD_REV = 262144;

  /// < Pronunciation of Name
  static const int BT_PBAP_FIELD_SOUND = 524288;

  /// < Uniform Resource Locator
  static const int BT_PBAP_FIELD_URL = 1048576;

  /// < Unique ID
  static const int BT_PBAP_FIELD_UID = 2097152;

  /// < Public Encryption Key
  static const int BT_PBAP_FIELD_KEY = 4194304;

  /// < Nickname
  static const int BT_PBAP_FIELD_NICKNAME = 8388608;

  /// < Categories
  static const int BT_PBAP_FIELD_CATEGORIES = 16777216;

  /// < Product ID
  static const int BT_PBAP_FIELD_PROID = 33554432;

  /// < Class information
  static const int BT_PBAP_FIELD_CLASS = 67108864;

  /// < String used for sorting operations
  static const int BT_PBAP_FIELD_SORT_STRING = 134217728;

  /// < Time stamp
  static const int BT_PBAP_FIELD_X_IRMC_CALL_DATETIME = 268435456;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_MODULE
/// @brief Enumerations of Bluetooth error codes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_error_e {
  /// < Successful
  static const int BT_ERROR_NONE = 0;

  /// < Operation cancelled
  static const int BT_ERROR_CANCELLED = -125;

  /// < Invalid parameter
  static const int BT_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int BT_ERROR_OUT_OF_MEMORY = -12;

  /// < Device or resource busy
  static const int BT_ERROR_RESOURCE_BUSY = -16;

  /// < Timeout error
  static const int BT_ERROR_TIMED_OUT = -1073741823;

  /// < Operation now in progress
  static const int BT_ERROR_NOW_IN_PROGRESS = -115;

  /// < BT is Not Supported
  static const int BT_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Permission denied
  static const int BT_ERROR_PERMISSION_DENIED = -13;

  /// < Quota exceeded
  static const int BT_ERROR_QUOTA_EXCEEDED = -122;

  /// < No data available
  static const int BT_ERROR_NO_DATA = -61;

  /// < Device policy restriction (Since 3.0)
  static const int BT_ERROR_DEVICE_POLICY_RESTRICTION = -1073741820;

  /// < Local adapter not initialized
  static const int BT_ERROR_NOT_INITIALIZED = -29359871;

  /// < Local adapter not enabled
  static const int BT_ERROR_NOT_ENABLED = -29359870;

  /// < Operation already done
  static const int BT_ERROR_ALREADY_DONE = -29359869;

  /// < Operation failed
  static const int BT_ERROR_OPERATION_FAILED = -29359868;

  /// < Operation not in progress
  static const int BT_ERROR_NOT_IN_PROGRESS = -29359867;

  /// < Remote device not bonded
  static const int BT_ERROR_REMOTE_DEVICE_NOT_BONDED = -29359866;

  /// < Authentication rejected
  static const int BT_ERROR_AUTH_REJECTED = -29359865;

  /// < Authentication failed
  static const int BT_ERROR_AUTH_FAILED = -29359864;

  /// < Remote device not found
  static const int BT_ERROR_REMOTE_DEVICE_NOT_FOUND = -29359863;

  /// < Service search failed
  static const int BT_ERROR_SERVICE_SEARCH_FAILED = -29359862;

  /// < Remote device is not connected
  static const int BT_ERROR_REMOTE_DEVICE_NOT_CONNECTED = -29359861;

  /// < Resource temporarily unavailable
  static const int BT_ERROR_AGAIN = -29359860;

  /// < Service Not Found
  static const int BT_ERROR_SERVICE_NOT_FOUND = -29359859;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
/// @brief  Enumerations of the Bluetooth adapter state.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_adapter_state_e {
  /// < Bluetooth adapter is disabled
  static const int BT_ADAPTER_DISABLED = 0;

  /// < Bluetooth adapter is enabled
  static const int BT_ADAPTER_ENABLED = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
/// @brief Enumerations of the Bluetooth visibility mode.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_adapter_visibility_mode_e {
  /// < Other devices cannot find your device via discovery
  static const int BT_ADAPTER_VISIBILITY_MODE_NON_DISCOVERABLE = 0;

  /// < Discoverable mode
  static const int BT_ADAPTER_VISIBILITY_MODE_GENERAL_DISCOVERABLE = 1;

  /// < Discoverable mode with time limit. After specific period,
  /// it is changed to #BT_ADAPTER_VISIBILITY_MODE_NON_DISCOVERABLE.
  static const int BT_ADAPTER_VISIBILITY_MODE_LIMITED_DISCOVERABLE = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
/// @brief Enumerations of the discovery state of Bluetooth device.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_adapter_device_discovery_state_e {
  /// < Device discovery is started
  static const int BT_ADAPTER_DEVICE_DISCOVERY_STARTED = 0;

  /// < Device discovery is finished
  static const int BT_ADAPTER_DEVICE_DISCOVERY_FINISHED = 1;

  /// < The remote Bluetooth device is found
  static const int BT_ADAPTER_DEVICE_DISCOVERY_FOUND = 2;
}

/// @deprecated Deprecated since 2.3.1
/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief Enumerations of the discovery state of Bluetooth LE device.
/// @since_tizen @if WEARABLE @else 2.3 @endif
abstract class bt_adapter_le_device_discovery_state_e {
  /// < LE device discovery is started
  static const int BT_ADAPTER_LE_DEVICE_DISCOVERY_STARTED = 0;

  /// < LE device discovery is finished
  static const int BT_ADAPTER_LE_DEVICE_DISCOVERY_FINISHED = 1;

  /// < The remote Bluetooth LE device is found
  static const int BT_ADAPTER_LE_DEVICE_DISCOVERY_FOUND = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief  Enumerations of the Bluetooth advertising state.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_adapter_le_advertising_state_e {
  /// < Bluetooth advertising is stopped
  static const int BT_ADAPTER_LE_ADVERTISING_STOPPED = 0;

  /// < Bluetooth advertising is started
  static const int BT_ADAPTER_LE_ADVERTISING_STARTED = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief  Enumerations of the Bluetooth advertising mode.
/// @since_tizen 2.3.1
abstract class bt_adapter_le_advertising_mode_e {
  /// < Balanced advertising mode
  static const int BT_ADAPTER_LE_ADVERTISING_MODE_BALANCED = 0;

  /// < Low latency advertising mode
  static const int BT_ADAPTER_LE_ADVERTISING_MODE_LOW_LATENCY = 1;

  /// < Low energy advertising mode
  static const int BT_ADAPTER_LE_ADVERTISING_MODE_LOW_ENERGY = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief  Enumerations of the Bluetooth advertising filter policy.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_adapter_le_advertising_filter_policy_e {
  /// < White list is not in use
  static const int BT_ADAPTER_LE_ADVERTISING_FILTER_DEFAULT = 0;

  /// < Allow the scan
  /// request that in the White list
  static const int BT_ADAPTER_LE_ADVERTISING_FILTER_ALLOW_SCAN_WL = 1;

  /// < Allow the connection
  /// request that in the White list
  static const int BT_ADAPTER_LE_ADVERTISING_FILTER_ALLOW_CONN_WL = 2;

  /// < Allow the
  /// scan and connection request that in the White list
  static const int BT_ADAPTER_LE_ADVERTISING_FILTER_ALLOW_SCAN_CONN_WL = 3;
}

/// @deprecated Deprecated since 2.3.1
/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief  Enumerations of the Bluetooth advertising type.
/// @since_tizen @if WEARABLE @else 2.3 @endif
abstract class bt_adapter_le_advertising_type_e {
  /// < Connectable undirected advertising (ADV_IND)
  static const int BT_ADAPTER_LE_ADVERTISING_CONNECTABLE = 0;

  /// < Connectable high duty cycle directed advertising (ADV_DIRECT_IND)
  static const int BT_ADAPTER_LE_ADVERTISING_CONNECTABLE_DIRECT_HIGH = 1;

  /// < Scannable undirected advertising (ADV_SCAN_IND)
  static const int BT_ADAPTER_LE_ADVERTISING_SCANNABLE = 2;

  /// < Non connectable undirected advertising (ADV_NONCOND_IND)
  static const int BT_ADAPTER_LE_ADVERTISING_NON_CONNECTABLE = 3;

  /// < Connectable low duty cycle directed advertising (ADV_DIRECT_IND)
  static const int BT_ADAPTER_LE_ADVERTISING_CONNECTABLE_DIRECT_LOW = 4;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief  Enumerations of the Bluetooth LE packet type.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_adapter_le_packet_type_e {
  /// < Advertising packet
  static const int BT_ADAPTER_LE_PACKET_ADVERTISING = 0;

  /// < Scan response packet
  static const int BT_ADAPTER_LE_PACKET_SCAN_RESPONSE = 1;
}

/// @deprecated Deprecated since 2.3.1
/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief  Enumerations of the Bluetooth LE data type
/// that can be included in LE packets.
/// @since_tizen @if WEARABLE @else 2.3 @endif
abstract class bt_adapter_le_packet_data_type_e {
  /// < Complete list of 16 bit UUIDs
  static const int
      BT_ADAPTER_LE_PACKET_DATA_COMP_LIST_16_BIT_SERVICE_CLASS_UUIDS = 3;

  /// <local device name. unit-test uses this.
  static const int BT_ADAPTER_LE_PACKET_DATA_LOCAL_NAME = 9;

  /// < Manufacturer data
  static const int BT_ADAPTER_LE_PACKET_DATA_MANUFACTURER_SPECIFIC_DATA = 255;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief  Enumerations of the Bluetooth le scan mode.
/// @since_tizen 3.0
abstract class bt_adapter_le_scan_mode_e {
  /// < Balanced mode of power consumption and connection latency
  static const int BT_ADAPTER_LE_SCAN_MODE_BALANCED = 0;

  /// < Low connection latency but high power consumption
  static const int BT_ADAPTER_LE_SCAN_MODE_LOW_LATENCY = 1;

  /// < Low power consumption but high connection latency
  static const int BT_ADAPTER_LE_SCAN_MODE_LOW_ENERGY = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief Enumerations of device disconnect reason.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_device_disconnect_reason_e {
  /// < Disconnected by unknown reason
  static const int BT_DEVICE_DISCONNECT_REASON_UNKNOWN = 0;

  /// < Disconnected by timeout
  static const int BT_DEVICE_DISCONNECT_REASON_TIMEOUT = 1;

  /// < Disconnected by local host
  static const int BT_DEVICE_DISCONNECT_REASON_LOCAL_HOST = 2;

  /// < Disconnected by remote
  static const int BT_DEVICE_DISCONNECT_REASON_REMOTE = 3;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief Enumerations of connection link type.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_device_connection_link_type_e {
  /// < BR/EDR link
  static const int BT_DEVICE_CONNECTION_LINK_BREDR = 0;

  /// < LE link
  static const int BT_DEVICE_CONNECTION_LINK_LE = 1;

  /// < The connection type default
  static const int BT_DEVICE_CONNECTION_LINK_DEFAULT = 255;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief Enumerations of device authorization state.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_device_authorization_e {
  /// < The remote Bluetooth device is authorized
  static const int BT_DEVICE_AUTHORIZED = 0;

  /// < The remote Bluetooth device is unauthorized
  static const int BT_DEVICE_UNAUTHORIZED = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief Enumerations of Bluetooth profile.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_profile_e {
  /// < RFCOMM Profile
  static const int BT_PROFILE_RFCOMM = 1;

  /// < Advanced Audio Distribution Profile Source role
  static const int BT_PROFILE_A2DP = 2;

  /// < Headset Profile
  static const int BT_PROFILE_HSP = 4;

  /// < Human Interface Device Profile
  static const int BT_PROFILE_HID = 8;

  /// < Network Access Point Profile
  static const int BT_PROFILE_NAP = 16;

  /// < Audio Gateway Profile
  static const int BT_PROFILE_AG = 32;

  /// < Generic Attribute Profile
  static const int BT_PROFILE_GATT = 64;

  /// < NAP server Profile
  static const int BT_PROFILE_NAP_SERVER = 128;

  /// < Advanced Audio Distribution Profile Sink role
  static const int BT_PROFILE_A2DP_SINK = 256;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief Enumerations of device address type.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_device_address_type_e {
  /// < Public address
  static const int BT_DEVICE_PUBLIC_ADDRESS = 0;

  /// < Random address
  static const int BT_DEVICE_RANDOM_ADDRESS = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Enumerations of service class.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_service_class_t {
  /// < No service class
  static const int BT_SC_NONE = 0;

  /// < RES service class
  static const int BT_SC_RES_SERVICE_MASK = 1;

  /// < SPP service class
  static const int BT_SC_SPP_SERVICE_MASK = 2;

  /// < DUN service class
  static const int BT_SC_DUN_SERVICE_MASK = 4;

  /// < FAX service class
  static const int BT_SC_FAX_SERVICE_MASK = 8;

  /// < LAP service class
  static const int BT_SC_LAP_SERVICE_MASK = 16;

  /// < HSP service class
  static const int BT_SC_HSP_SERVICE_MASK = 32;

  /// < HFP service class
  static const int BT_SC_HFP_SERVICE_MASK = 64;

  /// < OPP service class
  static const int BT_SC_OPP_SERVICE_MASK = 128;

  /// < FTP service class
  static const int BT_SC_FTP_SERVICE_MASK = 256;

  /// < CTP service class
  static const int BT_SC_CTP_SERVICE_MASK = 512;

  /// < ICP service class
  static const int BT_SC_ICP_SERVICE_MASK = 1024;

  /// < SYNC service class
  static const int BT_SC_SYNC_SERVICE_MASK = 2048;

  /// < BPP service class
  static const int BT_SC_BPP_SERVICE_MASK = 4096;

  /// < BIP service class
  static const int BT_SC_BIP_SERVICE_MASK = 8192;

  /// < PANU service class
  static const int BT_SC_PANU_SERVICE_MASK = 16384;

  /// < NAP service class
  static const int BT_SC_NAP_SERVICE_MASK = 32768;

  /// < GN service class
  static const int BT_SC_GN_SERVICE_MASK = 65536;

  /// < SAP service class
  static const int BT_SC_SAP_SERVICE_MASK = 131072;

  /// < A2DP service class
  static const int BT_SC_A2DP_SERVICE_MASK = 262144;

  /// < AVRCP service class
  static const int BT_SC_AVRCP_SERVICE_MASK = 524288;

  /// < PBAP service class
  static const int BT_SC_PBAP_SERVICE_MASK = 1048576;

  /// < HID service class
  static const int BT_SC_HID_SERVICE_MASK = 2097152;

  /// < A2DP SOURCE service class
  static const int BT_SC_A2DP_SOURCE_SERVICE_MASK = 4194304;

  /// < ALL service class
  static const int BT_SC_ALL_SERVICE_MASK = 16777215;

  /// < MAX service class
  static const int BT_SC_MAX = 16777216;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Enumerations of major service class.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_major_service_class_e {
  /// < Limited discoverable mode
  static const int BT_MAJOR_SERVICE_CLASS_LIMITED_DISCOVERABLE_MODE = 8192;

  /// < Positioning class
  static const int BT_MAJOR_SERVICE_CLASS_POSITIONING = 65536;

  /// < Networking class
  static const int BT_MAJOR_SERVICE_CLASS_NETWORKING = 131072;

  /// < Rendering class
  static const int BT_MAJOR_SERVICE_CLASS_RENDERING = 262144;

  /// < Capturing class
  static const int BT_MAJOR_SERVICE_CLASS_CAPTURING = 524288;

  /// < Object transferring class
  static const int BT_MAJOR_SERVICE_CLASS_OBJECT_TRANSFER = 1048576;

  /// < Audio class
  static const int BT_MAJOR_SERVICE_CLASS_AUDIO = 2097152;

  /// < Telephony class
  static const int BT_MAJOR_SERVICE_CLASS_TELEPHONY = 4194304;

  /// < Information class
  static const int BT_MAJOR_SERVICE_CLASS_INFORMATION = 8388608;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Enumerations of major device class.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_major_device_class_e {
  /// < Miscellaneous major device class
  static const int BT_MAJOR_DEVICE_CLASS_MISC = 0;

  /// < Computer major device class
  static const int BT_MAJOR_DEVICE_CLASS_COMPUTER = 1;

  /// < Phone major device class
  static const int BT_MAJOR_DEVICE_CLASS_PHONE = 2;

  /// < LAN/Network access point major device class
  static const int BT_MAJOR_DEVICE_CLASS_LAN_NETWORK_ACCESS_POINT = 3;

  /// < Audio/Video major device class
  static const int BT_MAJOR_DEVICE_CLASS_AUDIO_VIDEO = 4;

  /// < Peripheral major device class
  static const int BT_MAJOR_DEVICE_CLASS_PERIPHERAL = 5;

  /// < Imaging major device class
  static const int BT_MAJOR_DEVICE_CLASS_IMAGING = 6;

  /// < Wearable device class
  static const int BT_MAJOR_DEVICE_CLASS_WEARABLE = 7;

  /// < Toy device class
  static const int BT_MAJOR_DEVICE_CLASS_TOY = 8;

  /// < Health device class
  static const int BT_MAJOR_DEVICE_CLASS_HEALTH = 9;

  /// < Uncategorized major device class
  static const int BT_MAJOR_DEVICE_CLASS_UNCATEGORIZED = 31;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Enumerations of minor device class.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_minor_device_class_e {
  /// < Uncategorized minor device class of computer
  static const int BT_MINOR_DEVICE_CLASS_COMPUTER_UNCATEGORIZED = 0;

  /// < Desktop workstation minor device class of computer
  static const int BT_MINOR_DEVICE_CLASS_COMPUTER_DESKTOP_WORKSTATION = 4;

  /// < Server minor device class of computer
  static const int BT_MINOR_DEVICE_CLASS_COMPUTER_SERVER_CLASS = 8;

  /// < Laptop minor device class of computer
  static const int BT_MINOR_DEVICE_CLASS_COMPUTER_LAPTOP = 12;

  /// < Handheld PC/PDA minor device class of computer
  static const int BT_MINOR_DEVICE_CLASS_COMPUTER_HANDHELD_PC_OR_PDA = 16;

  /// < Palm sized PC/PDA minor device class of computer
  static const int BT_MINOR_DEVICE_CLASS_COMPUTER_PALM_SIZED_PC_OR_PDA = 20;

  /// < Wearable(watch sized) minor device class of computer
  static const int BT_MINOR_DEVICE_CLASS_COMPUTER_WEARABLE_COMPUTER = 24;

  /// < Uncategorized minor device class of phone
  static const int BT_MINOR_DEVICE_CLASS_PHONE_UNCATEGORIZED = 0;

  /// < Cellular minor device class of phone
  static const int BT_MINOR_DEVICE_CLASS_PHONE_CELLULAR = 4;

  /// < Cordless minor device class of phone
  static const int BT_MINOR_DEVICE_CLASS_PHONE_CORDLESS = 8;

  /// < Smart phone minor device class of phone
  static const int BT_MINOR_DEVICE_CLASS_PHONE_SMART_PHONE = 12;

  /// < Wired modem or voice gateway minor device class of phone
  static const int BT_MINOR_DEVICE_CLASS_PHONE_WIRED_MODEM_OR_VOICE_GATEWAY =
      16;

  /// < Common ISDN minor device class of phone
  static const int BT_MINOR_DEVICE_CLASS_PHONE_COMMON_ISDN_ACCESS = 20;

  /// < Fully available minor device class of LAN/Network access point
  static const int
      BT_MINOR_DEVICE_CLASS_LAN_NETWORK_ACCESS_POINT_FULLY_AVAILABLE = 4;

  /// < 1-17% utilized minor device class of LAN/Network access point
  static const int
      BT_MINOR_DEVICE_CLASS_LAN_NETWORK_ACCESS_POINT_1_TO_17_PERCENT_UTILIZED =
      32;

  /// < 17-33% utilized minor device class of LAN/Network access point
  static const int
      BT_MINOR_DEVICE_CLASS_LAN_NETWORK_ACCESS_POINT_17_TO_33_PERCENT_UTILIZED =
      64;

  /// < 33-50% utilized minor device class of LAN/Network access point
  static const int
      BT_MINOR_DEVICE_CLASS_LAN_NETWORK_ACCESS_POINT_33_TO_50_PERCENT_UTILIZED =
      96;

  /// < 50-67% utilized minor device class of LAN/Network access point
  static const int
      BT_MINOR_DEVICE_CLASS_LAN_NETWORK_ACCESS_POINT_50_to_67_PERCENT_UTILIZED =
      128;

  /// < 67-83% utilized minor device class of LAN/Network access point
  static const int
      BT_MINOR_DEVICE_CLASS_LAN_NETWORK_ACCESS_POINT_67_TO_83_PERCENT_UTILIZED =
      160;

  /// < 83-99% utilized minor device class of LAN/Network access point
  static const int
      BT_MINOR_DEVICE_CLASS_LAN_NETWORK_ACCESS_POINT_83_TO_99_PERCENT_UTILIZED =
      192;

  /// < No service available minor device class of LAN/Network access point
  static const int
      BT_MINOR_DEVICE_CLASS_LAN_NETWORK_ACCESS_POINT_NO_SERVICE_AVAILABLE = 224;

  /// < Uncategorized minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_UNCATEGORIZED = 0;

  /// < Wearable headset minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_WEARABLE_HEADSET = 4;

  /// < Hands-free minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_HANDS_FREE = 8;

  /// < Microphone minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_MICROPHONE = 16;

  /// < Loudspeaker minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_LOUDSPEAKER = 20;

  /// < Headphones minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_HEADPHONES = 24;

  /// < Portable audio minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_PORTABLE_AUDIO = 28;

  /// < Car audio minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_CAR_AUDIO = 32;

  /// < Set-top box minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_SET_TOP_BOX = 36;

  /// < Hifi audio minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_HIFI_AUDIO_DEVICE = 40;

  /// < VCR minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_VCR = 44;

  /// < Video camera minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_VIDEO_CAMERA = 48;

  /// < Camcorder minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_CAMCORDER = 52;

  /// < Video monitor minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_VIDEO_MONITOR = 56;

  /// < Video display and loudspeaker minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_VIDEO_DISPLAY_LOUDSPEAKER =
      60;

  /// < Video conferencing minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_VIDEO_CONFERENCING = 64;

  /// < Gaming/toy minor device class of audio/video
  static const int BT_MINOR_DEVICE_CLASS_AUDIO_VIDEO_GAMING_TOY = 72;

  /// < Uncategorized minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERA_UNCATEGORIZED = 0;

  /// < Key board minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERAL_KEY_BOARD = 64;

  /// < Pointing device minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERAL_POINTING_DEVICE = 128;

  /// < Combo keyboard or pointing device minor device class of peripheral
  static const int
      BT_MINOR_DEVICE_CLASS_PERIPHERAL_COMBO_KEYBOARD_POINTING_DEVICE = 192;

  /// < Joystick minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERAL_JOYSTICK = 4;

  /// < Game pad minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERAL_GAME_PAD = 8;

  /// < Remote control minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERAL_REMOTE_CONTROL = 12;

  /// < Sensing device minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERAL_SENSING_DEVICE = 16;

  /// < Digitizer minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERAL_DIGITIZER_TABLET = 20;

  /// < Card reader minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERAL_CARD_READER = 24;

  /// < Digital pen minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERAL_DIGITAL_PEN = 28;

  /// < Handheld scanner minor device class of peripheral
  static const int BT_MINOR_DEVICE_CLASS_PERIPHERAL_HANDHELD_SCANNER = 32;

  /// < Handheld gestural input device minor device class of peripheral
  static const int
      BT_MINOR_DEVICE_CLASS_PERIPHERAL_HANDHELD_GESTURAL_INPUT_DEVICE = 36;

  /// < Display minor device class of imaging
  static const int BT_MINOR_DEVICE_CLASS_IMAGING_DISPLAY = 16;

  /// < Camera minor device class of imaging
  static const int BT_MINOR_DEVICE_CLASS_IMAGING_CAMERA = 32;

  /// < Scanner minor device class of imaging
  static const int BT_MINOR_DEVICE_CLASS_IMAGING_SCANNER = 64;

  /// < Printer minor device class of imaging
  static const int BT_MINOR_DEVICE_CLASS_IMAGING_PRINTER = 128;

  /// < Wrist watch minor device class of wearable
  static const int BT_MINOR_DEVICE_CLASS_WEARABLE_WRIST_WATCH = 4;

  /// < Pager minor device class of wearable
  static const int BT_MINOR_DEVICE_CLASS_WEARABLE_PAGER = 8;

  /// < Jacket minor device class of wearable
  static const int BT_MINOR_DEVICE_CLASS_WEARABLE_JACKET = 12;

  /// < Helmet minor device class of wearable
  static const int BT_MINOR_DEVICE_CLASS_WEARABLE_HELMET = 16;

  /// < Glasses minor device class of wearable
  static const int BT_MINOR_DEVICE_CLASS_WEARABLE_GLASSES = 20;

  /// < Robot minor device class of toy
  static const int BT_MINOR_DEVICE_CLASS_TOY_ROBOT = 4;

  /// < Vehicle minor device class of toy
  static const int BT_MINOR_DEVICE_CLASS_TOY_VEHICLE = 8;

  /// < Doll/Action minor device class of toy
  static const int BT_MINOR_DEVICE_CLASS_TOY_DOLL_ACTION = 12;

  /// < Controller minor device class of toy
  static const int BT_MINOR_DEVICE_CLASS_TOY_CONTROLLER = 16;

  /// < Game minor device class of toy
  static const int BT_MINOR_DEVICE_CLASS_TOY_GAME = 20;

  /// < Uncategorized minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_UNCATEGORIZED = 0;

  /// < Blood pressure monitor minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_BLOOD_PRESSURE_MONITOR = 4;

  /// < Thermometer minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_THERMOMETER = 8;

  /// < Weighing scale minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_WEIGHING_SCALE = 12;

  /// < Glucose minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_GLUCOSE_METER = 16;

  /// < Pulse oximeter minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_PULSE_OXIMETER = 20;

  /// < Heart/Pulse rate monitor minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_HEART_PULSE_RATE_MONITOR = 24;

  /// < Health data display minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_DATA_DISPLAY = 28;

  /// < Step counter minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_STEP_COUNTER = 32;

  /// < Body composition analyzer minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_BODY_COMPOSITION_ANALYZER = 36;

  /// < Peak flow monitor minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_PEAK_FLOW_MONITOR = 40;

  /// < Medication monitor minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_MEDICATION_MONITOR = 44;

  /// < Knee prosthesis minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_KNEE_PROSTHESIS = 48;

  /// < Ankle prosthesis minor device class of health
  static const int BT_MINOR_DEVICE_CLASS_HEALTH_ANKLE_PROSTHESIS = 52;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Enumerations of gap appearance type.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_appearance_type_e {
  /// < Unknown appearance type
  static const int BT_APPEARANCE_TYPE_UNKNOWN = 0;

  /// < Generic Phone type - Generic category
  static const int BT_APPEARANCE_TYPE_GENERIC_PHONE = 64;

  /// < Generic Computer type - Generic category
  static const int BT_APPEARANCE_TYPE_GENERIC_COMPUTER = 128;

  /// < Generic Watch type - Generic category
  static const int BT_APPEARANCE_TYPE_GENERIC_WATCH = 192;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Enumerations of the Bluetooth device's LE connection mode.
/// @since_tizen 3.0
abstract class bt_device_le_connection_mode_e {
  /// < Balanced mode of power consumption and connection latency
  static const int BT_DEVICE_LE_CONNECTION_MODE_BALANCED = 0;

  /// < Low connection latency but high power consumption
  static const int BT_DEVICE_LE_CONNECTION_MODE_LOW_LATENCY = 1;

  /// < Low power consumption but high connection latency
  static const int BT_DEVICE_LE_CONNECTION_MODE_LOW_ENERGY = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
/// @brief  Enumerations of connected Bluetooth device event role.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_socket_role_e {
  /// < Unknown role
  static const int BT_SOCKET_UNKNOWN = 0;

  /// < Server role
  static const int BT_SOCKET_SERVER = 1;

  /// < Client role
  static const int BT_SOCKET_CLIENT = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
/// @brief  Enumerations of Bluetooth socket connection state.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_socket_connection_state_e {
  /// < RFCOMM is connected
  static const int BT_SOCKET_CONNECTED = 0;

  /// < RFCOMM is disconnected
  static const int BT_SOCKET_DISCONNECTED = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_AUDIO_MODULE
/// @brief  Enumerations for the types of profiles related with audio
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_audio_profile_type_e {
  /// < All supported profiles related with audio
  static const int BT_AUDIO_PROFILE_TYPE_ALL = 0;

  /// < HSP(Headset Profile) and HFP(Hands-Free Profile)
  static const int BT_AUDIO_PROFILE_TYPE_HSP_HFP = 1;

  /// < A2DP(Advanced Audio Distribution Profile)
  static const int BT_AUDIO_PROFILE_TYPE_A2DP = 2;

  /// < AG(Audio Gateway)
  static const int BT_AUDIO_PROFILE_TYPE_AG = 3;

  /// < A2DP(Advanced Audio Distribution Profile) Sink role
  static const int BT_AUDIO_PROFILE_TYPE_A2DP_SINK = 4;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_AUDIO_AG_MODULE
/// @brief  Enumerations for the call handling event
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_ag_call_handling_event_e {
  /// < Request to answer an incoming call
  static const int BT_AG_CALL_HANDLING_EVENT_ANSWER = 0;

  /// < Request to release a call
  static const int BT_AG_CALL_HANDLING_EVENT_RELEASE = 1;

  /// < Request to reject an incoming call
  static const int BT_AG_CALL_HANDLING_EVENT_REJECT = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_AUDIO_AG_MODULE
/// @brief  Enumerations for the multi call handling event
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_ag_multi_call_handling_event_e {
  /// < Request to release held calls
  static const int BT_AG_MULTI_CALL_HANDLING_EVENT_RELEASE_HELD_CALLS = 0;

  /// < Request to release active calls
  static const int BT_AG_MULTI_CALL_HANDLING_EVENT_RELEASE_ACTIVE_CALLS = 1;

  /// < Request to put active calls into hold state and activate another (held or waiting) call
  static const int BT_AG_MULTI_CALL_HANDLING_EVENT_ACTIVATE_HELD_CALL = 2;

  /// < Request to add a held call to the conversation
  static const int BT_AG_MULTI_CALL_HANDLING_EVENT_MERGE_CALLS = 3;

  /// < Request to let a user who has two calls to connect these two calls together and release its connections to both other parties
  static const int BT_AG_MULTI_CALL_HANDLING_EVENT_EXPLICIT_CALL_TRANSFER = 4;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Enumerations for the equalizer state
/// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
abstract class bt_avrcp_equalizer_state_e {
  /// < Equalizer Off
  static const int BT_AVRCP_EQUALIZER_STATE_OFF = 1;

  /// < Equalizer On
  static const int BT_AVRCP_EQUALIZER_STATE_ON = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Enumerations for the repeat mode
/// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
abstract class bt_avrcp_repeat_mode_e {
  /// < Repeat Off
  static const int BT_AVRCP_REPEAT_MODE_OFF = 1;

  /// < Single track repeat
  static const int BT_AVRCP_REPEAT_MODE_SINGLE_TRACK = 2;

  /// < All track repeat
  static const int BT_AVRCP_REPEAT_MODE_ALL_TRACK = 3;

  /// < Group repeat
  static const int BT_AVRCP_REPEAT_MODE_GROUP = 4;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Enumerations for the shuffle mode
/// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
abstract class bt_avrcp_shuffle_mode_e {
  /// < Shuffle Off
  static const int BT_AVRCP_SHUFFLE_MODE_OFF = 1;

  /// < All tracks shuffle
  static const int BT_AVRCP_SHUFFLE_MODE_ALL_TRACK = 2;

  /// < Group shuffle
  static const int BT_AVRCP_SHUFFLE_MODE_GROUP = 3;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Enumerations for the scan mode
/// @since_tizen @if WEARABLE 3.0 @else 2.4 @endif
abstract class bt_avrcp_scan_mode_e {
  /// < Scan Off
  static const int BT_AVRCP_SCAN_MODE_OFF = 1;

  /// < All tracks scan
  static const int BT_AVRCP_SCAN_MODE_ALL_TRACK = 2;

  /// < Group scan
  static const int BT_AVRCP_SCAN_MODE_GROUP = 3;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Enumerations for the player state
/// @since_tizen 3.0
abstract class bt_avrcp_player_state_e {
  /// < Stopped
  static const int BT_AVRCP_PLAYER_STATE_STOPPED = 0;

  /// < Playing
  static const int BT_AVRCP_PLAYER_STATE_PLAYING = 1;

  /// < Paused
  static const int BT_AVRCP_PLAYER_STATE_PAUSED = 2;

  /// < Seek Forward
  static const int BT_AVRCP_PLAYER_STATE_FORWARD_SEEK = 3;

  /// < Seek Rewind
  static const int BT_AVRCP_PLAYER_STATE_REWIND_SEEK = 4;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Enumeration for the player control commands
/// @since_tizen 3.0
abstract class bt_avrcp_player_command_e {
  /// < Play
  static const int BT_AVRCP_CONTROL_PLAY = 1;

  /// < Pause
  static const int BT_AVRCP_CONTROL_PAUSE = 2;

  /// < Stop
  static const int BT_AVRCP_CONTROL_STOP = 3;

  /// < Next Track
  static const int BT_AVRCP_CONTROL_NEXT = 4;

  /// < Previous track
  static const int BT_AVRCP_CONTROL_PREVIOUS = 5;

  /// < Fast Forward
  static const int BT_AVRCP_CONTROL_FAST_FORWARD = 6;

  /// < Rewind
  static const int BT_AVRCP_CONTROL_REWIND = 7;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief Structure of Track metadata information.
/// @since_tizen 3.0
///
/// @see #bt_class_s
class bt_avrcp_metadata_attributes_info_s extends ffi.Struct {
  /// < Title
  external ffi.Pointer<ffi.Char> title;

  /// < Artist
  external ffi.Pointer<ffi.Char> artist;

  /// < Album name
  external ffi.Pointer<ffi.Char> album;

  /// < Album Genre
  external ffi.Pointer<ffi.Char> genre;

  /// < The total number of tracks
  @ffi.UnsignedInt()
  external int total_tracks;

  /// < Track number
  @ffi.UnsignedInt()
  external int number;

  /// < Duration
  @ffi.UnsignedInt()
  external int duration;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
/// @brief  Enumerations for the data channel type
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_hdp_channel_type_e {
  /// < Reliable Data Channel
  static const int BT_HDP_CHANNEL_TYPE_RELIABLE = 1;

  /// < Streaming Data Channel
  static const int BT_HDP_CHANNEL_TYPE_STREAMING = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Enumerations of the integer type for GATT handle's value.
/// @since_tizen 2.3.1
abstract class bt_data_type_int_e {
  /// < 8 bit signed int type
  static const int BT_DATA_TYPE_SINT8 = 0;

  /// < 16 bit signed int type
  static const int BT_DATA_TYPE_SINT16 = 1;

  /// < 32 bit signed int type
  static const int BT_DATA_TYPE_SINT32 = 2;

  /// < 8 bit unsigned int type
  static const int BT_DATA_TYPE_UINT8 = 3;

  /// < 16 bit unsigned int type
  static const int BT_DATA_TYPE_UINT16 = 4;

  /// < 32 bit unsigned int type
  static const int BT_DATA_TYPE_UINT32 = 5;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Enumerations of the float type for GATT handle's value.
/// @since_tizen 2.3.1
abstract class bt_data_type_float_e {
  /// < 32 bit float type
  static const int BT_DATA_TYPE_FLOAT = 0;

  /// < 16 bit float type
  static const int BT_DATA_TYPE_SFLOAT = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Enumerations of the write type.
/// @since_tizen 2.3.1
abstract class bt_gatt_write_type_e {
  /// < Write without response type
  static const int BT_GATT_WRITE_TYPE_WRITE_NO_RESPONSE = 0;

  /// < Write type
  static const int BT_GATT_WRITE_TYPE_WRITE = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Enumerations of the GATT handle's type.
/// @since_tizen 2.3.1
abstract class bt_gatt_type_e {
  /// < GATT service type
  static const int BT_GATT_TYPE_SERVICE = 1;
  static const int BT_GATT_TYPE_CHARACTERISTIC = 2;

  /// GATT characteristic type
  static const int BT_GATT_TYPE_DESCRIPTOR = 3;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Enumerations of the service type.
/// @since_tizen 2.3.1
abstract class bt_gatt_service_type_e {
  /// < GATT primary service type
  static const int BT_GATT_SERVICE_TYPE_PRIMARY = 1;

  /// < GATT secondary service type
  static const int BT_GATT_SERVICE_TYPE_SECONDARY = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Enumerations of the characteristic's property.
/// @since_tizen 2.3.1
abstract class bt_gatt_property_e {
  /// < Broadcast property
  static const int BT_GATT_PROPERTY_BROADCAST = 1;

  /// < Read property
  static const int BT_GATT_PROPERTY_READ = 2;

  /// < Write without response property
  static const int BT_GATT_PROPERTY_WRITE_WITHOUT_RESPONSE = 4;

  /// < Write property
  static const int BT_GATT_PROPERTY_WRITE = 8;

  /// < Notify property
  static const int BT_GATT_PROPERTY_NOTIFY = 16;

  /// < Indicate property
  static const int BT_GATT_PROPERTY_INDICATE = 32;

  /// < Authenticated signed writes property
  static const int BT_GATT_PROPERTY_AUTHENTICATED_SIGNED_WRITES = 64;

  /// < Extended properties
  static const int BT_GATT_PROPERTY_EXTENDED_PROPERTIES = 128;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
/// @brief  Enumerations of gatt server's service changing mode.
/// @since_tizen 3.0
abstract class bt_gatt_client_service_change_type_e {
  /// < Service added
  static const int BT_GATT_CLIENT_SERVICE_ADDED = 0;

  /// < Service removed
  static const int BT_GATT_CLIENT_SERVICE_REMOVED = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Enumerations of the attribute's permission.
/// @since_tizen 3.0
abstract class bt_gatt_permission_e {
  /// < Readable permission
  static const int BT_GATT_PERMISSION_READ = 1;

  /// < Writable permission
  static const int BT_GATT_PERMISSION_WRITE = 2;

  /// < Readable permission required encryption
  static const int BT_GATT_PERMISSION_ENCRYPT_READ = 4;

  /// < Writable permission required encryption
  static const int BT_GATT_PERMISSION_ENCRYPT_WRITE = 8;

  /// < Readable permission required encryption and authentication
  static const int BT_GATT_PERMISSION_ENCRYPT_AUTHENTICATED_READ = 16;

  /// < Writable permission required encryption and authentication
  static const int BT_GATT_PERMISSION_ENCRYPT_AUTHENTICATED_WRITE = 32;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
/// @brief  Enumerations of the remote device request types for attributes
/// @since_tizen 3.0
abstract class bt_gatt_att_request_type_e {
  static const int BT_GATT_REQUEST_TYPE_READ = 0;
  static const int BT_GATT_REQUEST_TYPE_WRITE = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_PAN_PANU_MODULE
/// @brief  Enumerations for the types of PAN(Personal Area Networking) service.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class bt_panu_service_type_e {
  /// < Network Access Point
  static const int BT_PANU_SERVICE_TYPE_NAP = 0;
}

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief  Enumeration of address book location for PBAP.
/// @since_tizen 3.0
abstract class bt_pbap_address_book_source_e {
  /// < Request for Addressbook from remote device
  static const int BT_PBAP_SOURCE_DEVICE = 0;

  /// < Request for address book from SIM
  static const int BT_PBAP_SOURCE_SIM = 1;
}

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief  Enumeration of folder type.
/// @since_tizen 3.0
abstract class bt_pbap_folder_type_e {
  /// < Request for address book
  static const int BT_PBAP_FOLDER_PHONE_BOOK = 0;

  /// < Request for incoming calls
  static const int BT_PBAP_FOLDER_INCOMING = 1;

  /// < Request for outgoing calls
  static const int BT_PBAP_FOLDER_OUTGOING = 2;

  /// < Request for missed calls
  static const int BT_PBAP_FOLDER_MISSED = 3;

  /// < Request for combined calls
  static const int BT_PBAP_FOLDER_COMBINED = 4;
}

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief  Enumeration of phone book search fields.
/// @since_tizen 3.0
abstract class bt_pbap_search_field_e {
  /// < Request for search by name (default)
  static const int BT_PBAP_SEARCH_NAME = 0;

  /// < Request for search by phone number
  static const int BT_PBAP_SEARCH_NUMBER = 1;

  /// < Request for search by sound
  static const int BT_PBAP_SEARCH_SOUND = 2;
}

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief  Enumeration of vCard Formats.
/// @since_tizen 3.0
abstract class bt_pbap_vcard_format_e {
  /// < vCard format 2.1 (default)
  static const int BT_PBAP_VCARD_FORMAT_VCARD21 = 0;

  /// < vCard format 3.0
  static const int BT_PBAP_VCARD_FORMAT_VCARD30 = 1;
}

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief  Enumeration of sorting orders.
/// @since_tizen 3.0
abstract class bt_pbap_sort_order_e {
  /// < Filter order indexed (default)
  static const int BT_PBAP_ORDER_INDEXED = 0;

  /// < Filter order alphanumeric
  static const int BT_PBAP_ORDER_ALPHANUMERIC = 1;

  /// < Filter order phonetic
  static const int BT_PBAP_ORDER_PHONETIC = 2;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief Class structure of device and service.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @see #bt_device_info_s
/// @see #bt_adapter_device_discovery_info_s
/// @see bt_device_bond_created_cb()
/// @see bt_adapter_device_discovery_state_changed_cb()
class bt_class_s extends ffi.Struct {
  /// < Major device class.
  @ffi.Int32()
  external int major_device_class;

  /// < Minor device class.
  @ffi.Int32()
  external int minor_device_class;

  /// < Major service class mask.
  /// This value can be a combination of #bt_major_service_class_e like #BT_MAJOR_SERVICE_CLASS_RENDERING | #BT_MAJOR_SERVICE_CLASS_AUDIO
  @ffi.Int()
  external int major_service_class_mask;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
/// @brief Structure of device discovery information.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @see #bt_class_s
/// @see bt_adapter_device_discovery_state_changed_cb()
class bt_adapter_device_discovery_info_s extends ffi.Struct {
  /// < The address of remote device
  external ffi.Pointer<ffi.Char> remote_address;

  /// < The name of remote device
  external ffi.Pointer<ffi.Char> remote_name;

  /// < The Bluetooth classes
  external bt_class_s bt_class;

  /// < The strength indicator of received signal
  @ffi.Int()
  external int rssi;

  /// < The bonding state
  @ffi.Bool()
  external bool is_bonded;

  /// < The UUID list of service
  external ffi.Pointer<ffi.Pointer<ffi.Char>> service_uuid;

  /// < The number of services
  @ffi.Int()
  external int service_count;

  /// < The Bluetooth appearance
  @ffi.Int32()
  external int appearance;

  /// < manufacturer specific data length
  @ffi.Int()
  external int manufacturer_data_len;

  /// < manufacturer specific data
  external ffi.Pointer<ffi.Char> manufacturer_data;
}

/// @deprecated Deprecated since 2.3.1
/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief Structure of le device discovery information.
/// @since_tizen @if WEARABLE @else 2.3 @endif
///
/// @see #bt_class_s
/// @see bt_adapter_le_device_discovery_state_changed_cb()
class bt_adapter_le_device_discovery_info_s extends ffi.Struct {
  /// < The address of remote device
  external ffi.Pointer<ffi.Char> remote_address;

  /// < The address type of remote device
  @ffi.Int()
  external int address_type;

  /// < The strength indicator of received signal
  @ffi.Int()
  external int rssi;

  /// < advertising indication data length
  @ffi.Int()
  external int adv_data_len;

  /// < advertising indication data
  external ffi.Pointer<ffi.Char> adv_data;

  /// < scan response data length
  @ffi.Int()
  external int scan_data_len;

  /// < scan response data
  external ffi.Pointer<ffi.Char> scan_data;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief Structure of le scan result information.
/// @since_tizen 2.3.1
///
/// @see bt_adapter_le_start_scan()
class bt_adapter_le_device_scan_result_info_s extends ffi.Struct {
  /// < The address of remote device
  external ffi.Pointer<ffi.Char> remote_address;

  /// < The address type of remote device
  @ffi.Int32()
  external int address_type;

  /// < The strength indicator of received signal
  @ffi.Int()
  external int rssi;

  /// < advertising indication data length
  @ffi.Int()
  external int adv_data_len;

  /// < advertising indication data
  external ffi.Pointer<ffi.Char> adv_data;

  /// < scan response data length
  @ffi.Int()
  external int scan_data_len;

  /// < scan response data
  external ffi.Pointer<ffi.Char> scan_data;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief The structure for LE iBeacon scan result information.
/// @since_tizen 4.0
///
/// @see bt_adapter_le_start_scan()
class bt_adapter_le_ibeacon_scan_result_info_s extends ffi.Struct {
  /// < Company ID
  @ffi.Int()
  external int company_id;

  /// < iBeacon type
  @ffi.Int()
  external int ibeacon_type;

  /// < UUID
  external ffi.Pointer<ffi.Char> uuid;

  /// < Major ID
  @ffi.Int()
  external int major_id;

  /// < Minor ID
  @ffi.Int()
  external int minor_id;

  /// < Measured power
  @ffi.Int()
  external int measured_power;
}

/// @deprecated Deprecated since 2.3.1
/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief Structure of advertising parameters.
/// @since_tizen @if WEARABLE @else 2.3 @endif
///
/// @see bt_adapter_le_advertising_state_changed_cb()
/// @see bt_adapter_le_start_advertising()
class bt_adapter_le_advertising_params_s extends ffi.Struct {
  /// < Minimum advertising interval for non-directed advertising.
  /// A multiple of 0.625ms is only allowed (Time range : 20ms to 10.24sec).
  @ffi.Float()
  external double interval_min;

  /// < Maximum advertising interval for non-directed advertising.
  /// A multiple of 0.625ms is only allowed (Time range : 20ms to 10.24sec).
  @ffi.Float()
  external double interval_max;

  @ffi.Char()
  external int filter_policy;

  @ffi.Char()
  external int type;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief LE service data structure.
/// @since_tizen 2.3.1
///
/// @see bt_adapter_le_get_scan_result_service_data()
class bt_adapter_le_service_data_s extends ffi.Struct {
  /// < 16 bit UUID of the service data
  external ffi.Pointer<ffi.Char> service_uuid;

  /// < Service data
  external ffi.Pointer<ffi.Char> service_data;

  /// < Service data length
  @ffi.Int()
  external int service_data_len;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief Device information structure used for identifying pear device.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @see #bt_class_s
/// @see bt_device_bond_created_cb()
class bt_device_info_s extends ffi.Struct {
  /// < The address of remote device
  external ffi.Pointer<ffi.Char> remote_address;

  /// < The name of remote device
  external ffi.Pointer<ffi.Char> remote_name;

  /// < The Bluetooth classes
  external bt_class_s bt_class;

  /// < The UUID list of service
  external ffi.Pointer<ffi.Pointer<ffi.Char>> service_uuid;

  /// < The number of services
  @ffi.Int()
  external int service_count;

  /// < The bonding state
  @ffi.Bool()
  external bool is_bonded;

  /// < The connection state
  @ffi.Bool()
  external bool is_connected;

  /// < The authorization state
  @ffi.Bool()
  external bool is_authorized;

  /// < manufacturer specific data length
  @ffi.Int()
  external int manufacturer_data_len;

  /// < manufacturer specific data
  external ffi.Pointer<ffi.Char> manufacturer_data;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief Service Discovery Protocol (SDP) data structure.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @details This protocol is used for discovering available services or pear device,
/// and finding one to connect with.
///
/// @see bt_device_service_searched_cb()
class bt_device_sdp_info_s extends ffi.Struct {
  /// < The address of remote device
  external ffi.Pointer<ffi.Char> remote_address;

  /// < The UUID list of service
  external ffi.Pointer<ffi.Pointer<ffi.Char>> service_uuid;

  /// < The number of services.
  @ffi.Int()
  external int service_count;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief Device connection information structure.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @see bt_device_connection_state_changed_cb()
class bt_device_connection_info_s extends ffi.Struct {
  /// < The address of remote device
  external ffi.Pointer<ffi.Char> remote_address;

  /// < Link type
  @ffi.Int32()
  external int link;

  /// < Disconnection reason
  @ffi.Int32()
  external int disconn_reason;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
/// @brief Rfcomm connection data used for exchanging data between Bluetooth devices.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @see bt_socket_connection_state_changed_cb()
class bt_socket_connection_s extends ffi.Struct {
  /// < The file descriptor of connected socket
  @ffi.Int()
  external int socket_fd;

  /// < The file descriptor of the server socket or -1 for client connection
  @ffi.Int()
  external int server_fd;

  /// < The local device role in this connection
  @ffi.Int32()
  external int local_role;

  /// < The remote device address
  external ffi.Pointer<ffi.Char> remote_address;

  /// < The service UUId
  external ffi.Pointer<ffi.Char> service_uuid;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
/// @brief Structure of RFCOMM received data.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @remarks User can use standard linux functions for reading/writing
/// data from/to sockets.
///
/// @see bt_socket_data_received_cb()
class bt_socket_received_data_s extends ffi.Struct {
  /// < The socket fd
  @ffi.Int()
  external int socket_fd;

  /// < The length of the received data
  @ffi.Int()
  external int data_size;

  /// < The received data
  external ffi.Pointer<ffi.Char> data;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
/// @brief Attribute protocol MTU change information structure.
/// @since_tizen 4.0
///
/// @see bt_gatt_client_att_mtu_changed_cb()
class bt_gatt_client_att_mtu_info_s extends ffi.Struct {
  /// < The address of remote device
  external ffi.Pointer<ffi.Char> remote_address;

  /// < MTU value
  @ffi.UnsignedInt()
  external int mtu;

  /// < Request status
  @ffi.UnsignedInt()
  external int status;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
/// @brief Enumerations of the Bluetooth HID mouse's button.
/// @since_tizen @if WEARABLE 3.0 @endif
abstract class bt_hid_mouse_button_e {
  /// <The mouse's none value
  static const int BT_HID_MOUSE_BUTTON_NONE = 0;

  /// <The mouse's left button value
  static const int BT_HID_MOUSE_BUTTON_LEFT = 1;

  /// <The mouse's right button value
  static const int BT_HID_MOUSE_BUTTON_RIGHT = 2;

  /// <The mouse's middle button value
  static const int BT_HID_MOUSE_BUTTON_MIDDLE = 4;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
/// @brief The structure type containing the HID mouse event information.
/// @since_tizen @if WEARABLE 3.0 @endif
///
/// @see bt_hid_device_send_mouse_event()
class bt_hid_mouse_data_s extends ffi.Struct {
  /// < The button values, we can combine key's values when we pressed multiple mouse buttons
  @ffi.Int()
  external int buttons;

  /// < The location's x value, -128 ~127
  @ffi.Int()
  external int axis_x;

  /// < The location's y value, -128 ~127
  @ffi.Int()
  external int axis_y;

  /// < The padding value, -128 ~127
  @ffi.Int()
  external int padding;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
/// @brief The structure type containing the HID keyboard event information.
/// @since_tizen @if WEARABLE 3.0 @endif
/// @details If you want to know more detail values, refer to http://www.usb.org/developers/hidpage/ and see "HID Usage Tables"
///
/// @see bt_hid_device_send_key_event()
class bt_hid_key_data_s extends ffi.Struct {
  /// < The modifier keys : such as shift, alt
  @ffi.UnsignedChar()
  external int modifier;

  @ffi.Array.multi([8])
  external ffi.Array<ffi.UnsignedChar> key;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
/// @brief Enumerations of the Bluetooth HID header type.
/// @since_tizen @if WEARABLE 3.0 @endif
abstract class bt_hid_header_type_e {
  /// < The Bluetooth HID header type: Handshake
  static const int BT_HID_HEADER_HANDSHAKE = 0;

  /// < The Bluetooth HID header type: HID control
  static const int BT_HID_HEADER_HID_CONTROL = 1;

  /// < The Bluetooth HID header type: Get report
  static const int BT_HID_HEADER_GET_REPORT = 2;

  /// < The Bluetooth HID header type: Set report
  static const int BT_HID_HEADER_SET_REPORT = 3;

  /// < The Bluetooth HID header type: Get protocol
  static const int BT_HID_HEADER_GET_PROTOCOL = 4;

  /// < The Bluetooth HID header type: Set protocol
  static const int BT_HID_HEADER_SET_PROTOCOL = 5;

  /// < The Bluetooth HID header type: Data
  static const int BT_HID_HEADER_DATA = 6;

  /// < The Bluetooth HID header type: Unknown
  static const int BT_HID_HEADER_UNKNOWN = 7;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
/// @brief Enumerations of the Bluetooth HID parameter type.
/// @since_tizen @if WEARABLE 3.0 @endif
abstract class bt_hid_param_type_e {
  /// < Parameter type: Input
  static const int BT_HID_PARAM_DATA_RTYPE_INPUT = 0;

  /// < Parameter type: Output
  static const int BT_HID_PARAM_DATA_RTYPE_OUTPUT = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
/// @brief Enumerations of the Bluetooth HID handshake type.
/// @since_tizen @if WEARABLE 3.0 @endif
abstract class bt_hid_handshake_type_e {
  /// < Handshake error code none
  static const int BT_HID_HANDSHAKE_SUCCESSFUL = 0;

  /// < Handshake error code Not Ready
  static const int BT_HID_HANDSHAKE_NOT_READY = 1;

  /// < Handshake error code send invalid report id
  static const int BT_HID_HANDSHAKE_ERR_INVALID_REPORT_ID = 2;

  /// < Handshake error code request unsupported request
  static const int BT_HID_HANDSHAKE_ERR_UNSUPPORTED_REQUEST = 3;

  /// < Handshake error code received invalid parameter
  static const int BT_HID_HANDSHAKE_ERR_INVALID_PARAMETER = 4;

  /// < unknown error
  static const int BT_HID_HANDSHAKE_ERR_UNKNOWN = 14;

  /// < Fatal error
  static const int BT_HID_HANDSHAKE_ERR_FATAL = 15;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
/// @brief The structure type containing data received from the HID Host.
/// @since_tizen @if WEARABLE 3.0 @endif
class bt_hid_device_received_data_s extends ffi.Struct {
  /// < The remote device's address
  external ffi.Pointer<ffi.Char> address;

  /// < The header type
  @ffi.Int32()
  external int header_type;

  /// < The parameter type
  @ffi.Int32()
  external int param_type;

  /// < The length of the received data
  @ffi.Int()
  external int data_size;

  /// < The received data
  external ffi.Pointer<ffi.Char> data;
}

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief The structure type containing vCard information.
/// @since_tizen 3.0
///
/// @see bt_pbap_client_pull_vcard()
class bt_pbap_vcard_info_s extends ffi.Struct {
  /// < The vcard index, used as a parameter for bt_pbap_client_pull_vcard()
  @ffi.Int()
  external int index;

  /// < The contact name of the vCard
  external ffi.Pointer<ffi.Char> contact_name;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief Enumeration for the scan filter type.
/// @since_tizen 4.0
/// @see bt_adapter_le_scan_filter_set_type()
abstract class bt_adapter_le_scan_filter_type_e {
  /// < iBeacon filter type
  static const int BT_ADAPTER_LE_SCAN_FILTER_TYPE_IBEACON = 0;

  /// < Proximity UUID filter type
  static const int BT_ADAPTER_LE_SCAN_FILTER_TYPE_PROXIMITY_UUID = 1;
}

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
/// @brief  Called when you get bonded devices repeatedly.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] device_info The bonded device information
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// \n @c false to break out of the loop.
/// @pre bt_adapter_foreach_bonded_device() will invoke this function.
///
/// @see bt_adapter_foreach_bonded_device()
typedef bt_adapter_bonded_device_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            ffi.Pointer<bt_device_info_s>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
/// @brief  Called when the Bluetooth adapter state changes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in]   result  The result of the adapter state changing
/// @param[in]   adapter_state  The adapter state to be changed
/// @param[in]   user_data  The user data passed from the callback registration function
/// @see bt_adapter_set_state_changed_cb()
/// @see bt_adapter_unset_state_changed_cb()
typedef bt_adapter_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
/// @brief  Called when adapter name changes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in]   device_name	The name of the Bluetooth device to be changed
/// @param[in]   user_data	The user data passed from the callback registration function
/// @pre This function will be invoked when the name of Bluetooth adapter changes
/// if you register this callback using bt_adapter_set_name_changed_cb().
/// @see bt_adapter_set_name()
/// @see bt_adapter_set_name_changed_cb()
/// @see bt_adapter_unset_name_changed_cb()
typedef bt_adapter_name_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
/// @brief  Called when the visibility mode changes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] result The result of the visibility mode changing
/// @param[in] visibility_mode The visibility mode to be changed
/// @param[in] user_data The user data passed from the callback registration function
///
/// @pre This function will be invoked when the visibility of Bluetooth adapter changes
/// if you register this callback using bt_adapter_set_visibility_mode_changed_cb().
///
/// @see bt_adapter_set_visibility_mode_changed_cb()
/// @see bt_adapter_unset_visibility_mode_changed_cb()
typedef bt_adapter_visibility_mode_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup  CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
/// @brief  Called every second until the visibility mode is changed to #BT_ADAPTER_VISIBILITY_MODE_NON_DISCOVERABLE.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @remarks  This callback function is called only if visibility mode is #BT_ADAPTER_VISIBILITY_MODE_LIMITED_DISCOVERABLE.
/// @param[in]  duration  The duration until the visibility mode is changed to #BT_ADAPTER_VISIBILITY_MODE_NON_DISCOVERABLE (in seconds)
/// @param[in]  user_data  The user data passed from the callback registration function
/// @pre  This function will be invoked if you register this callback using bt_adapter_set_visibility_duration_changed_cb().
/// @see  bt_adapter_set_visibility_duration_changed_cb()
/// @see  bt_adapter_unset_visibility_duration_changed_cb()
typedef bt_adapter_visibility_duration_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_MODULE
/// @brief  Called when the state of device discovery changes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @remarks If \a discovery_state is #BT_ADAPTER_DEVICE_DISCOVERY_FOUND,
/// then you can get some information, such as remote device address, remote device name, rssi, and bonding state.
///
/// @param[in] result The result of the device discovery
/// @param[in] discovery_state The discovery state to be changed
/// @param[in] discovery_info The information of the discovered device \n
/// If \a discovery_state is #BT_ADAPTER_DEVICE_DISCOVERY_STARTED or
/// #BT_ADAPTER_DEVICE_DISCOVERY_FINISHED, then \a discovery_info is NULL.
/// @param[in] user_data The user data passed from the callback registration function
///
/// @pre Either bt_adapter_start_device_discovery() or bt_adapter_stop_device_discovery() will invoke this function
/// if you register this callback using bt_adapter_set_device_discovery_state_changed_cb().
///
/// @see bt_adapter_start_device_discovery()
/// @see bt_adapter_stop_device_discovery()
/// @see bt_adapter_set_device_discovery_state_changed_cb()
/// @see bt_adapter_unset_device_discovery_state_changed_cb()
typedef bt_adapter_device_discovery_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int,
            ffi.Int32,
            ffi.Pointer<bt_adapter_device_discovery_info_s>,
            ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 2.3.1
/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief  Called when the state of LE device discovery changes.
/// @since_tizen @if WEARABLE @else 2.3 @endif
///
/// @remarks If \a discovery_state is #BT_ADAPTER_LE_DEVICE_DISCOVERY_FOUND,
/// then you can get some information, such as remote LE device address, remote device name, rssi, and bonding state.
///
/// @param[in] result The result of the LE device discovery
/// @param[in] discovery_state The discovery state to be changed
/// @param[in] discovery_info The information of the discovered LE device \n
/// If \a discovery_state is #BT_ADAPTER_LE_DEVICE_DISCOVERY_STARTED or
/// #BT_ADAPTER_LE_DEVICE_DISCOVERY_FINISHED, then \a discovery_info is NULL.
/// @param[in] user_data The user data passed from the callback registration function
///
/// @pre Either bt_adapter_start_device_discovery() or bt_adapter_stop_device_discovery() will invoke this function
/// if you register this callback using bt_adapter_set_device_discovery_state_changed_cb().
///
/// @see bt_adapter_le_start_device_discovery()
/// @see bt_adapter_le_stop_device_discovery()
/// @see bt_adapter_le_set_device_discovery_state_changed_cb()
/// @see bt_adapter_le_unset_device_discovery_state_changed_cb()
typedef bt_adapter_le_device_discovery_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int,
            ffi.Int32,
            ffi.Pointer<bt_adapter_le_device_discovery_info_s>,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief  Called when the LE advertisement has been found.
/// @since_tizen 2.3.1
///
/// @param[in] result The result of the LE scan
/// @param[in] info The information of the found LE advertisement.
/// @param[in] user_data The user data passed from the start function
///
/// @see bt_adapter_le_start_scan()
typedef bt_adapter_le_scan_result_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int,
            ffi.Pointer<bt_adapter_le_device_scan_result_info_s>,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief The handle to control Bluetooth LE advertising.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
typedef bt_advertiser_h = ffi.Pointer<ffi.Void>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_IPSP_MODULE
/// @brief Called when the IPSP initialization state changes.
/// @since_tizen 4.0
/// @param[in] result The result of the initialization or deinitialization request
/// @param[in] ipsp_initialized The initialized state: (@c true = initialized, @c false = deinitialized)
/// @param[in] user_data The user data passed from the initialization request function
/// @see bt_ipsp_initialize()
/// @see bt_ipsp_deinitialize()
typedef bt_ipsp_init_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_IPSP_MODULE
/// @brief Called when the IPSP connection state changes.
/// @since_tizen 4.0
/// @param[in] result The result of the connection or disconnection request
/// @param[in] connected The connection status: (@c true = connected, @c false = disconnected)
/// @param[in] remote_address  Address of remote device
/// @param[in] iface_name The network interface name for IPv6 network interface
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_ipsp_connect()
/// @see bt_ipsp_disconnect()
typedef bt_ipsp_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Bool, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief  Called when the state of advertiser changes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[out] result The result of the requested state change of advertiser
/// @param[out] advertiser The handle of the state changed advertiser
/// @param[out] adv_state The advertiser state to be changed
/// @param[out] user_data The user data passed from the start function
///
/// @see bt_adapter_le_start_advertising_new()
/// @see bt_adapter_le_stop_advertising()
typedef bt_adapter_le_advertising_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, bt_advertiser_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Called when you get connected profiles repeatedly.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] profile The connected Bluetooth profile
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// \n @c false to break out of the loop.
/// @pre bt_device_foreach_connected_profiles() will invoke this function.
/// @see bt_device_foreach_connected_profiles()
typedef bt_device_connected_profile = ffi.Pointer<
    ffi.NativeFunction<ffi.Bool Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief Called when the process of creating bond finishes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @remarks If the remote user does not respond within 60 seconds, a time out will happen with #BT_ERROR_TIMED_OUT result code.\n
/// If bt_device_cancel_bonding() is called and it returns #BT_ERROR_NONE, then this callback function will be called
/// with #BT_ERROR_CANCELLED result. \n
/// If creating a bond succeeds but service search fails, then this callback will be called with #BT_ERROR_SERVICE_SEARCH_FAILED.
/// In this case, you should try service search again by bt_device_start_service_search() to get the supported service list.
///
/// @param[in] result The result of the bonding device
/// @param[in] device_info The device information which you creates bond with
/// @param[in] user_data The user data passed from the callback registration function
///
/// @pre Either bt_device_create_bond() will invoke this function
/// if you register this callback using bt_device_set_bond_created_cb().
///
/// @see bt_device_create_bond()
/// @see bt_device_cancel_bonding()
/// @see bt_device_set_bond_created_cb()
/// @see bt_device_unset_bond_created_cb()
typedef bt_device_bond_created_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Pointer<bt_device_info_s>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Called when the bond destroys.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] result The result that a bond is destroyed
/// @param[in] remote_address The address of the remote Bluetooth device to destroy bond with
/// @param[in] user_data The user data passed from the callback registration function
/// @pre bt_device_destroy_bond() will invoke this function
/// if you register this callback using bt_device_set_bond_destroyed_cb().
///
/// @see bt_device_destroy_bond()
/// @see bt_device_set_bond_destroyed_cb()
/// @see bt_device_unset_bond_destroyed_cb()
typedef bt_device_bond_destroyed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Called when the authorization of device changes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] authorization The authorization of device
/// @param[in] remote_address The address of the remote Bluetooth device which is (un)authorized
/// @param[in] user_data The user data passed from the callback registration function
/// @pre bt_device_set_authorization() will invoke this function if you register this callback using bt_device_set_authorization_changed_cb().
///
/// @see bt_device_set_authorization()
/// @see #bt_device_set_authorization_changed_cb()
/// @see #bt_device_unset_authorization_changed_cb()
typedef bt_device_authorization_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Called when the process of service search finishes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @remark
///
/// @param[in] result The result of the service searching
/// @param[in] sdp_info The structure of service lists found on a device
/// @param[in] user_data The user data passed from the callback registration function
/// @pre Either bt_device_start_service_search() will invoke this function
/// if you register this callback using  bt_device_set_service_searched_cb().
///
/// @see bt_device_start_service_search()
/// @see bt_device_set_service_searched_cb()
/// @see bt_device_unset_service_searched_cb()
typedef bt_device_service_searched_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Pointer<bt_device_sdp_info_s>,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_DEVICE_MODULE
/// @brief  Called when the connection state is changed.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] connected The connection status: (@c true = connected, @c false = disconnected)
/// @param[in] conn_info The connection information
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_device_set_connection_state_changed_cb()
/// @see bt_device_unset_connection_state_changed_cb()
typedef bt_device_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Bool, ffi.Pointer<bt_device_connection_info_s>,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
/// @brief Called when you receive data.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] data The received data from the remote device
/// @param[in] user_data The user data passed from the callback registration function
///
/// @pre When the connected remote Bluetooth device invokes bt_socket_send_data(),
/// this function will be invoked if you register this function using bt_socket_set_data_received_cb().
///
/// @see bt_socket_set_data_received_cb()
/// @see bt_socket_unset_data_received_cb()
/// @see bt_socket_send_data()
typedef bt_socket_data_received_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<bt_socket_received_data_s>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
/// @brief  Called when a RFCOMM connection is requested.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] socket_fd  The file descriptor of socket on which a connection is requested
/// @param[in] remote_address  The address of remote device
/// @param[in] user_data The user data passed from the callback registration function
/// @pre If you register this callback function by bt_socket_set_connection_requested_cb(),
/// bt_socket_connection_requested_cb() will be invoked.
typedef bt_socket_connection_requested_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_SOCKET_MODULE
/// @brief  Called when the socket connection state changes.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] result The result of connection state changing
/// @param[in] connection_state The connection state
/// @param[in] connection The connection information which is established or disconnected
/// @param[in] user_data The user data passed from the callback registration function
/// @pre Either bt_socket_connect_rfcomm() will invoke this function.
/// In addition, bt_socket_connection_state_changed_cb() will be invoked when the socket connection state is changed.
/// @see bt_socket_listen_and_accept_rfcomm()
/// @see bt_socket_connect_rfcomm()
/// @see bt_socket_set_connection_state_changed_cb()
/// @see bt_socket_unset_connection_state_changed_cb()
typedef bt_socket_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Int32,
            ffi.Pointer<bt_socket_connection_s>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_SERVER_MODULE
/// @brief  Called when an OPP connection is requested.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @details You must call bt_opp_server_accept_connection() if you want to accept.
/// Otherwise, you must call bt_opp_server_reject_connection().
/// @param[in] remote_address  The address of remote device
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_opp_server_accept()
/// @see bt_opp_server_reject()
typedef bt_opp_server_connection_requested_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_SERVER_MODULE
/// @brief  Called when a file is being transferred.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] file  The path of file to be pushed
/// @param[in] size The file size (bytes)
/// @param[in] percent The progress in percentage (1 ~ 100)
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_opp_server_accept()
/// @see bt_opp_server_accept_connection()
typedef bt_opp_server_transfer_progress_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.LongLong, ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_SERVER_MODULE
/// @brief  Called when a transfer is finished.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] error_code  The result of push
/// @param[in] file  The path of file to be pushed
/// @param[in] size The file size (bytes)
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_opp_server_accept()
/// @see bt_opp_server_accept_connection()
typedef bt_opp_server_transfer_finished_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Char>, ffi.LongLong,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_CLIENT_MODULE
/// @brief  Called when OPP server responds to the push request.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] result  The result of OPP server response
/// @param[in] remote_address  The remote address
/// @param[in] user_data  The user data passed from the callback registration function
/// @pre bt_opp_client_push_files() will invoke this function.
/// @see bt_opp_client_push_files()
typedef bt_opp_client_push_responded_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_CLIENT_MODULE
/// @brief  Called when each file is being transferred.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] file  The path of file to be pushed
/// @param[in] size The file size (bytes)
/// @param[in] percent The progress in percentage (1 ~ 100). 100 means that a file is transferred completely.
/// @param[in] user_data The user data passed from the callback registration function
/// @pre bt_opp_client_push_files() will invoke this function.
/// @see bt_opp_client_push_files()
typedef bt_opp_client_push_progress_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.LongLong, ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_OPP_CLIENT_MODULE
/// @brief  Called when the push request is finished.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] result  The result of the push request
/// @param[in] remote_address  The remote address
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_opp_client_push_files()
typedef bt_opp_client_push_finished_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_HID_MODULE
/// @brief  Called when the connection state is changed.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @details  This callback is called when the connection state is changed.
/// When you call bt_hid_host_connect() or bt_hid_host_disconnect(), this callback is also called with error result even though these functions fail.
/// @param[in] result  The result of changing the connection state
/// @param[in] connected  The state to be changed. @a true means connected state, Otherwise, @a false.
/// @param[in] remote_address  The remote address
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_hid_host_connect()
/// @see bt_hid_host_disconnect()
typedef bt_hid_host_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Bool, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
/// @brief  Called when the Bluetooth HID Device connection state changes.
/// @details The following error codes can be delivered: \n
/// #BT_ERROR_NONE \n
/// #BT_ERROR_OPERATION_FAILED \n
/// @since_tizen @if WEARABLE 3.0 @endif
///
/// @param[in]   result  The result of changing the connection state.
/// @param[in]   connected  The requested state. @a true means the connection is enabled, @a false means the connection is disabled.
/// @param[in]   remote_address  The remote device's address
/// @param[in]   user_data  The user data passed from the callback registration function
/// @see bt_hid_device_activate()
typedef bt_hid_device_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Bool, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_HID_DEVICE_MODULE
/// @brief  Called when the HID Device receives data from the HID Host.
/// @details The following error codes can be delivered: \n
/// #BT_ERROR_NONE \n
/// #BT_ERROR_OPERATION_FAILED \n
/// @since_tizen @if WEARABLE 3.0 @endif
///
/// @param[in]   data  The data received from the HID Host.
/// @param[in]   user_data  The user data passed from the callback registration function
/// @see bt_hid_device_set_data_received_cb()
typedef bt_hid_device_data_received_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<bt_hid_device_received_data_s>,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_AUDIO_MODULE
/// @brief  Called when the connection state is changed.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @details  This callback is called when the connection state is changed.
/// When you call bt_audio_connect() or bt_audio_disconnect(), this callback is also called with error result even though these functions fail.
/// @param[in] result  The result of changing the connection state
/// @param[in] connected  The state to be changed. @a true means connected state, Otherwise, @a false.
/// @param[in] remote_address  The remote address
/// @param[in] type  The type of audio profile except #BT_AUDIO_PROFILE_TYPE_ALL
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_audio_set_connection_state_changed_cb()
/// @see bt_audio_unset_connection_state_changed_cb()
typedef bt_audio_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Bool, ffi.Pointer<ffi.Char>, ffi.Int32,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Called when the connection state is changed.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] connected  The state to be changed. @a true means connected state, Otherwise, @a false.
/// @param[in] remote_address  The remote address
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_avrcp_target_initialize()
/// @see bt_avrcp_target_deinitialize()
typedef bt_avrcp_target_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Bool, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Called when the equalizer state is changed by the remote control device.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] equalizer The equalizer state
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_avrcp_set_equalizer_state_changed_cb()
/// @see bt_avrcp_unset_equalizer_state_changed_cb()
typedef bt_avrcp_equalizer_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Called when the repeat mode is changed by the remote control device.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] repeat The repeat mode
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_avrcp_set_repeat_mode_changed_cb()
/// @see bt_avrcp_unset_repeat_mode_changed_cb()
typedef bt_avrcp_repeat_mode_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Called when the shuffle mode is changed by the remote control device.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] shuffle The shuffle mode
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_avrcp_set_shuffle_mode_changed_cb()
/// @see bt_avrcp_unset_shuffle_mode_changed_cb()
typedef bt_avrcp_shuffle_mode_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Called when the scan mode is changed by the remote control device.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] shuffle The shuffle mode
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_avrcp_set_scan_mode_changed_cb()
/// @see bt_avrcp_unset_scan_mode_changed_cb()
typedef bt_avrcp_scan_mode_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Called when the Song position mode is changed by the remote target device.
/// @since_tizen 3.0
/// @param[in] position Playback position in milliseconds. When position is 0 it means the track is starting and when it's greater than or equal to track's duration the track has ended.
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_avrcp_set_position_changed_cb()
/// @see bt_avrcp_unset_position_changed_cb()
typedef bt_avrcp_position_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.UnsignedInt, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Called when the Song Play status mode is changed by the remote target device.
/// @since_tizen 3.0
/// @param[in] play_state The song play status
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_avrcp_set_play_status_changed_cb()
/// @see bt_avrcp_unset_play_status_changed_cb()
typedef bt_avrcp_play_status_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Called when the Song metadata information is changed by the remote target device.
/// @since_tizen 3.0
/// @param[in] track The song metadata information
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_avrcp_set_track_info_changed_cb()
/// @see bt_avrcp_unset_track_info_changed_cb()
typedef bt_avrcp_track_info_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<bt_avrcp_metadata_attributes_info_s>,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_AVRCP_MODULE
/// @brief  Called when the connection state is changed.
/// @since_tizen 3.0
/// @param[in] connected  The state to be changed. @a true means connected state, Otherwise, @a false.
/// @param[in] remote_address  The remote address
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_avrcp_control_initialize()
/// @see bt_avrcp_control_deinitialize()
typedef bt_avrcp_control_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Bool, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
/// @brief  Called when the connection is established.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] result  The result of connecting to the remote device
/// @param[in] remote_address  The address of connected remote device
/// @param[in] app_id  The ID of application
/// @param[in] type  The type of HDP(Health Device Profile) channel
/// @param[in] channel  The connected data channel
/// @param[in] user_data The user data passed from the callback registration function
/// @see  bt_hdp_disconnected_cb
/// @see bt_hdp_set_connection_state_changed_cb()
/// @see bt_hdp_unset_connection_state_changed_cb()
typedef bt_hdp_connected_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Int32, ffi.UnsignedInt, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
/// @brief  Called when the connection is disconnected.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] result  The result of disconnecting from the remote device
/// @param[in] remote_address  The address of disconnected remote device
/// @param[in] channel  The connected data channel
/// @param[in] user_data The user data passed from the callback registration function
/// @see  bt_hdp_connected_cb
/// @see bt_hdp_set_connection_state_changed_cb()
/// @see bt_hdp_unset_connection_state_changed_cb()
typedef bt_hdp_disconnected_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Char>, ffi.UnsignedInt,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_HDP_MODULE
/// @brief  Called when the you receive the data.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] channel  The connected data channel
/// @param[in] data  The received data
/// @param[in] size  The size of received data (byte)
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_hdp_set_data_received_cb()
/// @see bt_hdp_unset_data_received_cb()
typedef bt_hdp_data_received_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.UnsignedInt, ffi.Pointer<ffi.Char>,
            ffi.UnsignedInt, ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 2.3.1. Use bt_gatt_foreach_cb instead.
/// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Called when you get the primary services repeatedly.
/// @since_tizen @if WEARABLE @else 2.3 @endif
///
/// @param[in]  service  The attribute handle of service
/// @param[in]  user_data  The user data passed from the foreach function
/// @return  @c true to continue with the next iteration of the loop,
/// \n @c false to break out of the loop.
/// @pre  bt_gatt_foreach_primary_services() will invoke this function.
/// @see  bt_gatt_foreach_primary_services()
typedef bt_gatt_primary_service_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(bt_gatt_attribute_h, ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 2.3.1. Use bt_gatt_h instead.
/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  The attribute handle of GATT(Generic Attribute Profile).
/// @since_tizen @if WEARABLE @else 2.3 @endif
typedef bt_gatt_attribute_h = ffi.Pointer<ffi.Void>;

/// @deprecated Deprecated since 2.3.1. This is not required because characteristic discovery is happened automatically.
/// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Called after the characteristics are discovered by bt_gatt_discover_characteristics().
/// @since_tizen @if WEARABLE @else 2.3 @endif
///
/// @remarks  If bt_gatt_discover_characteristics() failed, then this callback function is called only once with 0 total and NULL characteristic_handle.
/// @param[in]  result  The result of discovering
/// @param[in]  index  The index of characteristics in a service, starts from 0
/// @param[in]  total  The total number of characteristics in a service
/// @param[in]  characteristic  The attribute handle of characteristic
/// @param[in]  user_data  The user data passed from the request function
/// @return  @c true to continue with the next iteration of the loop,
/// \n @c false to break out of the loop.
/// @pre  bt_gatt_discover_characteristics() will invoke this callback.
/// @see  bt_gatt_discover_characteristics()
typedef bt_gatt_characteristics_discovered_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Int, ffi.Int, bt_gatt_attribute_h,
            ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 2.3.1. Use bt_gatt_foreach_cb instead.
/// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Called when you get the included services repeatedly.
/// @since_tizen @if WEARABLE @else 2.3 @endif
///
/// @param[in]  service  The attribute handle of service
/// @param[in]  user_data  The user data passed from the foreach function
/// @return  @c true to continue with the next iteration of the loop,
/// \n @c false to break out of the loop.
/// @pre  bt_gatt_foreach_included_services() will invoke this function.
/// @see  bt_gatt_foreach_included_services()
typedef bt_gatt_included_service_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(bt_gatt_attribute_h, ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 2.3.1. Use bt_gatt_client_characteristic_value_changed_cb instead.
/// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Called when a characteristic in service is changed.
/// @since_tizen @if WEARABLE @else 2.3 @endif
///
/// @param[in]  characteristic  The attribute handle of characteristic
/// @param[in]  value  The value of characteristic (byte array)
/// @param[in]  value_length  The length of value
/// @param[in]  user_data  The user data passed from the callback registration function
/// @see bt_gatt_set_characteristic_changed_cb()
/// @see bt_gatt_unset_characteristic_changed_cb()
typedef bt_gatt_characteristic_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(bt_gatt_attribute_h, ffi.Pointer<ffi.UnsignedChar>,
            ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 2.3.1. Use bt_gatt_client_request_completed_cb instead.
/// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Called when a characteristic value is written.
/// @since_tizen @if WEARABLE @else 2.3 @endif
///
/// @see bt_gatt_set_characteristic_value()
typedef bt_gatt_characteristic_write_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 2.3.1. Use bt_gatt_client_request_completed_cb instead.
/// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Called when a characteristic value is read.
/// @since_tizen @if WEARABLE @else 2.3 @endif
///
/// @param[in]  value  The value of characteristic (byte array)
/// @param[in]  value_length  The length of value
/// @param[in]  user_data  The user data passed from the foreach function
/// @see bt_gatt_read_characteristic_value()
typedef bt_gatt_characteristic_read_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.UnsignedChar>, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @deprecated Deprecated since 2.3.1. This is not required because descriptor discovery is happened automatically.
/// @ingroup  CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Called after the characteristics descriptors are discovered by bt_gatt_discover_characteristic_descriptor().
/// @since_tizen @if WEARABLE @else 2.3 @endif
///
/// @param[in]  result  The result of discovering
/// @param[in]  characteristic_format  The format of the information data.
/// characteristic_format = 0x01 indicates UUIDs are 16-bits
/// characteristic_format = 0x02 indicates UUIDs are 128-bits
/// @param[in]  total  The total number of elements in characteristic_descriptor
/// @param[in]  characteristic descriptor  The attribute handle and the UUID of characteristic descriptor
/// @param[in]  user_data  The user data passed from the request function
/// @see  bt_gatt_discover_characteristic_descriptor()
typedef bt_gatt_characteristic_descriptor_discovered_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.UnsignedChar, ffi.Int,
            bt_gatt_attribute_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief The handle of a service, characteristic or descriptor.
/// @since_tizen 2.3.1
typedef bt_gatt_h = ffi.Pointer<ffi.Void>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
/// @brief The handle of a GATT client which is associated with a remote device.
/// @since_tizen 2.3.1
typedef bt_gatt_client_h = ffi.Pointer<ffi.Void>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief  Called when you get GATT handles repeatedly
/// @since_tizen 2.3.1
///
/// @param[in] total The total number of GATT handles to be called
/// @param[in] index The index of current GATT handle. It starts from 0.
/// @param[in] gatt_handle The GATT handle
/// @param[in] user_data The user data passed from the foreach function
///
/// @see bt_gatt_service_foreach_characteristics()
/// @see bt_gatt_service_foreach_included_services()
/// @see bt_gatt_characteristic_foreach_descriptors()
/// @see bt_gatt_client_foreach_services()
typedef bt_gatt_foreach_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Int, bt_gatt_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
/// @brief  Called when the client request(e.g. read / write) has been completed
/// @since_tizen 2.3.1
///
/// @param[in] result The result of a request
/// @param[in] request_handle The requesting GATT handle
/// @param[in] user_data The user data passed from the requesting function
///
/// @see bt_gatt_client_read_value()
/// @see bt_gatt_client_write_value()
typedef bt_gatt_client_request_completed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, bt_gatt_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
/// @brief Called when the ATT MTU value is changed.
/// @since_tizen 4.0
///
/// @remarks The @a mtu_info must not be freed by application.
/// @a mtu_info can be used only inside the callback.
/// If it's needed outside, make a copy.
///
/// @param[in] client The handle of a GATT client which is associated with a remote device
/// @param[in] mtu_info The MTU information
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_gatt_client_set_connection_state_changed_cb()
/// @see bt_gatt_client_unset_connection_state_changed_cb()
typedef bt_gatt_client_att_mtu_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            bt_gatt_client_h,
            ffi.Pointer<bt_gatt_client_att_mtu_info_s>,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
/// @brief  Called when a value of a watched characteristic's GATT handle has been changed
/// @since_tizen 2.3.1
///
/// @remarks After this function is returned, a changed value is automatically
/// applied to @a characteristic. Before that, @a characteristic has an old value.
///
/// @param[in] characteristic The characteristic's GATT handle of which value change is informed. It has an old value.
/// @param[in] value The new value
/// @param[in] len The length of @a value
/// @param[in] user_data The user data passed from the registering function
///
/// @see bt_gatt_client_set_characteristic_value_changed_cb()
typedef bt_gatt_client_characteristic_value_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            bt_gatt_h, ffi.Pointer<ffi.Char>, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_CLIENT_MODULE
/// @brief  Called when a service of a remote GATT server has been changed.
/// @since_tizen 3.0
///
/// @param[in] client The handle of a GATT client which is associated with a remote device.
/// @param[in] change_type The changed type
/// @param[in] service_uuid The changed service uuid
/// @param[in] user_data The user data passed from the registering function
///
/// @see bt_gatt_client_set_characteristic_value_changed_cb()
typedef bt_gatt_client_service_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(bt_gatt_client_h, ffi.Int32, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_MODULE
/// @brief Called when the connection state is changed.
/// @since_tizen @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @details This callback is called when the connection state is changed.
/// When you called bt_gatt_connect() or bt_gatt_disconnect(), this callback is also called with error result even though these functions fail.
///
/// @param[in] result The result of changing the connection state.
/// @param[in] connected The state to be changed, @a true means connected state, Otherwise, @a false.
/// @param[in] remote_address The remote_address
/// @param[in] user_data The user data passed from the callback registration function.
///
/// @see bt_gatt_connect()
/// @see bt_gatt_disconnect()
/// @see bt_gatt_set_connection_state_changed_cb()
/// @see bt_gatt_unset_connection_state_changed_cb()
typedef bt_gatt_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Bool, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
/// @brief The handle of a GATT server.
/// @since_tizen 3.0
typedef bt_gatt_server_h = ffi.Pointer<ffi.Void>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
/// @brief  Called when the remote device requests to read a value on a GATT server.
/// @since_tizen 3.0
///
/// @details For finishing the request, call the function #bt_gatt_server_send_response in callback.
///
/// @remarks The @a remote_address must not be freed by application.
/// @remarks The @a server must not be freed by application.
/// @remarks The @a gatt_handle must not be freed by application.
///
/// @param[in] remote_address The address of the requesting remote device
/// @param[in] request_id The identification of this request. It will be used to send a response.
/// @param[in] server The GATT server handle
/// @param[in] gatt_handle The characteristic or descriptor's GATT handle to be read
/// @param[in] offset The requested offset from where the GATT handle's value is read
/// @param[in] user_data The user data passed from the registration function
///
/// @see bt_gatt_server_set_read_value_requested_cb()
/// @see bt_gatt_server_send_response()
typedef bt_gatt_server_read_value_requested_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Int, bt_gatt_server_h,
            bt_gatt_h, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
/// @brief  Called when the remote device enables or disables the Notification/Indication for particular characteristics.
/// @since_tizen 3.0
///
/// @details By using this callback function, server can know notification state.
///
/// @remarks The @a server must not be freed by application.
/// @remarks The @a gatt_handle must not be freed by application.
///
/// @param[in] notify Indicates whether the Notification/Indication is enabled or not
/// @param[in] server The GATT server handle
/// @param[in] gatt_handle The characteristic's GATT handle to be read
/// @param[in] user_data The user data passed from the registration function
///
/// @see bt_gatt_server_set_read_value_requested_cb()
typedef bt_gatt_server_characteristic_notification_state_changed_cb
    = ffi.Pointer<
        ffi.NativeFunction<
            ffi.Void Function(
                ffi.Bool, bt_gatt_server_h, bt_gatt_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
/// @brief  Called when a value of a characteristic or descriptor's GATT handle has been changed.
/// @since_tizen 3.0
///
/// @details For finishing the request, call the function #bt_gatt_server_send_response in callback.
///
/// @remarks After this function is returned, a changed value is automatically
/// applied to @a gatt_handle. Before that, @a gatt_handle has an old value.
/// @remarks The @a remote_address must not be freed by application.
/// @remarks The @a server must not be freed by application.
/// @remarks The @a gatt_handle must not be freed by application.
/// @remarks The @a value must not be freed by application.
///
/// @param[in] remote_address The address of the remote device which requests a change
/// @param[in] request_id The identification of this request. It will be used to send a response.
/// @param[in] server The GATT server handle
/// @param[in] gatt_handle The characteristic or descriptor's GATT handle which has an old value
/// @param[in] response_needed Indicates whether a response is required by the remote device - @c true if required, @c false if not
/// @param[in] offset The requested offset from where the @a gatt_handle value will be updated
/// @param[in] value The new value
/// @param[in] len The length of @a value
/// @param[in] user_data The user data passed from the registration function
///
/// @see bt_gatt_server_set_write_value_requested_cb()
/// @see bt_gatt_server_send_response()
typedef bt_gatt_server_write_value_requested_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.Char>,
            ffi.Int,
            bt_gatt_server_h,
            bt_gatt_h,
            ffi.Bool,
            ffi.Int,
            ffi.Pointer<ffi.Char>,
            ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_GATT_SERVER_MODULE
/// @brief  Called when the sending notification / indication is done.
/// @since_tizen 3.0
///
/// @remarks The @a remote_address must not be freed by application.
/// @remarks The @a server must not be freed by application.
/// @remarks The @a characteristic must not be freed by application.
///
/// @remarks In case of an indication, once a confirmation is received from the remote device this callback will be called. \n
/// This callback will be called several times if there are two or more remote devices which enable a Client Characteristic Configuration Descriptor(CCCD). \n
/// For the last remote device, @a completed will be set as true.
///
/// @param[in] result The result of a sending operation
/// @param[in] remote_address The address of the remote device
/// @param[in] server The GATT server handle
/// @param[in] characteristic The characteristic's GATT handle
/// @param[in] completed If this callback is for the last remote device which enables a CCCD, it will be true. Or it will be false.
/// @param[in] user_data The user data passed from the requesting function
///
/// @see bt_gatt_server_notify_characteristic_changed_value()
typedef bt_gatt_server_notification_sent_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Char>, bt_gatt_server_h,
            bt_gatt_h, ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief  Called when PBAP is Connected or Disconnected.
/// @details The following error codes can be delivered: \n
/// #BT_ERROR_NONE \n
/// #BT_ERROR_OPERATION_FAILED \n
/// @since_tizen 3.0
///
/// @param[in] result The result of connecting to or disconnecting from the remote device
/// @param[in] connected The PBAP connection status (@c true = connected, @c false = disconnected)
/// @param[in] remote_address The remote device address (@a remote_address is valid only inside this function. To use outside the callback, make a copy. @a remote_address should not be freed.)
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_pbap_client_connect()
/// @see bt_pbap_client_disconnect()
typedef bt_pbap_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Bool, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief  Called when PBAP Phonebook size calculation completes.
/// @details The following error codes can be delivered: \n
/// #BT_ERROR_NONE \n
/// #BT_ERROR_OPERATION_FAILED \n
/// @since_tizen 3.0
///
/// @param[in] result The result of getting the phone book size
/// @param[in] remote_address The remote device address (@a remote_address is valid only inside this function. To use outside the callback, make a copy. @a remote_address should not be freed.)
/// @param[in] size Size of Phonebook
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_pbap_client_get_phone_book_size()
/// @see bt_pbap_client_connect()
/// @see bt_pbap_client_disconnect()
typedef bt_pbap_phone_book_size_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Pointer<ffi.Char>, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief  Called when PBAP Phonebook Pull completes.
/// @details The received phone book file will be saved in the platform downloads folder. \n
/// The following error codes can be delivered: \n
/// #BT_ERROR_NONE \n
/// #BT_ERROR_OPERATION_FAILED \n
/// @since_tizen 3.0
///
/// @param[in] result The result of getting the phone book
/// @param[in] remote_address The remote device address (@a remote_address is valid only inside this function. To use outside the callback, make a copy. @a remote_address should not be freed.)
/// @param[in] vcf_file The absolute path of the file in which the vCards are saved (@a vcf_file is valid only inside this function. To use outside the callback, make a copy. @a vcf_file should not be freed.)
/// @param[in] successful true if the operation was successful, false if not
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_pbap_client_get_phone_book()
/// @see bt_pbap_client_connect()
/// @see bt_pbap_client_disconnect()
typedef bt_pbap_phone_book_received_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @WEARABLE_ONLY
/// @ingroup CAPI_NETWORK_BLUETOOTH_PBAP_MODULE
/// @brief  Called when PBAP List vCards completes.
/// @details The following error codes can be delivered: \n
/// #BT_ERROR_NONE \n
/// #BT_ERROR_OPERATION_FAILED \n
/// @since_tizen 3.0
///
/// @param[in] result The result of getting the vcard list
/// @param[in] remote_address The remote device address (@a remote_address is valid only inside this function. To use outside the callback, make a copy. @a remote_address should not be freed.)
/// @param[in] vcard_info List of vcard information (@a vcard_info is valid only inside this function. To use outside the callback, make a copy. @a vcard_info should not be freed.)
/// @param[in] count Number of contacts in the list
/// @param[in] successful true if the operation was successful, false if not
/// @param[in] user_data The user data passed from the callback registration function
/// @see bt_pbap_client_get_list()
/// @see bt_pbap_client_connect()
/// @see bt_pbap_client_disconnect()
typedef bt_pbap_list_vcards_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<bt_pbap_vcard_info_s>,
            ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_NETWORK_BLUETOOTH_ADAPTER_LE_MODULE
/// @brief The handle of a Bluetooth LE scan filter.
/// @since_tizen 4.0
typedef bt_scan_filter_h = ffi.Pointer<ffi.Void>;

/// @brief Enumeration for security type of Wi-Fi.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_wifi_security_type_e {
  /// < Security disabled
  static const int CONNECTION_WIFI_SECURITY_TYPE_NONE = 0;

  /// < WEP
  static const int CONNECTION_WIFI_SECURITY_TYPE_WEP = 1;

  /// < WPA-PSK
  static const int CONNECTION_WIFI_SECURITY_TYPE_WPA_PSK = 2;

  /// < WPA2-PSK
  static const int CONNECTION_WIFI_SECURITY_TYPE_WPA2_PSK = 3;

  /// < EAP
  static const int CONNECTION_WIFI_SECURITY_TYPE_EAP = 4;
}

/// @brief Enumeration for encryption modes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_wifi_encryption_type_e {
  /// < Encryption disabled
  static const int CONNECTION_WIFI_ENCRYPTION_TYPE_NONE = 0;

  /// < WEP
  static const int CONNECTION_WIFI_ENCRYPTION_TYPE_WEP = 1;

  /// < TKIP
  static const int CONNECTION_WIFI_ENCRYPTION_TYPE_TKIP = 2;

  /// < AES
  static const int CONNECTION_WIFI_ENCRYPTION_TYPE_AES = 3;

  /// < TKIP and AES are both supported
  static const int CONNECTION_WIFI_ENCRYPTION_TYPE_TKIP_AES_MIXED = 4;
}

/// @brief Enumeration for cellular service type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_cellular_service_type_e {
  /// < Unknown
  static const int CONNECTION_CELLULAR_SERVICE_TYPE_UNKNOWN = 0;

  /// < Internet
  static const int CONNECTION_CELLULAR_SERVICE_TYPE_INTERNET = 1;

  /// < MMS
  static const int CONNECTION_CELLULAR_SERVICE_TYPE_MMS = 2;

  /// < Prepaid internet
  static const int CONNECTION_CELLULAR_SERVICE_TYPE_PREPAID_INTERNET = 3;

  /// < Prepaid MMS
  static const int CONNECTION_CELLULAR_SERVICE_TYPE_PREPAID_MMS = 4;

  /// < Tethering
  static const int CONNECTION_CELLULAR_SERVICE_TYPE_TETHERING = 5;

  /// < Specific application
  static const int CONNECTION_CELLULAR_SERVICE_TYPE_APPLICATION = 6;
}

/// @brief Enumeration for cellular pdn type.
/// @since_tizen 3.0
/// @remarks Use CONNECTION_CELLULAR_PDN_TYPE_IPV4_IPV6 instead of
/// CONNECTION_CELLULAR_PDN_TYPE_IPV4_IPv6.
abstract class connection_cellular_pdn_type_e {
  static const int CONNECTION_CELLULAR_PDN_TYPE_UNKNOWN = 0;

  /// > Unknown
  static const int CONNECTION_CELLULAR_PDN_TYPE_IPV4 = 1;

  /// > IPv4
  static const int CONNECTION_CELLULAR_PDN_TYPE_IPV6 = 2;

  /// > IPv6
  static const int CONNECTION_CELLULAR_PDN_TYPE_IPV4_IPv6 = 3;

  /// > IPv4 and IPv6 (Deprecated since 4.0)
  static const int CONNECTION_CELLULAR_PDN_TYPE_IPV4_IPV6 = 4;
}

/// @brief Enumeration for cellular authentication type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_cellular_auth_type_e {
  /// < No authentication
  static const int CONNECTION_CELLULAR_AUTH_TYPE_NONE = 0;

  /// < PAP authentication
  static const int CONNECTION_CELLULAR_AUTH_TYPE_PAP = 1;

  /// < CHAP authentication
  static const int CONNECTION_CELLULAR_AUTH_TYPE_CHAP = 2;
}

/// @brief Enumeration for profile state type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_profile_state_e {
  /// < Disconnected state
  static const int CONNECTION_PROFILE_STATE_DISCONNECTED = 0;

  /// < Association state
  static const int CONNECTION_PROFILE_STATE_ASSOCIATION = 1;

  /// < Configuration state
  static const int CONNECTION_PROFILE_STATE_CONFIGURATION = 2;

  /// < Connected state
  static const int CONNECTION_PROFILE_STATE_CONNECTED = 3;
}

/// @brief Enumeration for address family.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_address_family_e {
  /// < IPV4 Address type
  static const int CONNECTION_ADDRESS_FAMILY_IPV4 = 0;

  /// < IPV6 Address type
  static const int CONNECTION_ADDRESS_FAMILY_IPV6 = 1;
}

/// @brief Enumeration for IP configuration type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_ip_config_type_e {
  /// Not defined
  static const int CONNECTION_IP_CONFIG_TYPE_NONE = 0;

  /// Manual IP configuration
  static const int CONNECTION_IP_CONFIG_TYPE_STATIC = 1;

  /// Config IP using DHCP client
  static const int CONNECTION_IP_CONFIG_TYPE_DYNAMIC = 2;

  /// Config IP from Auto IP pool (169.254/16). Later with DHCP client, if available
  static const int CONNECTION_IP_CONFIG_TYPE_AUTO = 3;

  /// Indicates an IP address that can not be modified
  static const int CONNECTION_IP_CONFIG_TYPE_FIXED = 4;
}

/// @brief Enumeration for proxy method type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_proxy_type_e {
  /// Direct connection
  static const int CONNECTION_PROXY_TYPE_DIRECT = 0;

  /// Auto configuration (use PAC file). If URL property is not set,
  /// DHCP/WPAD auto-discover will be tried
  static const int CONNECTION_PROXY_TYPE_AUTO = 1;

  /// Manual configuration
  static const int CONNECTION_PROXY_TYPE_MANUAL = 2;
}

/// @brief Enumeration for DNS configuration type.
/// @since_tizen 4.0
abstract class connection_dns_config_type_e {
  /// < Not defined
  static const int CONNECTION_DNS_CONFIG_TYPE_NONE = 0;

  /// < Manual DNS configuration
  static const int CONNECTION_DNS_CONFIG_TYPE_STATIC = 1;

  /// < Config DNS using DHCP client
  static const int CONNECTION_DNS_CONFIG_TYPE_DYNAMIC = 2;
}

/// @brief Enumeration for network connection type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_profile_type_e {
  /// < Cellular type
  static const int CONNECTION_PROFILE_TYPE_CELLULAR = 0;

  /// < Wi-Fi type
  static const int CONNECTION_PROFILE_TYPE_WIFI = 1;

  /// < Ethernet type
  static const int CONNECTION_PROFILE_TYPE_ETHERNET = 2;

  /// < Bluetooth type
  static const int CONNECTION_PROFILE_TYPE_BT = 3;
}

/// @brief The profile handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef connection_profile_h = ffi.Pointer<ffi.Void>;

/// @brief Called when the state of the profile is changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] state             The state
/// @param[in] user_data         The user data passed from the callback registration function
/// @see connection_profile_set_state_changed_cb()
/// @see connection_profile_unset_state_changed_cb()
typedef connection_profile_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for connection type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_type_e {
  /// < Disconnected
  static const int CONNECTION_TYPE_DISCONNECTED = 0;

  /// < Wi-Fi type
  static const int CONNECTION_TYPE_WIFI = 1;

  /// < Cellular type
  static const int CONNECTION_TYPE_CELLULAR = 2;

  /// < Ethernet type
  static const int CONNECTION_TYPE_ETHERNET = 3;

  /// < Bluetooth type
  static const int CONNECTION_TYPE_BT = 4;

  /// < Proxy type for internet connection (Since 3.0)
  static const int CONNECTION_TYPE_NET_PROXY = 5;
}

/// @brief Enumeration for cellular network state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_cellular_state_e {
  /// < Out of service
  static const int CONNECTION_CELLULAR_STATE_OUT_OF_SERVICE = 0;

  /// < Flight mode
  static const int CONNECTION_CELLULAR_STATE_FLIGHT_MODE = 1;

  /// < Roaming is turned off
  static const int CONNECTION_CELLULAR_STATE_ROAMING_OFF = 2;

  /// < Call is only available
  static const int CONNECTION_CELLULAR_STATE_CALL_ONLY_AVAILABLE = 3;

  /// < Available but not connected yet
  static const int CONNECTION_CELLULAR_STATE_AVAILABLE = 4;

  /// < Connected
  static const int CONNECTION_CELLULAR_STATE_CONNECTED = 5;
}

/// @brief Enumeration for Wi-Fi state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_wifi_state_e {
  /// < Wi-Fi is deactivated
  static const int CONNECTION_WIFI_STATE_DEACTIVATED = 0;

  /// < Disconnected
  static const int CONNECTION_WIFI_STATE_DISCONNECTED = 1;

  /// < Connected
  static const int CONNECTION_WIFI_STATE_CONNECTED = 2;
}

/// @brief Enumeration for ethernet state.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class connection_ethernet_state_e {
  /// < There is no Ethernet profile to open
  static const int CONNECTION_ETHERNET_STATE_DEACTIVATED = 0;

  /// < Disconnected
  static const int CONNECTION_ETHERNET_STATE_DISCONNECTED = 1;

  /// < Connected
  static const int CONNECTION_ETHERNET_STATE_CONNECTED = 2;
}

/// @brief Enumeration for Bluetooth state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_bt_state_e {
  /// < There is no Bluetooth profile to open
  static const int CONNECTION_BT_STATE_DEACTIVATED = 0;

  /// < Disconnected
  static const int CONNECTION_BT_STATE_DISCONNECTED = 1;

  /// < Connected
  static const int CONNECTION_BT_STATE_CONNECTED = 2;
}

/// @brief Enumeration for connection iterator type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_iterator_type_e {
  /// < The iterator of the registered profile
  static const int CONNECTION_ITERATOR_TYPE_REGISTERED = 0;

  /// < The iterator of the connected profile
  static const int CONNECTION_ITERATOR_TYPE_CONNECTED = 1;

  /// < The iterator of the default profile
  static const int CONNECTION_ITERATOR_TYPE_DEFAULT = 2;
}

/// @brief Enumeration for reset profile type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_reset_option_e {
  /// Initialized with the default profile defined by csc
  static const int CONNECTION_RESET_DEFAULT_PROFILE = 0;

  /// Remove all profiles
  static const int CONNECTION_RESET_CLEAR_PROFILE = 1;
}

/// @brief Enumeration for the attached or detached state of ethernet cable.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class connection_ethernet_cable_state_e {
  /// < Ethernet cable is detached
  static const int CONNECTION_ETHERNET_CABLE_DETACHED = 0;

  /// < Ethernet cable is attached
  static const int CONNECTION_ETHERNET_CABLE_ATTACHED = 1;
}

/// @brief Enumeration for connection errors.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_error_e {
  /// Successful
  static const int CONNECTION_ERROR_NONE = 0;

  /// Invalid parameter
  static const int CONNECTION_ERROR_INVALID_PARAMETER = -22;

  /// Out of memory error
  static const int CONNECTION_ERROR_OUT_OF_MEMORY = -12;

  /// Invalid operation
  static const int CONNECTION_ERROR_INVALID_OPERATION = -38;

  /// Address family not supported
  static const int CONNECTION_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED = -97;

  /// Operation failed
  static const int CONNECTION_ERROR_OPERATION_FAILED = -29424639;

  /// End of iteration
  static const int CONNECTION_ERROR_ITERATOR_END = -29424638;

  /// There is no connection
  static const int CONNECTION_ERROR_NO_CONNECTION = -29424637;

  /// Now inprogress
  static const int CONNECTION_ERROR_NOW_IN_PROGRESS = -115;

  /// Already exists
  static const int CONNECTION_ERROR_ALREADY_EXISTS = -29424636;

  /// Operation is aborted
  static const int CONNECTION_ERROR_OPERATION_ABORTED = -29424635;

  /// DHCP failed
  static const int CONNECTION_ERROR_DHCP_FAILED = -29424634;

  /// Invalid key
  static const int CONNECTION_ERROR_INVALID_KEY = -29424633;

  /// No reply
  static const int CONNECTION_ERROR_NO_REPLY = -29424632;

  /// Permission denied
  static const int CONNECTION_ERROR_PERMISSION_DENIED = -13;

  /// Not supported
  static const int CONNECTION_ERROR_NOT_SUPPORTED = -1073741822;
}

/// @brief Enumeration for statistics type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class connection_statistics_type_e {
  /// < Last received data
  static const int CONNECTION_STATISTICS_TYPE_LAST_RECEIVED_DATA = 0;

  /// < Last sent data
  static const int CONNECTION_STATISTICS_TYPE_LAST_SENT_DATA = 1;

  /// < Total received data
  static const int CONNECTION_STATISTICS_TYPE_TOTAL_RECEIVED_DATA = 2;

  /// < Total sent data
  static const int CONNECTION_STATISTICS_TYPE_TOTAL_SENT_DATA = 3;
}

/// @brief The connection handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef connection_h = ffi.Pointer<ffi.Void>;

/// @deprecated Deprecated since 4.0. Use connection_ethernet_cable_state_changed_cb instead.
/// @brief Called when ethernet cable is plugged [in/out].
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] state             The state of ethernet cable
/// @param[in] user_data         The user data passed to callback registration function
typedef connection_ethernet_cable_state_chaged_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when ethernet cable is plugged [in/out].
/// @since_tizen 4.0
/// @param[in] state             The state of ethernet cable
/// @param[in] user_data         The user data passed to callback registration function
typedef connection_ethernet_cable_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the type of a connection is changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] type              The type of the current network connection
/// @param[in] user_data         The user data passed from the callback registration function
/// @see connection_set_type_changed_cb()
/// @see connection_unset_type_changed_cb()
typedef connection_type_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the address is changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] ipv4_address      The IP address for IPv4
/// @param[in] ipv6_address      The IP address for IPv6
/// @param[in] user_data         The user data passed from the callback registration function
/// @see connection_set_ip_address_changed_cb()
/// @see connection_unset_ip_address_changed_cb()
/// @see connection_set_proxy_address_changed_cb()
/// @see connection_unset_proxy_address_changed_cb()
typedef connection_address_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief The profiles iterator handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef connection_profile_iterator_h = ffi.Pointer<ffi.Void>;

/// @brief Called when connection_set_default_cellular_service_profile_async() finishes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] result            The result
/// @param[in] user_data         The user data passed from connection_open_profile()
/// @pre connection_set_default_cellular_service_profile_async() will invoke this callback function.
/// @see connection_set_default_cellular_service_profile_async()
typedef connection_set_default_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called after connection_open_profile() is finished.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] result            The result
/// @param[in] user_data         The user data passed from connection_open_profile()
/// @pre connection_open_profile() will invoke this callback function.
/// @see connection_open_profile()
typedef connection_opened_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called after connection_close_profile() is finished.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] result            The result
/// @param[in] user_data         The user data passed from connection_close_profile()
/// @pre connection_close_profile() will invoke this callback function.
/// @see connection_close_profile()
typedef connection_closed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called after connection_reset_profile() is finished.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] result            The result
/// @param[in] user_data         The user data passed from connection_reset_profile()
/// @pre connection_reset_profile() will invoke this callback function.
/// @see connection_reset_profile()
typedef connection_reset_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called with an IPv6 address.
/// @since_tizen 4.0
/// @remarks   If @a ipv6_address is needed outside the callback, a copy should be made. \n
/// @a ipv6_address will be freed automatically after the execution of this callback.
/// @param[in]  ipv6_address     The IPv6 address
/// @param[in]  user_data        The user data passed from the foreach function
/// @return  @c true to continue with the next iteration of the loop, \n
/// @c false to break out of the loop
/// @pre  connection_foreach_ipv6_addresses() will invoke this callback.
/// @see  connection_foreach_ipv6_addresses()
typedef connection_ipv6_address_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for Network Service Discovery DNSSD error code.
/// @since_tizen 3.0
abstract class dnssd_error_e {
  /// < Successful
  static const int DNSSD_ERROR_NONE = 0;

  /// < Out of memory
  static const int DNSSD_ERROR_OUT_OF_MEMORY = -12;

  /// < Permission denied
  static const int DNSSD_ERROR_PERMISSION_DENIED = -13;

  /// < Invalid operation
  static const int DNSSD_ERROR_INVALID_OPERATION = -38;

  /// < Invalid function parameter
  static const int DNSSD_ERROR_INVALID_PARAMETER = -22;

  /// < Not supported
  static const int DNSSD_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Not Initialized
  static const int DNSSD_ERROR_NOT_INITIALIZED = -30015487;

  /// < Already registered
  static const int DNSSD_ERROR_ALREADY_REGISTERED = -30015486;

  /// < Name conflict
  static const int DNSSD_ERROR_NAME_CONFLICT = -30015485;

  /// < Background daemon not running
  static const int DNSSD_ERROR_SERVICE_NOT_RUNNING = -30015484;

  /// <  Service not found
  static const int DNSSD_ERROR_SERVICE_NOT_FOUND = -30015483;

  /// < Operation failed
  static const int DNSSD_ERROR_OPERATION_FAILED = -30015482;
}

/// @brief Enumeration for Network Service Discovery DNSSD browse state.
/// @since_tizen 3.0
abstract class dnssd_service_state_e {
  /// <Available DNS-SD service found
  static const int DNSSD_SERVICE_STATE_AVAILABLE = 0;

  /// <DNS-SD service not available
  static const int DNSSD_SERVICE_STATE_UNAVAILABLE = 1;

  /// <Lookup failure for service name
  static const int DNSSD_SERVICE_STATE_NAME_LOOKUP_FAILED = 2;

  /// <Lookup failure for host name and port number
  static const int DNSSD_SERVICE_STATE_HOST_NAME_LOOKUP_FAILED = 3;

  /// <Lookup failure for IP address
  static const int DNSSD_SERVICE_STATE_ADDRESS_LOOKUP_FAILED = 4;
}

/// @brief The DNSSD service handle.
/// @since_tizen 3.0
typedef dnssd_service_h = ffi.UnsignedInt;

/// @brief Called when the registration of DNSSD service is finished.
/// @since_tizen 3.0
/// @param[in] result The result of registration.\n
/// #DNSSD_ERROR_NONE Successful\n
/// #DNSSD_ERROR_NAME_CONFLICT Name Conflict\n
/// #DNSSD_ERROR_ALREADY_REGISTERED Already Registered
/// @param[in] local_service The DNSSD local service handle
/// @param[in] user_data The user data passed from the request function
/// @see dnssd_register_local_service()
typedef dnssd_registered_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, dnssd_service_h, ffi.Pointer<ffi.Void>)>>;

/// @brief The DNSSD Browser handle.
/// @since_tizen 3.0
typedef dnssd_browser_h = ffi.UnsignedInt;

/// @brief Called when a DNSSD service is found.
/// @details remote_service is valid only when service_state is
/// DNSSD_SERVICE_STATE_AVAILABLE or DNSSD_SERVICE_STATE_UNAVAILABLE.
/// In case of service_state DNSSD_SERVICE_STATE_UNAVAILABLE, application
/// can only use dnssd_service_get_type() and dnssd_service_get_name().
/// Other get functions can only be used when service_state is
/// DNSSD_SERVICE_STATE_AVAILABLE.
/// @since_tizen 3.0
/// @param[in] service_state The DNSSD service state of remote service
/// @param[in] remote_service The DNSSD remote service handle
/// @param[in] user_data The user data passed from the request function
/// @see dnssd_start_browsing_service()
typedef dnssd_found_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, dnssd_service_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for type of observation.
/// @since_tizen 3.0
abstract class iotcon_observe_type_e {
  /// < Indicates no option
  static const int IOTCON_OBSERVE_NO_TYPE = 0;

  /// < Indicates action of registering observation
  static const int IOTCON_OBSERVE_REGISTER = 1;

  /// < Indicates action of unregistering observation
  static const int IOTCON_OBSERVE_DEREGISTER = 2;
}

/// @brief Enumeration for policy of observation.
/// @since_tizen 3.0
abstract class iotcon_observe_policy_e {
  /// < Indicates observation request for most up-to-date notifications only
  static const int IOTCON_OBSERVE_IGNORE_OUT_OF_ORDER = 0;

  /// < Indicates observation request for all notifications including state notifications
  static const int IOTCON_OBSERVE_ACCEPT_OUT_OF_ORDER = 1;
}

/// @brief Enumeration for connectivities which can be held in a resource.
/// @remarks IOTCON_CONNECTIVITY_PREFER_UDP and IOTCON_CONNECTIVITY_PREFER_TCP should be mutually exclusive.
/// @remarks IOTCON_CONNECTIVITY_IPV4_ONLY and IOTCON_CONNECTIVITY_IPV6_ONLY should be mutually exclusive.
/// @since_tizen 3.0
abstract class iotcon_connectivity_type_e {
  /// < Indicates all connectivities
  static const int IOTCON_CONNECTIVITY_ALL = 0;

  /// < Indicates Internet Protocol connectivity
  static const int IOTCON_CONNECTIVITY_IP = 1;

  /// < It is related to IOTCON_CONNECTIVITY_IP, and it indicates UDP is preferred
  static const int IOTCON_CONNECTIVITY_PREFER_UDP = 65536;

  /// < It is related to IOTCON_CONNECTIVITY_IP, and it indicates TCP is preferred
  static const int IOTCON_CONNECTIVITY_PREFER_TCP = 131072;

  /// < When this bit is set with IOTCON_CONNECTIVITY_IP, resources are discovered for IPv4
  static const int IOTCON_CONNECTIVITY_IPV4_ONLY = 262144;

  /// < When this bit is set with IOTCON_CONNECTIVITY_IP, resources are discovered for IPv6
  static const int IOTCON_CONNECTIVITY_IPV6_ONLY = 524288;
}

/// @brief Enumeration for policy which can be held in a resource.
/// @since_tizen 3.0
abstract class iotcon_resource_policy_e {
  /// < Indicates resource uninitialized
  static const int IOTCON_RESOURCE_NO_POLICY = 0;

  /// < Indicates resource that is allowed to be discovered
  static const int IOTCON_RESOURCE_DISCOVERABLE = 1;

  /// < Indicates resource that is allowed to be observed
  static const int IOTCON_RESOURCE_OBSERVABLE = 2;

  /// < Indicates resource initialized and activated
  static const int IOTCON_RESOURCE_ACTIVE = 4;

  /// < Indicates resource which takes some delay to respond
  static const int IOTCON_RESOURCE_SLOW = 8;

  /// < Indicates secure resource
  static const int IOTCON_RESOURCE_SECURE = 16;

  /// < When this bit is set, the resource is allowed to be discovered only if discovery request contains an explicit querystring.
  static const int IOTCON_RESOURCE_EXPLICIT_DISCOVERABLE = 32;
}

/// @brief Enumeration for type of request.
/// @since_tizen 3.0
abstract class iotcon_request_type_e {
  /// < Indicates none
  static const int IOTCON_REQUEST_UNKNOWN = 0;

  /// < Indicates get method of request
  static const int IOTCON_REQUEST_GET = 1;

  /// < Indicates put method of request
  static const int IOTCON_REQUEST_PUT = 2;

  /// < Indicates post method of request
  static const int IOTCON_REQUEST_POST = 3;

  /// < Indicates delete method of request
  static const int IOTCON_REQUEST_DELETE = 4;
}

/// @brief Enumeration for result of response.
/// @since_tizen 3.0
abstract class iotcon_response_result_e {
  /// < Indicates result of response for success
  static const int IOTCON_RESPONSE_OK = 0;

  /// < Indicates result of response for error
  static const int IOTCON_RESPONSE_ERROR = 1;

  /// < Indicates result of response for resource creation
  static const int IOTCON_RESPONSE_RESOURCE_CREATED = 2;

  /// < Indicates result of response for resource deletion
  static const int IOTCON_RESPONSE_RESOURCE_DELETED = 3;

  /// < Indicates result of response for resource change
  static const int IOTCON_RESPONSE_RESOURCE_CHANGED = 4;

  /// < Indicates result of response for slow resource
  static const int IOTCON_RESPONSE_SLOW = 5;

  /// < Indicates result of response for accessing unauthorized resource
  static const int IOTCON_RESPONSE_FORBIDDEN = 6;
}

/// @brief Enumeration for result of presence.
/// @since_tizen 3.0
abstract class iotcon_presence_result_e {
  /// < Indicates for successful action of presence
  static const int IOTCON_PRESENCE_OK = 0;

  /// < Indicates for stopped action of presence
  static const int IOTCON_PRESENCE_STOPPED = 1;

  /// < Indicates for no response of presence for some time
  static const int IOTCON_PRESENCE_TIMEOUT = 2;
}

/// @brief Enumeration for operation of presence response.
/// @since_tizen 3.0
abstract class iotcon_presence_trigger_e {
  /// < Indicates for resource creation operation of server
  static const int IOTCON_PRESENCE_RESOURCE_CREATED = 0;

  /// < Indicates for resource update operation of server
  static const int IOTCON_PRESENCE_RESOURCE_UPDATED = 1;

  /// < Indicates for resource destruction operation of server
  static const int IOTCON_PRESENCE_RESOURCE_DESTROYED = 2;
}

/// @brief Enumeration for types of representation that is possible to have.
/// @since_tizen 3.0
abstract class iotcon_type_e {
  /// < Indicates for representation that have no type
  static const int IOTCON_TYPE_NONE = 0;

  /// < Indicates for representation that have int type
  static const int IOTCON_TYPE_INT = 1;

  /// < Indicates for representation that have bool type
  static const int IOTCON_TYPE_BOOL = 2;

  /// < Indicates for representation that have double type
  static const int IOTCON_TYPE_DOUBLE = 3;

  /// < Indicates for representation that have string type
  static const int IOTCON_TYPE_STR = 4;

  /// < Indicates for representation that have byte string type
  static const int IOTCON_TYPE_BYTE_STR = 5;

  /// < Indicates for representation that have null type
  static const int IOTCON_TYPE_NULL = 6;

  /// < Indicates for representation that have list type
  static const int IOTCON_TYPE_LIST = 7;

  /// < Indicates for representation that have another representation type
  static const int IOTCON_TYPE_ATTRIBUTES = 8;
}

/// @brief Enumeration for properties of device information.
/// @since_tizen 3.0
abstract class iotcon_device_info_e {
  /// < Indicates human friendly name for device
  static const int IOTCON_DEVICE_INFO_NAME = 0;

  /// < Indicates spec version of the core specification
  static const int IOTCON_DEVICE_INFO_SPEC_VER = 1;

  /// < Indicates unique identifier for OCF device
  static const int IOTCON_DEVICE_INFO_ID = 2;

  /// < Indicates version of the specs this device data model is implemented to
  static const int IOTCON_DEVICE_INFO_DATA_MODEL_VER = 3;
}

/// @brief Enumeration for properties of platform information.
/// @since_tizen 3.0
abstract class iotcon_platform_info_e {
  /// < Indicates platform identifier
  static const int IOTCON_PLATFORM_INFO_ID = 0;

  /// < Indicates name of manufacturer
  static const int IOTCON_PLATFORM_INFO_MANUF_NAME = 1;

  /// < Indicates URL to manufacturer
  static const int IOTCON_PLATFORM_INFO_MANUF_URL = 2;

  /// < Indicates model number as designated by manufacturer
  static const int IOTCON_PLATFORM_INFO_MODEL_NUMBER = 3;

  /// < Indicates manufacturing date of device
  static const int IOTCON_PLATFORM_INFO_DATE_OF_MANUF = 4;

  /// < Indicates version of platform defined by manufacturer
  static const int IOTCON_PLATFORM_INFO_PLATFORM_VER = 5;

  /// < Indicates version of platform resident OS
  static const int IOTCON_PLATFORM_INFO_OS_VER = 6;

  /// < Indicates version of platform hardware
  static const int IOTCON_PLATFORM_INFO_HARDWARE_VER = 7;

  /// < Indicates version of device firmware
  static const int IOTCON_PLATFORM_INFO_FIRMWARE_VER = 8;

  /// < Indicates URL that points to support information from manufacturer
  static const int IOTCON_PLATFORM_INFO_SUPPORT_URL = 9;

  /// < Indicates reference time for the device
  static const int IOTCON_PLATFORM_INFO_SYSTEM_TIME = 10;
}

/// @brief Enumeration for states of remote resource.
/// @since_tizen 3.0
abstract class iotcon_remote_resource_state_e {
  /// < Indicates remote resource is alive
  static const int IOTCON_REMOTE_RESOURCE_ALIVE = 0;

  /// < Indicates remote resource is lost
  static const int IOTCON_REMOTE_RESOURCE_LOST_SIGNAL = 1;
}

/// @brief Enumeration for quality of service.
/// @since_tizen 3.0
abstract class iotcon_qos_e {
  /// < Indicates low quality of service
  static const int IOTCON_QOS_LOW = 0;

  /// < Indicates high quality of service
  static const int IOTCON_QOS_HIGH = 1;
}

class icl_resource extends ffi.Opaque {}

class icl_lite_resource extends ffi.Opaque {}

class icl_resource_response extends ffi.Opaque {}

class icl_observers extends ffi.Opaque {}

class icl_resource_request extends ffi.Opaque {}

class icl_remote_resource extends ffi.Opaque {}

class icl_presence extends ffi.Opaque {}

class icl_presence_response extends ffi.Opaque {}

class icl_device_info extends ffi.Opaque {}

class icl_platform_info extends ffi.Opaque {}

class icl_resource_ifaces extends ffi.Opaque {}

class icl_resource_types extends ffi.Opaque {}

class icl_options extends ffi.Opaque {}

class icl_query extends ffi.Opaque {}

class icl_representation_s extends ffi.Opaque {}

class icl_list_s extends ffi.Opaque {}

class icl_attributes_s extends ffi.Opaque {}

/// @brief The iotcon_value_h type values list handle.
/// @details @a iotcon_list_h is an opaque data structure.
/// @since_tizen 3.0
typedef iotcon_list_h = ffi.Pointer<icl_list_s>;

/// @brief The attributes handle.
/// @details @a iotcon_attributes_h is an opaque data structure to have attribute value map.
/// Attribute value map consists of a key and a value.
/// Datatype of the key is string and the value should be one of them #IOTCON_TYPE_INT,
/// #IOTCON_TYPE_BOOL, #IOTCON_TYPE_DOUBLE, #IOTCON_TYPE_STR, #IOTCON_TYPE_NULL,
/// #IOTCON_TYPE_LIST and #IOTCON_TYPE_ATTRIBUTES.
/// @since_tizen 3.0
typedef iotcon_attributes_h = ffi.Pointer<icl_attributes_s>;

/// @brief Specifies the type of function passed to iotcon_list_foreach_int().
/// @since_tizen 3.0
/// @param[in] pos The number of the integer value (0 being the first)
/// @param[in] value The integer value
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_list_foreach_int() will invoke this callback function.
/// @see iotcon_list_foreach_int()
typedef iotcon_list_int_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_list_foreach_bool().
/// @since_tizen 3.0
/// @param[in] pos The number of the boolean value (0 being the first)
/// @param[in] value The boolean value
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_list_foreach_bool() will invoke this callback function.
/// @see iotcon_list_foreach_bool()
typedef iotcon_list_bool_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_list_foreach_double().
/// @since_tizen 3.0
/// @param[in] pos The number of the double value (0 being the first)
/// @param[in] value The double value
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_list_foreach_double() will invoke this callback function.
/// @see iotcon_list_foreach_double()
typedef iotcon_list_double_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Double, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_list_foreach_byte_str().
/// @since_tizen 3.0
/// @param[in] pos The number of the string value (0 being the first)
/// @param[in] value The byte string value
/// @param[in] len The length of @a value
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_list_foreach_byte_str() will invoke this callback function.
/// @see iotcon_list_foreach_byte_str()
typedef iotcon_list_byte_str_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Pointer<ffi.UnsignedChar>, ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_list_foreach_str().
/// @since_tizen 3.0
/// @param[in] pos The number of the string value (0 being the first)
/// @param[in] value The string value
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_list_foreach_str() will invoke this callback function.
/// @see iotcon_list_foreach_str()
typedef iotcon_list_str_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_list_foreach_list().
/// @since_tizen 3.0
/// @param[in] pos The number of the list value (0 being the first)
/// @param[in] value The list value
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_list_foreach_list() will invoke this callback function.
/// @see iotcon_list_foreach_list()
typedef iotcon_list_list_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, iotcon_list_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_list_foreach_attributes().
/// @since_tizen 3.0
/// @param[in] pos The number of the attributes value (0 being the first)
/// @param[in] value The attributes value
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_list_foreach_attributes() will invoke this callback function.
/// @see iotcon_list_foreach_attributes()
typedef iotcon_list_attributes_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            ffi.Int, iotcon_attributes_h, ffi.Pointer<ffi.Void>)>>;

/// @brief The query handle.
/// @details @a iotcon_query_h is an opaque data structure to have attribute value map which consists of key and value.
/// Datatype of both key and value are string.
/// @a iotcon_query_h also have length.
/// The length is total length of all keys and values of map.
/// The length should be less than or equal to 64.
/// @since_tizen 3.0
typedef iotcon_query_h = ffi.Pointer<icl_query>;

/// @brief Specifies the type of function passed to iotcon_query_foreach().
/// @since_tizen 3.0
/// @param[in] key The key of the query
/// @param[in] value The value of the query
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_query_foreach() will invoke this callback function.
/// @see iotcon_query_foreach()
typedef iotcon_query_foreach_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_attributes_foreach().
/// @since_tizen 3.0
/// @param[in] attributes The attributes handle
/// @param[in] key The key
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_attributes_foreach() will invoke this callback function.
/// @see iotcon_attributes_foreach()
typedef iotcon_attributes_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(iotcon_attributes_h, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief The options handle.
/// @details @a iotcon_options_h is an opaque data structure to have attribute value map which consists of a key and a value.
/// Datatype of key is an integer and value is string.
/// @since_tizen 3.0
typedef iotcon_options_h = ffi.Pointer<icl_options>;

/// @brief Specifies the type of function passed to iotcon_options_foreach().
/// @since_tizen 3.0
/// @param[in] id The information of the option
/// @param[in] data The data of the option
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_options_foreach() will invoke this callback function.
/// @see iotcon_options_foreach()
typedef iotcon_options_foreach_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            ffi.UnsignedShort, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief The representation handle.
/// @details @a iotcon_representation_h is an opaque data structure to have uri_path, list of resource types and interfaces.
/// It could contain other representation as children.
/// @since_tizen 3.0
typedef iotcon_representation_h = ffi.Pointer<icl_representation_s>;

/// @brief The resource types handle.
/// @details @a iotcon_resource_types_h is an opaque data structure to have list of resource types. A resource type is datatype of string.
/// @since_tizen 3.0
typedef iotcon_resource_types_h = ffi.Pointer<icl_resource_types>;

/// @brief The resource interface handle.
/// @details @a iotcon_resource_interfaces_h is an opaque data structure to have list of resource interfaces. A resource interface is datatype of string.
/// @since_tizen 3.0
typedef iotcon_resource_interfaces_h = ffi.Pointer<icl_resource_ifaces>;

/// @brief Specifies the type of function passed to iotcon_representation_foreach_children().
/// @since_tizen 3.0
/// @param[in] child The child Representation handle
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_representation_foreach_children() will invoke this callback function.
/// @see iotcon_representation_foreach_children()
typedef iotcon_children_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(iotcon_representation_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_resource_types_foreach().
/// @since_tizen 3.0
/// @param[in] type The value of the resource types
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_resource_types_foreach() will invoke this callback function.
/// @see iotcon_resource_types_foreach()
typedef iotcon_resource_types_foreach_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the iface of function passed to iotcon_resource_interfaces_foreach().
/// @since_tizen 3.0
/// @remarks @a iface could be a value such as #IOTCON_INTERFACE_DEFAULT.
/// @param[in] iface The value of the resource ifaces
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_resource_interfaces_foreach() will invoke this callback function.
/// @see iotcon_resource_interfaces_foreach()
typedef iotcon_resource_interfaces_foreach_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_IOT_CONNECTIVITY_MODULE
/// @brief Enumeration for IoTCon error code.
/// @since_tizen 3.0
/// @{
abstract class iotcon_error_e {
  /// < Successful
  static const int IOTCON_ERROR_NONE = 0;

  /// < I/O error
  static const int IOTCON_ERROR_IO_ERROR = -5;

  /// < Out of memory
  static const int IOTCON_ERROR_OUT_OF_MEMORY = -12;

  /// < Permission denied
  static const int IOTCON_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int IOTCON_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Invalid parameter
  static const int IOTCON_ERROR_INVALID_PARAMETER = -22;

  /// < No data available
  static const int IOTCON_ERROR_NO_DATA = -61;

  /// < Time out
  static const int IOTCON_ERROR_TIMEOUT = -1073741823;

  /// < IoTivity errors
  static const int IOTCON_ERROR_IOTIVITY = -29884415;

  /// < Representation errors
  static const int IOTCON_ERROR_REPRESENTATION = -29884414;

  /// < Invalid type
  static const int IOTCON_ERROR_INVALID_TYPE = -29884413;

  /// < Already
  static const int IOTCON_ERROR_ALREADY = -29884412;

  /// < System errors
  static const int IOTCON_ERROR_SYSTEM = -29884410;
}

/// @brief Specifies the type of function passed to iotcon_resource_create() and iotcon_resource_set_request_handler().
/// @details Called when server receives request from the client.
/// @since_tizen 3.0
/// @param[in] resource The resource requested
/// @param[in] request The request from client
/// @param[in] user_data The user data to pass to the function
/// @pre The callback must be registered using iotcon_resource_create()
/// @see iotcon_resource_create()
/// @see iotcon_resource_set_request_handler()
typedef iotcon_request_handler_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            iotcon_resource_h, iotcon_request_h, ffi.Pointer<ffi.Void>)>>;

/// @brief The resource handle.
/// @details @a iotcon_resource_h is an opaque data structure to represent registered resource by server.
/// A resource has host_address, uri_path, resource types, interfaces and internal handle.
/// If observable attribute of resource is true, client can observe this resource.
/// When client requests by CRUD functions, handler will be invoked if registered.
/// It could contain other resource as children.
/// @since_tizen 3.0
typedef iotcon_resource_h = ffi.Pointer<icl_resource>;

/// @brief The request handle.
/// @details @a iotcon_request_h is an opaque data structure to request to a particular resource.
/// @a iotcon_request_h is a data type of client's request which consists of header options, query, representation.
/// @since_tizen 3.0
typedef iotcon_request_h = ffi.Pointer<icl_resource_request>;

/// @brief The observers handle.
/// @details The list of observer IDs.
/// @since_tizen 3.0
typedef iotcon_observers_h = ffi.Pointer<icl_observers>;

/// @brief Specifies the type of function passed to iotcon_lite_resource_create().
/// @since_tizen 3.0
/// @param[in] resource The handle of the lite resource
/// @param[in] attributes The attributes of the lite resource
/// @param[in] user_data The user data to pass to the function
/// @return @c true to accept post request,
/// otherwise @c false to reject it
/// @pre The callback must be registered using iotcon_lite_resource_create().
/// @see iotcon_lite_resource_create()
typedef iotcon_lite_resource_post_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(iotcon_lite_resource_h, iotcon_attributes_h,
            ffi.Pointer<ffi.Void>)>>;

/// @brief The lite resource handle.
/// @details @a iotcon_lite_resource_h is an opaque data structure to represent registered resource by server.
/// A resource has host_address, uri_path, resource types, and internal handle.
/// If observable attribute of resource is true, client can observe this resource.
/// @since_tizen 3.0
typedef iotcon_lite_resource_h = ffi.Pointer<icl_lite_resource>;

/// @brief The response handle.
/// @details @a iotcon_response_h is an opaque data structure to respond to client.
/// @a iotcon_response_h is a data type of server's response which consists of result, header options, query, representation.
/// @since_tizen 3.0
typedef iotcon_response_h = ffi.Pointer<icl_resource_response>;

/// @brief The remote resource handle.
/// @details When Client is successful to find out resource from remote server, server's resource information is reorganized as @a iotcon_remote_resource_h by IoTCon.
/// Client can request CRUD to server by using this.
/// @a iotcon_remote_resource_h is an opaque data structure to have host_address, uri_path, resource types, interfaces, options and device id.
/// If observable attribute is true, remote resource is observable.
/// When you observe remote resource, observe_handle will be set.
/// @since_tizen 3.0
typedef iotcon_remote_resource_h = ffi.Pointer<icl_remote_resource>;

/// @brief Specifies the type of observe callback passed to iotcon_remote_resource_observe_register().
/// The @a err could be one of #iotcon_error_e. \n
/// The @a response is created by a server. Therefore, you can't get any values that the server didn't set.
/// @since_tizen 3.0
/// @param[in] resource The handle of the remote resource
/// @param[in] err The error code
/// @param[in] sequence_number The sequence number of observe
/// @param[in] response The handle of the response
/// @param[in] user_data The user data passed from the callback registration function
/// @pre The callback must be registered using iotcon_remote_resource_observe_register()
/// @see iotcon_remote_resource_observe_register()
/// @see iotcon_remote_resource_observe_deregister()
/// @see iotcon_resource_notify()
typedef iotcon_remote_resource_observe_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(iotcon_remote_resource_h, ffi.Int32, ffi.Int,
            iotcon_response_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of response function.
/// @details The function passed to iotcon_remote_resource_get(), iotcon_remote_resource_put(),
/// iotcon_remote_resource_post(), iotcon_remote_resource_delete().\n
/// The @a err could be one of #iotcon_error_e.\n
/// The @a request_type could be one of #iotcon_request_type_e.\n
/// The @a response is created by a server. Therefore, you can't get any values that the server didn't set.
/// @since_tizen 3.0
/// @param[in] resource The handle of the resource
/// @param[in] err The error code
/// @param[in] request_type The request type
/// @param[in] response The handle of the response
/// @param[in] user_data The user data passed from the callback registration function
/// @pre The callback must be registered using iotcon_remote_resource_get(), iotcon_remote_resource_put(), iotcon_remote_resource_post(), iotcon_remote_resource_delete().
/// @see iotcon_remote_resource_get()
/// @see iotcon_remote_resource_put()
/// @see iotcon_remote_resource_post()
/// @see iotcon_remote_resource_delete()
typedef iotcon_remote_resource_response_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(iotcon_remote_resource_h, ffi.Int32, ffi.Int32,
            iotcon_response_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_remote_resource_start_caching().
/// @since_tizen 3.0
/// @param[in] resource The handle of the remote resource
/// @param[in] representation The handle of the representation
/// @param[in] user_data The user data to pass to the function
/// @pre The callback must be registered using iotcon_remote_resource_start_caching()
/// @see iotcon_remote_resource_start_caching()
/// @see iotcon_remote_resource_stop_caching()
typedef iotcon_remote_resource_cached_representation_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(iotcon_remote_resource_h, iotcon_representation_h,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_remote_resource_start_monitoring().
/// @since_tizen 3.0
/// @param[in] resource The handle of the remote resource
/// @param[in] state The state of the remote resource
/// @param[in] user_data The user data to pass to the function
/// @pre The callback must be registered using iotcon_remote_resource_start_monitoring()
/// @see iotcon_remote_resource_start_monitoring()
/// @see iotcon_remote_resource_stop_monitoring()
typedef iotcon_remote_resource_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            iotcon_remote_resource_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_add_presence_cb().
/// @details Called when client receives presence events from the server.
/// The @a response handle contains presence information.
/// @since_tizen 3.0
/// @param[in] presence The presence handle
/// @param[in] err The error code(@c 0 on success, otherwise a negative error value)
/// @param[in] response The presence response handle
/// @param[in] user_data The user data to pass to the function
/// @pre The callback must be registered using iotcon_add_presence_cb().
/// @see iotcon_add_presence_cb()
/// @see iotcon_remove_presence_cb()
/// @see iotcon_presence_response_get_connectivity_type()
/// @see iotcon_presence_response_get_host_address()
/// @see iotcon_presence_response_get_resource_type()
/// @see iotcon_presence_response_get_result()
/// @see iotcon_presence_response_get_trigger()
typedef iotcon_presence_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(iotcon_presence_h, ffi.Int32,
            iotcon_presence_response_h, ffi.Pointer<ffi.Void>)>>;

/// @brief The presence handle.
/// @details @a iotcon_presence_h is a handle of presence subscription.
/// It is used to cancel presence.
/// @since_tizen 3.0
typedef iotcon_presence_h = ffi.Pointer<icl_presence>;

/// @brief The presence response handle.
/// @details @a iotcon_presence_response_h is a handle of presence response subscription. \n
/// It is used to get the information of presence response from server.
/// @since_tizen 3.0
typedef iotcon_presence_response_h = ffi.Pointer<icl_presence_response>;

/// @brief Specifies the type of function passed to iotcon_find_resource().
/// @details Called when a resource is found from the remote server. \n
/// The @a resource completes its life cycle in the function.
/// If you want to send requests(GET, PUT, POST, DELETE, and OBSERVE) on the @a resource,
/// you must clone the @a resource using iotcon_remote_resource_clone(). \n
/// The @a result could be one of #iotcon_error_e.
/// @since_tizen 3.0
/// @param[in] resource The handle of resource which is found
/// @param[in] result The result code (Lesser than 0 on fail, otherwise a response result value)
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue to find resource,
/// otherwise @c false to stop \n
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre The callback must be registered using iotcon_find_resource()
/// @see iotcon_find_resource()
typedef iotcon_found_resource_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            iotcon_remote_resource_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Specifies the type of function passed to iotcon_find_device_info().
/// @details The @a result could be one of #iotcon_error_e.
/// @since_tizen 3.0
/// @param[in] device_info The device information from remote server
/// @param[in] result The result code (@c 0 on success, otherwise a negative error value)
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue to find device information,
/// otherwise @c false to stop \n
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_find_device_info() will invoke this callback function.
/// @see iotcon_find_device_info()
/// @see iotcon_device_info_get_property()
typedef iotcon_device_info_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            iotcon_device_info_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief The device information handle.
/// @details @a iotcon_device_info_h is a handle of device information.
/// @since_tizen 3.0
typedef iotcon_device_info_h = ffi.Pointer<icl_device_info>;

/// @brief Specifies the type of function passed to iotcon_find_platform_info().
/// @details The @a result could be one of #iotcon_error_e.
/// @since_tizen 3.0
/// @param[in] platform_info The platform information from remote server
/// @param[in] result The result code (@c 0 on success, otherwise a negative error value)
/// @param[in] user_data The user data to pass to the function
/// @return @c true to continue to find platform information,
/// otherwise @c false to stop \n
/// #IOTCON_FUNC_CONTINUE and #IOTCON_FUNC_STOP are more friendly values for the return
/// @pre iotcon_find_platform_info() will invoke this callback function.
/// @see iotcon_find_platform_info()
/// @see iotcon_platform_info_get_property()
typedef iotcon_platform_info_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            iotcon_platform_info_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief The platform information handle.
/// @details @a iotcon_platform_info_h is a handle of platform information.
/// @since_tizen 3.0
typedef iotcon_platform_info_h = ffi.Pointer<icl_platform_info>;

/// @brief Specifies the type of function passed to iotcon_add_generated_pin_cb().
/// @details When a provisioning tool calls the function for registering this device, it is called, immediately.
/// @since_tizen 3.0
/// @param[in] pin The pin number which is generated automatically
/// @param[in] user_data The user data to pass to the function
/// @pre The callback must be registered using iotcon_add_generated_pin_cb()
/// @see iotcon_add_generated_pin_cb()
/// @see iotcon_remove_generated_pin_cb()
typedef iotcon_generated_pin_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Error codes reported by the MTP API.
/// @since_tizen 3.0
abstract class mtp_error_e {
  /// < Successful
  static const int MTP_ERROR_NONE = 0;

  /// < I/O error
  static const int MTP_ERROR_IO_ERROR = -5;

  /// < Invalid parameter
  static const int MTP_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int MTP_ERROR_OUT_OF_MEMORY = -12;

  /// < Permission denied
  static const int MTP_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int MTP_ERROR_NOT_SUPPORTED = -1073741822;

  /// < MTP communication error
  static const int MTP_ERROR_COMM_ERROR = -30146559;

  /// < MTP controller error
  static const int MTP_ERROR_CONTROLLER = -30146558;

  /// < MTP have not any device
  static const int MTP_ERROR_NO_DEVICE = -30146557;

  /// < MTP is not initialized
  static const int MTP_ERROR_NOT_INITIALIZED = -30146556;

  /// < MTP is not activated
  static const int MTP_ERROR_NOT_ACTIVATED = -30146555;

  /// < MTP communication is not initialized
  static const int MTP_ERROR_NOT_COMM_INITIALIZED = -30146554;

  /// < MTP Plugin failed
  static const int MTP_ERROR_PLUGIN_FAIL = -30146553;
}

/// @brief Enumerations for MTP Storage type
/// @since_tizen 3.0
abstract class mtp_storage_type_e {
  /// < Storage type is undefined
  static const int MTP_STORAGE_TYPE_UNDEFINED = 0;

  /// < Storage type is fixed ROM
  static const int MTP_STORAGE_TYPE_FIXED_ROM = 1;

  /// < Storage type is removable ROM
  static const int MTP_STORAGE_TYPE_REMOVABLE_ROM = 2;

  /// < Storage type is fixed RAM
  static const int MTP_STORAGE_TYPE_FIXED_RAM = 3;

  /// < Storage type is Removable RAM
  static const int MTP_STORAGE_TYPE_REMOVABLE_RAM = 4;
}

/// @brief Enumerations for MTP file type
/// @since_tizen 3.0
abstract class mtp_filetype_e {
  /// < FOLDER file type
  static const int MTP_FILETYPE_FOLDER = 0;

  /// < WAV file type
  static const int MTP_FILETYPE_WAV = 1;

  /// < MP3 file type
  static const int MTP_FILETYPE_MP3 = 2;

  /// < WMA file type
  static const int MTP_FILETYPE_WMA = 3;

  /// < OGG file type
  static const int MTP_FILETYPE_OGG = 4;

  /// < AUDIBLE file type
  static const int MTP_FILETYPE_AUDIBLE = 5;

  /// < MP4 file type
  static const int MTP_FILETYPE_MP4 = 6;

  /// < UNDEF_AUDIO file type
  static const int MTP_FILETYPE_UNDEF_AUDIO = 7;

  /// < WMV file type
  static const int MTP_FILETYPE_WMV = 8;

  /// < AVI file type
  static const int MTP_FILETYPE_AVI = 9;

  /// < MPEG file type
  static const int MTP_FILETYPE_MPEG = 10;

  /// < ASF file type
  static const int MTP_FILETYPE_ASF = 11;

  /// < QT file type
  static const int MTP_FILETYPE_QT = 12;

  /// < UNDEF_VIDEO file type
  static const int MTP_FILETYPE_UNDEF_VIDEO = 13;

  /// < JPEG file type
  static const int MTP_FILETYPE_JPEG = 14;

  /// < JFIF file type
  static const int MTP_FILETYPE_JFIF = 15;

  /// < TIFF file type
  static const int MTP_FILETYPE_TIFF = 16;

  /// < BMP file type
  static const int MTP_FILETYPE_BMP = 17;

  /// < GIF file type
  static const int MTP_FILETYPE_GIF = 18;

  /// < PICT file type
  static const int MTP_FILETYPE_PICT = 19;

  /// < PNG file type
  static const int MTP_FILETYPE_PNG = 20;

  /// < VCALENDAR1 file type
  static const int MTP_FILETYPE_VCALENDAR1 = 21;

  /// < VCALENDAR2 file type
  static const int MTP_FILETYPE_VCALENDAR2 = 22;

  /// < VCARD2 file type
  static const int MTP_FILETYPE_VCARD2 = 23;

  /// < VCARD3 file type
  static const int MTP_FILETYPE_VCARD3 = 24;

  /// < WINDOWSIMAGEFORMAT file type
  static const int MTP_FILETYPE_WINDOWSIMAGEFORMAT = 25;

  /// < WINEXEC file type
  static const int MTP_FILETYPE_WINEXEC = 26;

  /// < TEXT file type
  static const int MTP_FILETYPE_TEXT = 27;

  /// < HTML file type
  static const int MTP_FILETYPE_HTML = 28;

  /// < FIRMWARE file type
  static const int MTP_FILETYPE_FIRMWARE = 29;

  /// < AAC file type
  static const int MTP_FILETYPE_AAC = 30;

  /// < MEDIACARD file type
  static const int MTP_FILETYPE_MEDIACARD = 31;

  /// < FLAC file type
  static const int MTP_FILETYPE_FLAC = 32;

  /// < MP2 file type
  static const int MTP_FILETYPE_MP2 = 33;

  /// < M4A file type
  static const int MTP_FILETYPE_M4A = 34;

  /// < DOC file type
  static const int MTP_FILETYPE_DOC = 35;

  /// < XML file type
  static const int MTP_FILETYPE_XML = 36;

  /// < XLS file type
  static const int MTP_FILETYPE_XLS = 37;

  /// < PPT file type
  static const int MTP_FILETYPE_PPT = 38;

  /// < MHT file type
  static const int MTP_FILETYPE_MHT = 39;

  /// < JP2 file type
  static const int MTP_FILETYPE_JP2 = 40;

  /// < JPX file type
  static const int MTP_FILETYPE_JPX = 41;

  /// < ALBUM file type
  static const int MTP_FILETYPE_ALBUM = 42;

  /// < PLAYLIST file type
  static const int MTP_FILETYPE_PLAYLIST = 43;

  /// < Unknown file type
  static const int MTP_FILETYPE_UNKNOWN = 44;

  /// < Helper enum value for certain function
  static const int MTP_FILETYPE_ALL = 45;

  /// < Helper enum value for certain function
  static const int MTP_FILETYPE_ALL_IMAGE = 46;
}

/// @brief Enumerations for MTP event type
/// @since_tizen 3.0
abstract class mtp_event_e {
  /// < Unknown event type
  static const int MTP_EVENT_UNKNOWN = 0;

  /// < Storage is added
  static const int MTP_EVENT_STORAGE_ADDED = 1;

  /// < Storage is removed
  static const int MTP_EVENT_STORAGE_REMOVED = 2;

  /// < Object is added
  static const int MTP_EVENT_OBJECT_ADDED = 3;

  /// < Object is removed
  static const int MTP_EVENT_OBJECT_REMOVED = 4;

  /// < Device is added
  static const int MTP_EVENT_DEVICE_ADDED = 5;

  /// < Device is removed
  static const int MTP_EVENT_DEVICE_REMOVED = 6;

  /// < MTP is turned off
  static const int MTP_EVENT_TURNED_OFF = 7;
}

/// @brief The handle to the mtp device
/// @since_tizen 3.0
typedef mtp_device_h = ffi.Int;

/// @brief The handle to the mtp storage
/// @since_tizen 3.0
typedef mtp_storage_h = ffi.Int;

/// @brief The handle to the mtp object
/// @since_tizen 3.0
typedef mtp_object_h = ffi.Int;

/// @brief Called when mtp event is occured.
/// @since_tizen 3.0
/// @remarks Depending on the type of event, the meaning of event parameter is different.
/// - If event is device event, then event_parameter type is mtp_device_h.
/// - If event is storage event, then event_parameter type is mtp_storage_h.
/// - If event is object event, then event_parameter type is mtp_object_h.
/// - If event is MTP_EVENT_TURNED_OFF, then event_parameter is 0.
///
/// @param [in] event The event
/// @param [in] event_parameter The event parameter
/// @param [in] user_data The user data passed from the callback registration function
///
/// @see mtp_set_mtp_event_cb()
/// @see mtp_unset_mtp_event_cb()
typedef mtp_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for Network Service Discovery SSDP error code.
/// @since_tizen 3.0
abstract class ssdp_error_e {
  /// < Successful
  static const int SSDP_ERROR_NONE = 0;

  /// < Out of memory
  static const int SSDP_ERROR_OUT_OF_MEMORY = -12;

  /// < Permission denied
  static const int SSDP_ERROR_PERMISSION_DENIED = -13;

  /// < Invalid function parameter
  static const int SSDP_ERROR_INVALID_PARAMETER = -22;

  /// < Not supported
  static const int SSDP_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Not initialized
  static const int SSDP_ERROR_NOT_INITIALIZED = -29949951;

  /// < Operation failed
  static const int SSDP_ERROR_OPERATION_FAILED = -29949948;

  /// < Service not found
  static const int SSDP_ERROR_SERVICE_NOT_FOUND = -29949947;

  /// < Service already registered
  static const int SSDP_ERROR_SERVICE_ALREADY_REGISTERED = -29949946;
}

/// @brief Enumeration for Network Service Discovery SSDP service browse state.
/// @since_tizen 3.0
abstract class ssdp_service_state_e {
  /// < A new service is available
  static const int SSDP_SERVICE_STATE_AVAILABLE = 0;

  /// < A service is not available
  static const int SSDP_SERVICE_STATE_UNAVAILABLE = 1;
}

/// @brief The SSDP service handle.
/// @since_tizen 3.0
typedef ssdp_service_h = ffi.UnsignedInt;

/// @brief Called when the registration of SSDP service is finished.
/// @since_tizen 3.0
/// @param[in] result The result of registration
/// @param[in] ssdp_service The SSDP local service handle
/// @param[in] user_data The user data passed from the request function
/// @see ssdp_register_local_service()
typedef ssdp_registered_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ssdp_service_h, ffi.Pointer<ffi.Void>)>>;

/// @brief The SSDP browser handle.
/// @since_tizen 3.0
typedef ssdp_browser_h = ffi.UnsignedInt;

/// @brief Called when a service has become available or unavailable.
/// @since_tizen 3.0
/// @param[in] state The state of found service
/// @param[in] ssdp_service The SSDP remote service handle
/// @param[in] user_data The user data passed from the request function
/// @see ssdp_start_browsing_service()
typedef ssdp_found_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ssdp_service_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Error codes reported by the smartcard API.
/// @since_tizen 2.3.1
/// @ingroup CAPI_NETWORK_SMARTCARD_SE_SERVICE_MODULE
abstract class smartcard_error_e {
  /// < Successful
  static const int SMARTCARD_ERROR_NONE = 0;

  /// < A general error occurred
  static const int SMARTCARD_ERROR_GENERAL = -29818879;

  /// < I/O error
  static const int SMARTCARD_ERROR_IO_ERROR = -5;

  /// < No such element error
  static const int SMARTCARD_ERROR_NO_SUCH_ELEMENT = -29818878;

  /// < Illegal state of execution error
  static const int SMARTCARD_ERROR_ILLEGAL_STATE = -29818877;

  /// < Invalid function parameter
  static const int SMARTCARD_ERROR_INVALID_PARAMETER = -22;

  /// < Illegal reference
  static const int SMARTCARD_ERROR_ILLEGAL_REFERENCE = -29818876;

  /// < Operation not supported from SE
  static const int SMARTCARD_ERROR_OPERATION_NOT_SUPPORTED = -29818875;

  /// < Permission denied
  static const int SMARTCARD_ERROR_PERMISSION_DENIED = -13;

  /// < No channel available
  static const int SMARTCARD_ERROR_CHANNEL_NOT_AVAILABLE = -29818874;

  /// < Smartcard service not initialized
  static const int SMARTCARD_ERROR_NOT_INITIALIZED = -29818873;

  /// < Not supported
  static const int SMARTCARD_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Out of memory
  static const int SMARTCARD_ERROR_OUT_OF_MEMORY = -12;
}

/// @brief Enumerations for Smartcard reader event type
/// @since_tizen 3.0
/// @ingroup CAPI_NETWORK_SMARTCARD_READER_MODULE
abstract class smartcard_reader_event_type_e {
  /// < This event notifies the application that I/O error occurs on smartcard reader
  static const int SMARTCARD_READER_EVENT_TYPE_IO_ERROR = 0;

  /// < This event notifies the application that smartcard reader is inserted
  static const int SMARTCARD_READER_EVENT_TYPE_INSERTED = 1;

  /// < This event notifies the application that smartcard reader is removed
  static const int SMARTCARD_READER_EVENT_TYPE_REMOVED = 2;
}

/// @brief Called when a smartcard reader event occurs.
/// @since_tizen 3.0
/// @ingroup CAPI_NETWORK_SMARTCARD_READER_MODULE
///
/// @param [in] reader The reader handle
/// @param [in] event_type The reader event type
/// @param [in] user_data The user data passed from the callback registration function
///
/// @see smartcard_reader_set_event_cb()
/// @see smartcard_reader_unset_event_cb()
typedef smartcard_reader_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for the Wi-Fi error type.
/// @since_tizen 3.0
abstract class wifi_manager_error_e {
  /// Successful
  static const int WIFI_MANAGER_ERROR_NONE = 0;

  /// Invalid parameter
  static const int WIFI_MANAGER_ERROR_INVALID_PARAMETER = -22;

  /// Out of memory error
  static const int WIFI_MANAGER_ERROR_OUT_OF_MEMORY = -12;

  /// Invalid operation
  static const int WIFI_MANAGER_ERROR_INVALID_OPERATION = -38;

  /// Address family not supported
  static const int WIFI_MANAGER_ERROR_ADDRESS_FAMILY_NOT_SUPPORTED = -97;

  /// Operation failed
  static const int WIFI_MANAGER_ERROR_OPERATION_FAILED = -30277631;

  /// There is no connected AP
  static const int WIFI_MANAGER_ERROR_NO_CONNECTION = -30277630;

  /// Now in progress
  static const int WIFI_MANAGER_ERROR_NOW_IN_PROGRESS = -115;

  /// Already exists
  static const int WIFI_MANAGER_ERROR_ALREADY_EXISTS = -30277629;

  /// Operation is aborted
  static const int WIFI_MANAGER_ERROR_OPERATION_ABORTED = -30277628;

  /// DHCP failed
  static const int WIFI_MANAGER_ERROR_DHCP_FAILED = -30277627;

  /// Invalid key
  static const int WIFI_MANAGER_ERROR_INVALID_KEY = -30277626;

  /// No reply
  static const int WIFI_MANAGER_ERROR_NO_REPLY = -30277625;

  /// Restricted by security system policy
  static const int WIFI_MANAGER_ERROR_SECURITY_RESTRICTED = -30277624;

  /// Already initialized
  static const int WIFI_MANAGER_ERROR_ALREADY_INITIALIZED = -30277623;

  /// Out of range
  static const int WIFI_MANAGER_ERROR_OUT_OF_RANGE = -30277622;

  /// Connect failed
  static const int WIFI_MANAGER_ERROR_CONNECT_FAILED = -30277621;

  /// Login failed
  static const int WIFI_MANAGER_ERROR_LOGIN_FAILED = -30277620;

  /// Authentication failed
  static const int WIFI_MANAGER_ERROR_AUTHENTICATION_FAILED = -30277619;

  /// PIN missing
  static const int WIFI_MANAGER_ERROR_PIN_MISSING = -30277618;

  /// WPS Overlap (Since 4.0)
  static const int WIFI_MANAGER_ERROR_WPS_OVERLAP = -30277617;

  /// WPS Timeout (Since 4.0)
  static const int WIFI_MANAGER_ERROR_WPS_TIMEOUT = -30277616;

  /// WPS WEP Prohibited (Since 4.0)
  static const int WIFI_MANAGER_ERROR_WPS_WEP_PROHIBITED = -30277615;

  /// Permission Denied
  static const int WIFI_MANAGER_ERROR_PERMISSION_DENIED = -13;

  /// Not Supported
  static const int WIFI_MANAGER_ERROR_NOT_SUPPORTED = -1073741822;
}

/// @brief Enumeration for the state of the Wi-Fi device.
/// @since_tizen 3.0
abstract class wifi_manager_device_state_e {
  /// < Wi-Fi is Deactivated
  static const int WIFI_MANAGER_DEVICE_STATE_DEACTIVATED = 0;

  /// < Wi-Fi is activated
  static const int WIFI_MANAGER_DEVICE_STATE_ACTIVATED = 1;
}

/// @brief Enumeration for the state of the Wi-Fi connection.
/// @since_tizen 3.0
abstract class wifi_manager_connection_state_e {
  /// < Connection failed state
  static const int WIFI_MANAGER_CONNECTION_STATE_FAILURE = -1;

  /// < Disconnected state
  static const int WIFI_MANAGER_CONNECTION_STATE_DISCONNECTED = 0;

  /// < Association state
  static const int WIFI_MANAGER_CONNECTION_STATE_ASSOCIATION = 1;

  /// < Configuration state
  static const int WIFI_MANAGER_CONNECTION_STATE_CONFIGURATION = 2;

  /// < Connected state
  static const int WIFI_MANAGER_CONNECTION_STATE_CONNECTED = 3;
}

/// @brief Enumeration for the state of the static IP conflict.
/// @since_tizen 5.0
abstract class wifi_manager_ip_conflict_state_e {
  /// < Unknown state
  static const int WIFI_MANAGER_IP_CONFLICT_STATE_UNKNOWN = 0;

  /// < Resolved state
  static const int WIFI_MANAGER_IP_CONFLICT_STATE_CONFLICT_NOT_DETECTED = 1;

  /// < Conflict state
  static const int WIFI_MANAGER_IP_CONFLICT_STATE_CONFLICT_DETECTED = 2;
}

/// @brief Enumeration for the RSSI level.
/// @since_tizen 3.0
abstract class wifi_manager_rssi_level_e {
  /// < No signal
  static const int WIFI_MANAGER_RSSI_LEVEL_0 = 0;

  /// < Very weak signal ~ -83dBm
  static const int WIFI_MANAGER_RSSI_LEVEL_1 = 1;

  /// < Weak signal -82 ~ -75dBm
  static const int WIFI_MANAGER_RSSI_LEVEL_2 = 2;

  /// < Strong signal -74 ~ -64dBm
  static const int WIFI_MANAGER_RSSI_LEVEL_3 = 3;

  /// < Very strong signal -63dBm ~
  static const int WIFI_MANAGER_RSSI_LEVEL_4 = 4;
}

/// @brief Enumeration for the wifi scanning state.
/// @since_tizen 4.0
abstract class wifi_manager_scan_state_e {
  /// < Scan is not running
  static const int WIFI_MANAGER_SCAN_STATE_NOT_SCANNING = 0;

  /// < Scan is in progress
  static const int WIFI_MANAGER_SCAN_STATE_SCANNING = 1;
}

/// @brief Enumeration for the TDLS Discovery State.
/// @since_tizen 4.0
abstract class wifi_manager_tdls_discovery_state_e {
  /// < Discovery is in progress
  static const int WIFI_MANAGER_TDLS_DISCOVERY_STATE_ONGOING = 0;

  /// < Discovery is finished
  static const int WIFI_MANAGER_TDLS_DISCOVERY_STATE_FINISHED = 1;
}

/// @brief Enumeration for the Wi-Fi Module state.
/// @since_tizen 4.0
abstract class wifi_manager_module_state_e {
  /// < Wi-Fi Module is detached
  static const int WIFI_MANAGER_MODULE_STATE_DETACHED = 0;

  /// < Wi-Fi Module is attached
  static const int WIFI_MANAGER_MODULE_STATE_ATTACHED = 1;
}

/// @brief Enumeration for the Net IP configuration type.
/// @since_tizen 3.0
abstract class wifi_manager_ip_config_type_e {
  /// Not defined
  static const int WIFI_MANAGER_IP_CONFIG_TYPE_NONE = 0;

  /// Manual IP configuration
  static const int WIFI_MANAGER_IP_CONFIG_TYPE_STATIC = 1;

  /// Config IP using DHCP client
  static const int WIFI_MANAGER_IP_CONFIG_TYPE_DYNAMIC = 2;

  /// Config IP from Auto IP pool (169.254/16). Later with DHCP client, if available
  static const int WIFI_MANAGER_IP_CONFIG_TYPE_AUTO = 3;

  /// Indicates an IP address that can not be modified
  static const int WIFI_MANAGER_IP_CONFIG_TYPE_FIXED = 4;
}

/// @brief Enumeration for DNS Configuration type.
/// @since_tizen 4.0
abstract class wifi_manager_dns_config_type_e {
  /// < Not defined
  static const int WIFI_MANAGER_DNS_CONFIG_TYPE_NONE = 0;

  /// < Manual DNS configuration
  static const int WIFI_MANAGER_DNS_CONFIG_TYPE_STATIC = 1;

  /// < Config DNS using DHCP client
  static const int WIFI_MANAGER_DNS_CONFIG_TYPE_DYNAMIC = 2;
}

/// @brief Enumeration for the address type.
/// @since_tizen 3.0
abstract class wifi_manager_address_family_e {
  /// < IPV4 Address family
  static const int WIFI_MANAGER_ADDRESS_FAMILY_IPV4 = 0;

  /// < IPV6 Address family
  static const int WIFI_MANAGER_ADDRESS_FAMILY_IPV6 = 1;
}

/// @brief Enumeration for the proxy method type.
/// @since_tizen 3.0
abstract class wifi_manager_proxy_type_e {
  /// Direct connection
  static const int WIFI_MANAGER_PROXY_TYPE_DIRECT = 0;

  /// Auto configuration(Use PAC file). If URL property is not set,
  /// DHCP/WPAD auto-discover will be tried
  static const int WIFI_MANAGER_PROXY_TYPE_AUTO = 1;

  /// Manual configuration
  static const int WIFI_MANAGER_PROXY_TYPE_MANUAL = 2;
}

/// @brief Enumeration for Wi-Fi security type.
/// @details The following security modes are used in infrastructure and ad-hoc mode.
/// For now all EAP security mechanisms are provided only in infrastructure mode.
///
/// @since_tizen 3.0
abstract class wifi_manager_security_type_e {
  /// < Security disabled
  static const int WIFI_MANAGER_SECURITY_TYPE_NONE = 0;

  /// < WEP
  static const int WIFI_MANAGER_SECURITY_TYPE_WEP = 1;

  /// < WPA-PSK
  static const int WIFI_MANAGER_SECURITY_TYPE_WPA_PSK = 2;

  /// < WPA2-PSK
  static const int WIFI_MANAGER_SECURITY_TYPE_WPA2_PSK = 3;

  /// < EAP
  static const int WIFI_MANAGER_SECURITY_TYPE_EAP = 4;
}

/// @brief Enumeration for Wi-Fi encryption type.
/// @details The following encryption modes are used in infrastructure and ad-hoc mode.
/// @since_tizen 3.0
abstract class wifi_manager_encryption_type_e {
  /// < Encryption disabled
  static const int WIFI_MANAGER_ENCRYPTION_TYPE_NONE = 0;

  /// < WEP
  static const int WIFI_MANAGER_ENCRYPTION_TYPE_WEP = 1;

  /// < TKIP
  static const int WIFI_MANAGER_ENCRYPTION_TYPE_TKIP = 2;

  /// < AES
  static const int WIFI_MANAGER_ENCRYPTION_TYPE_AES = 3;

  /// < TKIP and AES are both supported
  static const int WIFI_MANAGER_ENCRYPTION_TYPE_TKIP_AES_MIXED = 4;
}

/// @brief Enumeration for EAP type.
/// @since_tizen 3.0
abstract class wifi_manager_eap_type_e {
  /// < EAP PEAP type
  static const int WIFI_MANAGER_EAP_TYPE_PEAP = 0;

  /// < EAP TLS type
  static const int WIFI_MANAGER_EAP_TYPE_TLS = 1;

  /// < EAP TTLS type
  static const int WIFI_MANAGER_EAP_TYPE_TTLS = 2;

  /// < EAP SIM type
  static const int WIFI_MANAGER_EAP_TYPE_SIM = 3;

  /// < EAP AKA type
  static const int WIFI_MANAGER_EAP_TYPE_AKA = 4;
}

/// @brief Enumeration for EAP phase2 authentication type.
/// @since_tizen 3.0
abstract class wifi_manager_eap_auth_type_e {
  /// < EAP phase2 authentication none
  static const int WIFI_MANAGER_EAP_AUTH_TYPE_NONE = 0;

  /// < EAP phase2 authentication PAP
  static const int WIFI_MANAGER_EAP_AUTH_TYPE_PAP = 1;

  /// < EAP phase2 authentication MSCHAP
  static const int WIFI_MANAGER_EAP_AUTH_TYPE_MSCHAP = 2;

  /// < EAP phase2 authentication MSCHAPv2
  static const int WIFI_MANAGER_EAP_AUTH_TYPE_MSCHAPV2 = 3;

  /// < EAP phase2 authentication GTC
  static const int WIFI_MANAGER_EAP_AUTH_TYPE_GTC = 4;

  /// < EAP phase2 authentication MD5
  static const int WIFI_MANAGER_EAP_AUTH_TYPE_MD5 = 5;
}

/// @brief Enumeration for Wi-Fi disconnect reason, provided by the supplicant.
/// @since_tizen 4.0
abstract class wifi_manager_disconnect_reason_e {
  /// Locally Generate Disconnect from user side (Since 5.0)
  static const int WIFI_REASON_LOCAL_GENERATE_FROM_USER = -3;

  /// Unspecified reason
  static const int WIFI_REASON_UNSPECIFIED = 1;

  /// Previous authentication no longer valid
  static const int WIFI_REASON_PREV_AUTH_NOT_VALID = 2;

  /// Deauthenticated because sending STA is leaving (or has left) IBSS or ESS
  static const int WIFI_REASON_DEAUTH_LEAVING = 3;

  /// Disassociated due to inactivity
  static const int WIFI_REASON_DISASSOC_DUE_TO_INACTIVITY = 4;

  /// Disassociated because AP is unable to handle all currently associated STAs
  static const int WIFI_REASON_DISASSOC_AP_BUSY = 5;

  /// Class 2 frame received from nonauthenticated STA
  static const int WIFI_REASON_CLASS2_FRAME_FROM_NONAUTH_STA = 6;

  /// Class 3 frame received from nonassociated STA
  static const int WIFI_REASON_CLASS3_FRAME_FROM_NONASSOC_STA = 7;

  /// Disassociated because sending STA is leaving (or has left) BSS
  static const int WIFI_REASON_DISASSOC_STA_HAS_LEFT = 8;

  /// STA requesting (re)association is not authenticated with responding STA
  static const int WIFI_REASON_STA_REQ_ASSOC_WITHOUT_AUTH = 9;

  /// Disassociated because the information in the Power Capability
  /// element is unacceptable
  static const int WIFI_REASON_PWR_CAPABILITY_NOT_VALID = 10;

  /// Disassociated because the information in the Supported Channels
  /// element is unacceptable
  static const int WIFI_REASON_SUPPORTED_CHANNEL_NOT_VALID = 11;

  /// Invalid element i.e., an element defined in this standard for which the
  /// content does not meet the specifications in Clause 8
  static const int WIFI_REASON_INVALID_IE = 13;

  /// Message Integrity Code (MIC) failure
  static const int WIFI_REASON_MICHAEL_MIC_FAILURE = 14;

  /// 4-Way Handshake timeout
  static const int WIFI_REASON_4WAY_HANDSHAKE_TIMEOUT = 15;

  /// Group Key Handshake timeout
  static const int WIFI_REASON_GROUP_KEY_UPDATE_TIMEOUT = 16;

  /// Element in 4-Way Handshake different from (Re)Association Request/Probe
  /// Response/Beacon frame
  static const int WIFI_REASON_IE_IN_4WAY_DIFFERS = 17;

  /// Invalid group cipher
  static const int WIFI_REASON_GROUP_CIPHER_NOT_VALID = 18;

  /// Invalid pairwise cipher
  static const int WIFI_REASON_PAIRWISE_CIPHER_NOT_VALID = 19;

  /// Invalid AKMP
  static const int WIFI_REASON_AKMP_NOT_VALID = 20;

  /// Unsupported RSNE version
  static const int WIFI_REASON_UNSUPPORTED_RSN_IE_VERSION = 21;

  /// Invalid RSNE capabilities
  static const int WIFI_REASON_INVALID_RSN_IE_CAPAB = 22;

  /// IEEE 802.1X authentication failed
  static const int WIFI_REASON_IEEE_802_1X_AUTH_FAILED = 23;

  /// Cipher suite rejected because of the security policy
  static const int WIFI_REASON_CIPHER_SUITE_REJECTED = 24;

  /// TDLS direct-link teardown due to TDLS peer STA unreachable via the
  /// TDLS direct link
  static const int WIFI_REASON_TDLS_TEARDOWN_UNREACHABLE = 25;

  /// TDLS direct-link teardown for unspecified reason
  static const int WIFI_REASON_TDLS_TEARDOWN_UNSPECIFIED = 26;

  /// Disassociated because excessive number of frames need to be acknowledged,
  /// but are not acknowledged due to AP transmissions and/or poor channel conditions
  static const int WIFI_REASON_DISASSOC_LOW_ACK = 34;

  /// SME cancels the mesh peering instance with the reason other than reaching
  /// the maximum number of peer mesh STAs
  static const int WIFI_REASON_MESH_PEERING_CANCELLED = 52;

  /// The mesh STA has reached the supported maximum number of peer mesh STAs
  static const int WIFI_REASON_MESH_MAX_PEERS = 53;

  /// The received information violates the Mesh Configuration policy
  /// configured in the mesh STA profile
  static const int WIFI_REASON_MESH_CONFIG_POLICY_VIOLATION = 54;

  /// The mesh STA has received a Mesh Peering Close message requesting
  /// to close the mesh peering
  static const int WIFI_REASON_MESH_CLOSE_RCVD = 55;

  /// The mesh STA has resent dot11MeshMaxRetries Mesh Peering Open messages,
  /// without receiving a Mesh Peering Confirm message
  static const int WIFI_REASON_MESH_MAX_RETRIES = 56;

  /// The confirmTimer for the mesh peering instance times out
  static const int WIFI_REASON_MESH_CONFIRM_TIMEOUT = 57;

  /// The mesh STA fails to unwrap the GTK or the values in the wrapped
  /// contents do not match
  static const int WIFI_REASON_MESH_INVALID_GTK = 58;

  /// The mesh STA receives inconsistent information about the mesh parameters
  /// between Mesh Peering Management frames
  static const int WIFI_REASON_MESH_INCONSISTENT_PARAMS = 59;

  /// The mesh STA does not have proxy information for this external destination
  static const int WIFI_REASON_MESH_INVALID_SECURITY_CAP = 60;
}

/// @brief Enumeration for Wi-Fi Association Status code, provided by the supplicant.
/// @details The Wi-Fi Standard Reference : Status codes (IEEE 802.11-2007, 7.3.1.9, Table 7-23).
/// @since_tizen 5.0
abstract class wifi_manager_assoc_status_code_e {
  /// Successful
  static const int WLAN_STATUS_SUCCESS = 0;

  /// Unspecified failure
  static const int WLAN_STATUS_UNSPECIFIED_FAILURE = 1;

  /// Responding STA does not support the specified authentication
  /// algorithm
  static const int WLAN_STATUS_NOT_SUPPORTED_AUTH_ALG = 13;

  /// Association denied because AP is unable to handle additional
  /// associated STAs
  static const int WLAN_STATUS_AP_UNABLE_TO_HANDLE_NEW_STA = 17;

  /// Association denied because the requesting STA does not support
  /// HT feature
  static const int WLAN_STATUS_ASSOC_DENIED_NO_HT = 27;

  /// Association request rejected temporarily
  static const int WLAN_STATUS_ASSOC_REJECTED_TEMPORARILY = 30;

  /// Robust management frame policy violation
  static const int WLAN_STATUS_ROBUST_MGMT_FRAME_POLICY_VIOLATION = 31;

  /// Invalid element
  static const int WLAN_STATUS_INVALID_IE = 40;

  /// Invalid group cipher
  static const int WLAN_STATUS_GROUP_CIPHER_NOT_VALID = 41;

  /// Invalid pairwise cipher
  static const int WLAN_STATUS_PAIRWISE_CIPHER_NOT_VALID = 42;

  /// Invalid AKMP
  static const int WLAN_STATUS_AKMP_NOT_VALID = 43;

  /// Cipher suite rejected because of security policy
  static const int WLAN_STATUS_CIPHER_REJECTED_PER_POLICY = 46;

  /// Association denied because the Listen interval is too large
  static const int WLAN_STATUS_ASSOC_DENIED_LISTEN_INT_TOO_LARGE = 51;

  /// Invalid pairwise master key identifier (PKMID)
  static const int WLAN_STATUS_INVALID_PMKID = 53;

  /// Invalid MDE
  static const int WLAN_STATUS_INVALID_MDIE = 54;

  /// Invalid FTE
  static const int WLAN_STATUS_INVALID_FTIE = 55;

  /// Association denied because the requesting STA does not support
  /// VHT feature
  static const int WLAN_STATUS_ASSOC_DENIED_NO_VHT = 104;
}

/// @brief Enumeration for the state of the Wi-Fi TDLS.
/// @since_tizen 3.0
abstract class wifi_manager_tdls_state_e {
  /// < Wi-Fi TDLS is Disconnected
  static const int WIFI_MANAGER_TDLS_STATE_DISCONNECTED = 0;

  /// < Wi-Fi TDLS is Connected
  static const int WIFI_MANAGER_TDLS_STATE_CONNECTED = 1;
}

/// @brief Enumeration for Wi-Fi Frame type.
/// @since_tizen 5.0
/// @see wifi_manager_add_vsie()
/// @see wifi_manager_remove_vsie()
/// @see wifi_manager_get_vsie()
abstract class wifi_manager_vsie_frames_e {
  /// WiFi probe request frame
  static const int WIFI_MANAGER_VSIE_FRAME_PROBE_REQ = 0;

  /// WiFi association request frame
  static const int WIFI_MANAGER_VSIE_FRAME_ASSOC_REQ = 1;

  /// WiFi re-association request frame
  static const int WIFI_MANAGER_VSIE_FRAME_REASSOC = 2;

  /// WiFi authentication request frame
  static const int WIFI_MANAGER_VSIE_FRAME_AUTH_REQ = 3;

  /// WiFi action frame
  static const int WIFI_MANAGER_VSIE_FRAME_ACTION = 4;
}

/// @brief The Wi-Fi manager handle.
/// @since_tizen 3.0
typedef wifi_manager_h = ffi.Pointer<ffi.Void>;

/// @brief Called after wifi_manager_activate() or wifi_manager_activate_with_wifi_picker_tested() is completed.
/// @since_tizen 3.0
/// @param[in] result        The result
/// @param[in] user_data     The user data passed from wifi_manager_activate() and wifi_manager_activate_with_wifi_picker_tested()
/// @pre wifi_manager_activate() or wifi_manager_activate_with_wifi_picker_tested() will invoke this callback function.
/// @see wifi_manager_activate()
/// @see wifi_manager_activate_with_wifi_picker_tested()
typedef wifi_manager_activated_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called after wifi_manager_deactivate() is completed.
/// @since_tizen 3.0
/// @param[in] result        The result
/// @param[in] user_data     The user data passed from wifi_manager_deactivate()
/// @pre wifi_manager_deactivate() will invoke this callback function.
/// @see wifi_manager_deactivate()
typedef wifi_manager_deactivated_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the scan is finished.
/// @since_tizen 3.0
/// @param[in] error_code    The error code
/// @param[in] user_data     The user data passed from the callback registration function
/// @see wifi_manager_scan()
/// @see wifi_manager_set_background_scan_cb()
/// @see wifi_manager_unset_background_scan_cb()
typedef wifi_manager_scan_finished_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief The Wi-Fi specific ap scan handle.
/// @since_tizen 4.0
typedef wifi_manager_specific_scan_h = ffi.Pointer<ffi.Void>;

/// @brief Called when the connection process is completed.
/// @details The following functions start the connection process and will
/// result in the callback being called:
/// - wifi_manager_connect()
/// - wifi_manager_connect_by_wps_pbc()
/// - wifi_manager_connect_by_wps_pin()
/// - wifi_manager_connect_by_wps_pbc_without_ssid()
/// - wifi_manager_connect_by_wps_pin_without_ssid()
/// - wifi_manager_connect_hidden_ap()
/// @since_tizen 3.0
/// @param[in] result        The result
/// @param[in] user_data     The user data passed from the connection function.
/// @pre Any connection function will invoke this callback.
/// @see wifi_manager_connect()
/// @see wifi_manager_connect_by_wps_pbc()
/// @see wifi_manager_connect_by_wps_pin()
/// @see wifi_manager_connect_by_wps_pbc_without_ssid()
/// @see wifi_manager_connect_by_wps_pin_without_ssid()
/// @see wifi_manager_connect_hidden_ap()
typedef wifi_manager_connected_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief The Wi-Fi access point handle.
/// @since_tizen 3.0
typedef wifi_manager_ap_h = ffi.Pointer<ffi.Void>;

/// @brief Called for each found access point.
/// @since_tizen 3.0
/// @remarks @a AP is valid only in this function. In order to use @a AP outside this function, you must copy the AP with wifi_manager_ap_clone().
/// @param[in]  ap           The access point
/// @param[in]  user_data    The user data passed from the request function
/// @return  @c true to continue with the next iteration of the loop, \n
/// otherwise @c false to break out of the loop
/// @pre  wifi_manager_foreach_found_ap() will invoke this callback.
/// @pre  wifi_manager_foreach_found_specific_ap() will invoke this callback.
/// @see  wifi_manager_foreach_found_ap()
/// @see  wifi_manager_foreach_found_specific_ap()
typedef wifi_manager_found_ap_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(wifi_manager_ap_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Called after wifi_manager_disconnect() is completed.
/// @since_tizen 3.0
/// @param[in] result        The result
/// @param[in] user_data     The user data passed from wifi_manager_disconnect()
/// @pre wifi_manager_disconnect() will invoke this callback function.
/// @see wifi_manager_disconnect()
typedef wifi_manager_disconnected_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the device state is changed.
/// @since_tizen 3.0
/// @param[in] state         The device state
/// @param[in] user_data     The user data passed from the callback registration function
/// @see wifi_manager_set_device_state_changed_cb()
/// @see wifi_manager_unset_device_state_changed_cb()
typedef wifi_manager_device_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the scanning state is changed.
/// @since_tizen 4.0
/// @param[in] state         The wifi scanning state
/// @param[in] user_data     The user data passed from the callback registration function
/// @see wifi_manager_set_scan_state_changed_cb()
/// @see wifi_manager_unset_scan_state_changed_cb()
typedef wifi_manager_scan_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the connection state is changed.
/// @since_tizen 3.0
/// @param[in] state         The connection state
/// @param[in] ap            The access point
/// @param[in] user_data     The user data passed from the callback registration function
/// @see wifi_manager_set_connection_state_changed_cb()
/// @see wifi_manager_unset_connection_state_changed_cb()
typedef wifi_manager_connection_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, wifi_manager_ap_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the RSSI of connected Wi-Fi is changed.
/// @since_tizen 3.0
/// @param[in] rssi_level    The level of RSSI
/// @param[in] user_data     The user data passed from the callback registration function
/// @see wifi_manager_set_rssi_level_changed_cb()
/// @see wifi_manager_unset_rssi_level_changed_cb()
typedef wifi_manager_rssi_level_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the Wi-Fi Module state is changed.
/// @since_tizen 4.0
/// @param[in] wifi_module_state    The Wi-Fi Module state
/// @param[in] user_data            The user data passed from the callback registration function
/// @see wifi_manager_set_module_state_changed_cb()
/// @see wifi_manager_unset_module_state_changed_cb()
typedef wifi_manager_module_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the BSSID scan is finished.
/// @since_tizen 4.0
/// @param[in] error_code    The error code
/// @param[in] user_data     The user data passed from the callback registration function
/// @see wifi_manager_scan()
/// @see wifi_manager_bssid_scan()
/// @see wifi_manager_set_background_scan_cb()
/// @see wifi_manager_unset_background_scan_cb()
typedef wifi_manager_bssid_scan_finished_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called with an IPv6 address.
/// @since_tizen 4.0
/// @remarks  If @a ipv6_address is needed outside the callback, a copy should be
/// made. @a ipv6_address will be freed automatically after the execution
/// of this callback.
/// @param[in]  ipv6_address  The IPv6 address
/// @param[in]  user_data  The user data passed from the foreach function
/// @return  @c true to continue with the next iteration of the loop, \n
/// @c false to break out of the loop
/// @pre  wifi_manager_ap_foreach_ipv6_address() will invoke this callback.
/// @see  wifi_manager_ap_foreach_ipv6_address()
typedef wifi_manager_ap_ipv6_address_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief The Wi-Fi access point configuration handle
/// @since_tizen 3.0
typedef wifi_manager_config_h = ffi.Pointer<ffi.Void>;

/// @brief Called for each found access point configuration.
/// @since_tizen 3.0
/// @remarks @a config is valid only in this function. In order to use @a config outside this function, you must copy the config with wifi_manager_config_clone().
///
/// @param[in]  config       The access point configuration handle
/// @param[in]  user_data    The user data passed from the request function
///
/// @return  @c true to continue with the next iteration of the loop, otherwise @c false to break out of the loop \n
/// @pre  wifi_manager_config_foreach_configuration() will invoke this callback.
/// @see  wifi_manager_config_foreach_configuration()
typedef wifi_manager_config_list_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(wifi_manager_config_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the Wi-Fi TDLS is discovered.
/// @remarks @a peer_mac_addr is usable only in the callback. To use outside the callback, make a copy.
/// @param[in] state          The TDLS state
/// @param[in] peer_mac_addr  The MAC address of the TDLS peer
/// @param[in] user_data      The user data passed from the callback registration function
/// @see wifi_manager_tdls_set_discovered_cb()
/// @see wifi_manager_tdls_unset_discovered_cb()
typedef wifi_manager_tdls_discovered_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the Wi-Fi TDLS state is changed.
/// @since_tizen 3.0
///
/// @param[in] state          The TDLS state
/// @param[in] peer_mac_addr  The MAC address of the TDLS peer
/// @param[in] user_data      The user data passed from the callback registration function
/// @see wifi_manager_tdls_set_state_changed_cb()
/// @see wifi_manager_tdls_unset_state_changed_cb()
typedef wifi_manager_tdls_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the IP conflict state is changed.
/// @since_tizen 5.0
/// @remarks @a mac should not be freed. @a mac is available only in the callback. To use
/// outside the callback, make a copy.
/// @param[in] mac           The destination MAC address causing conflict
/// @param[in] state         The current state
/// @param[in] user_data     The user data passed from the callback registration function
/// @see wifi_manager_set_ip_conflict_cb()
/// @see wifi_manager_unset_ip_conflict_cb()
typedef wifi_manager_ip_conflict_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.Char>, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @partner
/// @brief Enumeration for CSR Errors.
/// @since_tizen 3.0
abstract class csr_error_e {
  /// < Successful
  static const int CSR_ERROR_NONE = 0;

  /// < Invalid function parameter
  static const int CSR_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int CSR_ERROR_OUT_OF_MEMORY = -12;

  /// < Permission denied
  static const int CSR_ERROR_PERMISSION_DENIED = -13;

  /// < Device needed to run API is not supported
  static const int CSR_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Busy for processing another request
  static const int CSR_ERROR_BUSY = -16;

  /// < Socket error between client and server
  static const int CSR_ERROR_SOCKET = -31653887;

  /// < The given handle is invalid
  static const int CSR_ERROR_INVALID_HANDLE = -31653886;

  /// < Server has been failed for some reason
  static const int CSR_ERROR_SERVER = -31653885;

  /// < No Task exists
  static const int CSR_ERROR_NO_TASK = -31653884;

  /// < DB transaction error
  static const int CSR_ERROR_DB = -31653883;

  /// < Removing file or application is failed
  static const int CSR_ERROR_REMOVE_FAILED = -31653882;

  /// < Getting user response is failed
  static const int CSR_ERROR_USER_RESPONSE_FAILED = -31653881;

  /// < File not exist
  static const int CSR_ERROR_FILE_DO_NOT_EXIST = -31653880;

  /// < File changed after detection
  static const int CSR_ERROR_FILE_CHANGED = -31653879;

  /// < File type is invalid
  static const int CSR_ERROR_FILE_SYSTEM = -31653872;

  /// < Insufficient permission of engine
  static const int CSR_ERROR_ENGINE_PERMISSION = -31653871;

  /// < No engine exists
  static const int CSR_ERROR_ENGINE_NOT_EXIST = -31653870;

  /// < Engine is in disabled state
  static const int CSR_ERROR_ENGINE_DISABLED = -31653869;

  /// < Engine is not activated
  static const int CSR_ERROR_ENGINE_NOT_ACTIVATED = -31653868;

  /// < Engine internal error
  static const int CSR_ERROR_ENGINE_INTERNAL = -31653863;

  /// < System error
  static const int CSR_ERROR_SYSTEM = -31653633;
}

class __csr_engine_h extends ffi.Opaque {}

/// @platform
/// @brief Enumeration for engine identifier.
/// @since_tizen 3.0
abstract class csr_engine_id_e {
  /// < Content screening engine id
  static const int CSR_ENGINE_CS = 1;

  /// < Web protection engine id
  static const int CSR_ENGINE_WP = 2;
}

/// @platform
/// @brief Enumeration for state of engine activation.
/// @since_tizen 3.0
abstract class csr_activated_e {
  /// < Engine is not activated
  static const int CSR_NOT_ACTIVATED = 1;

  /// < Engine is activated
  static const int CSR_ACTIVATED = 2;
}

/// @platform
/// @brief Enumeration for state of engine.
/// @since_tizen 3.0
abstract class csr_state_e {
  /// < Enable engine
  static const int CSR_STATE_ENABLE = 1;

  /// < Disable engine
  static const int CSR_STATE_DISABLE = 2;
}

/// @platform
/// @brief Engine handle.
/// @since_tizen 3.0
typedef csr_engine_h = ffi.Pointer<__csr_engine_h>;

/// @partner
/// @brief Enumeration for severity level of a detected malware.
/// @since_tizen 3.0
abstract class csr_cs_severity_level_e {
  /// < Low Severity. User can choose how to handle between skip, ignore and remove.
  static const int CSR_CS_SEVERITY_LOW = 1;

  /// < Medium Severity. User can choose how to handle between skip, ignore and remove.
  static const int CSR_CS_SEVERITY_MEDIUM = 2;

  /// < High Severity. User can choose how to handle between skip and remove.
  static const int CSR_CS_SEVERITY_HIGH = 3;
}

/// @partner
/// @brief Enumeration for the option of asking user about handling a detected malware.
/// @since_tizen 3.0
abstract class csr_cs_ask_user_e {
  /// < Do not ask the user even if malicious contents were found.
  static const int CSR_CS_ASK_USER_NO = 0;

  /// < Ask the user when malicious contents were found.
  static const int CSR_CS_ASK_USER_YES = 1;
}

/// @partner
/// @brief Enumeration for the user response from popup.
/// @since_tizen 3.0
abstract class csr_cs_user_response_e {
  /// < No response from user.
  static const int CSR_CS_USER_RESPONSE_USER_NOT_ASKED = 0;

  /// < A user decided to remove a detected malicious content and it was removed.
  static const int CSR_CS_USER_RESPONSE_REMOVE = 1;

  /// < A user decided to process a detected malware.
  static const int CSR_CS_USER_RESPONSE_PROCESSING_ALLOWED = 2;

  /// < A user decided not to process a detected malware.
  static const int CSR_CS_USER_RESPONSE_PROCESSING_DISALLOWED = 3;
}

/// @partner
/// @brief Enumeration for the action types for the detected malware files.
/// @since_tizen 3.0
abstract class csr_cs_action_e {
  /// < Remove the detected malware file.
  static const int CSR_CS_ACTION_REMOVE = 0;

  /// < Ignore the detected malware file.
  static const int CSR_CS_ACTION_IGNORE = 1;

  /// < Unignore the previously ignored file.
  static const int CSR_CS_ACTION_UNIGNORE = 2;
}

/// @partner
/// @brief Enumeration for maximum core usage during scanning.
/// @since_tizen 3.0
abstract class csr_cs_core_usage_e {
  /// < Use default setting value.
  static const int CSR_CS_CORE_USAGE_DEFAULT = 0;

  /// < Use all cores during scanning.
  static const int CSR_CS_CORE_USAGE_ALL = 1;

  /// < Use half cores during scanning.
  static const int CSR_CS_CORE_USAGE_HALF = 2;

  /// < Use a single core during scanning.
  static const int CSR_CS_CORE_USAGE_SINGLE = 3;
}

class __csr_cs_context_s extends ffi.Opaque {}

class __csr_cs_malware_s extends ffi.Opaque {}

class __csr_cs_malware_list_s extends ffi.Opaque {}

class __csr_cs_engine_s extends ffi.Opaque {}

/// @partner
/// @brief Content screening APIs context handle.
/// @since_tizen 3.0
typedef csr_cs_context_h = ffi.Pointer<__csr_cs_context_s>;

/// @partner
/// @brief Detected malware handle.
/// @since_tizen 3.0
typedef csr_cs_malware_h = ffi.Pointer<__csr_cs_malware_s>;

/// @partner
/// @brief Called when each file scanning is done without malware.
/// @since_tizen 3.0
/// @remarks Only for asynchronous scan functions.
/// @remarks Called for each file or application which is not detected malware.
/// @param[in] file_path A path of the file scanned. It would be package path if it's in application
/// @param[in] user_data A pointer of a user data. It's provided by client when calling asynchronous scanning method
/// @see csr_cs_set_file_scanned_cb()
/// @see csr_cs_scan_files_async()
/// @see csr_cs_scan_dir_async()
/// @see csr_cs_scan_dirs_async()
typedef csr_cs_file_scanned_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @partner
/// @brief Called when each file scanning is done with malware.
/// @since_tizen 3.0
/// @remarks Only for asynchronous scan functions.
/// @remarks Called for each file or application which is detected malware.
/// @remarks @a malware will be released when a context is released using csr_cs_context_destroy().
/// @param[in] malware The detected malware handle
/// @param[in] user_data A pointer of a user data. It's provided by client when calling asynchronous scanning method
/// @see csr_cs_set_detected_cb()
/// @see csr_cs_scan_files_async()
/// @see csr_cs_scan_dir_async()
/// @see csr_cs_scan_dirs_async()
typedef csr_cs_detected_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(csr_cs_malware_h, ffi.Pointer<ffi.Void>)>>;

/// @partner
/// @brief Called when scanning is finished successfully.
/// @since_tizen 3.0
/// @remarks Only for asynchronous scan functions.
/// @remarks Called only once at the end of scanning when success.
/// @param[in] user_data A pointer of a user data. It's provided by client when calling asynchronous scanning method
/// @see csr_cs_set_completed_cb()
/// @see csr_cs_scan_files_async()
/// @see csr_cs_scan_dir_async()
/// @see csr_cs_scan_dirs_async()
typedef csr_cs_completed_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @partner
/// @brief Called when scanning is cancelled by csr_cs_cancel_scanning().
/// @since_tizen 3.0
/// @remarks Only for asynchronous scan functions.
/// @remarks Called only once at the end of scanning by being cancelled.
/// @param[in] user_data A pointer of a user data. It's provided by client when calling asynchronous scanning method
/// @see csr_cs_set_cancelled_cb()
/// @see csr_cs_cancel_scanning()
/// @see csr_cs_scan_files_async()
/// @see csr_cs_scan_dir_async()
/// @see csr_cs_scan_dirs_async()
typedef csr_cs_cancelled_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @partner
/// @brief Called when scanning is stopped with an error.
/// @details The following error codes can be delivered.\n
/// #CSR_ERROR_FILE_DO_NOT_EXIST,\n
/// #CSR_ERROR_SOCKET,\n
/// #CSR_ERROR_SERVER,\n
/// #CSR_ERROR_ENGINE_NOT_EXIST,\n
/// #CSR_ERROR_ENGINE_DISABLED,\n
/// #CSR_ERROR_ENGINE_NOT_ACTIVATED,\n
/// #CSR_ERROR_ENGINE_PERMISSION,\n
/// #CSR_ERROR_ENGINE_INTERNAL
/// @since_tizen 3.0
/// @remarks Only for asynchronous scan functions.
/// @remarks Called only once at the end of scanning when failed with error.
/// @param[in] error_code Error code of #csr_error_e defined in csr-error.h
/// @param[in] user_data A pointer of a user data. It's provided by client when calling asynchronous scanning method
/// @see csr_cs_set_error_cb()
/// @see csr_cs_scan_files_async()
/// @see csr_cs_scan_dir_async()
/// @see csr_cs_scan_dirs_async()
typedef csr_cs_error_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @partner
/// @brief Detected malware list handle.
/// @since_tizen 3.0
typedef csr_cs_malware_list_h = ffi.Pointer<__csr_cs_malware_list_s>;

class __csr_wp_context_s extends ffi.Opaque {}

class __csr_wp_check_result_h extends ffi.Opaque {}

/// @partner
/// @brief Enumeration for the options about prompting a popup to a user.
/// @since_tizen 3.0
abstract class csr_wp_ask_user_e {
  /// < Do not ask the user even if a URL turns out risky.
  static const int CSR_WP_ASK_USER_NO = 0;

  /// < Ask the user when a URL turns out risky
  static const int CSR_WP_ASK_USER_YES = 1;
}

/// @partner
/// @brief Enumeration for the user response for a popup.
/// @since_tizen 3.0
abstract class csr_wp_user_response_e {
  /// < There was no popup for asking the user.
  static const int CSR_WP_USER_RESPONSE_USER_NOT_ASKED = 0;

  /// < A user allowed to process the url.
  static const int CSR_WP_USER_RESPONSE_PROCESSING_ALLOWED = 1;

  /// < A user disallowed to process the url.
  static const int CSR_WP_USER_RESPONSE_PROCESSING_DISALLOWED = 2;
}

/// @partner
/// @brief Enumeration for risk level of a url.
/// @since_tizen 3.0
abstract class csr_wp_risk_level_e {
  /// < Risk Low.
  static const int CSR_WP_RISK_LOW = 1;

  /// < Risk Unverified. There is no information about the url.
  static const int CSR_WP_RISK_UNVERIFIED = 2;

  /// < Risk Medium. Prompt the user before processing. Ask the user if they want the application to process the url.
  static const int CSR_WP_RISK_MEDIUM = 3;

  /// < High Risk.Do not process the url and just notify the user
  static const int CSR_WP_RISK_HIGH = 4;
}

/// @partner
/// @brief CSR WP context handle.
/// @since_tizen 3.0
typedef csr_wp_context_h = ffi.Pointer<__csr_wp_context_s>;

/// @partner
/// @brief CSR WP scan result handle.
/// @since_tizen 3.0
typedef csr_wp_check_result_h = ffi.Pointer<__csr_wp_check_result_h>;

/// @brief       Enumeration of device policy API errors
/// @since_tizen 3.0
abstract class dpm_error_type_e {
  /// < The operation was successful
  static const int DPM_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int DPM_ERROR_INVALID_PARAMETER = -22;

  /// < Connection refused
  static const int DPM_ERROR_CONNECTION_REFUSED = -111;

  /// < Time out
  static const int DPM_ERROR_TIMED_OUT = -1073741823;

  /// < Access privilege is not sufficient
  static const int DPM_ERROR_PERMISSION_DENIED = -13;

  /// < Operation not permitted
  static const int DPM_ERROR_NOT_PERMITTED = -1;

  /// < File exists
  static const int DPM_ERROR_FILE_EXISTS = -17;

  /// < Out of memory
  static const int DPM_ERROR_OUT_OF_MEMORY = -12;

  /// < No Data
  static const int DPM_ERROR_NO_DATA = -61;
}

/// @brief       The device policy manager handle
/// @details     The device policy manager handle is an abstraction of the
/// logical connection between the device policy manager and
/// it's client. The device policy manager handle must be
/// created by using dpm_manager_create() before attempting to
/// use almost any of the device policy APIs, and it should
/// be freed when interaction with the device policy manager
/// is no longer required.
/// To release the handle, use dpm_manager_destroy().
/// @since_tizen 3.0
/// @see         dpm_manager_create()
/// @see         dpm_manager_destroy()
typedef device_policy_manager_h = ffi.Pointer<ffi.Void>;

/// @brief       Called when a policy is changed.
/// @since_tizen 3.0
/// @param[in]   name The name of the policy
/// @param[in]   state The current state of the policy
/// @param[in]   user_data The user data passed from dpm_manager_add_policy_changed_cb
/// @see         dpm_manager_add_policy_changed_cb()
/// @see         dpm_manager_remove_policy_changed_cb()
typedef dpm_policy_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief       Called when a zone raises a signal.
/// @since_tizen 3.0
/// @param[in]   name The zone name
/// @param[in]   object The object name triggered the signal
/// @param[in]   user_data The user data passed from dpm_zone_add_signal_cb
/// @see         dpm_zone_add_signal_cb()
/// @see         dpm_zone_remove_signal_cb()
typedef dpm_signal_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief       Enumeration for dpm password quality type
/// @since_tizen 3.0
abstract class dpm_password_quality_e {
  /// < No requirements for password.
  static const int DPM_PASSWORD_QUALITY_UNSPECIFIED = 0;

  /// < EAS(Exchange ActiveSync) requirement for simple password
  static const int DPM_PASSWORD_QUALITY_SIMPLE_PASSWORD = 1;

  /// < Some kind password is required, but doesn't care what it is
  static const int DPM_PASSWORD_QUALITY_SOMETHING = 16;

  /// < Containing at least numeric characters
  static const int DPM_PASSWORD_QUALITY_NUMERIC = 32;

  /// < Containing at least alphabetic (or other symbol) characters
  static const int DPM_PASSWORD_QUALITY_ALPHABETIC = 64;

  /// < Containing at least numeric and alphabetic characters
  static const int DPM_PASSWORD_QUALITY_ALPHANUMERIC = 128;
}

/// @brief       Enumeration for dpm password status type
/// @since_tizen 3.0
abstract class dpm_password_status_e {
  /// < Password normal status
  static const int DPM_PASSWORD_STATUS_NORMAL = 0;

  /// < Password successfully changed
  static const int DPM_PASSWORD_STATUS_CHANGED = 1;

  /// < Password not changed
  static const int DPM_PASSWORD_STATUS_NOT_CHANGED = 2;

  /// < Password change required
  static const int DPM_PASSWORD_STATUS_CHANGE_REQUIRED = 3;

  /// < Password Max Attempts Exceeded
  static const int DPM_PASSWORD_STATUS_MAX_ATTEMPTS_EXCEEDED = 4;

  /// < Password expired
  static const int DPM_PASSWORD_STATUS_EXPIRED = 5;

  /// < Device unlock failed by Password Recovery
  static const int DPM_PASSWORD_STATUS_RECOVERY_PASSWORD_FAILED = 6;

  /// < Device unlock succeeded by Password Recovery
  static const int DPM_PASSWORD_STATUS_RECOVERY_PASSWORD_SUCCEEDED = 7;

  /// < Password quality successfully changed
  static const int DPM_PASSWORD_STATUS_QUALITY_CHANGED = 8;

  /// < Password min_length successfully changed
  static const int DPM_PASSWORD_STATUS_MIN_LENGTH_CHANGED = 9;

  /// < Password complex_char successfully changed
  static const int DPM_PASSWORD_STATUS_COMPLEX_CHAR_CHANGED = 10;

  /// < Password pattern successfully changed
  static const int DPM_PASSWORD_STATUS_PATTERN_CHANGED = 11;
}

/// @brief       The password forbidden string list iterator handle
/// @since_tizen 3.0
/// @see         dpm_password_create_iterator()
/// @see         dpm_password_iterator_next()
/// @see         dpm_password_destroy_iterator()
typedef dpm_password_iterator_h = ffi.Pointer<ffi.Void>;

/// @brief       Enumeration for device wipe type.
/// @since_tizen 3.0
abstract class dpm_security_wipe_type_e {
  /// < Wipe internal memory
  static const int DPM_SECURITY_WIPE_INTERNAL_STORAGE = 1;

  /// < Wipe external memory
  static const int DPM_SECURITY_WIPE_EXTERNAL_STORAGE = 2;
}

/// @brief       Enumeration for zone state
/// @since_tizen 3.0
abstract class dpm_zone_state_e {
  /// < Zone has been defined, but it can not start.
  static const int DPM_ZONE_STATE_LOCKED = 1;

  /// < Zone has been started.
  static const int DPM_ZONE_STATE_RUNNING = 2;

  /// < This presents all of the state
  static const int DPM_ZONE_STATE_ALL = 255;
}

/// @brief       Called to get all the name of created zones.
/// @since_tizen 3.0
/// @param[in]   name The zone name
/// @param[in]   user_data The user data passed from dpm_zone_foreach_name
/// @return      true to continue with the next iteration of the loop, otherwise false to break out out the loop
/// @see         dpm_zone_foreach_name()
typedef dpm_zone_foreach_name_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for Key Manager Errors.
/// @since_tizen 2.3
abstract class key_manager_error_e {
  /// < Successful
  static const int CKMC_ERROR_NONE = 0;

  /// < Invalid function parameter
  static const int CKMC_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int CKMC_ERROR_OUT_OF_MEMORY = -12;

  /// < Permission denied
  static const int CKMC_ERROR_PERMISSION_DENIED = -13;

  /// < Device needed to run API is not supported
  static const int CKMC_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Socket error between client and Central Key Manager
  static const int CKMC_ERROR_SOCKET = -31522815;

  /// < Invalid request from client
  static const int CKMC_ERROR_BAD_REQUEST = -31522814;

  /// < Invalid response from Central Key Manager
  static const int CKMC_ERROR_BAD_RESPONSE = -31522813;

  /// < Transmitting request failed
  static const int CKMC_ERROR_SEND_FAILED = -31522812;

  /// < Receiving response failed
  static const int CKMC_ERROR_RECV_FAILED = -31522811;

  /// < Optional password which used when saving is incorrect
  static const int CKMC_ERROR_AUTHENTICATION_FAILED = -31522810;

  /// < The output buffer size which is passed as parameter is too small
  static const int CKMC_ERROR_BUFFER_TOO_SMALL = -31522809;

  /// < Central Key Manager has been failed for some reason
  static const int CKMC_ERROR_SERVER_ERROR = -31522808;

  /// < The database was not unlocked - user did not login
  static const int CKMC_ERROR_DB_LOCKED = -31522807;

  /// < An internal error inside the database
  static const int CKMC_ERROR_DB_ERROR = -31522806;

  /// < Provided alias already exists in the database
  static const int CKMC_ERROR_DB_ALIAS_EXISTS = -31522805;

  /// < No data for given alias
  static const int CKMC_ERROR_DB_ALIAS_UNKNOWN = -31522804;

  /// < CA certificate(s) were unknown and chain could not be created
  static const int CKMC_ERROR_VERIFICATION_FAILED = -31522803;

  /// < A provided file or binary has not a valid format
  static const int CKMC_ERROR_INVALID_FORMAT = -31522802;

  /// < A provided file doesn't exist or cannot be accessed in the file system
  static const int CKMC_ERROR_FILE_ACCESS_DENIED = -31522801;

  /// < The data is saved as unexportable so it cannot be leaked
  static const int CKMC_ERROR_NOT_EXPORTABLE = -31522800;

  /// < Save key/certificate/pkcs12 failed because of file system error
  static const int CKMC_ERROR_FILE_SYSTEM = -31522799;

  /// < The error with unknown reason
  static const int CKMC_ERROR_UNKNOWN = -31522561;
}

/// @brief Enumeration for key types of key manager.
/// @since_tizen 2.3
abstract class ckmc_key_type {
  /// < Key type not specified
  static const int CKMC_KEY_NONE = 0;

  /// < RSA public key
  static const int CKMC_KEY_RSA_PUBLIC = 1;

  /// < RSA private key
  static const int CKMC_KEY_RSA_PRIVATE = 2;

  /// < ECDSA public key
  static const int CKMC_KEY_ECDSA_PUBLIC = 3;

  /// < ECDSA private key
  static const int CKMC_KEY_ECDSA_PRIVATE = 4;

  /// < DSA public key
  static const int CKMC_KEY_DSA_PUBLIC = 5;

  /// < DSA private key
  static const int CKMC_KEY_DSA_PRIVATE = 6;

  /// < AES key
  static const int CKMC_KEY_AES = 7;
}

/// @brief Enumeration for data format.
/// @since_tizen 2.3
abstract class ckmc_data_format {
  /// < DER format base64 encoded data
  static const int CKMC_FORM_DER_BASE64 = 0;

  /// < DER encoded data
  static const int CKMC_FORM_DER = 1;

  /// < PEM encoded data. It consists of the DER format base64 encoded
  /// with additional header and footer lines.
  static const int CKMC_FORM_PEM = 2;
}

/// @brief Enumeration for elliptic curve.
/// @since_tizen 2.3
abstract class ckmc_ec_type {
  /// < Elliptic curve domain "secp192r1" listed in "SEC 2" recommended
  /// elliptic curve domain
  static const int CKMC_EC_PRIME192V1 = 0;

  /// < "SEC 2" recommended elliptic curve domain - secp256r1
  static const int CKMC_EC_PRIME256V1 = 1;

  /// < NIST curve P-384(covers "secp384r1", the elliptic curve domain
  /// listed in See SEC 2
  static const int CKMC_EC_SECP384R1 = 2;
}

/// @brief Enumeration for hash algorithm.
/// @since_tizen 2.3
abstract class ckmc_hash_algo {
  /// < No Hash Algorithm
  static const int CKMC_HASH_NONE = 0;

  /// < Hash Algorithm SHA1
  static const int CKMC_HASH_SHA1 = 1;

  /// < Hash Algorithm SHA256
  static const int CKMC_HASH_SHA256 = 2;

  /// < Hash Algorithm SHA384
  static const int CKMC_HASH_SHA384 = 3;

  /// < Hash Algorithm SHA512
  static const int CKMC_HASH_SHA512 = 4;
}

/// @brief Enumeration for RSA padding algorithm.
/// @since_tizen 2.3
abstract class ckmc_rsa_padding_algo {
  /// < No Padding
  static const int CKMC_NONE_PADDING = 0;

  /// < PKCS#1 Padding
  static const int CKMC_PKCS1_PADDING = 1;

  /// < X9.31 padding
  static const int CKMC_X931_PADDING = 2;
}

/// @deprecated Deprecated since @if MOBILE 2.4. @elseif WEARABLE 3.0. @endif [Use ckmc_permission_e() instead]
/// @brief Enumeration for database access rights.
/// @since_tizen 2.3
abstract class ckmc_access_right {
  /// < Access right for read
  static const int CKMC_AR_READ = 0;

  /// < Access right for read and remove
  static const int CKMC_AR_READ_REMOVE = 1;
}

/// @brief Enumeration for permissions to access/modify alias.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class ckmc_permission {
  /// < Clear permissions
  static const int CKMC_PERMISSION_NONE = 0;

  /// < Eead allowed
  static const int CKMC_PERMISSION_READ = 1;

  /// < Remove allowed
  static const int CKMC_PERMISSION_REMOVE = 2;
}

/// @brief The structure for binary buffer used in key manager CAPI.
/// @since_tizen 2.3
class __ckmc_raw_buff extends ffi.Struct {
  /// < Byte array containing binary data
  external ffi.Pointer<ffi.UnsignedChar> data;

  /// < The size of the binary data
  @ffi.Size()
  external int size;
}

/// @brief The structure for a policy for storing key/certificate/binary data.
/// @since_tizen 2.3
class __ckmc_policy extends ffi.Struct {
  /// < Byte array used to encrypt data inside CKM. If it is not null, the data
  /// (or key, or certificate) is stored encrypted with this password inside
  /// key manager
  external ffi.Pointer<ffi.Char> password;

  /// < If true key may be extracted from storage
  @ffi.Bool()
  external bool extractable;
}

/// @brief The structure for key used in key manager CAPI.
/// @since_tizen 2.3
class __ckmc_key extends ffi.Struct {
  /// < Byte array of key. raw_key may be encrypted with password
  external ffi.Pointer<ffi.UnsignedChar> raw_key;

  /// < The byte size of raw_key
  @ffi.Size()
  external int key_size;

  /// < The raw_key's type
  @ffi.Int32()
  external int key_type;

  /// < Byte array used to decrypt data raw_key inside key manager.
  external ffi.Pointer<ffi.Char> password;
}

/// @brief The structure for certificate used in key manager CAPI.
/// @since_tizen 2.3
class __ckmc_cert extends ffi.Struct {
  /// < Byte array of certificate
  external ffi.Pointer<ffi.UnsignedChar> raw_cert;

  /// < Byte size of raw_cert
  @ffi.Size()
  external int cert_size;

  /// < Raw_cert's encoding format
  @ffi.Int32()
  external int data_format;
}

/// @brief The structure for linked list of alias.
/// @since_tizen 2.3
class __ckmc_alias_list extends ffi.Struct {
  /// < The name of key, certificate or data stored in key manager
  external ffi.Pointer<ffi.Char> alias;

  /// < The pointer pointing to the next ckmc_alias_list_s
  external ffi.Pointer<__ckmc_alias_list> next;
}

/// @brief The structure for linked list of ckmc_cert_s
/// @since_tizen 2.3
class __ckmc_cert_list extends ffi.Struct {
  /// < The pointer of ckmc_cert_s
  external ffi.Pointer<ckmc_cert_s> cert;

  /// < The pointer pointing to the next ckmc_cert_list_s
  external ffi.Pointer<__ckmc_cert_list> next;
}

/// @brief The structure for certificate used in key manager CAPI.
/// @since_tizen 2.3
typedef ckmc_cert_s = __ckmc_cert;

/// @brief Enumeration for OCSP status.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class ckmc_ocsp_status {
  /// < OCSP status is good
  static const int CKMC_OCSP_STATUS_GOOD = 0;

  /// < The certificate is revoked
  static const int CKMC_OCSP_STATUS_REVOKED = 1;

  /// < Unknown error
  static const int CKMC_OCSP_STATUS_UNKNOWN = 2;

  /// < The certificate does not provide OCSP extension
  static const int CKMC_OCSP_ERROR_UNSUPPORTED = 3;

  /// < The invalid URL in certificate OCSP extension
  static const int CKMC_OCSP_ERROR_INVALID_URL = 4;

  /// < The invalid response from OCSP server
  static const int CKMC_OCSP_ERROR_INVALID_RESPONSE = 5;

  /// < OCSP remote server error
  static const int CKMC_OCSP_ERROR_REMOTE = 6;

  /// < Network connection error
  static const int CKMC_OCSP_ERROR_NET = 7;

  /// < OpenSSL API error
  static const int CKMC_OCSP_ERROR_INTERNAL = 8;
}

/// @brief The structure for PKCS12 used in key manager CAPI.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
class __ckmc_pkcs12 extends ffi.Struct {
  /// < The private key, may be null
  external ffi.Pointer<ckmc_key_s> priv_key;

  /// < The certificate, may be null
  external ffi.Pointer<ckmc_cert_s> cert;

  /// < The chain certificate list, may be null
  external ffi.Pointer<ckmc_cert_list_s> ca_chain;
}

/// @brief The structure for key used in key manager CAPI.
/// @since_tizen 2.3
typedef ckmc_key_s = __ckmc_key;

/// @brief The structure for linked list of ckmc_cert_s
/// @since_tizen 2.3
typedef ckmc_cert_list_s = __ckmc_cert_list;

/// @brief Enumeration for crypto algorithm parameters.
/// @since_tizen 3.0
/// @see #ckmc_algo_type_e
abstract class ckmc_param_name {
  static const int CKMC_PARAM_ALGO_TYPE = 1;

  /// < 16B buffer (up to 2^64-1 bytes long in case of AES GCM)
  static const int CKMC_PARAM_ED_IV = 101;

  /// < integer - ctr length in bits
  static const int CKMC_PARAM_ED_CTR_LEN = 102;

  /// < buffer
  static const int CKMC_PARAM_ED_AAD = 103;

  /// < integer - tag length in bits
  static const int CKMC_PARAM_ED_TAG_LEN = 104;

  /// < buffer
  static const int CKMC_PARAM_ED_LABEL = 105;
}

class __ckmc_param_list extends ffi.Opaque {}

/// @brief Enumeration for crypto algorithm types.
/// @since_tizen 3.0
/// @see #ckmc_param_name_e
abstract class ckmc_algo_type {
  /// < AES-CTR algorithm
  /// Supported parameters:
  /// - CKMC_PARAM_ALGO_TYPE = CKMC_ALGO_AES_CTR(mandatory),
  /// - CKMC_PARAM_ED_IV = 16-byte initialization vector(mandatory)
  /// - CKMC_PARAM_ED_CTR_LEN = length of counter block in bits
  /// (optional, only 128b is supported at the moment)
  static const int CKMC_ALGO_AES_CTR = 1;

  /// < AES-CBC algorithm
  /// Supported parameters:
  /// - CKMC_PARAM_ALGO_TYPE = CKMC_ALGO_AES_CBC(mandatory),
  /// - CKMC_PARAM_ED_IV = 16-byte initialization vector(mandatory)
  static const int CKMC_ALGO_AES_CBC = 2;

  /// < AES-GCM algorithm
  /// Supported parameters:
  /// - CKMC_PARAM_ALGO_TYPE = CKMC_ALGO_AES_GCM(mandatory),
  /// - CKMC_PARAM_ED_IV = initialization vector(mandatory)
  /// - CKMC_PARAM_ED_TAG_LEN = GCM tag length in bits. One of
  /// {32, 64, 96, 104, 112, 120, 128} (optional, if not present, the
  /// length 128 is used)
  /// - CKMC_PARAM_ED_AAD = additional authentication data(optional)
  static const int CKMC_ALGO_AES_GCM = 3;

  /// < AES-CFB algorithm
  /// Supported parameters:
  /// - CKMC_PARAM_ALGO_TYPE = CKMC_ALGO_AES_CFB(mandatory),
  /// - CKMC_PARAM_ED_IV = 16-byte initialization vector(mandatory)
  static const int CKMC_ALGO_AES_CFB = 4;

  /// < RSA-OAEP algorithm
  /// Supported parameters:
  /// - CKMC_PARAM_ALGO_TYPE = CKMC_ALGO_RSA_OAEP(required),
  /// - CKMC_PARAM_ED_LABEL = label to be associated with the message
  /// (optional, not supported at the moment)
  static const int CKMC_ALGO_RSA_OAEP = 5;
}

/// @brief The structure for binary buffer used in key manager CAPI.
/// @since_tizen 2.3
typedef ckmc_raw_buffer_s = __ckmc_raw_buff;

/// @brief The structure for PKCS12 used in key manager CAPI.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef ckmc_pkcs12_s = __ckmc_pkcs12;

/// @brief The structure for linked list of alias.
/// @since_tizen 2.3
typedef ckmc_alias_list_s = __ckmc_alias_list;

/// @brief Algorithm parameter list handle.
/// @since_tizen 3.0
/// @remarks Each parameter list must have at least one CKMC_PARAM_ALGO_TYPE parameter that identifies the algorithm.
/// See #ckmc_algo_type_e for available algorithms and additional parameters they support.
/// @see ckmc_generate_new_params()
/// @see ckmc_param_list_new()
/// @see ckmc_param_list_set_integer()
/// @see ckmc_param_list_set_buffer()
/// @see ckmc_param_list_get_integer()
/// @see ckmc_param_list_get_buffer()
/// @see ckmc_param_list_free()
/// @see #ckmc_algo_type_e
/// @see #ckmc_param_name_e
typedef ckmc_param_list_h = ffi.Pointer<__ckmc_param_list>;

/// @brief The structure for a policy for storing key/certificate/binary data.
/// @since_tizen 2.3
typedef ckmc_policy_s = __ckmc_policy;

/// @brief Enumeration for error codes of Privacy Privilege Manager.
/// @since_tizen 4.0
abstract class ppm_error_e {
  /// Successful
  static const int PRIVACY_PRIVILEGE_MANAGER_ERROR_NONE = 0;

  /// I/O error
  static const int PRIVACY_PRIVILEGE_MANAGER_ERROR_IO_ERROR = -5;

  /// Invalid parameter
  static const int PRIVACY_PRIVILEGE_MANAGER_ERROR_INVALID_PARAMETER = -22;

  /// Operation already in progress
  static const int PRIVACY_PRIVILEGE_MANAGER_ERROR_ALREADY_IN_PROGRESS = -114;

  /// Out of memory
  static const int PRIVACY_PRIVILEGE_MANAGER_ERROR_OUT_OF_MEMORY = -12;

  /// Unknown error
  static const int PRIVACY_PRIVILEGE_MANAGER_ERROR_UNKNOWN = -1073741824;
}

/// @brief Enumeration for results of a permission check.
/// @since_tizen 4.0
abstract class ppm_check_result_e {
  /// The application has permission to use a privilege.
  static const int PRIVACY_PRIVILEGE_MANAGER_CHECK_RESULT_ALLOW = 0;

  /// The application doesn't have permission to use a privilege.
  static const int PRIVACY_PRIVILEGE_MANAGER_CHECK_RESULT_DENY = 1;

  /// The user has to be asked whether to grant permission to use a privilege.
  static const int PRIVACY_PRIVILEGE_MANAGER_CHECK_RESULT_ASK = 2;
}

/// @brief Enumeration for results of a permission request.
/// @since_tizen 4.0
abstract class ppm_request_result_e {
  /// The user granted permission to use a privilege for an indefinite period of time.
  static const int PRIVACY_PRIVILEGE_MANAGER_REQUEST_RESULT_ALLOW_FOREVER = 0;

  /// The user denied granting permission to use a privilege for an indefinite period of time.
  static const int PRIVACY_PRIVILEGE_MANAGER_REQUEST_RESULT_DENY_FOREVER = 1;

  /// The user denied granting permission to use a privilege once.
  static const int PRIVACY_PRIVILEGE_MANAGER_REQUEST_RESULT_DENY_ONCE = 2;
}

/// @brief Enumeration for status codes of a permission request.
/// @since_tizen 4.0
abstract class ppm_call_cause_e {
  /// Callback was called with a valid answer.
  static const int PRIVACY_PRIVILEGE_MANAGER_CALL_CAUSE_ANSWER = 0;

  /// Callback was called because of an error.
  static const int PRIVACY_PRIVILEGE_MANAGER_CALL_CAUSE_ERROR = 1;
}

/// @brief Called when the application receives a response upon calling ppm_request_permission().
///
/// @since_tizen 4.0
///
/// @param[in]   cause       The value representing a reason why this callback
/// has been called.
/// @param[in]   result      The result of a response triggered by calling ppm_request_permission().
/// This is a valid value only if the @a cause parameter is equal to
/// #PRIVACY_PRIVILEGE_MANAGER_CALL_CAUSE_ANSWER.
/// @param[in]   privilege   The privilege that has been checked. This pointer is managed by the API and
/// it is valid only in the body of the callback function.
/// @param[in]   user_data   User specific data, this pointer has been passed
/// to ppm_request_permission().
///
/// @see ppm_request_permission()
typedef ppm_request_response_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for error code for Privilege Information.
/// @since_tizen @if WEARABLE 2.3.1 @elseif MOBILE 2.3 @endif
abstract class privilege_info_error_e {
  /// < Successful
  static const int PRVINFO_ERROR_NONE = 0;

  /// < Invalid function parameter
  static const int PRVINFO_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int PRVINFO_ERROR_OUT_OF_MEMORY = -12;

  /// < Unknown error
  static const int PRVINFO_ERROR_INTERNAL_ERROR = -1073741824;
}

class yaca_context_s extends ffi.Opaque {}

class yaca_key_s extends ffi.Opaque {}

/// @brief Enumeration of YACA key formats.
///
/// @since_tizen 3.0
abstract class yaca_key_format_e {
  /// Key is either PKCS#1 for RSA or SSLeay for DSA, also use this option for symmetric
  static const int YACA_KEY_FORMAT_DEFAULT = 0;

  /// Key is in PKCS#8, can only be used for asymmetric private keys
  static const int YACA_KEY_FORMAT_PKCS8 = 1;
}

/// @brief Enumeration of YACA key file formats.
///
/// @since_tizen 3.0
abstract class yaca_key_file_format_e {
  /// Key file is in raw binary format, used for symmetric keys
  static const int YACA_KEY_FILE_FORMAT_RAW = 0;

  /// Key file is encoded in ASCII-base64, used for symmetric keys
  static const int YACA_KEY_FILE_FORMAT_BASE64 = 1;

  /// Key file is in PEM file format, used for asymmetric keys
  static const int YACA_KEY_FILE_FORMAT_PEM = 2;

  /// Key file is in DER file format, used for asymmetric keys
  static const int YACA_KEY_FILE_FORMAT_DER = 3;
}

/// @brief Enumeration of YACA key types, Initialization Vector is considered as key.
///
/// @since_tizen 3.0
abstract class yaca_key_type_e {
  /// Generic symmetric cipher KEY
  static const int YACA_KEY_TYPE_SYMMETRIC = 0;

  /// DES* key - must be handled differently because of parity bits
  static const int YACA_KEY_TYPE_DES = 1;

  /// Initialization Vector for symmetric algorithms
  static const int YACA_KEY_TYPE_IV = 2;

  /// RSA public key
  static const int YACA_KEY_TYPE_RSA_PUB = 3;

  /// RSA private key
  static const int YACA_KEY_TYPE_RSA_PRIV = 4;

  /// Digital Signature Algorithm public key
  static const int YACA_KEY_TYPE_DSA_PUB = 5;

  /// Digital Signature Algorithm private key
  static const int YACA_KEY_TYPE_DSA_PRIV = 6;

  /// Diffie-Hellman public key
  static const int YACA_KEY_TYPE_DH_PUB = 7;

  /// Diffie-Hellman private key
  static const int YACA_KEY_TYPE_DH_PRIV = 8;

  /// Elliptic Curve public key (for DSA and DH)
  static const int YACA_KEY_TYPE_EC_PUB = 9;

  /// Elliptic Curve private key (for DSA and DH)
  static const int YACA_KEY_TYPE_EC_PRIV = 10;

  /// Digital Signature Algorithm parameters
  static const int YACA_KEY_TYPE_DSA_PARAMS = 11;

  /// Diffie-Hellman parameters
  static const int YACA_KEY_TYPE_DH_PARAMS = 12;

  /// Elliptic Curve parameters
  static const int YACA_KEY_TYPE_EC_PARAMS = 13;
}

/// @brief Enumeration of YACA key lengths.
/// It is possible to use arbitrary integer instead,
/// this enum values are placed here to avoid magic numbers.
///
/// @since_tizen 3.0
abstract class yaca_key_bit_length_e {
  /// 64 bits
  static const int YACA_KEY_LENGTH_IV_64BIT = 64;

  /// 128 bits
  static const int YACA_KEY_LENGTH_IV_128BIT = 128;

  /// 8 bits
  static const int YACA_KEY_LENGTH_UNSAFE_8BIT = 8;

  /// 40 bits
  static const int YACA_KEY_LENGTH_UNSAFE_40BIT = 40;

  /// 64 bits
  static const int YACA_KEY_LENGTH_UNSAFE_64BIT = 64;

  /// 80 bits
  static const int YACA_KEY_LENGTH_UNSAFE_80BIT = 80;

  /// 128 bits
  static const int YACA_KEY_LENGTH_UNSAFE_128BIT = 128;

  /// 192 bits
  static const int YACA_KEY_LENGTH_192BIT = 192;

  /// 256 bits
  static const int YACA_KEY_LENGTH_256BIT = 256;

  /// 512 bits
  static const int YACA_KEY_LENGTH_512BIT = 512;

  /// 1024 bits
  static const int YACA_KEY_LENGTH_1024BIT = 1024;

  /// 2048 bits
  static const int YACA_KEY_LENGTH_2048BIT = 2048;

  /// 3072 bits
  static const int YACA_KEY_LENGTH_3072BIT = 3072;

  /// 4096 bits
  static const int YACA_KEY_LENGTH_4096BIT = 4096;
}

/// @brief Enumeration of YACA elliptic curve types with their bit lengths.
/// It's meant to be passed or returned as a @a key_bit_len param
/// in appropriate functions when dealing with elliptic curves.
///
/// @since_tizen 3.0
abstract class yaca_key_bit_length_ec_e {
  /// Elliptic curve prime192v1
  static const int YACA_KEY_LENGTH_EC_PRIME192V1 = 805306560;

  /// Elliptic curve prime256v1
  static const int YACA_KEY_LENGTH_EC_PRIME256V1 = 805306624;

  /// Elliptic curve secp256k1
  static const int YACA_KEY_LENGTH_EC_SECP256K1 = 824180992;

  /// Elliptic curve secp384r1
  static const int YACA_KEY_LENGTH_EC_SECP384R1 = 823132544;

  /// Elliptic curve secp521r1
  static const int YACA_KEY_LENGTH_EC_SECP521R1 = 823132681;
}

/// @brief Enumeration of YACA DH parameters taken from RFC 5114.
/// It's meant to be passed or returned as a @a key_bit_len param
/// in appropriate functions when dealing with DH and wanting to
/// use RFC 5114 values.
///
/// @since_tizen 3.0
abstract class yaca_key_bit_length_dh_rfc_e {
  /// RFC 5114 DH parameters 1024_160
  static const int YACA_KEY_LENGTH_DH_RFC_1024_160 = 536871936;

  /// RFC 5114 DH parameters 2048_224
  static const int YACA_KEY_LENGTH_DH_RFC_2048_224 = 553650176;

  /// RFC 5114 DH parameters 2048_256
  static const int YACA_KEY_LENGTH_DH_RFC_2048_256 = 570427392;
}

/// @brief Enumeration of YACA message digest algorithms.
///
/// @since_tizen 3.0
abstract class yaca_digest_algorithm_e {
  /// Message digest algorithm MD5
  static const int YACA_DIGEST_MD5 = 0;

  /// Message digest algorithm SHA1
  static const int YACA_DIGEST_SHA1 = 1;

  /// Message digest algorithm SHA2, 224bit
  static const int YACA_DIGEST_SHA224 = 2;

  /// Message digest algorithm SHA2, 256bit
  static const int YACA_DIGEST_SHA256 = 3;

  /// Message digest algorithm SHA2, 384bit
  static const int YACA_DIGEST_SHA384 = 4;

  /// Message digest algorithm SHA2, 512bit
  static const int YACA_DIGEST_SHA512 = 5;
}

/// @brief Enumeration of YACA symmetric encryption algorithms.
///
/// @since_tizen 3.0
abstract class yaca_encrypt_algorithm_e {
  /// AES encryption.
  /// - Supported key lengths: @c 128, @c 192 and @c 256 bits.
  /// - Supported block cipher modes:\n
  /// #YACA_BCM_CBC,\n
  /// #YACA_BCM_OFB,\n
  /// #YACA_BCM_CFB,\n
  /// #YACA_BCM_CFB1,\n
  /// #YACA_BCM_CFB8,\n
  /// #YACA_BCM_ECB,\n
  /// #YACA_BCM_GCM,\n
  /// #YACA_BCM_CCM,\n
  /// #YACA_BCM_CTR,\n
  /// #YACA_BCM_WRAP
  /// - see #yaca_block_cipher_mode_e for details on additional properties (mandatory).
  static const int YACA_ENCRYPT_AES = 0;

  /// DES encryption.
  /// - Supported key lengths: @c 64 bits.
  /// - Supported block cipher modes:\n
  /// #YACA_BCM_CBC,\n
  /// #YACA_BCM_OFB,\n
  /// #YACA_BCM_CFB,\n
  /// #YACA_BCM_CFB1,\n
  /// #YACA_BCM_CFB8,\n
  /// #YACA_BCM_ECB
  /// - see #yaca_block_cipher_mode_e for details on additional properties (mandatory).
  static const int YACA_ENCRYPT_UNSAFE_DES = 1;

  /// 3DES 2-key encryption.
  /// - Supported key lengths: @c 128 bits.
  /// - Supported block cipher modes:\n
  /// #YACA_BCM_CBC,\n
  /// #YACA_BCM_OFB,\n
  /// #YACA_BCM_CFB,\n
  /// #YACA_BCM_ECB
  /// - see #yaca_block_cipher_mode_e for details on additional properties (mandatory).
  /// - Use double DES keys to perform corresponding 2-key 3DES encryption.
  static const int YACA_ENCRYPT_UNSAFE_3DES_2TDEA = 2;

  /// 3DES 3-key encryption.
  /// - Supported key lengths: @c 192 bits.
  /// - Supported block cipher modes:\n
  /// #YACA_BCM_CBC,\n
  /// #YACA_BCM_OFB,\n
  /// #YACA_BCM_CFB,\n
  /// #YACA_BCM_CFB1,\n
  /// #YACA_BCM_CFB8,\n
  /// #YACA_BCM_ECB,\n
  /// #YACA_BCM_WRAP
  /// - see #yaca_block_cipher_mode_e for details on additional properties (mandatory).
  /// - Use triple DES keys to perform corresponding 3-key 3DES encryption.
  static const int YACA_ENCRYPT_3DES_3TDEA = 3;

  /// RC2 encryption.
  /// This is a variable key length cipher.
  /// - Supported key lengths: 8-1024 bits in steps of 8 bits.
  /// - Effective key bits property by default equals to 128 bits.\n
  /// Effective key bits can be set using yaca_context_set_property() and
  /// #YACA_PROPERTY_RC2_EFFECTIVE_KEY_BITS.\n
  /// It can be set after yaca_encrypt_initialize() / yaca_decrypt_initialize(), and before
  /// yaca_encrypt_update() / yaca_decrypt_update() in encryption / decryption operation.
  ///
  /// - Supported block cipher modes:\n
  /// #YACA_BCM_CBC,\n
  /// #YACA_BCM_OFB,\n
  /// #YACA_BCM_CFB,\n
  /// #YACA_BCM_ECB
  /// - see #yaca_block_cipher_mode_e for details on additional properties (mandatory).
  static const int YACA_ENCRYPT_UNSAFE_RC2 = 4;

  /// RC4 encryption.
  /// This is a variable key length cipher.
  /// - Supported key lengths: 40–2048 bits in steps of 8 bits.
  /// - Initialization Vector is not used.
  /// - This cipher doesn't support block cipher modes, use #YACA_BCM_NONE instead.
  static const int YACA_ENCRYPT_UNSAFE_RC4 = 5;

  /// CAST5 encryption.
  /// This is a variable key length cipher.
  /// - Supported key lengths: 40-128 bits in steps of 8 bits.
  /// - Supported block cipher modes:\n
  /// #YACA_BCM_CBC,\n
  /// #YACA_BCM_OFB,\n
  /// #YACA_BCM_CFB,\n
  /// #YACA_BCM_ECB
  /// - see #yaca_block_cipher_mode_e for details on additional properties (mandatory).
  static const int YACA_ENCRYPT_CAST5 = 6;
}

/// @brief Enumeration of YACA chaining modes for block ciphers.
///
/// @since_tizen 3.0
abstract class yaca_block_cipher_mode_e {
  /// Used when algorithm doesn't support block ciphers modes.
  /// Initialization Vector is not used.
  static const int YACA_BCM_NONE = 0;

  /// ECB block cipher mode.
  /// Initialization Vector is not used.
  ///
  /// By default the input data is padded using standard block padding (#YACA_PADDING_PKCS7).
  /// Padding can be disabled using yaca_context_set_property() and
  /// #YACA_PROPERTY_PADDING,#YACA_PADDING_NONE,
  /// then the total length of data passed until *_finalize() MUST be a multiple of block size.
  /// #YACA_PROPERTY_PADDING can be set at the latest before the *_finalize() call.
  static const int YACA_BCM_ECB = 1;

  /// CTR block cipher mode.
  /// 128-bit Initialization Vector for AES,
  /// 64-bit for other algorithms is mandatory.
  static const int YACA_BCM_CTR = 2;

  /// CBC block cipher mode.
  /// 128-bit Initialization Vector for AES,
  /// 64-bit for other algorithms is mandatory.
  ///
  /// By default the input data is padded using standard block padding (#YACA_PADDING_PKCS7).
  /// Padding can be disabled using yaca_context_set_property() and
  /// #YACA_PROPERTY_PADDING, #YACA_PADDING_NONE,
  /// then the total length of data passed until *_finalize() MUST be a multiple of block size.
  /// #YACA_PROPERTY_PADDING can be set at the latest before the *_finalize() call.
  static const int YACA_BCM_CBC = 3;

  /// GCM block cipher mode.
  /// This is a variable Initialization Vector length mode (recommended 96-bits).
  ///
  /// Supported properties:
  /// - #YACA_PROPERTY_GCM_TAG_LEN = GCM tag length (optional)\n
  /// Supported tag lengths: @c 4, @c 8, @c 12, @c 13, @c 14, @c 15, @c 16
  /// (16 bytes tag by default).\n
  /// Set after yaca_encrypt_finalize() / yaca_seal_finalize() and before
  /// yaca_context_get_property(#YACA_PROPERTY_GCM_TAG) in encryption / seal operation.\n
  /// The @a value should be a size_t variable.\n
  /// In decryption / open operation tag length is not set.\n\n
  ///
  /// - #YACA_PROPERTY_GCM_TAG = GCM tag\n
  /// Get after yaca_encrypt_finalize() / yaca_seal_finalize() in encryption / seal operation.\n
  /// Set after yaca_decrypt_update() / yaca_open_update() and before
  /// yaca_decrypt_finalize() / yaca_open_finalize() in decryption / open operation.\n\n
  ///
  /// - #YACA_PROPERTY_GCM_AAD = additional authentication data (optional)\n
  /// Set after yaca_encrypt_initialize() / yaca_seal_initialize() and before
  /// yaca_encrypt_update() / yaca_seal_update() in encryption / seal operation.\n
  /// Set after yaca_decrypt_initialize() / yaca_open_initialize() and before
  /// yaca_decrypt_update() / yaca_open_update() in decryption / open operation.\n\n
  ///
  /// @see yaca_context_set_property()
  /// @see yaca_context_get_property()
  static const int YACA_BCM_GCM = 4;

  /// Default CFB block cipher mode.
  /// 128-bit Initialization Vector for AES,
  /// 64-bit for other algorithms is mandatory.
  static const int YACA_BCM_CFB = 5;

  /// 1 bit CFB block cipher mode.
  /// 128-bit Initialization Vector for AES,
  /// 64-bit for other algorithms is mandatory.
  static const int YACA_BCM_CFB1 = 6;

  /// 8 bits CFB block cipher mode.
  /// 128-bit Initialization Vector for AES,
  /// 64-bit for other algorithms is mandatory.
  static const int YACA_BCM_CFB8 = 7;

  /// OFB block cipher mode.
  /// 128-bit Initialization Vector for AES,
  /// 64-bit for other algorithms is mandatory.
  static const int YACA_BCM_OFB = 8;

  /// CBC-MAC Mode (AES).
  /// This is a variable Initialization Vector length mode.\n
  /// Supported Initialization Vector lengths: 56-104 bits in steps of 8 bits
  /// (recommended 56-bits).\n\n
  ///
  /// Supported properties:
  /// - #YACA_PROPERTY_CCM_TAG_LEN = CCM tag length (optional)\n
  /// Supported tag lengths: 4-16 bytes in steps of 2 bytes (12 bytes tag by default).\n
  /// Set after yaca_encrypt_initialize() / yaca_seal_initialize() and before
  /// yaca_encrypt_update() / yaca_seal_update() in encryption / seal operation.\n
  /// The @a value should be a size_t variable.\n
  /// In decryption / open operation tag length is not set.\n\n
  ///
  /// - #YACA_PROPERTY_CCM_TAG = CCM tag\n
  /// Get after yaca_encrypt_finalize() / yaca_seal_finalize() in encryption / seal operation.\n
  /// Set after yaca_decrypt_initialize() / yaca_open_initialize() and before
  /// yaca_decrypt_update() / yaca_open_update() in decryption / open operation.\n\n
  ///
  /// - #YACA_PROPERTY_CCM_AAD = additional authentication data (optional)\n
  /// The total plaintext length must be passed to yaca_encrypt_update() / yaca_seal_update()
  /// if AAD is used.\n
  /// Set after yaca_encrypt_initialize() / yaca_seal_initialize() and before
  /// yaca_encrypt_update() / yaca_seal_update() in encryption / seal operation.\n
  /// You can only call yaca_encrypt_update() / yaca_seal_update() once for AAD
  /// and once for the plaintext.\n\n
  ///
  /// The total encrypted text length must be passed to yaca_decrypt_update() /
  /// yaca_open_update() if AAD is used.\n
  /// Set after yaca_decrypt_initialize() / yaca_open_initialize() and before
  /// yaca_decrypt_update() / yaca_open_update() in decryption / open operation.\n
  /// You can only call yaca_decrypt_update() / yaca_open_update() once for AAD
  /// and once for the encrypted text.\n\n
  ///
  /// @see yaca_context_set_property()
  /// @see yaca_context_get_property()
  static const int YACA_BCM_CCM = 9;

  /// Used with #YACA_ENCRYPT_AES or #YACA_ENCRYPT_3DES_3TDEA to perform a key wrapping
  /// (key material symmetric encryption).
  ///
  /// Only a single yaca_encrypt_update() / yaca_decrypt_update() is allowed.
  ///
  /// Usage in yaca_seal_initialize() / yaca_open_finalize() is forbidden.
  ///
  /// Key used to do the wrapping with #YACA_ENCRYPT_AES can be a 128-bit key, a 192-bit key,
  /// or a 256-bit key.\n
  /// 64-bit Initialization Vector is used.\n
  /// Wrapped key can be a 128-bit key, a 192-bit key, or a 256-bit key.\n
  /// #YACA_ENCRYPT_AES allows wrapping multiple keys together.
  ///
  /// Key used to do the wrapping with #YACA_ENCRYPT_3DES_3TDEA can be a 192-bit DES key only.\n
  /// Initialization Vector is not used.\n
  /// Wrapped key can be a 128-bit DES key (two-key), or a 192-bit DES key (three-key).\n
  /// #YACA_ENCRYPT_3DES_3TDEA allows wrapping only one key.
  static const int YACA_BCM_WRAP = 10;
}

/// @brief Enumeration of YACA non-standard properties for algorithms.
///
/// @since_tizen 3.0
///
/// @see #yaca_padding_e
abstract class yaca_property_e {
  /// Padding for the encrypt/decrypt or sign/verify operation. Property type is #yaca_padding_e.
  ///
  /// This property can be set at the latest before the *_finalize() call.
  static const int YACA_PROPERTY_PADDING = 0;

  /// GCM Additional Authentication Data. Property type is a buffer (e.g. char*)
  static const int YACA_PROPERTY_GCM_AAD = 1;

  /// GCM Tag. Property type is a buffer (e.g. char*)
  static const int YACA_PROPERTY_GCM_TAG = 2;

  /// GCM Tag length in bytes. Property type is size_t.
  static const int YACA_PROPERTY_GCM_TAG_LEN = 3;

  /// CCM Additional Authentication Data. Property type is a buffer (e.g. char*)
  static const int YACA_PROPERTY_CCM_AAD = 4;

  /// CCM Tag. Property type is a buffer (e.g. char*)
  static const int YACA_PROPERTY_CCM_TAG = 5;

  /// CCM Tag length in bytes. Property type is size_t.
  static const int YACA_PROPERTY_CCM_TAG_LEN = 6;

  /// RC2 effective key bits, 1-1024, 1 bit resolution. Property type is size_t.
  static const int YACA_PROPERTY_RC2_EFFECTIVE_KEY_BITS = 7;
}

/// @brief Enumeration of YACA paddings.
///
/// @since_tizen 3.0
abstract class yaca_padding_e {
  /// No padding at all. This method assumes that the input data already has a proper length for
  /// a given cryptographic operation (e.g. it has been padded by the client). Suitable for
  /// symmetric encrypt/decrypt operations as well as low-level RSA operations.
  static const int YACA_PADDING_NONE = 0;

  /// X9.31 padding. Suitable for RSA sign/verify operation. Not supported in low-level
  /// RSA operations.
  static const int YACA_PADDING_X931 = 1;

  /// PKCS #1 v1.5 padding. Suitable for RSA sign/verify and low-level RSA operations.
  /// For low-level operations the input must be at least 11 bytes shorter than the key length.
  static const int YACA_PADDING_PKCS1 = 2;

  /// PKCS #1 PSS padding. Suitable for RSA sign/verify operations. Not supported in low-level
  /// RSA operations.
  static const int YACA_PADDING_PKCS1_PSS = 3;

  /// EME-OAEP as defined in PKCS #1 v2.0 with SHA-1, MGF1 and an empty encoding parameter.
  /// Suitable for low-level RSA public_encrypt/private_decrypt operations. For low-level
  /// operations the input must be at least 42 bytes shorter than the key length.
  static const int YACA_PADDING_PKCS1_OAEP = 4;

  /// PKCS #1 v1.5 padding with an SSL-specific modification that denotes that the party
  /// is SSL3 capable. It is used for rollback attack detection in SSLv3. If during decryption it
  /// turns out that both parties are using #YACA_PADDING_PKCS1_SSLV23 (both are communicating
  /// using SSL2 and both are SSL3 capable) it is treated as a rollback attack and an error is
  /// returned. Suitable for low-level RSA public_encrypt/private_decrypt operations. For
  /// low-level operations the input must be at least 11 bytes shorter than the key length.
  static const int YACA_PADDING_PKCS1_SSLV23 = 5;

  /// PKCS #7 padding. Suitable for symmetric encrypt/decrypt operation.
  static const int YACA_PADDING_PKCS7 = 6;
}

/// @brief Enumeration of YACA key derivation functions.
///
/// @since_tizen 3.0
abstract class yaca_kdf_e {
  /// ANSI X9.42 key derivation function,
  /// (shared secret derived using Diffie-Helmann key exchange protocol).
  static const int YACA_KDF_X942 = 0;

  /// ANSI X9.62 key derivation function,
  /// (shared secret derived using EC Diffie-Helmann key exchange protocol).
  static const int YACA_KDF_X962 = 1;
}

/// @brief The context handle.
///
/// @since_tizen 3.0
typedef yaca_context_h = ffi.Pointer<yaca_context_s>;

/// @brief The handle of a key, an Initialization Vector or a key generation parameters.
///
/// @since_tizen 3.0
typedef yaca_key_h = ffi.Pointer<yaca_key_s>;

/// @brief Enumeration of YACA error values.
///
/// @since_tizen 3.0
abstract class yaca_error_e {
  /// Successful
  static const int YACA_ERROR_NONE = 0;

  /// Invalid function parameter
  static const int YACA_ERROR_INVALID_PARAMETER = -22;

  /// Out of memory
  static const int YACA_ERROR_OUT_OF_MEMORY = -12;

  /// Internal error
  static const int YACA_ERROR_INTERNAL = -31653887;

  /// Data mismatch
  static const int YACA_ERROR_DATA_MISMATCH = -31653886;

  /// Invalid password
  static const int YACA_ERROR_INVALID_PASSWORD = -31653885;
}

/// @brief Enumeration for calendar errors.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_error_e {
  /// < Successful
  static const int CALENDAR_ERROR_NONE = 0;

  /// < Out of memory
  static const int CALENDAR_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int CALENDAR_ERROR_INVALID_PARAMETER = -22;

  /// < Requested data does not exist
  static const int CALENDAR_ERROR_NO_DATA = -61;

  /// < Operation now in progress
  static const int CALENDAR_ERROR_NOW_IN_PROGRESS = -115;

  /// < Operation already in progress
  static const int CALENDAR_ERROR_ALREADY_IN_PROGRESS = -114;

  /// < Operation not permitted
  static const int CALENDAR_ERROR_NOT_PERMITTED = -1;

  /// < FS is full
  static const int CALENDAR_ERROR_FILE_NO_SPACE = -28;

  /// < Permission denied
  static const int CALENDAR_ERROR_PERMISSION_DENIED = -13;

  /// < No access to the database
  static const int CALENDAR_ERROR_DB_FAILED = -33554430;

  /// < Iterator is on the last position
  static const int CALENDAR_ERROR_ITERATOR_END = -33554428;

  /// < Database not found
  static const int CALENDAR_ERROR_DB_RECORD_NOT_FOUND = -33554427;

  /// < Unknown IPC error
  static const int CALENDAR_ERROR_IPC = -33554241;

  /// < Error from another modules
  static const int CALENDAR_ERROR_SYSTEM = -33554193;

  /// < Not supported (Since 4.0)
  static const int CALENDAR_ERROR_NOT_SUPPORTED = -1073741822;
}

class __calendar_record_h extends ffi.Opaque {}

class __calendar_filter_h extends ffi.Opaque {}

class __calendar_list_h extends ffi.Opaque {}

class __calendar_query_h extends ffi.Opaque {}

class __calendar_h extends ffi.Opaque {}

/// @brief Enumeration for the filter match type of a string.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_match_str_flag_e {
  /// < Full string, case-sensitive
  static const int CALENDAR_MATCH_EXACTLY = 0;

  /// < Full string, case-insensitive
  static const int CALENDAR_MATCH_FULLSTRING = 1;

  /// < Sub string, case-insensitive
  static const int CALENDAR_MATCH_CONTAINS = 2;

  /// < Start with, case-insensitive
  static const int CALENDAR_MATCH_STARTSWITH = 3;

  /// < End with, case-insensitive
  static const int CALENDAR_MATCH_ENDSWITH = 4;

  /// < IS NOT NULL
  static const int CALENDAR_MATCH_EXISTS = 5;

  /// < Calendar match string flag max enum count
  static const int CALENDAR_MATCH_STR_MAX = 6;
}

/// @brief Enumeration for the filter match type of an integer.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_match_int_flag_e {
  /// < '='
  static const int CALENDAR_MATCH_EQUAL = 0;

  /// < '>'
  static const int CALENDAR_MATCH_GREATER_THAN = 1;

  /// < '>='
  static const int CALENDAR_MATCH_GREATER_THAN_OR_EQUAL = 2;

  /// < '<'
  static const int CALENDAR_MATCH_LESS_THAN = 3;

  /// < '<='
  static const int CALENDAR_MATCH_LESS_THAN_OR_EQUAL = 4;

  /// < '<>', this flag can yield poor performance
  static const int CALENDAR_MATCH_NOT_EQUAL = 5;

  /// < IS NULL
  static const int CALENDAR_MATCH_NONE = 6;

  /// < Calendar match integer flag max enum count
  static const int CALENDAR_MATCH_INT_MAX = 7;
}

/// @brief Enumeration for a filter operator.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_filter_operator_e {
  /// < AND
  static const int CALENDAR_FILTER_OPERATOR_AND = 0;

  /// < OR
  static const int CALENDAR_FILTER_OPERATOR_OR = 1;

  /// < Calendar filter operator max enum count
  static const int CALENDAR_FILTER_OPERATOR_MAX = 2;
}

/// @brief Enumeration for the calendar book type.
/// @details "OR"ing is supported.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_book_type_e {
  /// < Default calendar book type
  static const int CALENDAR_BOOK_TYPE_NONE = 0;

  /// < Event calendar book type
  static const int CALENDAR_BOOK_TYPE_EVENT = 1;

  /// < To-do calendar book type
  static const int CALENDAR_BOOK_TYPE_TODO = 2;
}

/// @brief Enumeration for the calendar sensitivity type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_sensitivity_e {
  /// < Public Sensitivity
  static const int CALENDAR_SENSITIVITY_PUBLIC = 0;

  /// < Private Sensitivity
  static const int CALENDAR_SENSITIVITY_PRIVATE = 1;

  /// < Confidential Sensitivity
  static const int CALENDAR_SENSITIVITY_CONFIDENTIAL = 2;
}

/// @brief Enumeration for the attendee status.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_attendee_status_e {
  /// < Pending status
  static const int CALENDAR_ATTENDEE_STATUS_PENDING = 0;

  /// < Accepted status
  static const int CALENDAR_ATTENDEE_STATUS_ACCEPTED = 1;

  /// < Declined status
  static const int CALENDAR_ATTENDEE_STATUS_DECLINED = 2;

  /// < Tentative status
  static const int CALENDAR_ATTENDEE_STATUS_TENTATIVE = 3;

  /// < Delegated status
  static const int CALENDAR_ATTENDEE_STATUS_DELEGATED = 4;

  /// < Completed status
  static const int CALENDAR_ATTENDEE_STATUS_COMPLETED = 5;

  /// < In process status
  static const int CALENDAR_ATTENDEE_STATUS_IN_PROCESS = 6;

  /// < Calendar attendee status max enum count
  static const int CALENDAR_ATTENDEE_STATUS_MAX = 7;
}

/// @brief Enumeration for the attendee role.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_attendee_role_e {
  /// < Participation is required
  static const int CALENDAR_ATTENDEE_ROLE_REQ_PARTICIPANT = 0;

  /// < Accepted status
  static const int CALENDAR_ATTENDEE_ROLE_OPT_PARTICIPANT = 1;

  /// < Non-Participant
  static const int CALENDAR_ATTENDEE_ROLE_NON_PARTICIPANT = 2;

  /// < Chairperson
  static const int CALENDAR_ATTENDEE_ROLE_CHAIR = 3;

  /// < Calendar attendee role max enum count
  static const int CALENDAR_ATTENDEE_ROLE_MAX = 4;
}

/// @brief Enumeration for the attendee cutype.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_attendee_cutyep_e {
  /// < Individual cutype
  static const int CALENDAR_ATTENDEE_CUTYPE_INDIVIDUAL = 0;

  /// < Group cutype
  static const int CALENDAR_ATTENDEE_CUTYPE_GROUP = 1;

  /// < Resource cutype
  static const int CALENDAR_ATTENDEE_CUTYPE_RESOURCE = 2;

  /// < Room cutype
  static const int CALENDAR_ATTENDEE_CUTYPE_ROOM = 3;

  /// < Unknown cutype
  static const int CALENDAR_ATTENDEE_CUTYPE_UNKNOWN = 4;

  /// < Calendar attendee cutype max enum count
  static const int CALENDAR_ATTENDEE_CUTYPE_MAX = 5;
}

/// @brief Enumeration for the alarm time unit type of an event, such as minutes, hours, days, and so on.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_alarm_time_unit_type_e {
  /// < No reminder set
  static const int CALENDAR_ALARM_NONE = -1;

  /// < Specific in seconds
  static const int CALENDAR_ALARM_TIME_UNIT_SPECIFIC = 1;

  /// < Alarm time unit in minutes
  static const int CALENDAR_ALARM_TIME_UNIT_MINUTE = 60;

  /// < Alarm time unit in hours
  static const int CALENDAR_ALARM_TIME_UNIT_HOUR = 3600;

  /// < Alarm time unit in days
  static const int CALENDAR_ALARM_TIME_UNIT_DAY = 86400;

  /// < Alarm time unit in weeks
  static const int CALENDAR_ALARM_TIME_UNIT_WEEK = 604800;
}

/// @brief Enumeration for the alarm action.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_alarm_action_e {
  /// < Audio action
  static const int CALENDAR_ALARM_ACTION_AUDIO = 0;

  /// < Display action
  static const int CALENDAR_ALARM_ACTION_DISPLAY = 1;

  /// < Email action
  static const int CALENDAR_ALARM_ACTION_EMAIL = 2;

  /// < Calendar alarm action max enum count
  static const int CALENDAR_ALARM_ACTION_MAX = 3;
}

/// @brief Enumeration for the frequency of an event's recurrence.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_recurrence_frequency_e {
  /// < No recurrence event
  static const int CALENDAR_RECURRENCE_NONE = 0;

  /// < An event occurs every day
  static const int CALENDAR_RECURRENCE_DAILY = 1;

  /// < An event occurs on the same day of every week. According to the week flag, the event will recur every day of the week
  static const int CALENDAR_RECURRENCE_WEEKLY = 2;

  /// < An event occurs on the same day of every month
  static const int CALENDAR_RECURRENCE_MONTHLY = 3;

  /// < An event occurs on the same day of every year
  static const int CALENDAR_RECURRENCE_YEARLY = 4;
}

/// @brief Enumeration for the event status.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_event_status_e {
  /// < No status
  static const int CALENDAR_EVENT_STATUS_NONE = 1;

  /// < The event is tentative
  static const int CALENDAR_EVENT_STATUS_TENTATIVE = 2;

  /// < The event is confirmed
  static const int CALENDAR_EVENT_STATUS_CONFIRMED = 4;

  /// < The event is canceled
  static const int CALENDAR_EVENT_STATUS_CANCELLED = 8;
}

/// @brief Enumeration for the busy status of an event.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_event_busy_status_e {
  /// < The free status
  static const int CALENDAR_EVENT_BUSY_STATUS_FREE = 0;

  /// < The busy status
  static const int CALENDAR_EVENT_BUSY_STATUS_BUSY = 1;

  /// < The unavailable status
  static const int CALENDAR_EVENT_BUSY_STATUS_UNAVAILABLE = 2;

  /// < The tentative status
  static const int CALENDAR_EVENT_BUSY_STATUS_TENTATIVE = 3;
}

/// @brief Enumeration for the calendar event item's priority.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_event_priority_e {
  /// < No priority
  static const int CALENDAR_EVENT_PRIORITY_NONE = 1;

  /// < Low priority
  static const int CALENDAR_EVENT_PRIORITY_LOW = 8;

  /// < Normal priority
  static const int CALENDAR_EVENT_PRIORITY_NORMAL = 4;

  /// < High priority
  static const int CALENDAR_EVENT_PRIORITY_HIGH = 2;
}

/// @brief Enumeration for the calendar to-do item's priority.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_todo_priority_e {
  /// < No priority
  static const int CALENDAR_TODO_PRIORITY_NONE = 1;

  /// < Low priority
  static const int CALENDAR_TODO_PRIORITY_LOW = 8;

  /// < Normal priority
  static const int CALENDAR_TODO_PRIORITY_NORMAL = 4;

  /// < High priority
  static const int CALENDAR_TODO_PRIORITY_HIGH = 2;
}

/// @brief Enumeration for the status of a to-do.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_todo_status_e {
  /// < No status
  static const int CALENDAR_TODO_STATUS_NONE = 256;

  /// < Needs action status
  static const int CALENDAR_TODO_STATUS_NEEDS_ACTION = 512;

  /// < Completed status
  static const int CALENDAR_TODO_STATUS_COMPLETED = 1024;

  /// < Work in process status
  static const int CALENDAR_TODO_STATUS_IN_PROCESS = 2048;

  /// < Canceled status
  static const int CALENDAR_TODO_STATUS_CANCELED = 4096;
}

/// @brief Enumeration for the time type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_time_type_e {
  /// < Unix time
  static const int CALENDAR_TIME_UTIME = 0;

  /// < Local time
  static const int CALENDAR_TIME_LOCALTIME = 1;
}

/// @brief Enumeration for the range type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_range_type_e {
  /// < Range until
  static const int CALENDAR_RANGE_UNTIL = 0;

  /// < Range count
  static const int CALENDAR_RANGE_COUNT = 1;

  /// < No range
  static const int CALENDAR_RANGE_NONE = 2;
}

/// @brief Enumeration for the system type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_system_type_e {
  /// < Locale's default calendar
  static const int CALENDAR_SYSTEM_NONE = 0;

  /// < Locale's default calendar
  static const int CALENDAR_SYSTEM_GREGORIAN = 1;

  /// < East asian lunisolar calendar
  static const int CALENDAR_SYSTEM_EAST_ASIAN_LUNISOLAR = 2;
}

/// @brief Enumeration for the meeting status.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_meeting_status_e {
  /// < No meeting
  static const int CALENDAR_MEETING_STATUS_NOTMEETING = 0;

  /// < Meeting exists
  static const int CALENDAR_MEETING_STATUS_MEETING = 1;

  /// < Meeting received
  static const int CALENDAR_MEETING_STATUS_RECEIVED = 2;

  /// < Meeting canceled
  static const int CALENDAR_MEETING_STATUS_CANCELED = 3;
}

/// @brief Enumeration for weekdays.
/// @details Same value as UCalendarDaysOfWeek in ICU.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_days_of_week_e {
  /// < Sunday
  static const int CALENDAR_SUNDAY = 1;

  /// < Monday
  static const int CALENDAR_MONDAY = 2;

  /// < Tuesday
  static const int CALENDAR_TUESDAY = 3;

  /// < Wednesday
  static const int CALENDAR_WEDNESDAY = 4;

  /// < Thursday
  static const int CALENDAR_THURSDAY = 5;

  /// < Friday
  static const int CALENDAR_FRIDAY = 6;

  /// < Saturday
  static const int CALENDAR_SATURDAY = 7;
}

/// @brief Enumeration for the modified status of a record.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_record_modified_status_e {
  /// < The record is inserted
  static const int CALENDAR_RECORD_MODIFIED_STATUS_INSERTED = 0;

  /// < The record is updated
  static const int CALENDAR_RECORD_MODIFIED_STATUS_UPDATED = 1;

  /// < The record is deleted
  static const int CALENDAR_RECORD_MODIFIED_STATUS_DELETED = 2;
}

/// @brief The structure of time.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
class calendar_time_s extends ffi.Struct {
  /// < type
  @ffi.Int32()
  external int type;

  external UnnamedUnion2 time;
}

class UnnamedUnion2 extends ffi.Union {
  /// < utime
  @ffi.LongLong()
  external int utime;

  external UnnamedStruct5 date;
}

class UnnamedStruct5 extends ffi.Struct {
  /// < year
  @ffi.Int()
  external int year;

  /// < month
  @ffi.Int()
  external int month;

  /// < mday
  @ffi.Int()
  external int mday;

  /// < hour
  @ffi.Int()
  external int hour;

  /// < minute
  @ffi.Int()
  external int minute;

  /// < second
  @ffi.Int()
  external int second;

  /// < Deprecated since 2.4:leap month
  @ffi.Bool()
  external bool is_leap_month;
}

/// @brief Enumeration for the type of a record.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_record_type_e {
  /// < No record type
  static const int CALENDAR_RECORD_TYPE_NONE = 0;

  /// < Book type
  static const int CALENDAR_RECORD_TYPE_CALENDAR_BOOK = 1;

  /// < Event type
  static const int CALENDAR_RECORD_TYPE_EVENT = 2;

  /// < Todo type
  static const int CALENDAR_RECORD_TYPE_TODO = 3;
}

/// @brief Enumeration for the book mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_book_mode_e {
  /// < All modules can read and write records of this calendar_book
  static const int CALENDAR_BOOK_MODE_NONE = 0;

  /// < All modules can only read records of this calendar book
  static const int CALENDAR_BOOK_MODE_RECORD_READONLY = 1;
}

/// @brief Enumeration for the sync event type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
abstract class calendar_book_sync_event_type_e {
  /// < This book would not be synced to others except me
  static const int CALENDAR_BOOK_SYNC_EVENT_FOR_ME = 0;

  /// < This book would be synced to everyone and deleted events would be deleted on time
  static const int CALENDAR_BOOK_SYNC_EVENT_FOR_EVERY_AND_DELETE = 1;

  /// < This book would be synced to everyone but deleted events would be retained. Deleted events are removed by calendar_db_clean_after_sync() API
  static const int CALENDAR_BOOK_SYNC_EVENT_FOR_EVERY_AND_REMAIN = 2;
}

class _calendar_book_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int name;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int color;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int visibility;

  @ffi.UnsignedInt()
  external int sync_event;

  @ffi.UnsignedInt()
  external int account_id;

  @ffi.UnsignedInt()
  external int store_type;

  @ffi.UnsignedInt()
  external int sync_data1;

  @ffi.UnsignedInt()
  external int sync_data2;

  @ffi.UnsignedInt()
  external int sync_data3;

  @ffi.UnsignedInt()
  external int sync_data4;

  @ffi.UnsignedInt()
  external int mode;
}

class _calendar_event_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int summary;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int categories;

  @ffi.UnsignedInt()
  external int exdate;

  @ffi.UnsignedInt()
  external int event_status;

  @ffi.UnsignedInt()
  external int priority;

  @ffi.UnsignedInt()
  external int timezone;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int busy_status;

  @ffi.UnsignedInt()
  external int sensitivity;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int organizer_name;

  @ffi.UnsignedInt()
  external int organizer_email;

  @ffi.UnsignedInt()
  external int meeting_status;

  @ffi.UnsignedInt()
  external int original_event_id;

  @ffi.UnsignedInt()
  external int latitude;

  @ffi.UnsignedInt()
  external int longitude;

  @ffi.UnsignedInt()
  external int email_id;

  @ffi.UnsignedInt()
  external int created_time;

  @ffi.UnsignedInt()
  external int last_modified_time;

  @ffi.UnsignedInt()
  external int is_deleted;

  @ffi.UnsignedInt()
  external int freq;

  @ffi.UnsignedInt()
  external int range_type;

  @ffi.UnsignedInt()
  external int until_time;

  @ffi.UnsignedInt()
  external int count;

  @ffi.UnsignedInt()
  external int interval;

  @ffi.UnsignedInt()
  external int bysecond;

  @ffi.UnsignedInt()
  external int byminute;

  @ffi.UnsignedInt()
  external int byhour;

  @ffi.UnsignedInt()
  external int byday;

  @ffi.UnsignedInt()
  external int bymonthday;

  @ffi.UnsignedInt()
  external int byyearday;

  @ffi.UnsignedInt()
  external int byweekno;

  @ffi.UnsignedInt()
  external int bymonth;

  @ffi.UnsignedInt()
  external int bysetpos;

  @ffi.UnsignedInt()
  external int wkst;

  @ffi.UnsignedInt()
  external int recurrence_id;

  @ffi.UnsignedInt()
  external int rdate;

  @ffi.UnsignedInt()
  external int has_attendee;

  @ffi.UnsignedInt()
  external int has_alarm;

  @ffi.UnsignedInt()
  external int calendar_system_type;

  @ffi.UnsignedInt()
  external int sync_data1;

  @ffi.UnsignedInt()
  external int sync_data2;

  @ffi.UnsignedInt()
  external int sync_data3;

  @ffi.UnsignedInt()
  external int sync_data4;

  @ffi.UnsignedInt()
  external int start_time;

  @ffi.UnsignedInt()
  external int start_tzid;

  @ffi.UnsignedInt()
  external int end_time;

  @ffi.UnsignedInt()
  external int end_tzid;

  @ffi.UnsignedInt()
  external int calendar_alarm;

  @ffi.UnsignedInt()
  external int calendar_attendee;

  @ffi.UnsignedInt()
  external int exception;

  @ffi.UnsignedInt()
  external int extended;

  @ffi.UnsignedInt()
  external int is_allday;

  @ffi.UnsignedInt()
  external int link_count;

  @ffi.UnsignedInt()
  external int link_base_id;
}

class _calendar_todo_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int summary;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int categories;

  @ffi.UnsignedInt()
  external int todo_status;

  @ffi.UnsignedInt()
  external int priority;

  @ffi.UnsignedInt()
  external int sensitivity;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int latitude;

  @ffi.UnsignedInt()
  external int longitude;

  @ffi.UnsignedInt()
  external int created_time;

  @ffi.UnsignedInt()
  external int last_modified_time;

  @ffi.UnsignedInt()
  external int completed_time;

  @ffi.UnsignedInt()
  external int progress;

  @ffi.UnsignedInt()
  external int is_deleted;

  @ffi.UnsignedInt()
  external int freq;

  @ffi.UnsignedInt()
  external int range_type;

  @ffi.UnsignedInt()
  external int until_time;

  @ffi.UnsignedInt()
  external int count;

  @ffi.UnsignedInt()
  external int interval;

  @ffi.UnsignedInt()
  external int bysecond;

  @ffi.UnsignedInt()
  external int byminute;

  @ffi.UnsignedInt()
  external int byhour;

  @ffi.UnsignedInt()
  external int byday;

  @ffi.UnsignedInt()
  external int bymonthday;

  @ffi.UnsignedInt()
  external int byyearday;

  @ffi.UnsignedInt()
  external int byweekno;

  @ffi.UnsignedInt()
  external int bymonth;

  @ffi.UnsignedInt()
  external int bysetpos;

  @ffi.UnsignedInt()
  external int wkst;

  @ffi.UnsignedInt()
  external int has_alarm;

  @ffi.UnsignedInt()
  external int sync_data1;

  @ffi.UnsignedInt()
  external int sync_data2;

  @ffi.UnsignedInt()
  external int sync_data3;

  @ffi.UnsignedInt()
  external int sync_data4;

  @ffi.UnsignedInt()
  external int start_time;

  @ffi.UnsignedInt()
  external int start_tzid;

  @ffi.UnsignedInt()
  external int due_time;

  @ffi.UnsignedInt()
  external int due_tzid;

  @ffi.UnsignedInt()
  external int calendar_alarm;

  @ffi.UnsignedInt()
  external int organizer_name;

  @ffi.UnsignedInt()
  external int organizer_email;

  @ffi.UnsignedInt()
  external int has_attendee;

  @ffi.UnsignedInt()
  external int calendar_attendee;

  @ffi.UnsignedInt()
  external int extended;

  @ffi.UnsignedInt()
  external int is_allday;
}

class _calendar_timezone_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int tz_offset_from_gmt;

  @ffi.UnsignedInt()
  external int standard_name;

  @ffi.UnsignedInt()
  external int standard_start_month;

  @ffi.UnsignedInt()
  external int standard_start_position_of_week;

  @ffi.UnsignedInt()
  external int standard_start_day;

  @ffi.UnsignedInt()
  external int standard_start_hour;

  @ffi.UnsignedInt()
  external int standard_bias;

  @ffi.UnsignedInt()
  external int day_light_name;

  @ffi.UnsignedInt()
  external int day_light_start_month;

  @ffi.UnsignedInt()
  external int day_light_start_position_of_week;

  @ffi.UnsignedInt()
  external int day_light_start_day;

  @ffi.UnsignedInt()
  external int day_light_start_hour;

  @ffi.UnsignedInt()
  external int day_light_bias;
}

class _calendar_attendee_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int parent_id;

  @ffi.UnsignedInt()
  external int number;

  @ffi.UnsignedInt()
  external int cutype;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int group;

  @ffi.UnsignedInt()
  external int email;

  @ffi.UnsignedInt()
  external int role;

  @ffi.UnsignedInt()
  external int status;

  @ffi.UnsignedInt()
  external int rsvp;

  @ffi.UnsignedInt()
  external int delegatee_uri;

  @ffi.UnsignedInt()
  external int delegator_uri;

  @ffi.UnsignedInt()
  external int name;

  @ffi.UnsignedInt()
  external int member;
}

class _calendar_alarm_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int parent_id;

  @ffi.UnsignedInt()
  external int tick;

  @ffi.UnsignedInt()
  external int tick_unit;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int summary;

  @ffi.UnsignedInt()
  external int action;

  @ffi.UnsignedInt()
  external int attach;

  @ffi.UnsignedInt()
  external int alarm_time;
}

class _calendar_updated_info_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int modified_status;

  @ffi.UnsignedInt()
  external int version;
}

class _calendar_event_calendar_book_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int event_id;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int summary;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int categories;

  @ffi.UnsignedInt()
  external int exdate;

  @ffi.UnsignedInt()
  external int event_status;

  @ffi.UnsignedInt()
  external int priority;

  @ffi.UnsignedInt()
  external int timezone;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int busy_status;

  @ffi.UnsignedInt()
  external int sensitivity;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int organizer_name;

  @ffi.UnsignedInt()
  external int organizer_email;

  @ffi.UnsignedInt()
  external int meeting_status;

  @ffi.UnsignedInt()
  external int original_event_id;

  @ffi.UnsignedInt()
  external int latitude;

  @ffi.UnsignedInt()
  external int longitude;

  @ffi.UnsignedInt()
  external int email_id;

  @ffi.UnsignedInt()
  external int created_time;

  @ffi.UnsignedInt()
  external int last_modified_time;

  @ffi.UnsignedInt()
  external int freq;

  @ffi.UnsignedInt()
  external int range_type;

  @ffi.UnsignedInt()
  external int until_time;

  @ffi.UnsignedInt()
  external int count;

  @ffi.UnsignedInt()
  external int interval;

  @ffi.UnsignedInt()
  external int bysecond;

  @ffi.UnsignedInt()
  external int byminute;

  @ffi.UnsignedInt()
  external int byhour;

  @ffi.UnsignedInt()
  external int byday;

  @ffi.UnsignedInt()
  external int bymonthday;

  @ffi.UnsignedInt()
  external int byyearday;

  @ffi.UnsignedInt()
  external int byweekno;

  @ffi.UnsignedInt()
  external int bymonth;

  @ffi.UnsignedInt()
  external int bysetpos;

  @ffi.UnsignedInt()
  external int wkst;

  @ffi.UnsignedInt()
  external int recurrence_id;

  @ffi.UnsignedInt()
  external int rdate;

  @ffi.UnsignedInt()
  external int has_attendee;

  @ffi.UnsignedInt()
  external int has_alarm;

  @ffi.UnsignedInt()
  external int calendar_system_type;

  @ffi.UnsignedInt()
  external int sync_data1;

  @ffi.UnsignedInt()
  external int sync_data2;

  @ffi.UnsignedInt()
  external int sync_data3;

  @ffi.UnsignedInt()
  external int sync_data4;

  @ffi.UnsignedInt()
  external int start_time;

  @ffi.UnsignedInt()
  external int start_tzid;

  @ffi.UnsignedInt()
  external int end_time;

  @ffi.UnsignedInt()
  external int end_tzid;

  @ffi.UnsignedInt()
  external int is_allday;

  @ffi.UnsignedInt()
  external int calendar_book_visibility;

  @ffi.UnsignedInt()
  external int calendar_book_account_id;
}

class _calendar_todo_calendar_book_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int todo_id;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int summary;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int categories;

  @ffi.UnsignedInt()
  external int todo_status;

  @ffi.UnsignedInt()
  external int priority;

  @ffi.UnsignedInt()
  external int sensitivity;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int latitude;

  @ffi.UnsignedInt()
  external int longitude;

  @ffi.UnsignedInt()
  external int created_time;

  @ffi.UnsignedInt()
  external int last_modified_time;

  @ffi.UnsignedInt()
  external int completed_time;

  @ffi.UnsignedInt()
  external int progress;

  @ffi.UnsignedInt()
  external int freq;

  @ffi.UnsignedInt()
  external int range_type;

  @ffi.UnsignedInt()
  external int until_time;

  @ffi.UnsignedInt()
  external int count;

  @ffi.UnsignedInt()
  external int interval;

  @ffi.UnsignedInt()
  external int bysecond;

  @ffi.UnsignedInt()
  external int byminute;

  @ffi.UnsignedInt()
  external int byhour;

  @ffi.UnsignedInt()
  external int byday;

  @ffi.UnsignedInt()
  external int bymonthday;

  @ffi.UnsignedInt()
  external int byyearday;

  @ffi.UnsignedInt()
  external int byweekno;

  @ffi.UnsignedInt()
  external int bymonth;

  @ffi.UnsignedInt()
  external int bysetpos;

  @ffi.UnsignedInt()
  external int wkst;

  @ffi.UnsignedInt()
  external int has_alarm;

  @ffi.UnsignedInt()
  external int sync_data1;

  @ffi.UnsignedInt()
  external int sync_data2;

  @ffi.UnsignedInt()
  external int sync_data3;

  @ffi.UnsignedInt()
  external int sync_data4;

  @ffi.UnsignedInt()
  external int start_time;

  @ffi.UnsignedInt()
  external int start_tzid;

  @ffi.UnsignedInt()
  external int due_time;

  @ffi.UnsignedInt()
  external int due_tzid;

  @ffi.UnsignedInt()
  external int organizer_name;

  @ffi.UnsignedInt()
  external int organizer_email;

  @ffi.UnsignedInt()
  external int has_attendee;

  @ffi.UnsignedInt()
  external int is_allday;

  @ffi.UnsignedInt()
  external int calendar_book_visibility;

  @ffi.UnsignedInt()
  external int calendar_book_account_id;
}

class _calendar_event_calendar_book_attendee_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int event_id;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int summary;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int categories;

  @ffi.UnsignedInt()
  external int exdate;

  @ffi.UnsignedInt()
  external int event_status;

  @ffi.UnsignedInt()
  external int priority;

  @ffi.UnsignedInt()
  external int timezone;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int busy_status;

  @ffi.UnsignedInt()
  external int sensitivity;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int organizer_name;

  @ffi.UnsignedInt()
  external int organizer_email;

  @ffi.UnsignedInt()
  external int meeting_status;

  @ffi.UnsignedInt()
  external int original_event_id;

  @ffi.UnsignedInt()
  external int latitude;

  @ffi.UnsignedInt()
  external int longitude;

  @ffi.UnsignedInt()
  external int email_id;

  @ffi.UnsignedInt()
  external int created_time;

  @ffi.UnsignedInt()
  external int last_modified_time;

  @ffi.UnsignedInt()
  external int freq;

  @ffi.UnsignedInt()
  external int range_type;

  @ffi.UnsignedInt()
  external int until_time;

  @ffi.UnsignedInt()
  external int count;

  @ffi.UnsignedInt()
  external int interval;

  @ffi.UnsignedInt()
  external int bysecond;

  @ffi.UnsignedInt()
  external int byminute;

  @ffi.UnsignedInt()
  external int byhour;

  @ffi.UnsignedInt()
  external int byday;

  @ffi.UnsignedInt()
  external int bymonthday;

  @ffi.UnsignedInt()
  external int byyearday;

  @ffi.UnsignedInt()
  external int byweekno;

  @ffi.UnsignedInt()
  external int bymonth;

  @ffi.UnsignedInt()
  external int bysetpos;

  @ffi.UnsignedInt()
  external int wkst;

  @ffi.UnsignedInt()
  external int recurrence_id;

  @ffi.UnsignedInt()
  external int rdate;

  @ffi.UnsignedInt()
  external int has_attendee;

  @ffi.UnsignedInt()
  external int has_alarm;

  @ffi.UnsignedInt()
  external int calendar_system_type;

  @ffi.UnsignedInt()
  external int sync_data1;

  @ffi.UnsignedInt()
  external int sync_data2;

  @ffi.UnsignedInt()
  external int sync_data3;

  @ffi.UnsignedInt()
  external int sync_data4;

  @ffi.UnsignedInt()
  external int start_time;

  @ffi.UnsignedInt()
  external int start_tzid;

  @ffi.UnsignedInt()
  external int end_time;

  @ffi.UnsignedInt()
  external int end_tzid;

  @ffi.UnsignedInt()
  external int is_allday;

  @ffi.UnsignedInt()
  external int calendar_book_visibility;

  @ffi.UnsignedInt()
  external int calendar_book_account_id;

  @ffi.UnsignedInt()
  external int attendee_email;

  @ffi.UnsignedInt()
  external int attendee_name;

  @ffi.UnsignedInt()
  external int attendee_member;
}

class _calendar_instance_utime_calendar_book_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int event_id;

  @ffi.UnsignedInt()
  external int start_time;

  @ffi.UnsignedInt()
  external int end_time;

  @ffi.UnsignedInt()
  external int summary;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int busy_status;

  @ffi.UnsignedInt()
  external int event_status;

  @ffi.UnsignedInt()
  external int priority;

  @ffi.UnsignedInt()
  external int sensitivity;

  @ffi.UnsignedInt()
  external int has_rrule;

  @ffi.UnsignedInt()
  external int latitude;

  @ffi.UnsignedInt()
  external int longitude;

  @ffi.UnsignedInt()
  external int has_alarm;

  @ffi.UnsignedInt()
  external int original_event_id;

  @ffi.UnsignedInt()
  external int calendar_book_visibility;

  @ffi.UnsignedInt()
  external int calendar_book_account_id;

  @ffi.UnsignedInt()
  external int last_modified_time;

  @ffi.UnsignedInt()
  external int sync_data1;
}

class _calendar_instance_localtime_calendar_book_property_ids
    extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int event_id;

  @ffi.UnsignedInt()
  external int start_time;

  @ffi.UnsignedInt()
  external int end_time;

  @ffi.UnsignedInt()
  external int summary;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int busy_status;

  @ffi.UnsignedInt()
  external int event_status;

  @ffi.UnsignedInt()
  external int priority;

  @ffi.UnsignedInt()
  external int sensitivity;

  @ffi.UnsignedInt()
  external int has_rrule;

  @ffi.UnsignedInt()
  external int latitude;

  @ffi.UnsignedInt()
  external int longitude;

  @ffi.UnsignedInt()
  external int has_alarm;

  @ffi.UnsignedInt()
  external int original_event_id;

  @ffi.UnsignedInt()
  external int calendar_book_visibility;

  @ffi.UnsignedInt()
  external int calendar_book_account_id;

  @ffi.UnsignedInt()
  external int last_modified_time;

  @ffi.UnsignedInt()
  external int sync_data1;

  @ffi.UnsignedInt()
  external int is_allday;
}

class _calendar_instance_utime_calendar_book_extended_property_ids
    extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int event_id;

  @ffi.UnsignedInt()
  external int start_time;

  @ffi.UnsignedInt()
  external int end_time;

  @ffi.UnsignedInt()
  external int summary;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int busy_status;

  @ffi.UnsignedInt()
  external int event_status;

  @ffi.UnsignedInt()
  external int priority;

  @ffi.UnsignedInt()
  external int sensitivity;

  @ffi.UnsignedInt()
  external int has_rrule;

  @ffi.UnsignedInt()
  external int latitude;

  @ffi.UnsignedInt()
  external int longitude;

  @ffi.UnsignedInt()
  external int has_alarm;

  @ffi.UnsignedInt()
  external int original_event_id;

  @ffi.UnsignedInt()
  external int calendar_book_visibility;

  @ffi.UnsignedInt()
  external int calendar_book_account_id;

  @ffi.UnsignedInt()
  external int last_modified_time;

  @ffi.UnsignedInt()
  external int sync_data1;

  @ffi.UnsignedInt()
  external int organizer_name;

  @ffi.UnsignedInt()
  external int categories;

  @ffi.UnsignedInt()
  external int has_attendee;

  @ffi.UnsignedInt()
  external int sync_data2;

  @ffi.UnsignedInt()
  external int sync_data3;

  @ffi.UnsignedInt()
  external int sync_data4;
}

class _calendar_instance_localtime_calendar_book_extended_property_ids
    extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int event_id;

  @ffi.UnsignedInt()
  external int start_time;

  @ffi.UnsignedInt()
  external int end_time;

  @ffi.UnsignedInt()
  external int summary;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int calendar_book_id;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int busy_status;

  @ffi.UnsignedInt()
  external int event_status;

  @ffi.UnsignedInt()
  external int priority;

  @ffi.UnsignedInt()
  external int sensitivity;

  @ffi.UnsignedInt()
  external int has_rrule;

  @ffi.UnsignedInt()
  external int latitude;

  @ffi.UnsignedInt()
  external int longitude;

  @ffi.UnsignedInt()
  external int has_alarm;

  @ffi.UnsignedInt()
  external int original_event_id;

  @ffi.UnsignedInt()
  external int calendar_book_visibility;

  @ffi.UnsignedInt()
  external int calendar_book_account_id;

  @ffi.UnsignedInt()
  external int last_modified_time;

  @ffi.UnsignedInt()
  external int sync_data1;

  @ffi.UnsignedInt()
  external int organizer_name;

  @ffi.UnsignedInt()
  external int categories;

  @ffi.UnsignedInt()
  external int has_attendee;

  @ffi.UnsignedInt()
  external int is_allday;

  @ffi.UnsignedInt()
  external int sync_data2;

  @ffi.UnsignedInt()
  external int sync_data3;

  @ffi.UnsignedInt()
  external int sync_data4;
}

class _calendar_extended_property_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int record_id;

  @ffi.UnsignedInt()
  external int record_type;

  @ffi.UnsignedInt()
  external int key;

  @ffi.UnsignedInt()
  external int value;
}

typedef calendar_record_h = ffi.Pointer<__calendar_record_h>;
typedef calendar_list_h = ffi.Pointer<__calendar_list_h>;
typedef calendar_query_h = ffi.Pointer<__calendar_query_h>;

/// @brief Called when a designated view changes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
/// @param[in] view_uri The view URI
/// @param[in] user_data The user data passed from the callback registration function
/// @see calendar_db_add_changed_cb()
typedef calendar_db_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;
typedef calendar_filter_h = ffi.Pointer<__calendar_filter_h>;

/// @brief Called to get a record handle of
/// \ref CAPI_SOCIAL_CALENDAR_SVC_VIEW_MODULE_calendar_event or \ref CAPI_SOCIAL_CALENDAR_SVC_VIEW_MODULE_calendar_todo.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
/// @param[in] record The record handle (\ref CAPI_SOCIAL_CALENDAR_SVC_VIEW_MODULE_calendar_event or \ref CAPI_SOCIAL_CALENDAR_SVC_VIEW_MODULE_calendar_todo)
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre calendar_vcalendar_parse_to_calendar_foreach() will invoke this callback.
/// @see calendar_vcalendar_parse_to_calendar_foreach()
/// @see calendar_record_get_uri_p()
typedef calendar_vcalendar_parse_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(calendar_record_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an alarm is alerted.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @elseif TV 4.0 @endif
/// @param[in] param Value string like id=value&time=value&tick=value&unit=value&type=value
/// @param[in] user_data The user data passed from the callback registration function
/// @see calendar_reminder_add_cb()
typedef calendar_reminder_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for contacts errors.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_error_e {
  /// < Successful
  static const int CONTACTS_ERROR_NONE = 0;

  /// < Out of memory
  static const int CONTACTS_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int CONTACTS_ERROR_INVALID_PARAMETER = -22;

  /// < FS Full
  static const int CONTACTS_ERROR_FILE_NO_SPACE = -28;

  /// < Permission denied
  static const int CONTACTS_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int CONTACTS_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Requested data does not exist
  static const int CONTACTS_ERROR_NO_DATA = -61;

  /// < Database table locked or file locked
  static const int CONTACTS_ERROR_DB_LOCKED = -33619839;

  /// < Unknown DB error
  static const int CONTACTS_ERROR_DB = -33619809;

  /// < IPC server is not available
  static const int CONTACTS_ERROR_IPC_NOT_AVALIABLE = -33619791;

  /// < Unknown IPC error
  static const int CONTACTS_ERROR_IPC = -33619777;

  /// < Internal system module error
  static const int CONTACTS_ERROR_SYSTEM = -33619729;

  /// < Implementation Error, Temporary Use
  static const int CONTACTS_ERROR_INTERNAL = -33619713;
}

class __contacts_record_h extends ffi.Opaque {}

class __contacts_filter_h extends ffi.Opaque {}

class __contacts_list_h extends ffi.Opaque {}

class __contacts_query_h extends ffi.Opaque {}

class __contacts_h extends ffi.Opaque {}

/// @brief Enumeration for contacts data type.
/// @since_tizen 3.0
abstract class contacts_data_type_e {
  static const int CONTACTS_DATA_TYPE_NAME = 1;
  static const int CONTACTS_DATA_TYPE_POSTAL = 2;
  static const int CONTACTS_DATA_TYPE_MESSENGER = 3;
  static const int CONTACTS_DATA_TYPE_URL = 4;
  static const int CONTACTS_DATA_TYPE_EVENT = 5;
  static const int CONTACTS_DATA_TYPE_COMPANY = 6;
  static const int CONTACTS_DATA_TYPE_NICKNAME = 7;
  static const int CONTACTS_DATA_TYPE_NUMBER = 8;
  static const int CONTACTS_DATA_TYPE_EMAIL = 9;
  static const int CONTACTS_DATA_TYPE_PROFILE = 10;
  static const int CONTACTS_DATA_TYPE_RELATIONSHIP = 11;
  static const int CONTACTS_DATA_TYPE_NOTE = 12;
  static const int CONTACTS_DATA_TYPE_IMAGE = 13;
  static const int CONTACTS_DATA_TYPE_SIP = 14;
  static const int CONTACTS_DATA_TYPE_EXTENSION = 100;
}

/// @brief Enumeration for contacts number type.
/// @details The number can be made with a set of values by specifying one or more values.
/// Example : CTS_NUM_TYPE_HOME|CTS_NUM_TYPE_VOICE
/// Exceptionally, CTS_NUM_TYPE_CUSTOM is exclusive.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_number_type_e {
  /// < Other number type
  static const int CONTACTS_NUMBER_TYPE_OTHER = 0;

  /// < Custom number type
  static const int CONTACTS_NUMBER_TYPE_CUSTOM = 1;

  /// < A telephone number associated with a residence
  static const int CONTACTS_NUMBER_TYPE_HOME = 2;

  /// < A telephone number associated with a place of work
  static const int CONTACTS_NUMBER_TYPE_WORK = 4;

  /// < A voice telephone number
  static const int CONTACTS_NUMBER_TYPE_VOICE = 8;

  /// < A facsimile telephone number
  static const int CONTACTS_NUMBER_TYPE_FAX = 16;

  /// < The telephone number has voice messaging support
  static const int CONTACTS_NUMBER_TYPE_MSG = 32;

  /// < A cellular telephone number
  static const int CONTACTS_NUMBER_TYPE_CELL = 64;

  /// < A paging device telephone number
  static const int CONTACTS_NUMBER_TYPE_PAGER = 128;

  /// < A bulletin board system telephone number
  static const int CONTACTS_NUMBER_TYPE_BBS = 256;

  /// < A MODEM connected telephone number
  static const int CONTACTS_NUMBER_TYPE_MODEM = 512;

  /// < A car-phone telephone number
  static const int CONTACTS_NUMBER_TYPE_CAR = 1024;

  /// < An ISDN service telephone number
  static const int CONTACTS_NUMBER_TYPE_ISDN = 2048;

  /// < A video conferencing telephone number
  static const int CONTACTS_NUMBER_TYPE_VIDEO = 4096;

  /// < A personal communication services telephone number
  static const int CONTACTS_NUMBER_TYPE_PCS = 8192;

  /// < A company main number
  static const int CONTACTS_NUMBER_TYPE_COMPANY_MAIN = 16384;

  /// < A radio phone number
  static const int CONTACTS_NUMBER_TYPE_RADIO = 32768;

  /// < An additional type for main
  static const int CONTACTS_NUMBER_TYPE_MAIN = 536870912;

  /// < An additional type for assistant
  static const int CONTACTS_NUMBER_TYPE_ASSISTANT = 1073741824;
}

/// @brief Enumeration for Contact email type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_email_type_e {
  /// < Other email type
  static const int CONTACTS_EMAIL_TYPE_OTHER = 0;

  /// < Custom email type
  static const int CONTACTS_EMAIL_TYPE_CUSTOM = 1;

  /// < An email address associated with a residence
  static const int CONTACTS_EMAIL_TYPE_HOME = 2;

  /// < An email address associated with a place of work
  static const int CONTACTS_EMAIL_TYPE_WORK = 4;

  /// < A mobile email address
  static const int CONTACTS_EMAIL_TYPE_MOBILE = 8;
}

/// @brief Enumeration for Contact company type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_company_type_e {
  /// < Other company type
  static const int CONTACTS_COMPANY_TYPE_OTHER = 0;

  /// < Custom company type
  static const int CONTACTS_COMPANY_TYPE_CUSTOM = 1;

  /// < Work company type
  static const int CONTACTS_COMPANY_TYPE_WORK = 2;
}

/// @brief Enumeration for Contact address type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_address_type_e {
  /// < Other address type
  static const int CONTACTS_ADDRESS_TYPE_OTHER = 0;

  /// < A delivery address for a residence
  static const int CONTACTS_ADDRESS_TYPE_CUSTOM = 1;

  /// < A delivery address for a residence
  static const int CONTACTS_ADDRESS_TYPE_HOME = 2;

  /// < A delivery address for a place of work
  static const int CONTACTS_ADDRESS_TYPE_WORK = 4;

  /// < A domestic delivery address
  static const int CONTACTS_ADDRESS_TYPE_DOM = 8;

  /// < An international delivery address
  static const int CONTACTS_ADDRESS_TYPE_INTL = 16;

  /// < A postal delivery address
  static const int CONTACTS_ADDRESS_TYPE_POSTAL = 32;

  /// < A parcel delivery address
  static const int CONTACTS_ADDRESS_TYPE_PARCEL = 64;
}

/// @brief Enumeration for Contact URL type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_url_type_e {
  /// < Other URL type
  static const int CONTACTS_URL_TYPE_OTHER = 0;

  /// < Custom URL type
  static const int CONTACTS_URL_TYPE_CUSTOM = 1;

  /// < Home URL type
  static const int CONTACTS_URL_TYPE_HOME = 2;

  /// < Work URL type
  static const int CONTACTS_URL_TYPE_WORK = 3;
}

/// @brief Enumeration for Contact messenger type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_messenger_type_e {
  /// < Other messenger type
  static const int CONTACTS_MESSENGER_TYPE_OTHER = 0;

  /// < Custom messenger type
  static const int CONTACTS_MESSENGER_TYPE_CUSTOM = 1;

  /// < Google messenger type
  static const int CONTACTS_MESSENGER_TYPE_GOOGLE = 2;

  /// < Windows live messenger type
  static const int CONTACTS_MESSENGER_TYPE_WLM = 3;

  /// < Yahoo messenger type
  static const int CONTACTS_MESSENGER_TYPE_YAHOO = 4;

  /// < Facebook messenger type
  static const int CONTACTS_MESSENGER_TYPE_FACEBOOK = 5;

  /// < ICQ type
  static const int CONTACTS_MESSENGER_TYPE_ICQ = 6;

  /// < AOL instance messenger type
  static const int CONTACTS_MESSENGER_TYPE_AIM = 7;

  /// < QQ type
  static const int CONTACTS_MESSENGER_TYPE_QQ = 8;

  /// < Jabber type
  static const int CONTACTS_MESSENGER_TYPE_JABBER = 9;

  /// < Skype type
  static const int CONTACTS_MESSENGER_TYPE_SKYPE = 10;

  /// < IRC type
  static const int CONTACTS_MESSENGER_TYPE_IRC = 11;
}

/// @brief Enumeration for Call history type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_phone_log_type_e {
  /// < None
  static const int CONTACTS_PLOG_TYPE_NONE = 0;

  /// < Incoming call
  static const int CONTACTS_PLOG_TYPE_VOICE_INCOMING = 1;

  /// < Outgoing call
  static const int CONTACTS_PLOG_TYPE_VOICE_OUTGOING = 2;

  /// < Incoming video call
  static const int CONTACTS_PLOG_TYPE_VIDEO_INCOMING = 3;

  /// < Outgoing video call
  static const int CONTACTS_PLOG_TYPE_VIDEO_OUTGOING = 4;

  /// < Not confirmed missed call
  static const int CONTACTS_PLOG_TYPE_VOICE_INCOMING_UNSEEN = 5;

  /// < Confirmed missed call
  static const int CONTACTS_PLOG_TYPE_VOICE_INCOMING_SEEN = 6;

  /// < Not confirmed missed video call
  static const int CONTACTS_PLOG_TYPE_VIDEO_INCOMING_UNSEEN = 7;

  /// < Confirmed missed video call
  static const int CONTACTS_PLOG_TYPE_VIDEO_INCOMING_SEEN = 8;

  /// < Rejected call
  static const int CONTACTS_PLOG_TYPE_VOICE_REJECT = 9;

  /// < Rejected video call
  static const int CONTACTS_PLOG_TYPE_VIDEO_REJECT = 10;

  /// < Blocked call
  static const int CONTACTS_PLOG_TYPE_VOICE_BLOCKED = 11;

  /// < Blocked video call
  static const int CONTACTS_PLOG_TYPE_VIDEO_BLOCKED = 12;

  /// < Incoming MMS
  static const int CONTACTS_PLOG_TYPE_MMS_INCOMING = 101;

  /// < Outgoing MMS
  static const int CONTACTS_PLOG_TYPE_MMS_OUTGOING = 102;

  /// < Incoming SMS
  static const int CONTACTS_PLOG_TYPE_SMS_INCOMING = 103;

  /// < Outgoing SMS
  static const int CONTACTS_PLOG_TYPE_SMS_OUTGOING = 104;

  /// < Blocked SMS
  static const int CONTACTS_PLOG_TYPE_SMS_BLOCKED = 105;

  /// < Blocked MMS
  static const int CONTACTS_PLOG_TYPE_MMS_BLOCKED = 106;

  /// < Received email
  static const int CONTACTS_PLOG_TYPE_EMAIL_RECEIVED = 201;

  /// < Sent email
  static const int CONTACTS_PLOG_TYPE_EMAIL_SENT = 202;
}

/// @brief Enumeration for Contact event type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_event_type_e {
  /// < Other event type
  static const int CONTACTS_EVENT_TYPE_OTHER = 0;

  /// < Custom event type
  static const int CONTACTS_EVENT_TYPE_CUSTOM = 1;

  /// < Birthday event type
  static const int CONTACTS_EVENT_TYPE_BIRTH = 2;

  /// < Anniversary event type
  static const int CONTACTS_EVENT_TYPE_ANNIVERSARY = 3;
}

/// @brief Enumeration for Contact event calendar type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_event_calendar_type_e {
  /// < Gregorian calendar
  static const int CONTACTS_EVENT_CALENDAR_TYPE_GREGORIAN = 0;

  /// < Chinese calenadr
  static const int CONTACTS_EVENT_CALENDAR_TYPE_CHINESE = 1;
}

/// @brief Enumeration for Contact image type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_image_type_e {
  /// < Other type
  static const int CONTACTS_IMAGE_TYPE_OTHER = 0;

  /// < Custom type
  static const int CONTACTS_IMAGE_TYPE_CUSTOM = 1;
}

/// @brief Enumeration for usage type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_usage_type_e {
  /// < None
  static const int CONTACTS_USAGE_STAT_TYPE_NONE = 0;

  /// < Outgoing call
  static const int CONTACTS_USAGE_STAT_TYPE_OUTGOING_CALL = 1;

  /// < Outgoing message
  static const int CONTACTS_USAGE_STAT_TYPE_OUTGOING_MSG = 2;

  /// < Outgoing email (Since 3.0)
  static const int CONTACTS_USAGE_STAT_TYPE_OUTGOING_EMAIL = 3;

  /// < Incoming call (Since 3.0)
  static const int CONTACTS_USAGE_STAT_TYPE_INCOMING_CALL = 4;

  /// < Incoming message (Since 3.0)
  static const int CONTACTS_USAGE_STAT_TYPE_INCOMING_MSG = 5;

  /// < Incoming email (Since 3.0)
  static const int CONTACTS_USAGE_STAT_TYPE_INCOMING_EMAIL = 6;

  /// < Missed call (Since 3.0)
  static const int CONTACTS_USAGE_STAT_TYPE_MISSED_CALL = 7;

  /// < Rejected call (Since 3.0)
  static const int CONTACTS_USAGE_STAT_TYPE_REJECTED_CALL = 8;

  /// < Blocked call (Since 3.0)
  static const int CONTACTS_USAGE_STAT_TYPE_BLOCKED_CALL = 9;

  /// < Blocked message (Since 3.0)
  static const int CONTACTS_USAGE_STAT_TYPE_BLOCKED_MSG = 10;
}

/// @brief Enumeration for Contact display name source type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_display_name_source_type_e {
  /// < Invalid source of display name
  static const int CONTACTS_DISPLAY_NAME_SOURCE_TYPE_INVALID = 0;

  /// < Produced display name from email record
  static const int CONTACTS_DISPLAY_NAME_SOURCE_TYPE_EMAIL = 1;

  /// < Produced display name from number record
  static const int CONTACTS_DISPLAY_NAME_SOURCE_TYPE_NUMBER = 2;

  /// < Produced display name from nickname record
  static const int CONTACTS_DISPLAY_NAME_SOURCE_TYPE_NICKNAME = 3;

  /// < Produced display name from company record
  static const int CONTACTS_DISPLAY_NAME_SOURCE_TYPE_COMPANY = 4;

  /// < Produced display name from name record
  static const int CONTACTS_DISPLAY_NAME_SOURCE_TYPE_NAME = 5;
}

/// @brief Enumeration for Address book mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_address_book_mode_e {
  /// < All module can read and write contacts of this address_book
  static const int CONTACTS_ADDRESS_BOOK_MODE_NONE = 0;

  /// < All module can only read contacts of this address_book
  static const int CONTACTS_ADDRESS_BOOK_MODE_READONLY = 1;
}

/// @brief Enumeration for link mode when inserting contact.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_contact_link_mode_e {
  /// < Auto link immediately
  static const int CONTACTS_CONTACT_LINK_MODE_NONE = 0;

  /// < Do not auto link when the contact is inserted
  static const int CONTACTS_CONTACT_LINK_MODE_IGNORE_ONCE = 1;
}

/// @brief Enumeration for Contact relationship type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_relationship_type_e {
  /// < Other relationship type
  static const int CONTACTS_RELATIONSHIP_TYPE_OTHER = 0;

  /// < Assistant type
  static const int CONTACTS_RELATIONSHIP_TYPE_ASSISTANT = 1;

  /// < Brother type
  static const int CONTACTS_RELATIONSHIP_TYPE_BROTHER = 2;

  /// < Child type
  static const int CONTACTS_RELATIONSHIP_TYPE_CHILD = 3;

  /// < Domestic Partner type
  static const int CONTACTS_RELATIONSHIP_TYPE_DOMESTIC_PARTNER = 4;

  /// < Father type
  static const int CONTACTS_RELATIONSHIP_TYPE_FATHER = 5;

  /// < Friend type
  static const int CONTACTS_RELATIONSHIP_TYPE_FRIEND = 6;

  /// < Manager type
  static const int CONTACTS_RELATIONSHIP_TYPE_MANAGER = 7;

  /// < Mother type
  static const int CONTACTS_RELATIONSHIP_TYPE_MOTHER = 8;

  /// < Parent type
  static const int CONTACTS_RELATIONSHIP_TYPE_PARENT = 9;

  /// < Partner type
  static const int CONTACTS_RELATIONSHIP_TYPE_PARTNER = 10;

  /// < Referred by type
  static const int CONTACTS_RELATIONSHIP_TYPE_REFERRED_BY = 11;

  /// < Relative type
  static const int CONTACTS_RELATIONSHIP_TYPE_RELATIVE = 12;

  /// < Sister type
  static const int CONTACTS_RELATIONSHIP_TYPE_SISTER = 13;

  /// < Spouse type
  static const int CONTACTS_RELATIONSHIP_TYPE_SPOUSE = 14;

  /// < Custom type
  static const int CONTACTS_RELATIONSHIP_TYPE_CUSTOM = 15;
}

/// @brief Enumeration for Contact search range.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_search_range_e {
  /// < Search record from name
  static const int CONTACTS_SEARCH_RANGE_NAME = 1;

  /// < Search record from name and number
  static const int CONTACTS_SEARCH_RANGE_NUMBER = 2;

  /// < Search record from name,number and data
  static const int CONTACTS_SEARCH_RANGE_DATA = 4;

  /// < Search record from name,number,data and email. Now, support only _contacts_person_email view_uri
  static const int CONTACTS_SEARCH_RANGE_EMAIL = 8;
}

/// @brief Enumeration for SIP(Session Intialion Protocol) type range.
/// @since_tizen 3.0
abstract class contacts_sip_type_e {
  /// < Other sip type
  static const int CONTACTS_SIP_TYPE_OTHER = 0;

  /// < Custom sip type
  static const int CONTACTS_SIP_TYPE_CUSTOM = 1;

  /// < Home sip type
  static const int CONTACTS_SIP_TYPE_HOME = 2;

  /// < Work sip type
  static const int CONTACTS_SIP_TYPE_WORK = 3;
}

class _contacts_address_book_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int account_id;

  @ffi.UnsignedInt()
  external int name;

  @ffi.UnsignedInt()
  external int mode;
}

class _contacts_group_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int name;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_path;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int extra_data;

  @ffi.UnsignedInt()
  external int is_read_only;

  @ffi.UnsignedInt()
  external int message_alert;
}

class _contacts_person_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_name_index;

  @ffi.UnsignedInt()
  external int display_contact_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int status;

  @ffi.UnsignedInt()
  external int is_favorite;

  @ffi.UnsignedInt()
  external int favorite_priority;

  @ffi.UnsignedInt()
  external int link_count;

  @ffi.UnsignedInt()
  external int addressbook_ids;

  @ffi.UnsignedInt()
  external int has_phonenumber;

  @ffi.UnsignedInt()
  external int has_email;

  @ffi.UnsignedInt()
  external int message_alert;

  @ffi.UnsignedInt()
  external int snippet_type;

  @ffi.UnsignedInt()
  external int snippet_string;
}

class _contacts_simple_contact_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_source_type;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int is_favorite;

  @ffi.UnsignedInt()
  external int has_phonenumber;

  @ffi.UnsignedInt()
  external int has_email;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int changed_time;

  @ffi.UnsignedInt()
  external int message_alert;
}

class _contacts_contact_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_source_type;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int is_favorite;

  @ffi.UnsignedInt()
  external int has_phonenumber;

  @ffi.UnsignedInt()
  external int has_email;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int changed_time;

  @ffi.UnsignedInt()
  external int link_mode;

  @ffi.UnsignedInt()
  external int name;

  @ffi.UnsignedInt()
  external int image;

  @ffi.UnsignedInt()
  external int company;

  @ffi.UnsignedInt()
  external int note;

  @ffi.UnsignedInt()
  external int number;

  @ffi.UnsignedInt()
  external int email;

  @ffi.UnsignedInt()
  external int event;

  @ffi.UnsignedInt()
  external int messenger;

  @ffi.UnsignedInt()
  external int address;

  @ffi.UnsignedInt()
  external int url;

  @ffi.UnsignedInt()
  external int nickname;

  @ffi.UnsignedInt()
  external int profile;

  @ffi.UnsignedInt()
  external int relationship;

  @ffi.UnsignedInt()
  external int group_relation;

  @ffi.UnsignedInt()
  external int extension1;

  @ffi.UnsignedInt()
  external int message_alert;

  @ffi.UnsignedInt()
  external int sip;
}

class _contacts_my_profile_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int changed_time;

  @ffi.UnsignedInt()
  external int name;

  @ffi.UnsignedInt()
  external int image;

  @ffi.UnsignedInt()
  external int company;

  @ffi.UnsignedInt()
  external int note;

  @ffi.UnsignedInt()
  external int number;

  @ffi.UnsignedInt()
  external int email;

  @ffi.UnsignedInt()
  external int event;

  @ffi.UnsignedInt()
  external int messenger;

  @ffi.UnsignedInt()
  external int address;

  @ffi.UnsignedInt()
  external int url;

  @ffi.UnsignedInt()
  external int nickname;

  @ffi.UnsignedInt()
  external int profile;

  @ffi.UnsignedInt()
  external int relationship;

  @ffi.UnsignedInt()
  external int extension1;

  @ffi.UnsignedInt()
  external int sip;
}

class _contacts_name_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int first;

  @ffi.UnsignedInt()
  external int last;

  @ffi.UnsignedInt()
  external int addition;

  @ffi.UnsignedInt()
  external int suffix;

  @ffi.UnsignedInt()
  external int prefix;

  @ffi.UnsignedInt()
  external int phonetic_first;

  @ffi.UnsignedInt()
  external int phonetic_middle;

  @ffi.UnsignedInt()
  external int phonetic_last;
}

class _contacts_number_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int is_default;

  @ffi.UnsignedInt()
  external int number;

  @ffi.UnsignedInt()
  external int normalized_number;

  @ffi.UnsignedInt()
  external int cleaned_number;

  @ffi.UnsignedInt()
  external int number_filter;
}

class _contacts_email_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int is_default;

  @ffi.UnsignedInt()
  external int email;
}

class _contacts_address_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int postbox;

  @ffi.UnsignedInt()
  external int extended;

  @ffi.UnsignedInt()
  external int street;

  @ffi.UnsignedInt()
  external int locality;

  @ffi.UnsignedInt()
  external int region;

  @ffi.UnsignedInt()
  external int postal_code;

  @ffi.UnsignedInt()
  external int country;

  @ffi.UnsignedInt()
  external int is_default;
}

class _contacts_note_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int note;
}

class _contacts_url_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int url;
}

class _contacts_event_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int date;

  @ffi.UnsignedInt()
  external int calendar_type;

  @ffi.UnsignedInt()
  external int is_leap_month;
}

class _contacts_group_relation_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int group_id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int name;
}

class _contacts_relationship_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int name;
}

class _contacts_image_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int path;

  @ffi.UnsignedInt()
  external int is_default;
}

class _contacts_company_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int name;

  @ffi.UnsignedInt()
  external int department;

  @ffi.UnsignedInt()
  external int job_title;

  @ffi.UnsignedInt()
  external int assistant_name;

  @ffi.UnsignedInt()
  external int role;

  @ffi.UnsignedInt()
  external int logo;

  @ffi.UnsignedInt()
  external int location;

  @ffi.UnsignedInt()
  external int description;

  @ffi.UnsignedInt()
  external int phonetic_name;
}

class _contacts_nickname_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int name;
}

class _contacts_messenger_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int im_id;
}

class _contacts_extension_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int data1;

  @ffi.UnsignedInt()
  external int data2;

  @ffi.UnsignedInt()
  external int data3;

  @ffi.UnsignedInt()
  external int data4;

  @ffi.UnsignedInt()
  external int data5;

  @ffi.UnsignedInt()
  external int data6;

  @ffi.UnsignedInt()
  external int data7;

  @ffi.UnsignedInt()
  external int data8;

  @ffi.UnsignedInt()
  external int data9;

  @ffi.UnsignedInt()
  external int data10;

  @ffi.UnsignedInt()
  external int data11;

  @ffi.UnsignedInt()
  external int data12;
}

class _contacts_sdn_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int name;

  @ffi.UnsignedInt()
  external int number;

  @ffi.UnsignedInt()
  external int sim_slot_no;
}

class _contacts_profile_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int uid;

  @ffi.UnsignedInt()
  external int text;

  @ffi.UnsignedInt()
  external int order;

  @ffi.UnsignedInt()
  external int service_operation;

  @ffi.UnsignedInt()
  external int mime;

  @ffi.UnsignedInt()
  external int app_id;

  @ffi.UnsignedInt()
  external int uri;

  @ffi.UnsignedInt()
  external int category;

  @ffi.UnsignedInt()
  external int extra_data;

  @ffi.UnsignedInt()
  external int contact_id;
}

class _contacts_activity_photo_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int activity_id;

  @ffi.UnsignedInt()
  external int photo_url;

  @ffi.UnsignedInt()
  external int sort_index;
}

class _contacts_activity_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int source_name;

  @ffi.UnsignedInt()
  external int status;

  @ffi.UnsignedInt()
  external int timestamp;

  @ffi.UnsignedInt()
  external int service_operation;

  @ffi.UnsignedInt()
  external int uri;

  @ffi.UnsignedInt()
  external int photo;
}

class _contacts_speeddial_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int speeddial_number;

  @ffi.UnsignedInt()
  external int number_id;

  @ffi.UnsignedInt()
  external int number;

  @ffi.UnsignedInt()
  external int number_label;

  @ffi.UnsignedInt()
  external int number_type;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int normalized_number;

  @ffi.UnsignedInt()
  external int cleaned_number;

  @ffi.UnsignedInt()
  external int number_filter;
}

class _contacts_phone_log_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int address;

  @ffi.UnsignedInt()
  external int log_time;

  @ffi.UnsignedInt()
  external int log_type;

  @ffi.UnsignedInt()
  external int extra_data1;

  @ffi.UnsignedInt()
  external int extra_data2;

  @ffi.UnsignedInt()
  external int normalized_address;

  @ffi.UnsignedInt()
  external int cleaned_address;

  @ffi.UnsignedInt()
  external int address_filter;

  @ffi.UnsignedInt()
  external int sim_slot_no;
}

class _contacts_contact_updated_info_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int version;

  @ffi.UnsignedInt()
  external int image_changed;
}

class _contacts_my_profile_updated_info_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int last_changed_type;

  @ffi.UnsignedInt()
  external int version;
}

class _contacts_group_updated_info_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int group_id;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int version;
}

class _contacts_group_member_updated_info_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int group_id;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int version;
}

class _contacts_grouprel_updated_info_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int group_id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int version;
}

class _contacts_person_contact_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_name_index;

  @ffi.UnsignedInt()
  external int display_contact_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int status;

  @ffi.UnsignedInt()
  external int is_favorite;

  @ffi.UnsignedInt()
  external int link_count;

  @ffi.UnsignedInt()
  external int addressbook_ids;

  @ffi.UnsignedInt()
  external int has_phonenumber;

  @ffi.UnsignedInt()
  external int has_email;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int address_book_name;

  @ffi.UnsignedInt()
  external int address_book_mode;

  @ffi.UnsignedInt()
  external int message_alert;

  @ffi.UnsignedInt()
  external int snippet_type;

  @ffi.UnsignedInt()
  external int snippet_string;
}

class _contacts_person_number_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_name_index;

  @ffi.UnsignedInt()
  external int display_contact_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int is_favorite;

  @ffi.UnsignedInt()
  external int has_phonenumber;

  @ffi.UnsignedInt()
  external int has_email;

  @ffi.UnsignedInt()
  external int number_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int is_primary_default;

  @ffi.UnsignedInt()
  external int number;

  @ffi.UnsignedInt()
  external int number_filter;

  @ffi.UnsignedInt()
  external int normalized_number;

  @ffi.UnsignedInt()
  external int message_alert;

  @ffi.UnsignedInt()
  external int cleaned_number;

  @ffi.UnsignedInt()
  external int snippet_type;

  @ffi.UnsignedInt()
  external int snippet_string;
}

class _contacts_person_email_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_name_index;

  @ffi.UnsignedInt()
  external int display_contact_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int is_favorite;

  @ffi.UnsignedInt()
  external int has_phonenumber;

  @ffi.UnsignedInt()
  external int has_email;

  @ffi.UnsignedInt()
  external int email_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int is_primary_default;

  @ffi.UnsignedInt()
  external int email;

  @ffi.UnsignedInt()
  external int message_alert;

  @ffi.UnsignedInt()
  external int snippet_type;

  @ffi.UnsignedInt()
  external int snippet_string;
}

class _contacts_person_grouprel_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_name_index;

  @ffi.UnsignedInt()
  external int display_contact_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int status;

  @ffi.UnsignedInt()
  external int is_favorite;

  @ffi.UnsignedInt()
  external int link_count;

  @ffi.UnsignedInt()
  external int addressbook_ids;

  @ffi.UnsignedInt()
  external int has_phonenumber;

  @ffi.UnsignedInt()
  external int has_email;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int group_id;

  @ffi.UnsignedInt()
  external int address_book_name;

  @ffi.UnsignedInt()
  external int address_book_mode;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int message_alert;

  @ffi.UnsignedInt()
  external int snippet_type;

  @ffi.UnsignedInt()
  external int snippet_string;
}

class _contacts_person_group_assigned_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_name_index;

  @ffi.UnsignedInt()
  external int display_contact_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int status;

  @ffi.UnsignedInt()
  external int is_favorite;

  @ffi.UnsignedInt()
  external int link_count;

  @ffi.UnsignedInt()
  external int linked_address_book_ids;

  @ffi.UnsignedInt()
  external int has_phonenumber;

  @ffi.UnsignedInt()
  external int has_email;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int group_id;

  @ffi.UnsignedInt()
  external int address_book_mode;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int message_alert;

  @ffi.UnsignedInt()
  external int snippet_type;

  @ffi.UnsignedInt()
  external int snippet_string;
}

class _contacts_person_group_not_assigned_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_name_index;

  @ffi.UnsignedInt()
  external int display_contact_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int status;

  @ffi.UnsignedInt()
  external int is_favorite;

  @ffi.UnsignedInt()
  external int link_count;

  @ffi.UnsignedInt()
  external int linked_address_book_ids;

  @ffi.UnsignedInt()
  external int has_phonenumber;

  @ffi.UnsignedInt()
  external int has_email;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int address_book_mode;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int message_alert;

  @ffi.UnsignedInt()
  external int snippet_type;

  @ffi.UnsignedInt()
  external int snippet_string;
}

class _contacts_person_phone_log_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int log_id;

  @ffi.UnsignedInt()
  external int address;

  @ffi.UnsignedInt()
  external int address_type;

  @ffi.UnsignedInt()
  external int log_time;

  @ffi.UnsignedInt()
  external int log_type;

  @ffi.UnsignedInt()
  external int extra_data1;

  @ffi.UnsignedInt()
  external int extra_data2;

  @ffi.UnsignedInt()
  external int normalized_address;

  @ffi.UnsignedInt()
  external int cleaned_address;

  @ffi.UnsignedInt()
  external int address_filter;

  @ffi.UnsignedInt()
  external int sim_slot_no;
}

class _contacts_person_usage_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_name_index;

  @ffi.UnsignedInt()
  external int display_contact_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int vibration;

  @ffi.UnsignedInt()
  external int is_favorite;

  @ffi.UnsignedInt()
  external int has_phonenumber;

  @ffi.UnsignedInt()
  external int has_email;

  @ffi.UnsignedInt()
  external int usage_type;

  @ffi.UnsignedInt()
  external int times_used;

  @ffi.UnsignedInt()
  external int message_alert;
}

class _contacts_contact_number_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_source_type;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int number_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int is_default;

  @ffi.UnsignedInt()
  external int number;

  @ffi.UnsignedInt()
  external int number_filter;

  @ffi.UnsignedInt()
  external int normalized_number;

  @ffi.UnsignedInt()
  external int cleaned_number;
}

class _contacts_contact_email_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_source_type;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int email_id;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;

  @ffi.UnsignedInt()
  external int is_default;

  @ffi.UnsignedInt()
  external int email;
}

class _contacts_contact_grouprel_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_source_type;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int group_id;

  @ffi.UnsignedInt()
  external int group_name;
}

class _contacts_contact_activity_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int display_name;

  @ffi.UnsignedInt()
  external int display_source_type;

  @ffi.UnsignedInt()
  external int address_book_id;

  @ffi.UnsignedInt()
  external int account_id;

  @ffi.UnsignedInt()
  external int person_id;

  @ffi.UnsignedInt()
  external int ringtone_path;

  @ffi.UnsignedInt()
  external int image_thumbnail_path;

  @ffi.UnsignedInt()
  external int activity_id;

  @ffi.UnsignedInt()
  external int source_name;

  @ffi.UnsignedInt()
  external int status;

  @ffi.UnsignedInt()
  external int timestamp;

  @ffi.UnsignedInt()
  external int service_operation;

  @ffi.UnsignedInt()
  external int uri;
}

class _contacts_phone_log_stat_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int log_count;

  @ffi.UnsignedInt()
  external int log_type;

  @ffi.UnsignedInt()
  external int sim_slot_no;
}

class _contacts_sip_property_ids extends ffi.Struct {
  external ffi.Pointer<ffi.Char> _uri;

  @ffi.UnsignedInt()
  external int id;

  @ffi.UnsignedInt()
  external int contact_id;

  @ffi.UnsignedInt()
  external int address;

  @ffi.UnsignedInt()
  external int type;

  @ffi.UnsignedInt()
  external int label;
}

typedef contacts_record_h = ffi.Pointer<__contacts_record_h>;
typedef contacts_list_h = ffi.Pointer<__contacts_list_h>;

/// @brief Enumeration for Contacts match string flags.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_match_str_flag_e {
  /// < Full string, case-sensitive
  static const int CONTACTS_MATCH_EXACTLY = 0;

  /// < Full string, case-insensitive
  static const int CONTACTS_MATCH_FULLSTRING = 1;

  /// < Sub string, case-insensitive
  static const int CONTACTS_MATCH_CONTAINS = 2;

  /// < Start with, case-insensitive
  static const int CONTACTS_MATCH_STARTSWITH = 3;

  /// < End with, case-insensitive
  static const int CONTACTS_MATCH_ENDSWITH = 4;

  /// < IS NOT NULL
  static const int CONTACTS_MATCH_EXISTS = 5;
}

/// @brief Enumeration for Contacts match int flags.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_match_int_flag_e {
  /// < '='
  static const int CONTACTS_MATCH_EQUAL = 0;

  /// < '>'
  static const int CONTACTS_MATCH_GREATER_THAN = 1;

  /// < '>='
  static const int CONTACTS_MATCH_GREATER_THAN_OR_EQUAL = 2;

  /// < '<'
  static const int CONTACTS_MATCH_LESS_THAN = 3;

  /// < '<='
  static const int CONTACTS_MATCH_LESS_THAN_OR_EQUAL = 4;

  /// < '<>', this flag can yield poor performance
  static const int CONTACTS_MATCH_NOT_EQUAL = 5;

  /// < IS NULL
  static const int CONTACTS_MATCH_NONE = 6;
}

/// @brief Enumeration for Contacts filter operators.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_filter_operator_e {
  /// < AND
  static const int CONTACTS_FILTER_OPERATOR_AND = 0;

  /// < OR
  static const int CONTACTS_FILTER_OPERATOR_OR = 1;
}

typedef contacts_filter_h = ffi.Pointer<__contacts_filter_h>;
typedef contacts_query_h = ffi.Pointer<__contacts_query_h>;

/// @brief Enumeration for contact change state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_changed_e {
  /// < Inserted
  static const int CONTACTS_CHANGE_INSERTED = 0;

  /// < Updated
  static const int CONTACTS_CHANGE_UPDATED = 1;

  /// < Deleted
  static const int CONTACTS_CHANGE_DELETED = 2;
}

/// @brief Called when the designated view changes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
/// @param[in] view_uri The view URI
/// @param[in] user_data The user data passed from the callback registration function
/// @pre The callback must be registered using contacts_db_add_changed_cb.
/// @see contacts_db_add_changed_cb()
typedef contacts_db_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for name display order.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_name_display_order_e {
  /// < First name comes at the first
  static const int CONTACTS_NAME_DISPLAY_ORDER_FIRSTLAST = 0;

  /// < First name comes at the last
  static const int CONTACTS_NAME_DISPLAY_ORDER_LASTFIRST = 1;
}

/// @brief Enumeration for name sorting order.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_name_sorting_order_e {
  /// < Contacts are first sorted based on the first name
  static const int CONTACTS_NAME_SORTING_ORDER_FIRSTLAST = 0;

  /// < Contacts are first sorted based on the last name
  static const int CONTACTS_NAME_SORTING_ORDER_LASTFIRST = 1;
}

/// @brief Called when a designated view changes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
/// @param[in] name_display_order The name display order setting value
/// @param[in] user_data The user data passed from the callback registration function
/// @pre The callback must be registered using contacts_setting_add_name_display_order_changed_cb().
/// contacts_setting_set_name_display_order() must be called to invoke this callback.
/// @see contacts_setting_add_name_display_order_changed_cb()
/// @see contacts_setting_remove_name_display_order_changed_cb()
typedef contacts_setting_name_display_order_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when a designated view changes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
/// @param[in] name_sorting_order The name sorting order setting value
/// @param[in] user_data The user data passed from the callback registration function
/// @pre The callback must be registered using contacts_setting_add_name_sorting_order_changed_cb().
/// contacts_setting_set_name_sorting_order() must be called to invoke this callback.
/// @see contacts_setting_add_name_sorting_order_changed_cb()
/// @see contacts_setting_remove_name_sorting_order_changed_cb()
typedef contacts_setting_name_sorting_order_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for Contacts person properties.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_person_property_e {
  /// < Default contacts record
  static const int CONTACTS_PERSON_PROPERTY_NAME_CONTACT = 0;

  /// < Default number record
  static const int CONTACTS_PERSON_PROPERTY_NUMBER = 1;

  /// < Default email record
  static const int CONTACTS_PERSON_PROPERTY_EMAIL = 2;

  /// < Default image record
  static const int CONTACTS_PERSON_PROPERTY_IMAGE = 3;
}

/// @brief Called whenever a contact is imported.
/// @since_tizen 3.0
/// @param[in] total The number of contacts that will be imported
/// @param[in] imported_cnt The number of already imported contacts
/// @param[in] user_data The user data passed from the callback registration function
/// @return @c true to continue with the import of contacts
/// otherwise @c false to stop the import of contacts
/// @pre contacts_sim_import_all_contacts_by_sim_slot_no() will invoke this callback.
/// @see contacts_sim_import_all_contacts_by_sim_slot_no()
typedef contacts_sim_import_progress_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to get a record handle of @ref CAPI_SOCIAL_CONTACTS_SVC_VIEW_MODULE_contacts_contact.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
/// @param[in] record The record handle
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre contacts_vcard_parse_to_contact_foreach() will invoke this callback.
/// @see contacts_vcard_parse_to_contact_foreach()
typedef contacts_vcard_parse_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(contacts_record_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for contact DB status.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
abstract class contacts_db_status_e {
  /// < Normal
  static const int CONTACTS_DB_STATUS_NORMAL = 0;

  /// < DB status is Changing collation
  static const int CONTACTS_DB_STATUS_CHANGING_COLLATION = 1;
}

/// @brief Called when contacts-service server status changes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 3.0 @endif
/// @param[in] status The current status of server
/// @param[in] user_data The user data passed from the callback registration function
/// @pre This function requires an open connection to contacts service by contacts_connect().
/// @see contacts_db_add_status_changed_cb()
typedef contacts_db_status_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for language type.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class phone_number_lang_e {
  /// < Amharic
  static const int PHONE_NUMBER_LANG_AMHARIC = 0;

  /// < Arabic
  static const int PHONE_NUMBER_LANG_ARABIC = 1;

  /// < Belarusian
  static const int PHONE_NUMBER_LANG_BELARUSIAN = 2;

  /// < Bulgarian
  static const int PHONE_NUMBER_LANG_BULGARIAN = 3;

  /// < Chinese
  static const int PHONE_NUMBER_LANG_CHINESE = 4;

  /// < Chinese(Traditional)
  static const int PHONE_NUMBER_LANG_CHINESE_TRADITIONAL = 5;

  /// < Czech
  static const int PHONE_NUMBER_LANG_CZECH = 6;

  /// < Dutch
  static const int PHONE_NUMBER_LANG_DUTCH = 7;

  /// < English
  static const int PHONE_NUMBER_LANG_ENGLISH = 8;

  /// < Finnish
  static const int PHONE_NUMBER_LANG_FINNISH = 9;

  /// < French
  static const int PHONE_NUMBER_LANG_FRENCH = 10;

  /// < German
  static const int PHONE_NUMBER_LANG_GERMAN = 11;

  /// < Greek
  static const int PHONE_NUMBER_LANG_GREEK = 12;

  /// < Hungarian
  static const int PHONE_NUMBER_LANG_HUNGARIAN = 13;

  /// < Indonesian
  static const int PHONE_NUMBER_LANG_INDONESIAN = 14;

  /// < Italian
  static const int PHONE_NUMBER_LANG_ITALIAN = 15;

  /// < Japanese
  static const int PHONE_NUMBER_LANG_JAPANESE = 16;

  /// < Korean
  static const int PHONE_NUMBER_LANG_KOREAN = 17;

  /// < Northern Sami
  static const int PHONE_NUMBER_LANG_NORTHERN_SAMI = 18;

  /// < Persian
  static const int PHONE_NUMBER_LANG_PERSIAN = 19;

  /// < Polish
  static const int PHONE_NUMBER_LANG_POLISH = 20;

  /// < Portuguese
  static const int PHONE_NUMBER_LANG_PORTUGUESE = 21;

  /// < Romanian
  static const int PHONE_NUMBER_LANG_ROMANIAN = 22;

  /// < Russian
  static const int PHONE_NUMBER_LANG_RUSSIAN = 23;

  /// < Serbian
  static const int PHONE_NUMBER_LANG_SERBIAN = 24;

  /// < Spanish
  static const int PHONE_NUMBER_LANG_SPANISH = 25;

  /// < Swedish
  static const int PHONE_NUMBER_LANG_SWEDISH = 26;

  /// < Thai
  static const int PHONE_NUMBER_LANG_THAI = 27;

  /// < Turkish
  static const int PHONE_NUMBER_LANG_TURKISH = 28;

  /// < Vietnamese
  static const int PHONE_NUMBER_LANG_VIETNAMESE = 29;

  /// < Current System Value (Since 3.0)
  static const int PHONE_NUMBER_LANG_SYSTEM = 30;
  static const int PHONE_NUMBER_LANG_MAX = 31;
}

/// @brief Enumeration for region type.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class phone_number_region_e {
  /// < Aland Islands
  static const int PHONE_NUMBER_REGION_ALAND_ISLANDS = 0;

  /// < Albania
  static const int PHONE_NUMBER_REGION_ALBANIA = 1;

  /// < Algeria
  static const int PHONE_NUMBER_REGION_ALGERIA = 2;

  /// < American Samoa
  static const int PHONE_NUMBER_REGION_AMERICAN_SAMOA = 3;

  /// < Angola
  static const int PHONE_NUMBER_REGION_ANGOLA = 4;

  /// < Anguilla
  static const int PHONE_NUMBER_REGION_ANGUILLA = 5;

  /// < Argentina
  static const int PHONE_NUMBER_REGION_ARGENTINA = 6;

  /// < Armenia
  static const int PHONE_NUMBER_REGION_ARMENIA = 7;

  /// < Ascension Island
  static const int PHONE_NUMBER_REGION_ASCENSION_ISLAND = 8;

  /// < Atigua and Barbuda
  static const int PHONE_NUMBER_REGION_ATIGUA_AND_BARBUDA = 9;

  /// < Austria
  static const int PHONE_NUMBER_REGION_AUSTRIA = 10;

  /// < Bahamas
  static const int PHONE_NUMBER_REGION_BAHAMAS = 11;

  /// < Barbados
  static const int PHONE_NUMBER_REGION_BARBADOS = 12;

  /// < Belarus
  static const int PHONE_NUMBER_REGION_BELARUS = 13;

  /// < Belgium
  static const int PHONE_NUMBER_REGION_BELGIUM = 14;

  /// < Benin
  static const int PHONE_NUMBER_REGION_BENIN = 15;

  /// < Bermuda
  static const int PHONE_NUMBER_REGION_BERMUDA = 16;

  /// < Bonaire Sint Eustatius and Saba
  static const int PHONE_NUMBER_REGION_BONAIRE_SINT_EUSTATIUS_AND_SABA = 17;

  /// < Botswana
  static const int PHONE_NUMBER_REGION_BOTSWANA = 18;

  /// < Brazil
  static const int PHONE_NUMBER_REGION_BRAZIL = 19;

  /// < Bulgaria
  static const int PHONE_NUMBER_REGION_BULGARIA = 20;

  /// < Burkina Faso
  static const int PHONE_NUMBER_REGION_BURKINA_FASO = 21;

  /// < Burundi
  static const int PHONE_NUMBER_REGION_BURUNDI = 22;

  /// < Cabo Verde
  static const int PHONE_NUMBER_REGION_CABO_VERDE = 23;

  /// < Cameroon
  static const int PHONE_NUMBER_REGION_CAMEROON = 24;

  /// < Canada
  static const int PHONE_NUMBER_REGION_CANADA = 25;

  /// < Cayman Island
  static const int PHONE_NUMBER_REGION_CAYMAN_ISLAND = 26;

  /// < Chile
  static const int PHONE_NUMBER_REGION_CHILE = 27;

  /// < China
  static const int PHONE_NUMBER_REGION_CHINA = 28;

  /// < Colombia
  static const int PHONE_NUMBER_REGION_COLOMBIA = 29;

  /// < Comoros
  static const int PHONE_NUMBER_REGION_COMOROS = 30;

  /// < Congo
  static const int PHONE_NUMBER_REGION_CONGO = 31;

  /// < Cote d'Ivoire
  static const int PHONE_NUMBER_REGION_COTE_D_IVOIRE = 32;

  /// < Cuba
  static const int PHONE_NUMBER_REGION_CUBA = 33;

  /// < Curacao
  static const int PHONE_NUMBER_REGION_CURACAO = 34;

  /// < Czech Republic
  static const int PHONE_NUMBER_REGION_CZECH_REPUBLIC = 35;

  /// < Congo (Democratic Republic of the)
  static const int PHONE_NUMBER_REGION_DEMOCRATIC_REPUBLIC_OF_THE_CONGO = 36;

  /// < Dominica
  static const int PHONE_NUMBER_REGION_DOMINICA = 37;

  /// < Domoinican Republic
  static const int PHONE_NUMBER_REGION_DOMINICAN_REPUBLIC = 38;

  /// < Egypt
  static const int PHONE_NUMBER_REGION_EGYPT = 39;

  /// < Estonia
  static const int PHONE_NUMBER_REGION_ESTONIA = 40;

  /// < Ethiopia
  static const int PHONE_NUMBER_REGION_ETHIOPIA = 41;

  /// < Finland
  static const int PHONE_NUMBER_REGION_FINLAND = 42;

  /// < France
  static const int PHONE_NUMBER_REGION_FRANCE = 43;

  /// < Gabon
  static const int PHONE_NUMBER_REGION_GABON = 44;

  /// < Gambia
  static const int PHONE_NUMBER_REGION_GAMBIA = 45;

  /// < Germany
  static const int PHONE_NUMBER_REGION_GERMANY = 46;

  /// < Ghana
  static const int PHONE_NUMBER_REGION_GHANA = 47;

  /// < Greece
  static const int PHONE_NUMBER_REGION_GREECE = 48;

  /// < Greenland
  static const int PHONE_NUMBER_REGION_GREENLAND = 49;

  /// < Grenada
  static const int PHONE_NUMBER_REGION_GRENADA = 50;

  /// < Guam
  static const int PHONE_NUMBER_REGION_GUAM = 51;

  /// < Guernsey
  static const int PHONE_NUMBER_REGION_GUERNSEY = 52;

  /// < Guinea
  static const int PHONE_NUMBER_REGION_GUINEA = 53;

  /// < Guinea-Bissau
  static const int PHONE_NUMBER_REGION_GUINEA_BISSAU = 54;

  /// < Hungary
  static const int PHONE_NUMBER_REGION_HUNGARY = 55;

  /// < Iceland
  static const int PHONE_NUMBER_REGION_ICELAND = 56;

  /// < India
  static const int PHONE_NUMBER_REGION_INDIA = 57;

  /// < Indonesia
  static const int PHONE_NUMBER_REGION_INDONESIA = 58;

  /// < Ireland
  static const int PHONE_NUMBER_REGION_IRELAND = 59;

  /// < Iran (Islamic Republic of)
  static const int PHONE_NUMBER_REGION_ISLAMIC_REPUBLIC_OF_IRAN = 60;

  /// < Isle of Man
  static const int PHONE_NUMBER_REGION_ISLE_OF_MAN = 61;

  /// < Italy
  static const int PHONE_NUMBER_REGION_ITALY = 62;

  /// < Jamaica
  static const int PHONE_NUMBER_REGION_JAMAICA = 63;

  /// < Japan
  static const int PHONE_NUMBER_REGION_JAPAN = 64;

  /// < Jersey
  static const int PHONE_NUMBER_REGION_JERSEY = 65;

  /// < Jordan
  static const int PHONE_NUMBER_REGION_JORDAN = 66;

  /// < Kazakhstan
  static const int PHONE_NUMBER_REGION_KAZAKHSTAN = 67;

  /// < Kenya
  static const int PHONE_NUMBER_REGION_KENYA = 68;

  /// < Kiribati
  static const int PHONE_NUMBER_REGION_KIRIBATI = 69;

  /// < Latvia
  static const int PHONE_NUMBER_REGION_LATVIA = 70;

  /// < Lesotho
  static const int PHONE_NUMBER_REGION_LESOTHO = 71;

  /// < Lithuania
  static const int PHONE_NUMBER_REGION_LITHUANIA = 72;

  /// < Luxembourg
  static const int PHONE_NUMBER_REGION_LUXEMBOURG = 73;

  /// < Madagascar
  static const int PHONE_NUMBER_REGION_MADAGASCAR = 74;

  /// < Mauritania
  static const int PHONE_NUMBER_REGION_MAURITANIA = 75;

  /// < Maritius
  static const int PHONE_NUMBER_REGION_MAURITIUS = 76;

  /// < Montserrat
  static const int PHONE_NUMBER_REGION_MONTSERRAT = 77;

  /// < Morocco
  static const int PHONE_NUMBER_REGION_MOROCCO = 78;

  /// < Mazambique
  static const int PHONE_NUMBER_REGION_MOZAMBIQUE = 79;

  /// < Namibia
  static const int PHONE_NUMBER_REGION_NAMIBIA = 80;

  /// < Netherlands
  static const int PHONE_NUMBER_REGION_NETHERLANDS = 81;

  /// < Nigeria
  static const int PHONE_NUMBER_REGION_NIGERIA = 82;

  /// < Northern Mariana Island
  static const int PHONE_NUMBER_REGION_NORTHERN_MARIANA_ISLANDS = 83;

  /// < Norway
  static const int PHONE_NUMBER_REGION_NORWAY = 84;

  /// < Peru
  static const int PHONE_NUMBER_REGION_PERU = 85;

  /// < Poland
  static const int PHONE_NUMBER_REGION_POLAND = 86;

  /// < Portugal
  static const int PHONE_NUMBER_REGION_PORTUGAL = 87;

  /// < Puerto Rico
  static const int PHONE_NUMBER_REGION_PUERTO_RICO = 88;

  /// < Korea (Republic of)
  static const int PHONE_NUMBER_REGION_REPUBLIC_OF_KOREA = 89;

  /// < Moldova (Republic of)
  static const int PHONE_NUMBER_REGION_REPUBLIC_OF_MOLDOVA = 90;

  /// < Romania
  static const int PHONE_NUMBER_REGION_ROMANIA = 91;

  /// < Russian Federation
  static const int PHONE_NUMBER_REGION_RUSSIAN_FEDERATION = 92;

  /// < Saint Helena, Ascension and Tristan da Cunha
  static const int PHONE_NUMBER_REGION_SAINT_HELENA = 93;

  /// < Saint Kitts and Nevis
  static const int PHONE_NUMBER_REGION_SAINT_KITTS_AND_NEVIS = 94;

  /// < Saint Lucia
  static const int PHONE_NUMBER_REGION_SAINT_LUCIA = 95;

  /// < Saint Vincent and the Grenadines
  static const int PHONE_NUMBER_REGION_SAINT_VINCENT_AND_THE_GRENADINES = 96;

  /// < Sao Tome and Principe
  static const int PHONE_NUMBER_REGION_SAO_TOME_AND_PRINCIPE = 97;

  /// < Saudi Arabia
  static const int PHONE_NUMBER_REGION_SAUDI_ARABIA = 98;

  /// < Senegal
  static const int PHONE_NUMBER_REGION_SENEGAL = 99;

  /// < Serbia
  static const int PHONE_NUMBER_REGION_SERBIA = 100;

  /// < Sierra Leone
  static const int PHONE_NUMBER_REGION_SIERRA_LEONE = 101;

  /// < Sint maarten (Dutch part)
  static const int PHONE_NUMBER_REGION_SINT_MAARTEN = 102;

  /// < Slovakia
  static const int PHONE_NUMBER_REGION_SLOVAKIA = 103;

  /// < Somalia
  static const int PHONE_NUMBER_REGION_SOMALIA = 104;

  /// < South Africa
  static const int PHONE_NUMBER_REGION_SOUTH_AFRICA = 105;

  /// < Spain
  static const int PHONE_NUMBER_REGION_SPAIN = 106;

  /// < Sri Lanka
  static const int PHONE_NUMBER_REGION_SRI_LANKA = 107;

  /// < Sudan
  static const int PHONE_NUMBER_REGION_SUDAN = 108;

  /// < Svalbard and Jan Mayen
  static const int PHONE_NUMBER_REGION_SVALBARD_AND_JAN_MAYEN = 109;

  /// < Swaziland
  static const int PHONE_NUMBER_REGION_SWAZILAND = 110;

  /// < Sweden
  static const int PHONE_NUMBER_REGION_SWEDEN = 111;

  /// < Switzerland
  static const int PHONE_NUMBER_REGION_SWITZERLAND = 112;

  /// < Taiwan Province of China
  static const int PHONE_NUMBER_REGION_TAIWAN_PROVINCE_OF_CHINA = 113;

  /// < Thailand
  static const int PHONE_NUMBER_REGION_THAILAND = 114;

  /// < Macedonia (the Former Yugoslav Republic of)
  static const int
      PHONE_NUMBER_REGION_THE_FORMER_YUGOSLAV_REPUBLIC_OF_MACEDONIA = 115;

  /// < Togo
  static const int PHONE_NUMBER_REGION_TOGO = 116;

  /// < Trinidad and Tobago
  static const int PHONE_NUMBER_REGION_TRINIDAD_AND_TOBAGO = 117;

  /// < Tristan da Cunha
  static const int PHONE_NUMBER_REGION_TRISTAN_DA_CUNHA = 118;

  /// < Tunisia
  static const int PHONE_NUMBER_REGION_TUNISIA = 119;

  /// < Turkey
  static const int PHONE_NUMBER_REGION_TURKEY = 120;

  /// < Turks and Caicos Islands
  static const int PHONE_NUMBER_REGION_TURKS_AND_CAICOS_ISLANDS = 121;

  /// < Uganda
  static const int PHONE_NUMBER_REGION_UGANDA = 122;

  /// < United Kingdom
  static const int PHONE_NUMBER_REGION_UNITED_KINGDOM = 123;

  /// < United States of America
  static const int PHONE_NUMBER_REGION_UNITED_STATES_OF_AMERICA = 124;

  /// < Venezuela
  static const int PHONE_NUMBER_REGION_VENEZUELA = 125;

  /// < Viet Nam
  static const int PHONE_NUMBER_REGION_VIET_NAM = 126;

  /// < Virgin Island (British)
  static const int PHONE_NUMBER_REGION_VIRGIN_ISLAND_BRITISH = 127;

  /// < Virgin Island (U.S.)
  static const int PHONE_NUMBER_REGION_VIRGIN_ISLAND_US = 128;

  /// < Western Sahara
  static const int PHONE_NUMBER_REGION_WESTERN_SAHARA = 129;

  /// < Zambia
  static const int PHONE_NUMBER_REGION_ZAMBIA = 130;

  /// < Zimbabwe
  static const int PHONE_NUMBER_REGION_ZIMBABWE = 131;

  /// < Andorra (Since 3.0)
  static const int PHONE_NUMBER_REGION_ANDORRA = 132;

  /// < United Arab Emirates (Since 3.0)
  static const int PHONE_NUMBER_REGION_UNITED_ARAB_EMIRATES = 133;

  /// < Afghanistan (Since 3.0)
  static const int PHONE_NUMBER_REGION_AFGHANISTAN = 134;

  /// < Australia (Since 3.0)
  static const int PHONE_NUMBER_REGION_AUSTRALIA = 135;

  /// < Aruba (Since 3.0)
  static const int PHONE_NUMBER_REGION_ARUBA = 136;

  /// < Azerbaijan (Since 3.0)
  static const int PHONE_NUMBER_REGION_AZERBAIJAN = 137;

  /// < Bosnia and Herzegovina (Since 3.0)
  static const int PHONE_NUMBER_REGION_BOSNIA_AND_HERZEGOVINA = 138;

  /// < Bangladesh (Since 3.0)
  static const int PHONE_NUMBER_REGION_BANGLADESH = 139;

  /// < Bahrain (Since 3.0)
  static const int PHONE_NUMBER_REGION_BAHRAIN = 140;

  /// < Saint Barthelemy, French Antilles (Since 3.0)
  static const int PHONE_NUMBER_REGION_SAINT_BARTHELEMY = 141;

  /// < Brunei Darussalam (Since 3.0)
  static const int PHONE_NUMBER_REGION_BRUNEI_DARUSSALAM = 142;

  /// < Bolivia (Since 3.0)
  static const int PHONE_NUMBER_REGION_BOLIVIA = 143;

  /// < Bhutan (Since 3.0)
  static const int PHONE_NUMBER_REGION_BHUTAN = 144;

  /// < Belize (Since 3.0)
  static const int PHONE_NUMBER_REGION_BELIZE = 145;

  /// < Cocos Islands (Since 3.0)
  static const int PHONE_NUMBER_REGION_COCOS_ISLANDS = 146;

  /// < Central African Republic (Since 3.0)
  static const int PHONE_NUMBER_REGION_CENTRAL_AFRICAN_REPUBLIC = 147;

  /// < Cook Islands (Since 3.0)
  static const int PHONE_NUMBER_REGION_COOK_ISLANDS = 148;

  /// < Costa Rica (Since 3.0)
  static const int PHONE_NUMBER_REGION_COSTA_RICA = 149;

  /// < Christmas Islands (Since 3.0)
  static const int PHONE_NUMBER_REGION_CHRISTMAS_ISLANDS = 150;

  /// < Cyprus (Since 3.0)
  static const int PHONE_NUMBER_REGION_CYPRUS = 151;

  /// < Djibouti (Since 3.0)
  static const int PHONE_NUMBER_REGION_DJIBOUTI = 152;

  /// < Denmark (Since 3.0)
  static const int PHONE_NUMBER_REGION_DENMARK = 153;

  /// < Ecuador (Since 3.0)
  static const int PHONE_NUMBER_REGION_ECUADOR = 154;

  /// < Eritrea (Since 3.0)
  static const int PHONE_NUMBER_REGION_ERITREA = 155;

  /// < Fiji (Since 3.0)
  static const int PHONE_NUMBER_REGION_FIJI = 156;

  /// < Falkland Islands (Since 3.0)
  static const int PHONE_NUMBER_REGION_FALKLAND_ISLANDS = 157;

  /// < Micronesia, Federated States of (Since 3.0)
  static const int PHONE_NUMBER_REGION_MICRONESIA = 158;

  /// < Faroe Islands (Since 3.0)
  static const int PHONE_NUMBER_REGION_FAROE_ISLANDS = 159;

  /// < Georgia (Since 3.0)
  static const int PHONE_NUMBER_REGION_GEORGIA = 160;

  /// < French Guiana (Since 3.0)
  static const int PHONE_NUMBER_REGION_FRENCH_GUIANA = 161;

  /// < Gibraltar (Since 3.0)
  static const int PHONE_NUMBER_REGION_GIBRALTAR = 162;

  /// < Guadeloupe (Since 3.0)
  static const int PHONE_NUMBER_REGION_GUADELOUPE = 163;

  /// < Equatorial Guinea (Since 3.0)
  static const int PHONE_NUMBER_REGION_EQUATORIAL_GUINEA = 164;

  /// < Guatemala (Since 3.0)
  static const int PHONE_NUMBER_REGION_GUATEMALA = 165;

  /// < Guyana (Since 3.0)
  static const int PHONE_NUMBER_REGION_GUYANA = 166;

  /// < Hong Kong (Since 3.0)
  static const int PHONE_NUMBER_REGION_HONG_KONG = 167;

  /// < Honduras (Since 3.0)
  static const int PHONE_NUMBER_REGION_HONDURAS = 168;

  /// < Croatia (Since 3.0)
  static const int PHONE_NUMBER_REGION_CROATIA = 169;

  /// < Haiti (Since 3.0)
  static const int PHONE_NUMBER_REGION_HAITI = 170;

  /// < Israel (Since 3.0)
  static const int PHONE_NUMBER_REGION_ISRAEL = 171;

  /// < British Indian Ocean Territory / Diego Garcia (Since 3.0)
  static const int PHONE_NUMBER_REGION_DIEGO_GARCIA = 172;

  /// < Iraq (Since 3.0)
  static const int PHONE_NUMBER_REGION_IRAQ = 173;

  /// < Kyrgyzstan (Since 3.0)
  static const int PHONE_NUMBER_REGION_KYRGYZSTAN = 174;

  /// < Cambodia (Since 3.0)
  static const int PHONE_NUMBER_REGION_CAMBODIA = 175;

  /// < Korea, Dem. People's Rep. of (Since 3.0)
  static const int PHONE_NUMBER_REGION_NORTH_KOREA = 176;

  /// < Kuwait (Since 3.0)
  static const int PHONE_NUMBER_REGION_KUWAIT = 177;

  /// < Lao People's Dem. Rep. (Since 3.0)
  static const int PHONE_NUMBER_REGION_LAOS = 178;

  /// < Lebanon (Since 3.0)
  static const int PHONE_NUMBER_REGION_LEBANON = 179;

  /// < Liechtenstein (Since 3.0)
  static const int PHONE_NUMBER_REGION_LIECHTENSTEIN = 180;

  /// < Liberia (Since 3.0)
  static const int PHONE_NUMBER_REGION_LIBERIA = 181;

  /// < Libya (Soc. People's Libyan Arab Jamahiriya) (Since 3.0)
  static const int PHONE_NUMBER_REGION_LIBYA = 182;

  /// < Monaco (Since 3.0)
  static const int PHONE_NUMBER_REGION_MONACO = 183;

  /// < Montenegro (Since 3.0)
  static const int PHONE_NUMBER_REGION_MONTENEGRO = 184;

  /// < Saint-Martin, French Antilles (Since 3.0)
  static const int PHONE_NUMBER_REGION_SAINT_MARTIN = 185;

  /// < Marshall Islands (Since 3.0)
  static const int PHONE_NUMBER_REGION_MARSHALL_ISLANDS = 186;

  /// < Mali (Since 3.0)
  static const int PHONE_NUMBER_REGION_MALI = 187;

  /// < Myanmar (Since 3.0)
  static const int PHONE_NUMBER_REGION_MYANMAR = 188;

  /// < Mongolia (Since 3.0)
  static const int PHONE_NUMBER_REGION_MONGOLIA = 189;

  /// < Macao, China (Since 3.0)
  static const int PHONE_NUMBER_REGION_MACAO = 190;

  /// < Martinique (French Dept. of) (Since 3.0)
  static const int PHONE_NUMBER_REGION_MARTINIQUE = 191;

  /// < Malta (Since 3.0)
  static const int PHONE_NUMBER_REGION_MALTA = 192;

  /// < Maldives (Since 3.0)
  static const int PHONE_NUMBER_REGION_MALDIVES = 193;

  /// < Malawi (Since 3.0)
  static const int PHONE_NUMBER_REGION_MALAWI = 194;

  /// < Mexico (Since 3.0)
  static const int PHONE_NUMBER_REGION_MEXICO = 195;

  /// < Malaysia (Since 3.0)
  static const int PHONE_NUMBER_REGION_MALAYSIA = 196;

  /// < New Caledonia (Territoire francais d'outre-mer) (Since 3.0)
  static const int PHONE_NUMBER_REGION_NEW_CALEDONIA = 197;

  /// < Niger (Since 3.0)
  static const int PHONE_NUMBER_REGION_NIGER = 198;

  /// < Norfolk Island (Since 3.0)
  static const int PHONE_NUMBER_REGION_NORFOLK_ISLAND = 199;

  /// < Nicaragua (Since 3.0)
  static const int PHONE_NUMBER_REGION_NICARAGUA = 200;

  /// < Nepal (Since 3.0)
  static const int PHONE_NUMBER_REGION_NEPAL = 201;

  /// < Nauru (Since 3.0)
  static const int PHONE_NUMBER_REGION_NAURU = 202;

  /// < Niue (Since 3.0)
  static const int PHONE_NUMBER_REGION_NIUE = 203;

  /// < New Zealand (Since 3.0)
  static const int PHONE_NUMBER_REGION_NEW_ZEALAND = 204;

  /// < Oman (Since 3.0)
  static const int PHONE_NUMBER_REGION_OMAN = 205;

  /// < Panama (Since 3.0)
  static const int PHONE_NUMBER_REGION_PANAMA = 206;

  /// < French Polynesia (Tahiti) (Territoire francais d'outre-mer) (Since 3.0)
  static const int PHONE_NUMBER_REGION_FRENCH_POLYNESIA = 207;

  /// < Papua New Guinea (Since 3.0)
  static const int PHONE_NUMBER_REGION_PAPUA_NEW_GUINEA = 208;

  /// < Philippines (Since 3.0)
  static const int PHONE_NUMBER_REGION_PHILIPPINES = 209;

  /// < Pakistan (Since 3.0)
  static const int PHONE_NUMBER_REGION_PAKISTAN = 210;

  /// < Saint Pierre and Miquelon (Collectivite territoriale de la Republique francaise) (Since 3.0)
  static const int PHONE_NUMBER_REGION_SAINT_PIERRE_AND_MIQUELON = 211;

  /// < Palestinian Authority (Since 3.0)
  static const int PHONE_NUMBER_REGION_PALESTINIAN_AUTHORITY = 212;

  /// < Palau (Since 3.0)
  static const int PHONE_NUMBER_REGION_PALAU = 213;

  /// < Paraguay (Since 3.0)
  static const int PHONE_NUMBER_REGION_PARAGUAY = 214;

  /// < Qatar (Since 3.0)
  static const int PHONE_NUMBER_REGION_QATAR = 215;

  /// < Reunion (French Departments and Territories in the Indian Ocean) (Since 3.0)
  static const int PHONE_NUMBER_REGION_REUNION = 216;

  /// < Rwanda (Since 3.0)
  static const int PHONE_NUMBER_REGION_RWANDA = 217;

  /// < Solomon Islands (Since 3.0)
  static const int PHONE_NUMBER_REGION_SOLOMON_ISLANDS = 218;

  /// < Seychelles (Since 3.0)
  static const int PHONE_NUMBER_REGION_SEYCHELLES = 219;

  /// < Singapore (Since 3.0)
  static const int PHONE_NUMBER_REGION_SINGAPORE = 220;

  /// < Slovenia (Since 3.0)
  static const int PHONE_NUMBER_REGION_SLOVENIA = 221;

  /// < San Marino (Since 3.0)
  static const int PHONE_NUMBER_REGION_SAN_MARINO = 222;

  /// < Suriname (Since 3.0)
  static const int PHONE_NUMBER_REGION_SURINAME = 223;

  /// < South Sudan (Since 3.0)
  static const int PHONE_NUMBER_REGION_SOUTH_SUDAN = 224;

  /// < El Salvador (Since 3.0)
  static const int PHONE_NUMBER_REGION_EL_SALVADOR = 225;

  /// < Syrian Arab Republic (Since 3.0)
  static const int PHONE_NUMBER_REGION_SYRIAN_ARAB_REPUBLIC = 226;

  /// < Chad (Since 3.0)
  static const int PHONE_NUMBER_REGION_CHAD = 227;

  /// < Tajikistan (Since 3.0)
  static const int PHONE_NUMBER_REGION_TAJIKISTAN = 228;

  /// < Tokelau (Since 3.0)
  static const int PHONE_NUMBER_REGION_TOKELAU = 229;

  /// < Timor-Leste (East Timor) (Since 3.0)
  static const int PHONE_NUMBER_REGION_TIMOR_LESTE = 230;

  /// < Turkmenistan (Since 3.0)
  static const int PHONE_NUMBER_REGION_TURKMENISTAN = 231;

  /// < Tonga (Since 3.0)
  static const int PHONE_NUMBER_REGION_TONGA = 232;

  /// < Tuvalu (Since 3.0)
  static const int PHONE_NUMBER_REGION_TUVALU = 233;

  /// < Tanzania (Since 3.0)
  static const int PHONE_NUMBER_REGION_TANZANIA = 234;

  /// < Ukraine (Since 3.0)
  static const int PHONE_NUMBER_REGION_UKRAINE = 235;

  /// < Uruguay (Since 3.0)
  static const int PHONE_NUMBER_REGION_URUGUAY = 236;

  /// < Uzbekistan (Since 3.0)
  static const int PHONE_NUMBER_REGION_UZBEKISTAN = 237;

  /// < Vatican City (Since 3.0)
  static const int PHONE_NUMBER_REGION_VATICAN_CITY = 238;

  /// < Vanuatu (Since 3.0)
  static const int PHONE_NUMBER_REGION_VANUATU = 239;

  /// < Wallis and Futuna (Territoire francais d'outre-mer) (Since 3.0)
  static const int PHONE_NUMBER_REGION_WALLIS_AND_FUTUNA = 240;

  /// < Samoa (Since 3.0)
  static const int PHONE_NUMBER_REGION_SAMOA = 241;

  /// < Yemen (Since 3.0)
  static const int PHONE_NUMBER_REGION_YEMEN = 242;

  /// < Mayotte (Since 3.0)
  static const int PHONE_NUMBER_REGION_MAYOTTE = 243;

  /// < Current System Value (Since 3.0)
  static const int PHONE_NUMBER_REGION_SYSTEM = 244;
  static const int PHONE_NUMBER_REGION_MAX = 245;
}

/// @brief Enumeration for match type.
/// @since_tizen 4.0
abstract class phone_number_blocking_rule_match_type_e {
  /// < Exact match
  static const int PHONE_NUMBER_MATCH_TYPE_EXACTLY = 0;

  /// < Includes
  static const int PHONE_NUMBER_MATCH_TYPE_INCLUDES = 1;

  /// < Starts with
  static const int PHONE_NUMBER_MATCH_TYPE_STARTS_WITH = 2;

  /// < Ends with
  static const int PHONE_NUMBER_MATCH_TYPE_ENDS_WITH = 3;
}

/// @brief Enumeration for phone number errors.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class phone_number_error_e {
  /// < Successful
  static const int PHONE_NUMBER_ERROR_NONE = 0;

  /// < I/O Error
  static const int PHONE_NUMBER_ERROR_IO_ERROR = -5;

  /// < Out of memory
  static const int PHONE_NUMBER_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int PHONE_NUMBER_ERROR_INVALID_PARAMETER = -22;

  /// < FS Full
  static const int PHONE_NUMBER_ERROR_FILE_NO_SPACE_ON_DEVICE = -28;

  /// < Permission denied
  static const int PHONE_NUMBER_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int PHONE_NUMBER_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Requested data does not exist
  static const int PHONE_NUMBER_ERROR_NO_DATA = -61;

  /// < Internal error (Since 3.0)
  static const int PHONE_NUMBER_ERROR_SYSTEM = -33685265;

  /// < No access to the database (Since 4.0)
  static const int PHONE_NUMBER_ERROR_DB_FAILED = -33685502;

  /// < Unknown IPC error (Since 4.0)
  static const int PHONE_NUMBER_ERROR_IPC = -33685313;
}

/// @brief The blocking rule handle.
/// @since_tizen 4.0
typedef phone_number_blocking_rule_h = ffi.Pointer<ffi.Void>;

/// @brief Enumeration for device's error code.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class device_error_e {
  /// < Successful
  static const int DEVICE_ERROR_NONE = 0;

  /// < Operation not permitted
  static const int DEVICE_ERROR_OPERATION_FAILED = -1;

  /// < Permission denied
  static const int DEVICE_ERROR_PERMISSION_DENIED = -13;

  /// < Invalid parameter
  static const int DEVICE_ERROR_INVALID_PARAMETER = -22;

  /// < Operation already in progress
  static const int DEVICE_ERROR_ALREADY_IN_PROGRESS = -114;

  /// < Not supported in this device
  static const int DEVICE_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Device or resource busy
  static const int DEVICE_ERROR_RESOURCE_BUSY = -16;

  /// < Not initialized
  static const int DEVICE_ERROR_NOT_INITIALIZED = -37748717;
}

/// @brief Enumeration for the battery level status.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class device_battery_level_e {
  /// < The battery goes empty. Prepare for the safe termination of the application, because the device starts a shutdown process soon after entering this level.
  static const int DEVICE_BATTERY_LEVEL_EMPTY = 0;

  /// < The battery charge is at a critical state. You may have to stop using multimedia features, because they are not guaranteed to work correctly at this battery status.
  static const int DEVICE_BATTERY_LEVEL_CRITICAL = 1;

  /// < The battery has little charge left.
  static const int DEVICE_BATTERY_LEVEL_LOW = 2;

  /// < The battery status is not to be careful.
  static const int DEVICE_BATTERY_LEVEL_HIGH = 3;

  /// < The battery status is fully charged. It means no more charge.
  static const int DEVICE_BATTERY_LEVEL_FULL = 4;
}

/// @brief Enumeration for battery health information.
/// @since_tizen 3.0
abstract class device_battery_health_e {
  /// < The battery health is good
  static const int DEVICE_BATTERY_HEALTH_GOOD = 0;

  /// < The temperature of the battery is cold
  static const int DEVICE_BATTERY_HEALTH_COLD = 1;

  /// < The battery is dead
  static const int DEVICE_BATTERY_HEALTH_DEAD = 2;

  /// < The temperature of the battery is high
  static const int DEVICE_BATTERY_HEALTH_OVER_HEAT = 3;

  /// < The battery is in over voltage state
  static const int DEVICE_BATTERY_HEALTH_OVER_VOLTAGE = 4;
}

/// @brief Enumeration for power source information.
/// @since_tizen 3.0
abstract class device_battery_power_source_e {
  /// < There is no power source
  static const int DEVICE_BATTERY_POWER_SOURCE_NONE = 0;

  /// < AC power cable is connected
  static const int DEVICE_BATTERY_POWER_SOURCE_AC = 1;

  /// < USB power cable is connected
  static const int DEVICE_BATTERY_POWER_SOURCE_USB = 2;

  /// < Power is provided by a wireless source
  static const int DEVICE_BATTERY_POWER_SOURCE_WIRELESS = 3;
}

/// @brief Enumeration for battery property information.
/// @since_tizen 3.0
abstract class device_battery_property_e {
  /// < The battery capacity (0 ~ 100 %)
  static const int DEVICE_BATTERY_PROPERTY_CAPACITY = 0;

  /// < The battery current (uA)
  static const int DEVICE_BATTERY_PROPERTY_CURRENT_NOW = 1;

  /// < The average battery current (uA)
  static const int DEVICE_BATTERY_PROPERTY_CURRENT_AVERAGE = 2;
}

/// @brief Enumeration for battery status information.
/// @since_tizen 3.0
abstract class device_battery_status_e {
  /// < Battery is charging
  static const int DEVICE_BATTERY_STATUS_CHARGING = 0;

  /// < Battery is discharging
  static const int DEVICE_BATTERY_STATUS_DISCHARGING = 1;

  /// < Battery is fully charged
  static const int DEVICE_BATTERY_STATUS_FULL = 2;

  /// < Battery is not charging
  static const int DEVICE_BATTERY_STATUS_NOT_CHARGING = 3;
}

/// @brief Enumeration for the device state callback.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class device_callback_e {
  /// < Called when a battery charge percentage is changed
  static const int DEVICE_CALLBACK_BATTERY_CAPACITY = 0;

  /// < Called when a battery level is changed
  static const int DEVICE_CALLBACK_BATTERY_LEVEL = 1;

  /// < Called when battery charging state is changed
  static const int DEVICE_CALLBACK_BATTERY_CHARGING = 2;

  /// < Called when a display state is changed
  static const int DEVICE_CALLBACK_DISPLAY_STATE = 3;

  /// < Called when a flash brightness is changed (Since Tizen @if Mobile 2.4 @elseif WEARABLE 3.0 @endif)
  static const int DEVICE_CALLBACK_FLASH_BRIGHTNESS = 4;
  static const int DEVICE_CALLBACK_MAX = 5;
}

/// @brief Called when a device status is changed.
/// @details Each device callback has a different output param type. \n
/// So you need to check below output param before using this function. \n
/// callback enum               output type \n
/// DEVICE_CALLBACK_BATTERY_CAPACITY        int \n
/// DEVICE_CALLBACK_BATTERY_LEVEL           int \n
/// DEVICE_CALLBACK_BATTERY_CHARGING        bool \n
/// DEVICE_CALLBACK_DISPLAY_STATE           int \n
/// DEVICE_CALLBACK_FLASH_BRIGHTNESS        int
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks DEVICE_CALLBACK_FLASH_BRIGHTNESS callback invoked when user set flash brightness by using device_flash_set_brightness(). It does not work by camera flash operation. To register DEVICE_CALLBACK_FLASH_BRIGHTNESS callback, you need to declare the LED privilege (%http://tizen.org/privilege/led).
/// @param[out] type The device type to monitor
/// @param[out] value The changed value
/// @param[out] user_data The user data passed from the callback registration function
typedef device_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int32, ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for the available display states.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class display_state_e {
  /// < Normal state
  static const int DISPLAY_STATE_NORMAL = 0;

  /// < @if TV @internal @endif Screen dim state
  static const int DISPLAY_STATE_SCREEN_DIM = 1;

  /// < Screen off state
  static const int DISPLAY_STATE_SCREEN_OFF = 2;
}

/// @brief The haptic device handle.
typedef haptic_device_h = ffi.Pointer<ffi.Void>;

/// @brief The haptic effect handle.
typedef haptic_effect_h = ffi.Pointer<ffi.Void>;

/// @brief Enumeration for custom LED flags.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class led_custom_flags {
  /// < blink LED
  static const int LED_CUSTOM_DUTY_ON = 1;

  /// < Default flag
  static const int LED_CUSTOM_DEFAULT = 1;
}

/// @brief Enumeration for lock type.
/// @details Each enum ensures that the suitable device is on until all the lock requests have been released or after a timeout.
/// <TABLE>
/// <TR><TH>Enum Type</TH><TH>CPU</TH><TH>Brightness(Display)</TH></TR>
/// <TR><TD>POWER_LOCK_CPU</TD><TD>ON</TD><TD>OFF</TD></TR>
/// <TR><TD>POWER_LOCK_DISPLAY</TD><TD>ON</TD><TD>ON(Normal)</TD></TR>
/// <TR><TD>POWER_LOCK_DISPLAY_DIM</TD><TD>ON</TD><TD>ON(Dim)</TD></TR>
/// </TABLE>
/// The POWER_LOCK_DISPLAY and POWER_LOCK_DISPLAY_DIM types were deprecated in Tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif.\n
/// Please use below api set instead of these types.\n
/// int efl_util_set_window_screen_mode(Evas_Object *window, efl_util_screen_mode_e mode); \n
/// int efl_util_get_window_screen_mode(Evas_Object *window, efl_util_screen_mode_e *mode);
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks An application can lock the specific type.
/// @remarks These enums are mutually exclusive.
/// @remarks You cannot combine with an enum below.
abstract class power_lock_e {
  /// < CPU lock
  static const int POWER_LOCK_CPU = 0;

  /// < Display normal lock (Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. Use efl_util_set_window_screen_mode() instead)
  static const int POWER_LOCK_DISPLAY = 1;

  /// < Display dim lock (Deprecated since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. Use efl_util_set_window_screen_mode() instead)
  static const int POWER_LOCK_DISPLAY_DIM = 2;
}

/// @brief Enumeration for Dlog Error.
/// @if MOBILE @since_tizen 2.3 @elseif WEARABLE @since_tizen 2.3.1 @endif
abstract class dlog_error_e {
  /// < Successful
  static const int DLOG_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int DLOG_ERROR_INVALID_PARAMETER = -22;

  /// < Operation not permitted
  static const int DLOG_ERROR_NOT_PERMITTED = -1;
}

/// @brief Enumeration for log priority values in ascending priority order.
/// @if MOBILE @since_tizen 2.3 @elseif WEARABLE @since_tizen 2.3.1 @endif
abstract class log_priority {
  /// < Keep this always at the start
  static const int DLOG_UNKNOWN = 0;

  /// < Default
  static const int DLOG_DEFAULT = 1;

  /// < Verbose
  static const int DLOG_VERBOSE = 2;

  /// < Debug
  static const int DLOG_DEBUG = 3;

  /// < Info
  static const int DLOG_INFO = 4;

  /// < Warning
  static const int DLOG_WARN = 5;

  /// < Error
  static const int DLOG_ERROR = 6;

  /// < Fatal
  static const int DLOG_FATAL = 7;

  /// < Silent
  static const int DLOG_SILENT = 8;

  /// < Keep this always at the end.
  static const int DLOG_PRIO_MAX = 9;
}

typedef va_list = __gnuc_va_list;
typedef __gnuc_va_list = __builtin_va_list;
typedef __builtin_va_list = ffi.Pointer<ffi.Char>;

/// @brief Enumeration for feedback interface type.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class feedback_type_e {
  /// < Feedback type none
  static const int FEEDBACK_TYPE_NONE = 0;

  /// < Feedback type for sound
  static const int FEEDBACK_TYPE_SOUND = 1;

  /// < Feedback type for vibration
  static const int FEEDBACK_TYPE_VIBRATION = 2;
  static const int FEEDBACK_TYPE_END = 3;
}

/// @brief Enumeration for feedback interface of the system pre-defined patterns.
/// @details Each feedback pattern can have separate media files of each types.
/// But depending on vendor design, pattern may not have any type of file.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class feedback_pattern_e {
  static const int FEEDBACK_PATTERN_NONE = -1;

  /// < Feedback pattern when general touch
  static const int FEEDBACK_PATTERN_TAP = 0;

  /// < Feedback pattern when touch text key
  static const int FEEDBACK_PATTERN_SIP = 1;

  /// < Feedback pattern when touch numeric 0 key
  static const int FEEDBACK_PATTERN_KEY0 = 6;

  /// < Feedback pattern when touch numeric 1 key
  static const int FEEDBACK_PATTERN_KEY1 = 7;

  /// < Feedback pattern when touch numeric 2 key
  static const int FEEDBACK_PATTERN_KEY2 = 8;

  /// < Feedback pattern when touch numeric 3 key
  static const int FEEDBACK_PATTERN_KEY3 = 9;

  /// < Feedback pattern when touch numeric 4 key
  static const int FEEDBACK_PATTERN_KEY4 = 10;

  /// < Feedback pattern when touch numeric 5 key
  static const int FEEDBACK_PATTERN_KEY5 = 11;

  /// < Feedback pattern when touch numeric 6 key
  static const int FEEDBACK_PATTERN_KEY6 = 12;

  /// < Feedback pattern when touch numeric 7 key
  static const int FEEDBACK_PATTERN_KEY7 = 13;

  /// < Feedback pattern when touch numeric 8 key
  static const int FEEDBACK_PATTERN_KEY8 = 14;

  /// < Feedback pattern when touch numeric 9 key
  static const int FEEDBACK_PATTERN_KEY9 = 15;

  /// < Feedback pattern when touch star key
  static const int FEEDBACK_PATTERN_KEY_STAR = 16;

  /// < Feedback pattern when touch sharp key
  static const int FEEDBACK_PATTERN_KEY_SHARP = 17;

  /// < Feedback pattern when touch backspace key
  static const int FEEDBACK_PATTERN_KEY_BACK = 18;

  /// < Feedback pattern when touch hold
  static const int FEEDBACK_PATTERN_HOLD = 19;

  /// < Feedback pattern when press hardware key
  static const int FEEDBACK_PATTERN_HW_TAP = 21;

  /// < Feedback pattern when holding press hardware key
  static const int FEEDBACK_PATTERN_HW_HOLD = 22;

  /// < Feedback pattern when incoming a message
  static const int FEEDBACK_PATTERN_MESSAGE = 23;

  /// < Feedback pattern when incoming an email
  static const int FEEDBACK_PATTERN_EMAIL = 25;

  /// < Feedback pattern when alert wake up call
  static const int FEEDBACK_PATTERN_WAKEUP = 27;

  /// < Feedback pattern when alert schedule alarm
  static const int FEEDBACK_PATTERN_SCHEDULE = 29;

  /// < Feedback pattern when alert timer
  static const int FEEDBACK_PATTERN_TIMER = 31;

  /// < Feedback pattern when alert general event
  static const int FEEDBACK_PATTERN_GENERAL = 33;

  /// < Feedback pattern when power on
  static const int FEEDBACK_PATTERN_POWERON = 36;

  /// < Feedback pattern when power off
  static const int FEEDBACK_PATTERN_POWEROFF = 37;

  /// < Feedback pattern when connecting charger
  static const int FEEDBACK_PATTERN_CHARGERCONN = 38;

  /// < Feedback pattern when occuring charging error
  static const int FEEDBACK_PATTERN_CHARGING_ERROR = 40;

  /// < Feedback pattern when full charged
  static const int FEEDBACK_PATTERN_FULLCHARGED = 42;

  /// < Feedback pattern when low battery
  static const int FEEDBACK_PATTERN_LOWBATT = 44;

  /// < Feedback pattern when lock
  static const int FEEDBACK_PATTERN_LOCK = 46;

  /// < Feedback pattern when unlock
  static const int FEEDBACK_PATTERN_UNLOCK = 47;

  /// < Feedback pattern when turn on vibration mode
  static const int FEEDBACK_PATTERN_VIBRATION_ON = 55;

  /// < Feedback pattern when turn off silent mode
  static const int FEEDBACK_PATTERN_SILENT_OFF = 56;

  /// < Feedback pattern when connecting with bluetooth
  static const int FEEDBACK_PATTERN_BT_CONNECTED = 57;

  /// < Feedback pattern when disconnecting with bluetooth
  static const int FEEDBACK_PATTERN_BT_DISCONNECTED = 58;

  /// < Feedback pattern when list reorder
  static const int FEEDBACK_PATTERN_LIST_REORDER = 62;

  /// < Feedback pattern when list slider sweep
  static const int FEEDBACK_PATTERN_LIST_SLIDER = 63;

  /// < Feedback pattern when pressed volume key
  static const int FEEDBACK_PATTERN_VOLUME_KEY = 64;

  /// < Feedback pattern for short feedback (Since 4.0)
  static const int FEEDBACK_PATTERN_SYSTEM_SHORT = 107;

  /// < Feedback pattern for error (Since 4.0)
  static const int FEEDBACK_PATTERN_SYSTEM_ERROR = 108;

  /// < Feedback pattern for long feedback (Since 4.0)
  static const int FEEDBACK_PATTERN_SYSTEM_LONG = 112;

  /// < Feedback pattern for normal feedback (Since 4.0)
  static const int FEEDBACK_PATTERN_SYSTEM_MID = 113;

  /// < Feedback pattern for end of effect (Since 4.0)
  static const int FEEDBACK_PATTERN_END_EFFECT = 117;

  /// < Feedback pattern for strong buzz (Since 4.0)
  static const int FEEDBACK_PATTERN_GENERAL_STRONG_BUZZ = 135;
  static const int FEEDBACK_PATTERN_END = 10000;
}

/// @brief Enumeration for the Feedback API error codes.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class feedback_error_e {
  /// < Successful
  static const int FEEDBACK_ERROR_NONE = 0;

  /// < Operation failed
  static const int FEEDBACK_ERROR_OPERATION_FAILED = -1;

  /// < Invalid parameter
  static const int FEEDBACK_ERROR_INVALID_PARAMETER = -22;

  /// < Not supported in this device
  static const int FEEDBACK_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Permission denied
  static const int FEEDBACK_ERROR_PERMISSION_DENIED = -13;

  /// < Not initialized
  static const int FEEDBACK_ERROR_NOT_INITIALIZED = -38404095;
}

/// @brief Enumeration for error codes of a media key.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_key_error_e {
  /// < Successful
  static const int MEDIA_KEY_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int MEDIA_KEY_ERROR_INVALID_PARAMETER = -22;

  /// < Reserve/Release failed
  static const int MEDIA_KEY_ERROR_OPERATION_FAILED = -37879807;
}

/// @brief Enumeration for media keys.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_key_e {
  /// < Play key
  static const int MEDIA_KEY_PLAY = 0;

  /// < Stop key
  static const int MEDIA_KEY_STOP = 1;

  /// < Pause key
  static const int MEDIA_KEY_PAUSE = 2;

  /// < Previous key
  static const int MEDIA_KEY_PREVIOUS = 3;

  /// < Next key
  static const int MEDIA_KEY_NEXT = 4;

  /// < Fastforward key
  static const int MEDIA_KEY_FASTFORWARD = 5;

  /// < Rewind key
  static const int MEDIA_KEY_REWIND = 6;

  /// < Playpause key
  static const int MEDIA_KEY_PLAYPAUSE = 7;

  /// < Media key for earjack
  static const int MEDIA_KEY_MEDIA = 8;

  /// < Unknown key
  static const int MEDIA_KEY_UNKNOWN = 9;
}

/// @brief Enumeration for event statuses of a media key.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class media_key_event_e {
  /// < Pressed status
  static const int MEDIA_KEY_STATUS_PRESSED = 0;

  /// < Released status
  static const int MEDIA_KEY_STATUS_RELEASED = 1;

  /// < Unknown status
  static const int MEDIA_KEY_STATUS_UNKNOWN = 2;
}

/// @brief Called when the status of the media key is changed.
///
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @param[in] key The key whose status is changed
/// @param[in] status The status of the key
/// @param[in] user_data The user data passed from the callback registration function
/// @pre media_key_reserve() will invoke this callback function.
/// @see media_key_reserve()
/// @see media_key_release()
typedef media_key_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for peripheral-io error.
/// @since_tizen 4.0
abstract class peripheral_error_e {
  /// < Successful
  static const int PERIPHERAL_ERROR_NONE = 0;

  /// < I/O error
  static const int PERIPHERAL_ERROR_IO_ERROR = -5;

  /// < No such device
  static const int PERIPHERAL_ERROR_NO_DEVICE = -6;

  /// < Try again
  static const int PERIPHERAL_ERROR_TRY_AGAIN = -11;

  /// < Out of memory
  static const int PERIPHERAL_ERROR_OUT_OF_MEMORY = -12;

  /// < Permission denied
  static const int PERIPHERAL_ERROR_PERMISSION_DENIED = -13;

  /// < Device or resource busy
  static const int PERIPHERAL_ERROR_RESOURCE_BUSY = -16;

  /// < Invalid parameter
  static const int PERIPHERAL_ERROR_INVALID_PARAMETER = -22;

  /// < Not supported
  static const int PERIPHERAL_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Unknown error
  static const int PERIPHERAL_ERROR_UNKNOWN = -1073741824;
}

/// @brief Enumeration of GPIO direction options.
/// @since_tizen 4.0
abstract class peripheral_gpio_direction_e {
  /// < Input Mode
  static const int PERIPHERAL_GPIO_DIRECTION_IN = 0;

  /// < Output mode with high value
  static const int PERIPHERAL_GPIO_DIRECTION_OUT_INITIALLY_HIGH = 1;

  /// < Output mode with low value
  static const int PERIPHERAL_GPIO_DIRECTION_OUT_INITIALLY_LOW = 2;
}

/// @brief Enumeration of edge types for the GPIO interrupt.
/// @since_tizen 4.0
abstract class peripheral_gpio_edge_e {
  /// < No interrupt on GPIO
  static const int PERIPHERAL_GPIO_EDGE_NONE = 0;

  /// < Interrupt on rising only
  static const int PERIPHERAL_GPIO_EDGE_RISING = 1;

  /// < Interrupt on falling only
  static const int PERIPHERAL_GPIO_EDGE_FALLING = 2;

  /// < Interrupt on rising & falling
  static const int PERIPHERAL_GPIO_EDGE_BOTH = 3;
}

class _peripheral_gpio_s extends ffi.Opaque {}

/// @brief The handle of a GPIO pin.
/// @since_tizen 4.0
typedef peripheral_gpio_h = ffi.Pointer<_peripheral_gpio_s>;

/// @platform
/// @brief The GPIO interrupted callback called when the GPIO interrupt is triggered.
/// @since_tizen 4.0
///
/// @param[in] gpio The GPIO handle
/// @param[in] error The GPIO error
/// @param[in] user_data The user data passed from the callback registration function
///
/// @see peripheral_gpio_set_interrupted_cb()
typedef peripheral_gpio_interrupted_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            peripheral_gpio_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

class _peripheral_i2c_s extends ffi.Opaque {}

/// @brief The handle of the I2C slave device.
/// @since_tizen 4.0
typedef peripheral_i2c_h = ffi.Pointer<_peripheral_i2c_s>;

class _peripheral_pwm_s extends ffi.Opaque {}

/// @brief Enumeration for Polarity.
/// @since_tizen 4.0
abstract class peripheral_pwm_polarity_e {
  /// < PWM signal start in the active high state (Normal)
  static const int PERIPHERAL_PWM_POLARITY_ACTIVE_HIGH = 0;

  /// < PWM signal start in the active low state (Inversed)
  static const int PERIPHERAL_PWM_POLARITY_ACTIVE_LOW = 1;
}

/// @brief The handle of the PWM peripherals.
/// @since_tizen 4.0
typedef peripheral_pwm_h = ffi.Pointer<_peripheral_pwm_s>;

class _peripheral_uart_s extends ffi.Opaque {}

/// @brief Enumeration for baud rate.
/// @since_tizen 4.0
abstract class peripheral_uart_baud_rate_e {
  /// < The number of signal in one second is 0
  static const int PERIPHERAL_UART_BAUD_RATE_0 = 0;

  /// < The number of signal in one second is 50
  static const int PERIPHERAL_UART_BAUD_RATE_50 = 1;

  /// < The number of signal in one second is 75
  static const int PERIPHERAL_UART_BAUD_RATE_75 = 2;

  /// < The number of signal in one second is 110
  static const int PERIPHERAL_UART_BAUD_RATE_110 = 3;

  /// < The number of signal in one second is 134
  static const int PERIPHERAL_UART_BAUD_RATE_134 = 4;

  /// < The number of signal in one second is 150
  static const int PERIPHERAL_UART_BAUD_RATE_150 = 5;

  /// < The number of signal in one second is 200
  static const int PERIPHERAL_UART_BAUD_RATE_200 = 6;

  /// < The number of signal in one second is 300
  static const int PERIPHERAL_UART_BAUD_RATE_300 = 7;

  /// < The number of signal in one second is 600
  static const int PERIPHERAL_UART_BAUD_RATE_600 = 8;

  /// < The number of signal in one second is 1200
  static const int PERIPHERAL_UART_BAUD_RATE_1200 = 9;

  /// < The number of signal in one second is 1800
  static const int PERIPHERAL_UART_BAUD_RATE_1800 = 10;

  /// < The number of signal in one second is 2400
  static const int PERIPHERAL_UART_BAUD_RATE_2400 = 11;

  /// < The number of signal in one second is 4800
  static const int PERIPHERAL_UART_BAUD_RATE_4800 = 12;

  /// < The number of signal in one second is 9600
  static const int PERIPHERAL_UART_BAUD_RATE_9600 = 13;

  /// < The number of signal in one second is 19200
  static const int PERIPHERAL_UART_BAUD_RATE_19200 = 14;

  /// < The number of signal in one second is 38400
  static const int PERIPHERAL_UART_BAUD_RATE_38400 = 15;

  /// < The number of signal in one second is 57600
  static const int PERIPHERAL_UART_BAUD_RATE_57600 = 16;

  /// < The number of signal in one second is 115200
  static const int PERIPHERAL_UART_BAUD_RATE_115200 = 17;

  /// < The number of signal in one second is 230400
  static const int PERIPHERAL_UART_BAUD_RATE_230400 = 18;
}

/// @brief Enumeration for byte size.
/// @since_tizen 4.0
abstract class peripheral_uart_byte_size_e {
  /// < 5 data bits
  static const int PERIPHERAL_UART_BYTE_SIZE_5BIT = 0;

  /// < 6 data bits
  static const int PERIPHERAL_UART_BYTE_SIZE_6BIT = 1;

  /// < 7 data bits
  static const int PERIPHERAL_UART_BYTE_SIZE_7BIT = 2;

  /// < 8 data bits
  static const int PERIPHERAL_UART_BYTE_SIZE_8BIT = 3;
}

/// @brief Enumeration for parity bit.
/// @since_tizen 4.0
abstract class peripheral_uart_parity_e {
  /// < No parity is used
  static const int PERIPHERAL_UART_PARITY_NONE = 0;

  /// < Even parity is used
  static const int PERIPHERAL_UART_PARITY_EVEN = 1;

  /// < ODD parity is used
  static const int PERIPHERAL_UART_PARITY_ODD = 2;
}

/// @brief Enumeration for stop bits.
/// @since_tizen 4.0
abstract class peripheral_uart_stop_bits_e {
  /// < One stop bit
  static const int PERIPHERAL_UART_STOP_BITS_1BIT = 0;

  /// < Two stop bits
  static const int PERIPHERAL_UART_STOP_BITS_2BIT = 1;
}

/// @brief Enumeration for hardware flow control.
/// @since_tizen 4.0
abstract class peripheral_uart_hardware_flow_control_e {
  /// < No hardware flow control
  static const int PERIPHERAL_UART_HARDWARE_FLOW_CONTROL_NONE = 0;

  /// < Automatic RTS/CTS hardware flow control
  static const int PERIPHERAL_UART_HARDWARE_FLOW_CONTROL_AUTO_RTSCTS = 1;
}

/// @brief Enumeration for software flow control.
/// @since_tizen 4.0
abstract class peripheral_uart_software_flow_control_e {
  /// < No software flow control
  static const int PERIPHERAL_UART_SOFTWARE_FLOW_CONTROL_NONE = 0;

  /// < XON/XOFF software flow control
  static const int PERIPHERAL_UART_SOFTWARE_FLOW_CONTROL_XONXOFF = 1;
}

/// @brief The handle to the UART peripherals.
/// @since_tizen 4.0
typedef peripheral_uart_h = ffi.Pointer<_peripheral_uart_s>;

class _peripheral_spi_s extends ffi.Opaque {}

/// @brief Enumeration of SPI transfer modes.
/// @since_tizen 4.0
abstract class peripheral_spi_mode_e {
  /// < CPOL = 0, CPHa = 0 Mode
  static const int PERIPHERAL_SPI_MODE_0 = 0;

  /// < CPOL = 0, CPHa = 1 Mode
  static const int PERIPHERAL_SPI_MODE_1 = 1;

  /// < CPOL = 1, CPHa = 0 Mode
  static const int PERIPHERAL_SPI_MODE_2 = 2;

  /// < CPOL = 1, CPHa = 1 Mode
  static const int PERIPHERAL_SPI_MODE_3 = 3;
}

/// @brief Enumeration of bit orders.
/// @since_tizen 4.0
abstract class peripheral_spi_bit_order_e {
  /// < Use most siginificant bit first
  static const int PERIPHERAL_SPI_BIT_ORDER_MSB = 0;

  /// < Use least significant bit first
  static const int PERIPHERAL_SPI_BIT_ORDER_LSB = 1;
}

/// @brief The handle of a SPI peripherals.
/// @since_tizen 4.0
typedef peripheral_spi_h = ffi.Pointer<_peripheral_spi_s>;

/// @brief        Enumeration for error codes for runtime information.
/// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class runtime_info_error_e {
  /// < Successful
  static const int RUNTIME_INFO_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int RUNTIME_INFO_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int RUNTIME_INFO_ERROR_OUT_OF_MEMORY = -12;

  /// < An input/output error occurred when read value from system
  static const int RUNTIME_INFO_ERROR_IO_ERROR = -5;

  /// < Remote I/O error occurred
  static const int RUNTIME_INFO_ERROR_REMOTE_IO = -121;

  /// < No permission to use the api
  static const int RUNTIME_INFO_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported parameter
  static const int RUNTIME_INFO_ERROR_NOT_SUPPORTED = -1073741822;

  /// < No data available (Since 3.0)
  static const int RUNTIME_INFO_ERROR_NO_DATA = -61;
}

/// @brief        Enumeration for keys for runtime information.
/// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class runtime_info_key_e {
  /// <Indicates whether Bluetooth is enabled.
  static const int RUNTIME_INFO_KEY_BLUETOOTH_ENABLED = 2;

  /// <Indicates whether Wi-Fi hotspot is enabled.
  static const int RUNTIME_INFO_KEY_WIFI_HOTSPOT_ENABLED = 3;

  /// <Indicates whether Bluetooth tethering is enabled.
  static const int RUNTIME_INFO_KEY_BLUETOOTH_TETHERING_ENABLED = 4;

  /// <Indicates whether USB tethering is enabled.
  static const int RUNTIME_INFO_KEY_USB_TETHERING_ENABLED = 5;

  /// <Indicates whether the location service is allowed to use location data from GPS satellites. (Deprecated since 4.0)
  static const int RUNTIME_INFO_KEY_LOCATION_SERVICE_ENABLED = 6;

  /// <Indicates whether the location service is allowed to use location data from cellular and Wi-Fi. (Deprecated since 4.0)
  static const int RUNTIME_INFO_KEY_LOCATION_NETWORK_POSITION_ENABLED = 8;

  /// <Indicates Whether the packet data through 3G network is enabled.
  static const int RUNTIME_INFO_KEY_PACKET_DATA_ENABLED = 9;

  /// <Indicates whether data roaming is enabled.
  static const int RUNTIME_INFO_KEY_DATA_ROAMING_ENABLED = 10;

  /// <Indicates whether vibration is enabled.
  static const int RUNTIME_INFO_KEY_VIBRATION_ENABLED = 12;

  /// <Indicates whether audio jack is connected.
  static const int RUNTIME_INFO_KEY_AUDIO_JACK_CONNECTED = 17;

  /// <Indicates the current status of GPS.
  static const int RUNTIME_INFO_KEY_GPS_STATUS = 18;

  /// <Indicates the battery is currently charging.
  static const int RUNTIME_INFO_KEY_BATTERY_IS_CHARGING = 19;

  /// <Indicates whether TV out is connected.
  static const int RUNTIME_INFO_KEY_TV_OUT_CONNECTED = 20;

  /// <Indicates the current status of audio jack.
  static const int RUNTIME_INFO_KEY_AUDIO_JACK_STATUS = 21;

  /// <Indicates whether USB is connected.
  static const int RUNTIME_INFO_KEY_USB_CONNECTED = 23;

  /// <Indicates whether charger is connected.
  static const int RUNTIME_INFO_KEY_CHARGER_CONNECTED = 24;

  /// <Indicates whether auto rotation is enabled.
  static const int RUNTIME_INFO_KEY_AUTO_ROTATION_ENABLED = 26;
}

/// @brief        Enumeration for Wi-Fi status.
/// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class runtime_info_wifi_status_e {
  /// < Wi-Fi is disabled.
  static const int RUNTIME_INFO_WIFI_STATUS_DISABLED = 0;

  /// < Wi-Fi is enabled and network connection is not established.
  static const int RUNTIME_INFO_WIFI_STATUS_UNCONNECTED = 1;

  /// < Network connection is established in Wi-Fi network.
  static const int RUNTIME_INFO_WIFI_STATUS_CONNECTED = 2;
}

/// @brief        Enumeration for GPS status.
/// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class runtime_info_gps_status_e {
  /// < GPS is disabled.
  static const int RUNTIME_INFO_GPS_STATUS_DISABLED = 0;

  /// < GPS is searching for satellites.
  static const int RUNTIME_INFO_GPS_STATUS_SEARCHING = 1;

  /// < GPS connection is established.
  static const int RUNTIME_INFO_GPS_STATUS_CONNECTED = 2;
}

/// @brief        Enumeration for audio jack status.
/// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
abstract class runtime_info_audio_jack_status_e {
  /// < Audio jack is not connected
  static const int RUNTIME_INFO_AUDIO_JACK_STATUS_UNCONNECTED = 0;

  /// < 3-conductor wire is connected.
  static const int RUNTIME_INFO_AUDIO_JACK_STATUS_CONNECTED_3WIRE = 1;

  /// < 4-conductor wire is connected.
  static const int RUNTIME_INFO_AUDIO_JACK_STATUS_CONNECTED_4WIRE = 2;
}

/// @brief        Called when the runtime information changes.
/// @since_tizen  @if WEARABLE 2.3.1 @else 2.3 @endif
///
/// @param[in] key        The type of notification
/// @param[in] user_data  The user data passed from the callback registration function
///
/// @pre  runtime_info_set_changed_cb() will invoke this callback function.
/// @see  runtime_info_set_changed_cb()
/// @see  runtime_info_unset_changed_cb()
typedef runtime_info_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief        Structure for memory information.
/// @since_tizen  @if WEARABLE 3.0 @else 2.4 @endif
class runtime_memory_info_s extends ffi.Struct {
  /// < Total memory (KiB)
  @ffi.Int()
  external int total;

  /// < Used memory (KiB)
  @ffi.Int()
  external int used;

  /// < Free memory (KiB)
  @ffi.Int()
  external int free;

  /// < Cache memory (KiB)
  @ffi.Int()
  external int cache;

  /// < Swap memory (KiB)
  @ffi.Int()
  external int swap;
}

/// @brief        Structure for memory information per process.
/// @since_tizen  @if WEARABLE 3.0 @else 2.4 @endif
class process_memory_info_s extends ffi.Struct {
  /// < Virtual memory size (KiB)
  @ffi.Int()
  external int vsz;

  /// < Resident set size (KiB)
  @ffi.Int()
  external int rss;

  /// < Proportional set size (KiB)
  @ffi.Int()
  external int pss;

  /// < Not modified and mapped by other processes (KiB)
  @ffi.Int()
  external int shared_clean;

  /// < Modified and mapped by other processes (KiB)
  @ffi.Int()
  external int shared_dirty;

  /// < Not modified and available only to that process (KiB)
  @ffi.Int()
  external int private_clean;

  /// < Modified and available only to that process (KiB)
  @ffi.Int()
  external int private_dirty;
}

/// @brief        Structure for CPU usage.
/// @since_tizen  @if WEARABLE 3.0 @else 2.4 @endif
class runtime_cpu_usage_s extends ffi.Struct {
  /// < Time running un-niced user processes (Percent)
  @ffi.Double()
  external double user;

  /// < Time running kernel processes (Percent)
  @ffi.Double()
  external double system;

  /// < Time running niced user processes (Percent)
  @ffi.Double()
  external double nice;

  /// < Time waiting for I/O completion (Percent)
  @ffi.Double()
  external double iowait;
}

/// @brief        Structure for CPU usage per process.
/// @since_tizen  @if WEARABLE 3.0 @else 2.4 @endif
class process_cpu_usage_s extends ffi.Struct {
  /// < Amount of time that this process has been scheduled in user mode (clock ticks)
  @ffi.Int()
  external int utime;

  /// < Amount of time that this process has been scheduled in kernel mode (clock ticks)
  @ffi.Int()
  external int stime;
}

class app_usages_s extends ffi.Opaque {}

/// @brief        Handle for app usage information.
/// @since_tizen  4.0
typedef app_usage_h = ffi.Pointer<app_usages_s>;

/// @brief   Enumeration for errors.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sensor_error_e {
  /// < Successful
  static const int SENSOR_ERROR_NONE = 0;

  /// < I/O error
  static const int SENSOR_ERROR_IO_ERROR = -5;

  /// < Invalid parameter
  static const int SENSOR_ERROR_INVALID_PARAMETER = -22;

  /// < Not supported
  static const int SENSOR_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Permission denied
  static const int SENSOR_ERROR_PERMISSION_DENIED = -13;

  /// < Out of memory
  static const int SENSOR_ERROR_OUT_OF_MEMORY = -12;

  /// < No data available
  /// @if MOBILE (Since 3.0) @elseif WEARABLE (Since 2.3.2) @endif
  static const int SENSOR_ERROR_NO_DATA = -61;

  /// < Sensor doesn't need calibration
  static const int SENSOR_ERROR_NOT_NEED_CALIBRATION = -38010877;

  /// < Operation failed
  static const int SENSOR_ERROR_OPERATION_FAILED = -38010874;

  /// < The sensor is supported, but currently not available
  /// @if MOBILE (Since 3.0) @elseif WEARABLE (Since 2.3.2) @endif
  static const int SENSOR_ERROR_NOT_AVAILABLE = -38010873;
}

/// @brief   Enumeration for proximity sensor events.
/// @details In its #sensor_event_s, #SENSOR_PROXIMITY reports the existence of
/// nearby objects in front of the sensor as one of the followings.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sensor_proximity_e {
  /// < An object is placed near the proximity sensor
  static const int SENSOR_PROXIMITY_NEAR = 0;

  /// < No object is placed near the proximity sensor
  static const int SENSOR_PROXIMITY_FAR = 5;
}

/// @brief   Enumeration for pedestrian state.
/// @details In its #sensor_event_s, #SENSOR_HUMAN_PEDOMETER reports the user's
/// pedestrian state as one of the followings.
/// @since_tizen 3.0
abstract class sensor_pedometer_state_e {
  /// < Uncertain
  static const int SENSOR_PEDOMETER_STATE_UNKNOWN = -1;

  /// < The user is not moving
  static const int SENSOR_PEDOMETER_STATE_STOP = 0;

  /// < The user is walking
  static const int SENSOR_PEDOMETER_STATE_WALK = 1;

  /// < The user is running
  static const int SENSOR_PEDOMETER_STATE_RUN = 2;
}

/// @brief   Enumeration for sleep state.
/// @details In its #sensor_event_s, #SENSOR_HUMAN_SLEEP_MONITOR reports the user's
/// sleep state as one of the followings.
/// @since_tizen 3.0
abstract class sensor_sleep_state_e {
  /// < Uncertain
  static const int SENSOR_SLEEP_STATE_UNKNOWN = -1;

  /// < The user is awake
  static const int SENSOR_SLEEP_STATE_WAKE = 0;

  /// < The user is asleep
  static const int SENSOR_SLEEP_STATE_SLEEP = 1;
}

/// @brief   Enumeration for sensor types.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sensor_type_e {
  /// < All sensors. This can be used to retrieve #sensor_h for all available sensors.
  static const int SENSOR_ALL = -1;

  /// < Accelerometer
  static const int SENSOR_ACCELEROMETER = 0;

  /// < Gravity sensor
  static const int SENSOR_GRAVITY = 1;

  /// < Linear acceleration sensor
  static const int SENSOR_LINEAR_ACCELERATION = 2;

  /// < Magnetic sensor
  static const int SENSOR_MAGNETIC = 3;

  /// < Rotation vector sensor
  static const int SENSOR_ROTATION_VECTOR = 4;

  /// < Orientation sensor
  static const int SENSOR_ORIENTATION = 5;

  /// < Gyroscope
  static const int SENSOR_GYROSCOPE = 6;

  /// < Light sensor
  static const int SENSOR_LIGHT = 7;

  /// < Proximity sensor
  static const int SENSOR_PROXIMITY = 8;

  /// < Pressure sensor
  static const int SENSOR_PRESSURE = 9;

  /// < Ultraviolet sensor
  static const int SENSOR_ULTRAVIOLET = 10;

  /// < Temperature sensor
  static const int SENSOR_TEMPERATURE = 11;

  /// < Humidity sensor
  static const int SENSOR_HUMIDITY = 12;

  /// < Heart-rate monitor @if MOBILE (Since 2.3.1) @endif
  /// @n Privilege : http://tizen.org/privilege/healthinfo
  static const int SENSOR_HRM = 13;

  /// < Green LED sensor of HRM @if MOBILE (Since 2.3.1) @endif
  /// @n Privilege : http://tizen.org/privilege/healthinfo
  static const int SENSOR_HRM_LED_GREEN = 14;

  /// < Infra-Red LED sensor of HRM @if MOBILE (Since 2.3.1) @endif
  /// @n Privilege : http://tizen.org/privilege/healthinfo
  static const int SENSOR_HRM_LED_IR = 15;

  /// < Red LED sensor of HRM @if MOBILE (Since 2.3.1) @endif
  /// @n Privilege : http://tizen.org/privilege/healthinfo
  static const int SENSOR_HRM_LED_RED = 16;

  /// < Uncalibrated Gyroscope sensor
  /// @if MOBILE (Since 2.4) @elseif WEARABLE (Since 2.3.2) @endif
  static const int SENSOR_GYROSCOPE_UNCALIBRATED = 17;

  /// < Uncalibrated Geomagnetic sensor
  /// @if MOBILE (Since 2.4) @elseif WEARABLE (Since 2.3.2) @endif
  static const int SENSOR_GEOMAGNETIC_UNCALIBRATED = 18;

  /// < Gyroscope-based rotation vector sensor
  /// @if MOBILE (Since 2.4) @elseif WEARABLE (Since 2.3.2) @endif
  static const int SENSOR_GYROSCOPE_ROTATION_VECTOR = 19;

  /// < Geomagnetic-based rotation vector sensor
  /// @if MOBILE (Since 2.4) @elseif WEARABLE (Since 2.3.2) @endif
  static const int SENSOR_GEOMAGNETIC_ROTATION_VECTOR = 20;

  /// < Significant motion sensor (Since 4.0)
  static const int SENSOR_SIGNIFICANT_MOTION = 256;

  /// < Pedometer (Since 3.0)
  /// @n Privilege : http://tizen.org/privilege/healthinfo
  static const int SENSOR_HUMAN_PEDOMETER = 768;

  /// < Sleep monitor (Since 3.0)
  /// @n Privilege : http://tizen.org/privilege/healthinfo
  static const int SENSOR_HUMAN_SLEEP_MONITOR = 769;

  /// < Sleep detector (Since 3.0)
  /// @n Privilege : http://tizen.org/privilege/healthinfo
  static const int SENSOR_HUMAN_SLEEP_DETECTOR = 770;

  /// < Stress monitor (Since 3.0)
  /// @n Privilege : http://tizen.org/privilege/healthinfo
  static const int SENSOR_HUMAN_STRESS_MONITOR = 771;

  /// < End of sensor enum values (Deprecated since 3.0)
  static const int SENSOR_LAST = 772;

  /// < Custom sensor (Deprecated since 3.0)
  static const int SENSOR_CUSTOM = 10000;
}

/// @brief   Sensor handle.
/// @details The handle for controlling a specific sensor can be retrieved using sensor_get_default_sensor().@n
/// The function returns the handle of the default sensor of a given type, and usually,
/// a device has one sensor for one type.
/// However, if the device supports multiple sensors of the same type,
/// sensor_get_sensor_list() function can be used to get the list of all the sensors of the type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef sensor_h = ffi.Pointer<ffi.Void>;

/// @brief  Called when a new sensor is added.
/// @since_tizen 4.0
///
/// @remarks @a uri should not be freed and can be used only in the callback.
/// To use outside the callback, make a copy.
///
/// @param[in]  uri         The URI of the newly added sensor
/// @param[in]  user_data   The user data had passed to sensor_add_sensor_added_cb().
///
/// @pre   A callback function needs to be set using sensor_add_sensor_added_cb().
/// @see   sensor_add_sensor_added_cb()
/// @see   sensor_remove_sensor_added_cb()
typedef sensor_added_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief  Called when a sensor is removed.
/// @since_tizen 4.0
///
/// @remarks @a uri should not be freed and can be used only in the callback.
/// To use outside the callback, make a copy.
///
/// @param[in]  uri        The URI of the removed sensor
/// @param[in]  user_data  The user data had passed to sensor_add_sensor_removed_cb()
///
/// @pre   A callback function needs to be set using sensor_add_sensor_removed_cb().
/// @see   sensor_add_sensor_removed_cb()
/// @see   sensor_remove_sensor_removed_cb()
typedef sensor_removed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

class sensor_listener_s extends ffi.Opaque {}

/// @brief   Sensor data event delivered via sensor_event_cb().
/// @details A sensor data is delivered as a structure, which contains the accuracy of the data,
/// the time when the data was observed, and the data array.
/// The data array is a fixed size @c float array, and the number of data fields
/// stored in the array varies with the sensor type.
/// For example, #SENSOR_ACCELEROMETER reports 3-dimensional data,
/// #sensor_event_s::value_count is thus set to 3.@n
/// Note that, even if the data values are @c float, in some cases,
/// it may contain one or more categorical data as in #sensor_proximity_e.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @see     #sensor_pedometer_state_e
/// @see     #sensor_sleep_state_e
class sensor_event_s extends ffi.Struct {
  /// < Accuracy of sensor data
  @ffi.Int()
  external int accuracy;

  /// < Time when the sensor data was observed
  @ffi.UnsignedLongLong()
  external int timestamp;

  /// < Number of sensor data values stored in #sensor_event_s::values
  @ffi.Int()
  external int value_count;

  @ffi.Array.multi([16])
  external ffi.Array<ffi.Float> values;
}

/// @brief   Enumeration for sensor data accuracy.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sensor_data_accuracy_e {
  /// < Undefined
  static const int SENSOR_DATA_ACCURACY_UNDEFINED = -1;

  /// < Not accurate
  static const int SENSOR_DATA_ACCURACY_BAD = 0;

  /// < Moderately accurate
  static const int SENSOR_DATA_ACCURACY_NORMAL = 1;

  /// < Highly accurate
  static const int SENSOR_DATA_ACCURACY_GOOD = 2;

  /// < Very highly accurate
  static const int SENSOR_DATA_ACCURACY_VERYGOOD = 3;
}

/// @brief   Enumeration for sensor listener behavior attributes
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
abstract class sensor_attribute_e {
  /// < Reference orientation of sensor data to be reported.@n
  /// See #sensor_axis_e for available attribute values.
  static const int SENSOR_ATTRIBUTE_AXIS_ORIENTATION = 1;

  /// < Pause-and-resume policy of sensors.@n
  /// See #sensor_pause_e for available attribute values.
  static const int SENSOR_ATTRIBUTE_PAUSE_POLICY = 2;
}

abstract class sensor_option_e {
  /// < Does not receive data when the LCD is off and in the power save mode
  static const int SENSOR_OPTION_DEFAULT = 0;

  /// < Receives data when the LCD is off
  static const int SENSOR_OPTION_ON_IN_SCREEN_OFF = 1;

  /// < Receives data in the power save mode
  static const int SENSOR_OPTION_ON_IN_POWERSAVE_MODE = 2;

  /// < Receives data when the LCD is off and in the power save mode
  static const int SENSOR_OPTION_ALWAYS_ON = 3;
}

/// @brief   Enumeration for reference orientations of sensor data
/// @details The sensor's physical orientation may differ from what applications are aware of,
/// in cases that the device has a rotated screen, physically or logically.
/// For example, a watch device may have right hand mode, which logically rotates
/// the display 180 degrees.
/// Applications may not be aware of such situations, thus they may receives
/// sensor data inverted in X and Y directions.
/// With #SENSOR_AXIS_DISPLAY_ORIENTED option, applications can get data that
/// are properly aligned with the orientation of which they are aware.@n
/// By default, #SENSOR_AXIS_DISPLAY_ORIENTED is used.
/// If you need to use the data that are not affected by display orientations,
/// #SENSOR_AXIS_DEVICE_ORIENTED needs to be set.
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
abstract class sensor_axis_e {
  /// < Using the device orientation as the reference coordinate system
  static const int SENSOR_AXIS_DEVICE_ORIENTED = 1;

  /// < Using the display orientation as the reference coordinate system
  static const int SENSOR_AXIS_DISPLAY_ORIENTED = 2;
}

/// @brief   Enumeration for pause policies of sensor listeners
/// @details To be power-efficient, you can set the policy of how to pause and resume
/// a sensor listener regarding the system status.
/// By default, #SENSOR_PAUSE_ALL is used to obtain the maximum power efficiency.
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
abstract class sensor_pause_e {
  /// < The sensor will not pause, unless the system goes into sleep mode
  static const int SENSOR_PAUSE_NONE = 0;

  /// < The sensor pauses while the display is off
  static const int SENSOR_PAUSE_ON_DISPLAY_OFF = 1;

  /// < The sensor pauses while the power-save mode is enabled
  static const int SENSOR_PAUSE_ON_POWERSAVE_MODE = 2;

  /// < The sensor pauses in all the above cases
  static const int SENSOR_PAUSE_ALL = 3;
}

/// @brief   Sensor listener handle.
/// @details For each #sensor_h, one or more sensor listeners can be created by using sensor_create_listener().
/// Then the sensor's data can observed asynchronously, can be read synchronously if available, via the listener.
/// Applications are also able to control the behavior of each sensor, for example,
/// update interval of sensor readings.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef sensor_listener_h = ffi.Pointer<sensor_listener_s>;

/// @brief   Called when a sensor event occurs.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @param[in] sensor    The corresponding sensor handle
/// @param[in] event     A sensor event
/// @param[in] data      The user data had passed to sensor_listener_set_event_cb()
///
/// @pre     The sensor needs to be started regarding a listener handle, using sensor_listener_start().
typedef sensor_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            sensor_h, ffi.Pointer<sensor_event_s>, ffi.Pointer<ffi.Void>)>>;

/// @brief   Called when the accuracy of a sensor changes.
/// @details Sensors can be affected by the environment.
/// For example, #SENSOR_MAGNETIC is sensitive to any surrounding objects that can influence
/// electromagnetic fields. This function is called if the accuracy of the corresponding sensor is changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
///
/// @param[in]   sensor      A sensor handle
/// @param[in]   timestamp   The time in milliseconds when the accuracy changed
/// @param[in]   accuracy    The current accuracy of the sensor
/// @param[in]   data        The user data had passed to sensor_listener_set_accuracy_cb()
typedef sensor_accuracy_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            sensor_h, ffi.UnsignedLongLong, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

class _sensor_provider_s extends ffi.Opaque {}

/// @brief   Sensor provider handle.
/// @details One or more sensor providers can be created by using sensor_create_provider().
/// The sensor's data can be published to listeners, via the provider.
/// @since_tizen 4.0
///
/// @see  sensor_create_provider()
/// @see  sensor_destroy_provider()
typedef sensor_provider_h = ffi.Pointer<_sensor_provider_s>;

/// @brief    Called when a sensor listener starts the sensor provider.
/// @since_tizen 4.0
///
/// @remarks @a provider is the object created with sensor_create_provider()
/// and is the object for which the callback was triggered.
///
/// @param[in]  provider    The sensor provider handle
/// @param[in]  user_data   The user data to be passed to the callback function
///
/// @pre     A callback function needs to be set using sensor_provider_set_start_cb().
/// @see     sensor_provider_set_start_cb()
typedef sensor_provider_start_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(sensor_provider_h, ffi.Pointer<ffi.Void>)>>;

/// @brief    Called when a sensor listener stops the sensor provider.
/// @since_tizen 4.0
///
/// @remarks @a provider is the object created with sensor_create_provider()
/// and is the object for which the callback was triggered.
///
/// @param[in]  provider     The sensor provider handle
/// @param[in]  user_data    The user data to be passed to the callback function
///
/// @pre    A callback function needs to be set using sensor_provider_set_stop_cb().
/// @see    sensor_provider_set_stop_cb()
typedef sensor_provider_stop_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(sensor_provider_h, ffi.Pointer<ffi.Void>)>>;

/// @brief    Called when the interval of the sensor provider is changed.
/// @since_tizen 4.0
///
/// @remarks @a provider is the object created with sensor_create_provider()
/// and is the object for which the callback was triggered.
///
/// @param[in]  provider    The sensor provider handle
/// @param[in]  interval_ms The interval
/// @param[in]  user_data   The user data to be passed to the callback function
///
/// @pre    A callback function needs to be set using sensor_provider_set_interval_changed_cb().
/// @see    sensor_provider_set_interval_changed_cb()
typedef sensor_provider_interval_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            sensor_provider_h, ffi.UnsignedInt, ffi.Pointer<ffi.Void>)>>;

/// @brief   Enumeration for option parameters for sensor recording.
/// @details None, one, or more option parameters can be set to #sensor_recorder_option_h,
/// then applications can request to record a specific sensor with the parameters via
/// sensor_recorder_start().
/// If a parameter is not supported for the specified sensor type, it will be ignored.
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
abstract class sensor_recorder_option_e {
  /// < Desired retention period for the recorded sensor data (hours); int;
  static const int SENSOR_RECORDER_OPTION_RETENTION_PERIOD = 0;

  /// < Desired interval between data records (minutes); int; see #sensor_recorder_interval_e
  static const int SENSOR_RECORDER_OPTION_INTERVAL = 1;
}

/// @brief   Enumeration for intervals between data records.
/// @details Some sensor types including #SENSOR_HRM may not fit to continuous monitoring and recording.
/// To reduce the battery use for recording such sensors, recording interval between each
/// sensor data is chosen. For example, an application set the interval of 1 hour,
/// the platform tries to retrieve the sensor data only once per hour, thus it will be more
/// battery efficient than to listen the sensor data continuously.@n
/// If the application does not set the interval explicitly, the default value is chosen.
/// The default values are differ from sensor to sensor.
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
/// @remarks If more than one applications set different intervals, the shortest value is chosen.
abstract class sensor_recorder_interval_e {
  /// < 10 Minutes
  static const int SENSOR_RECORDER_INTERVAL_10_MINUTES = 10;

  /// < 1 Hour
  static const int SENSOR_RECORDER_INTERVAL_1_HOUR = 60;

  /// < 3 Hours
  static const int SENSOR_RECORDER_INTERVAL_3_HOURS = 180;

  /// < 6 Hours
  static const int SENSOR_RECORDER_INTERVAL_6_HOURS = 360;

  /// < 12 Hours
  static const int SENSOR_RECORDER_INTERVAL_12_HOURS = 720;

  /// < 1 Day
  static const int SENSOR_RECORDER_INTERVAL_1_DAY = 1440;
}

/// @brief   Enumeration for filtering and aggregation parameters for querying sensor records.
/// @details None, one, or more query parameters can be set to #sensor_recorder_query_h,
/// to specify the data to be retrieved via sensor_recorder_read().
/// If a necessary parameter is not set, the default value is chosen.
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
abstract class sensor_recorder_query_e {
  /// < Start time of the data to be queried (Epoch); time_t; If unspecified, 1 day ago
  static const int SENSOR_RECORDER_QUERY_START_TIME = 0;

  /// < End time of the data to be queried (Epoch); time_t; If unspecified, the current time
  static const int SENSOR_RECORDER_QUERY_END_TIME = 1;

  /// < The anchor time to slice the querying duration of time (Epoch); time_t;
  /// It needs to be set with #SENSOR_RECORDER_QUERY_TIME_INTERVAL, otherwise, it is ignored
  static const int SENSOR_RECORDER_QUERY_ANCHOR_TIME = 2;

  /// < The interval of each sliced querying duration (minutes); int
  static const int SENSOR_RECORDER_QUERY_TIME_INTERVAL = 3;
}

/// @brief   Enumeration for data attributes can be contained in #sensor_recorder_data_h.
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
/// @see     sensor_recorder_data_get_int()
/// @see     sensor_recorder_data_get_double()
abstract class sensor_recorder_data_e {
  /// < Count of both walking and running steps; int
  /// @if WEARABLE (Since 3.0) @endif
  static const int SENSOR_RECORDER_DATA_STEPS = 0;

  /// < Count of walking steps; int
  /// @if WEARABLE (Since 3.0) @endif
  static const int SENSOR_RECORDER_DATA_WALK_STEPS = 1;

  /// < Count of running steps; int
  /// @if WEARABLE (Since 3.0) @endif
  static const int SENSOR_RECORDER_DATA_RUN_STEPS = 2;

  /// < Distance walked or ran (m); double
  /// @if WEARABLE (Since 3.0) @endif
  static const int SENSOR_RECORDER_DATA_DISTANCE = 3;

  /// < Calorie burned (kcal); double
  /// @if WEARABLE (Since 3.0) @endif
  static const int SENSOR_RECORDER_DATA_CALORIE = 4;

  /// < Heart Rate (BPM); int
  /// @if WEARABLE (Since 3.0) @endif
  static const int SENSOR_RECORDER_DATA_HEART_RATE = 16;

  /// < Sleep state; int; One of #sensor_sleep_state_e
  /// @if WEARABLE (Since 3.0) @endif
  static const int SENSOR_RECORDER_DATA_SLEEP_STATE = 32;

  /// < Pressure; double
  static const int SENSOR_RECORDER_DATA_PRESSURE = 48;

  /// < Max pressure; double
  static const int SENSOR_RECORDER_DATA_MAX_PRESSURE = 49;

  /// < Min pressure; double
  static const int SENSOR_RECORDER_DATA_MIN_PRESSURE = 50;

  /// < Average pressure; double
  static const int SENSOR_RECORDER_DATA_AVERAGE_PRESSURE = 51;
}

/// @brief   Option handle to contain recording policies and parameters.
/// @details one or more sensor options can be created by using sensor_recorder_create_option().
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
typedef sensor_recorder_option_h = ffi.Pointer<ffi.Void>;

/// @brief   Query handle to contain filtering and aggregation parameters for recorded data.
/// @details one or more sensor options can be created by using sensor_recorder_create_query().
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
typedef sensor_recorder_query_h = ffi.Pointer<ffi.Void>;

/// @brief   Called when the query results are retrieved.
/// @details One of the following errors can be delivered.\n
/// #SENSOR_ERROR_NONE, Successful\n
/// #SENSOR_ERROR_OPERATION_FAILED, Operation failed\n
/// #SENSOR_ERROR_NO_DATA, No data retrieved.
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
///
/// @param[in]  type        Sensor type
/// @param[in]  data        Retrieved data record
/// @param[in]  remains     Number of remaining records to be delivered
/// @param[in]  error       Error
/// @param[in]  user_data   The user data passed from sensor_recorder_read() or sensor_recorder_read_sync()
///
/// @return  If @c true, it continues to iterate to the next record; If @c false, the iteration stops
typedef sensor_recorder_data_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int32, sensor_recorder_data_h, ffi.Int, ffi.Int32,
            ffi.Pointer<ffi.Void>)>>;

/// @brief   Data handle to contain retrieved sensor records.
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
typedef sensor_recorder_data_h = ffi.Pointer<ffi.Void>;

/// @brief   Enumeration of the axis used in sensor_util_remap_coordinate_system().
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class sensor_util_axis_e {
  /// < -X
  static const int SENSOR_UTIL_AXIS_MINUS_X = 0;

  /// < -Y
  static const int SENSOR_UTIL_AXIS_MINUS_Y = 1;

  /// < -Z
  static const int SENSOR_UTIL_AXIS_MINUS_Z = 2;

  /// < +X
  static const int SENSOR_UTIL_AXIS_X = 3;

  /// < +Y
  static const int SENSOR_UTIL_AXIS_Y = 4;

  /// < +Z
  static const int SENSOR_UTIL_AXIS_Z = 5;
  static const int sensor_util_axis_minus_x = 0;
  static const int sensor_util_axis_minus_y = 1;
  static const int sensor_util_axis_minus_z = 2;
  static const int sensor_util_axis_x = 3;
  static const int sensor_util_axis_y = 4;
  static const int sensor_util_axis_z = 5;
}

/// @brief Enumeration for Storage of error codes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class storage_error_e {
  /// < Successful
  static const int STORAGE_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int STORAGE_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int STORAGE_ERROR_OUT_OF_MEMORY = -12;

  /// < Storage not supported
  static const int STORAGE_ERROR_NOT_SUPPORTED = -6;

  /// < Operation failed
  static const int STORAGE_ERROR_OPERATION_FAILED = -131054;
}

/// @brief Enumeration for the storage types.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class storage_type_e {
  /// < Internal device storage (built-in storage in a device, non-removable)
  static const int STORAGE_TYPE_INTERNAL = 0;

  /// < External storage
  static const int STORAGE_TYPE_EXTERNAL = 1;

  /// < Extended internal storage (External storage used as internal storage) (Since 4.0)
  static const int STORAGE_TYPE_EXTENDED_INTERNAL = 2;
}

/// @brief Enumeration for storage devices state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class storage_state_e {
  /// < Storage is present but cannot be mounted. Typically it happens if the file system of the storage is corrupted
  static const int STORAGE_STATE_UNMOUNTABLE = -2;

  /// < Storage is not present
  static const int STORAGE_STATE_REMOVED = -1;

  /// < Storage is present and mounted with read/write access
  static const int STORAGE_STATE_MOUNTED = 0;

  /// < Storage is present and mounted with read only access
  static const int STORAGE_STATE_MOUNTED_READ_ONLY = 1;
}

/// @brief Called to get information once for each supported storage.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] storage_id The unique storage ID
/// @param[in] type The type of the storage
/// @param[in] state The current state of the storage
/// @param[in] path The absolute path to the root directory of the storage
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, \n
/// otherwise @c false to break out of the loop
/// @pre	storage_foreach_device_supported() will invoke this callback function.
/// @see	storage_foreach_device_supported()
typedef storage_device_supported_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for the storage directory types.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class storage_directory_e {
  /// < Image directory
  static const int STORAGE_DIRECTORY_IMAGES = 0;

  /// < Sounds directory
  static const int STORAGE_DIRECTORY_SOUNDS = 1;

  /// < Videos directory
  static const int STORAGE_DIRECTORY_VIDEOS = 2;

  /// < Camera directory
  static const int STORAGE_DIRECTORY_CAMERA = 3;

  /// < Downloads directory
  static const int STORAGE_DIRECTORY_DOWNLOADS = 4;

  /// < Music directory
  static const int STORAGE_DIRECTORY_MUSIC = 5;

  /// < Documents directory
  static const int STORAGE_DIRECTORY_DOCUMENTS = 6;

  /// < Others directory
  static const int STORAGE_DIRECTORY_OTHERS = 7;

  /// < System ringtones directory. Only available for internal storage.
  static const int STORAGE_DIRECTORY_SYSTEM_RINGTONES = 8;
  static const int STORAGE_DIRECTORY_MAX = 9;
}

/// @brief Called when the state of storage changes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] storage_id The unique storage ID
/// @param[in] state The current state of the storage
/// @param[in] user_data The user data passed from the foreach function
/// @pre	storage_set_state_changed_cb() will invoke this callback function.
/// @see	storage_set_state_changed_cb()
/// @see	storage_unset_state_changed_cb()
typedef storage_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for storage device types.
/// @since_tizen 3.0
abstract class storage_dev_e {
  /// < SD card device (external storage)
  static const int STORAGE_DEV_EXT_SDCARD = 1001;

  /// < USB storage device (external storage)
  static const int STORAGE_DEV_EXT_USB_MASS_STORAGE = 1002;

  /// < Extended internal storage device (External storage used as internal storage) (Since 4.0)
  static const int STORAGE_DEV_EXTENDED_INTERNAL = 1003;
}

/// @brief Called when the state of a storage type changes.
/// @since_tizen 3.0
/// @param[in] storage_id The unique storage ID
/// @param[in] dev The type of the external storage device
/// @param[in] state The state of the storage
/// @param[in] fstype The type of the file system
/// @param[in] fsuuid The uuid of the file system
/// @param[in] mountpath The mount path of the file system
/// @param[in] primary The primary partition
/// @param[in] flags The flags for the storage status
/// @param[in] user_data The user data
/// @pre	storage_set_changed_cb() will invoke this callback function.
/// @see	storage_set_changed_cb()
/// @see	storage_unset_changed_cb()
typedef storage_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int,
            ffi.Int32,
            ffi.Int32,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Bool,
            ffi.Int,
            ffi.Pointer<ffi.Void>)>>;

class statvfs extends ffi.Opaque {}

/// @brief Enumeration for system information error codes.
abstract class system_info_error_e {
  /// < Successful
  static const int SYSTEM_INFO_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int SYSTEM_INFO_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int SYSTEM_INFO_ERROR_OUT_OF_MEMORY = -12;

  /// < An input/output error occurred when reading value from system
  static const int SYSTEM_INFO_ERROR_IO_ERROR = -5;

  /// < No permission to use the API
  static const int SYSTEM_INFO_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported parameter (Since 3.0)
  static const int SYSTEM_INFO_ERROR_NOT_SUPPORTED = -1073741822;
}

/// @internal
/// @brief It is not decided if it should be opened to public.
abstract class system_info_type_e {
  static const int SYSTEM_INFO_BOOL = 0;
  static const int SYSTEM_INFO_INT = 1;
  static const int SYSTEM_INFO_DOUBLE = 2;
  static const int SYSTEM_INFO_STRING = 3;
}

/// @internal
/// @brief Enumeration for system information key.
abstract class system_info_key_e {
  /// < @internal The model of the device
  static const int SYSTEM_INFO_KEY_MODEL = 0;

  /// < @internal The version of the Tizen API
  static const int SYSTEM_INFO_KEY_TIZEN_VERSION = 1;

  /// < @internal The name of platform
  static const int SYSTEM_INFO_KEY_PLATFORM_NAME = 2;

  /// < @internal The name of tizen version
  static const int SYSTEM_INFO_KEY_TIZEN_VERSION_NAME = 3;

  /// < @internal The manufacturer of the device
  static const int SYSTEM_INFO_KEY_MANUFACTURER = 4;

  /// < @internal The CORE CPU architecture of model
  static const int SYSTEM_INFO_KEY_CORE_CPU_ARCH = 5;

  /// < @internal The CORE CPU frequency of model
  static const int SYSTEM_INFO_KEY_CORE_CPU_FREQ = 6;

  /// < @internal The build string of platform binary
  static const int SYSTEM_INFO_KEY_BUILD_STRING = 7;

  /// < @internal The build date of platform binary
  static const int SYSTEM_INFO_KEY_BUILD_DATE = 8;

  /// < @internal The build time of platform binary
  static const int SYSTEM_INFO_KEY_BUILD_TIME = 9;

  /// < @internal The height of the screen in pixels
  static const int SYSTEM_INFO_KEY_SCREEN_HEIGHT = 10;

  /// < @internal The width of the screen in pixels
  static const int SYSTEM_INFO_KEY_SCREEN_WIDTH = 11;

  /// < @internal The physical screen height in millimeters
  static const int SYSTEM_INFO_KEY_PHYSICAL_SCREEN_HEIGHT = 12;

  /// < @internal The physical screen width in millimeters
  static const int SYSTEM_INFO_KEY_PHYSICAL_SCREEN_WIDTH = 13;

  /// < @internal Indicates whether the device supports tethering
  static const int SYSTEM_INFO_KEY_TETHERING_SUPPORTED = 14;
}

/// @brief Enumeration for system settings error.
/// @since_tizen 2.3
abstract class system_settings_error_e {
  /// < Successful
  static const int SYSTEM_SETTINGS_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int SYSTEM_SETTINGS_ERROR_INVALID_PARAMETER = -22;

  /// < Out of memory
  static const int SYSTEM_SETTINGS_ERROR_OUT_OF_MEMORY = -12;

  /// < Internal I/O error
  static const int SYSTEM_SETTINGS_ERROR_IO_ERROR = -5;

  /// < Permission denied
  static const int SYSTEM_SETTINGS_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported @if MOBILE (Since 2.3.1) @endif
  static const int SYSTEM_SETTINGS_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Not supported @if MOBILE (Since 2.3.1) @endif
  static const int SYSTEM_SETTINGS_ERROR_CALL_UNSUPPORTED_API = -1073741822;

  /// < Current lock screen app set 'password' type
  static const int SYSTEM_SETTINGS_ERROR_LOCKSCREEN_APP_PASSWORD_MODE =
      -38141951;
}

/// @brief Enumeration for System Settings Key.
/// @since_tizen 2.3
abstract class system_settings_key_e {
  /// < (string) The file path of the current ringtone
  static const int SYSTEM_SETTINGS_KEY_INCOMING_CALL_RINGTONE = 0;

  /// < (string) The file path of the current home screen wallpaper
  static const int SYSTEM_SETTINGS_KEY_WALLPAPER_HOME_SCREEN = 1;

  /// < (string) The file path of the current lock screen wallpaper
  static const int SYSTEM_SETTINGS_KEY_WALLPAPER_LOCK_SCREEN = 2;

  /// < (int) The current system font size
  static const int SYSTEM_SETTINGS_KEY_FONT_SIZE = 3;

  /// < (string) The current system font type
  static const int SYSTEM_SETTINGS_KEY_FONT_TYPE = 4;

  /// < (bool) Indicates whether the motion service is activated
  static const int SYSTEM_SETTINGS_KEY_MOTION_ACTIVATION = 5;

  /// < (string) The file path of the current email alert ringtone
  static const int SYSTEM_SETTINGS_KEY_EMAIL_ALERT_RINGTONE = 6;

  /// < (bool) Indicates whether the USB debugging is enabled (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int SYSTEM_SETTINGS_KEY_USB_DEBUGGING_ENABLED = 7;

  /// < (bool) Indicates whether the 3G data network is enabled (Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif)
  static const int SYSTEM_SETTINGS_KEY_3G_DATA_NETWORK_ENABLED = 8;

  /// < (string) Indicates lockscreen app pkg name
  static const int SYSTEM_SETTINGS_KEY_LOCKSCREEN_APP = 10;

  /// < (string) The current system default font type (only support Get)
  static const int SYSTEM_SETTINGS_KEY_DEFAULT_FONT_TYPE = 11;

  /// < (string) Indicates the current country setting in the <LANGUAGE>_<REGION> syntax. The country setting is in the ISO 639-2 format, and the region setting is in the ISO 3166-1 alpha-2 format
  static const int SYSTEM_SETTINGS_KEY_LOCALE_COUNTRY = 12;

  /// < (string) Indicates the current language setting in the <LANGUAGE>_<REGION> syntax. The language setting is in the ISO 639-2 format and the region setting is in the ISO 3166-1 alpha-2 format.
  static const int SYSTEM_SETTINGS_KEY_LOCALE_LANGUAGE = 13;

  /// < (bool) Indicates whether the 24-hour clock is used. If the value is @c false, the 12-hour clock is used.
  static const int SYSTEM_SETTINGS_KEY_LOCALE_TIMEFORMAT_24HOUR = 14;

  /// < (string) Indicates the current time zone.
  static const int SYSTEM_SETTINGS_KEY_LOCALE_TIMEZONE = 15;

  /// < (int) Once System changes time, this event occurs to notify time change.
  static const int SYSTEM_SETTINGS_KEY_TIME_CHANGED = 16;

  /// < GET (bool) Indicates whether the screen lock sound is enabled on the device. ex) LCD on/off sound
  static const int SYSTEM_SETTINGS_KEY_SOUND_LOCK = 17;

  /// < GET (bool) Indicates whether the device is in the silent mode.
  static const int SYSTEM_SETTINGS_KEY_SOUND_SILENT_MODE = 18;

  /// < GET (bool) Indicates whether the screen touch sound is enabled on the device.
  static const int SYSTEM_SETTINGS_KEY_SOUND_TOUCH = 19;

  /// < GET (bool) Indicates whether rotation control is automatic.
  static const int SYSTEM_SETTINGS_KEY_DISPLAY_SCREEN_ROTATION_AUTO = 20;

  /// < GET (string) Indicates device name.
  static const int SYSTEM_SETTINGS_KEY_DEVICE_NAME = 21;

  /// < GET (bool) Indicates whether the device user has enabled the motion feature.
  static const int SYSTEM_SETTINGS_KEY_MOTION_ENABLED = 22;

  /// < GET (bool) Indicates whether Wi-Fi-related notifications are enabled on the device.
  static const int SYSTEM_SETTINGS_KEY_NETWORK_WIFI_NOTIFICATION = 23;

  /// < GET (bool) Indicates whether the device is in the flight mode.
  static const int SYSTEM_SETTINGS_KEY_NETWORK_FLIGHT_MODE = 24;

  /// < (int) Indicates the backlight time (in seconds). @internal The following values can be used: 15, 30, 60, 120, 300, and 600.
  static const int SYSTEM_SETTINGS_KEY_SCREEN_BACKLIGHT_TIME = 25;

  /// < (string) Indicates the file path of the current notification tone set by the user.
  static const int SYSTEM_SETTINGS_KEY_SOUND_NOTIFICATION = 26;

  /// < (int) Indicates the time period for notification repetitions.
  static const int SYSTEM_SETTINGS_KEY_SOUND_NOTIFICATION_REPETITION_PERIOD =
      27;

  /// < (int) Indicates the current lock state
  static const int SYSTEM_SETTINGS_KEY_LOCK_STATE = 28;

  /// < (string) Indicates Ads ID for each device (Since 3.0)
  static const int SYSTEM_SETTINGS_KEY_ADS_ID = 29;

  /// < (int) Indicates Ultra Data Save status, one of #system_settings_uds_state_e values (Since 4.0)
  static const int SYSTEM_SETTINGS_KEY_ULTRA_DATA_SAVE = 30;

  /// < (string) Indicates Ultra Data Save Package List (Since 4.0), the list is a string containing whitelisted package names separated with semicolons (;)
  static const int SYSTEM_SETTINGS_KEY_ULTRA_DATA_SAVE_PKG_LIST = 31;

  /// < GET (bool) Indicates whether the accessibility TTS is enabled on the device. (Since 4.0)
  static const int SYSTEM_SETTINGS_KEY_ACCESSIBILITY_TTS = 32;

  /// < (bool) Indicates whether vibration is enabled on the device. (Since 4.0)
  static const int SYSTEM_SETTINGS_KEY_VIBRATION = 33;
  static const int SYSTEM_SETTINGS_KEY_MAX = 34;
}

/// @brief Enumeration for Idle Lock State
/// @since_tizen 2.3.1
abstract class system_settings_idle_lock_state_e {
  /// < Device is unlocked
  static const int SYSTEM_SETTINGS_LOCK_STATE_UNLOCK = 0;

  /// < Device is locked
  static const int SYSTEM_SETTINGS_LOCK_STATE_LOCK = 1;

  /// < Device is being locked
  static const int SYSTEM_SETTINGS_LOCK_STATE_LAUNCHING_LOCK = 2;
}

/// @brief Enumeration for font size.
/// @since_tizen 2.3
abstract class system_settings_font_size_e {
  /// < A small size
  static const int SYSTEM_SETTINGS_FONT_SIZE_SMALL = 0;

  /// < A normal size
  static const int SYSTEM_SETTINGS_FONT_SIZE_NORMAL = 1;

  /// < A large size
  static const int SYSTEM_SETTINGS_FONT_SIZE_LARGE = 2;

  /// < A huge size
  static const int SYSTEM_SETTINGS_FONT_SIZE_HUGE = 3;

  /// < A giant size
  static const int SYSTEM_SETTINGS_FONT_SIZE_GIANT = 4;
}

/// @brief Enumeration for Ultra Data Save
/// @since_tizen 4.0
abstract class system_settings_uds_state_e {
  /// < OFF
  static const int SYSTEM_SETTINGS_UDS_OFF = 0;

  /// < ON
  static const int SYSTEM_SETTINGS_UDS_ON = 1;

  /// < UDS on and the app is whitelisted
  static const int SYSTEM_SETTINGS_UDS_ON_WHITELISTED = 2;
}

/// @brief Called when the system settings changes.
/// @since_tizen 2.3
/// @param[in] key The key name of the system settings changed system settings
/// @param[in] user_data The user data passed from the callback registration function
/// @pre system_settings_set_changed_cb() will invoke this callback function.
/// @see system_settings_set_changed_cb()
/// @see system_settings_unset_changed_cb()
typedef system_settings_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @platform
/// @brief Called to get each string value from string typed list.
/// @since_tizen 3.0
/// @param[in] index zero based number indicating index of node in a list
/// @param[in] value value returned from the list
/// @param[in] cb_data  The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop, otherwise false to break out of the loop
typedef system_settings_iter_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for Trace Error.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 2.3.2 @endif
abstract class trace_error_e {
  /// < Successful
  static const int TRACE_ERROR_NONE = 0;

  /// < I/O error
  static const int TRACE_ERROR_IO_ERROR = -5;
}

/// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
/// @brief Enumeration of an endpoint's direction.
/// @since_tizen 3.0
abstract class usb_host_endpoint_direction_e {
  /// < IN direction
  static const int USB_HOST_DIRECTION_IN = 0;

  /// < OUT direction
  static const int USB_HOST_DIRECTION_OUT = 1;
}

/// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
/// @brief Enumeration of transfer type.
/// @since_tizen 3.0
abstract class usb_host_transfer_type_e {
  /// < Control transfer
  static const int USB_HOST_TRANSFER_TYPE_CONTROL = 0;

  /// < Isochronous transfer
  static const int USB_HOST_TRANSFER_TYPE_ISOCHRONOUS = 1;

  /// < Bulk transfer
  static const int USB_HOST_TRANSFER_TYPE_BULK = 2;

  /// < Interrupt transfer
  static const int USB_HOST_TRANSFER_TYPE_INTERRUPT = 3;
}

/// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
/// @brief Enumeration of isochronous endpoint's synchronization type.
/// @since_tizen 3.0
abstract class usb_host_iso_sync_type_e {
  /// < No synchronization
  static const int USB_HOST_ISO_SYNC_TYPE_NONE = 0;

  /// < Asynchronous
  static const int USB_HOST_ISO_SYNC_TYPE_ASYNC = 1;

  /// < Adaptive
  static const int USB_HOST_ISO_SYNC_TYPE_ADAPTIVE = 2;

  /// < Synchronous
  static const int USB_HOST_ISO_SYNC_TYPE_SYNC = 3;
}

/// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
/// @brief Enumeration of an endpoint's usage type.
/// @since_tizen 3.0
abstract class usb_host_usage_type_e {
  /// < Data endpoint
  static const int USB_HOST_USAGE_TYPE_DATA = 0;

  /// < Feedback endpoint
  static const int USB_HOST_USAGE_TYPE_FEEDBACK = 1;

  /// < Implicit feedback Data endpoint
  static const int USB_HOST_USAGE_TYPE_IMPLICIT = 2;
}

/// @ingroup CAPI_USB_HOST_MODULE
/// @brief Enumeration of error codes reported by USB host API.
/// @since_tizen 3.0
abstract class usb_host_error_e {
  /// < Successful
  static const int USB_HOST_ERROR_NONE = 0;

  /// < I/O error
  static const int USB_HOST_ERROR_IO_ERROR = -5;

  /// < Invalid parameter
  static const int USB_HOST_ERROR_INVALID_PARAMETER = -22;

  /// < Permission denied
  static const int USB_HOST_ERROR_PERMISSION_DENIED = -13;

  /// < No device
  static const int USB_HOST_ERROR_NO_SUCH_DEVICE = -6;

  /// < Entity not found
  static const int USB_HOST_ERROR_NOT_FOUND = -38469631;

  /// < Resource busy
  static const int USB_HOST_ERROR_RESOURCE_BUSY = -16;

  /// < Operation timed out
  static const int USB_HOST_ERROR_TIMED_OUT = -1073741823;

  /// < Overflow
  static const int USB_HOST_ERROR_OVERFLOW = -38469630;

  /// < Device is not opened
  static const int USB_HOST_ERROR_DEVICE_NOT_OPENED = -38469629;

  /// < Pipe error
  static const int USB_HOST_ERROR_BROKEN_PIPE = -32;

  /// < System call interrupted
  static const int USB_HOST_ERROR_INTERRUPTED_SYS_CALL = -4;

  /// < Insufficient memory
  static const int USB_HOST_ERROR_OUT_OF_MEMORY = -12;

  /// < Operation not supported
  static const int USB_HOST_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Other error
  static const int USB_HOST_ERROR_UNKNOWN = -1073741824;
}

/// @ingroup CAPI_USB_HOST_HOTPLUG_MODULE
/// @brief Enumeration of hotplug event types.
/// @since_tizen 4.0
abstract class usb_host_hotplug_event_e {
  /// < Device was connected
  static const int USB_HOST_HOTPLUG_EVENT_ATTACH = 0;

  /// < Device was disconnected
  static const int USB_HOST_HOTPLUG_EVENT_DETACH = 1;

  /// < Any event
  static const int USB_HOST_HOTPLUG_EVENT_ANY = 2;
}

class usb_host_context_s extends ffi.Opaque {}

class usb_host_device_s extends ffi.Opaque {}

class usb_host_config_s extends ffi.Opaque {}

class usb_host_interface_s extends ffi.Opaque {}

class usb_host_endpoint_s extends ffi.Opaque {}

class usb_host_hotplug_s extends ffi.Opaque {}

/// @ingroup CAPI_USB_HOST_MODULE
/// @brief Context handle to USB host.
/// @details This structure represents usb_host session.
/// Using own session allows to use this API independently.
/// For example calling usb_host_destroy() will not destroy resources
/// that are being used by another user of the library.
///
/// To create session there is need to call usb_host_create(),
/// to destroy call usb_host_destroy(). Each session created by usb_host_create()
/// has to be destroyed using usb_host_destroy()
/// @since_tizen 3.0
typedef usb_host_context_h = ffi.Pointer<usb_host_context_s>;

/// @ingroup CAPI_USB_HOST_DEV_MODULE
/// @brief Structure representing USB device.
/// @details This structure represents USB device found on USB bus.
///
/// This can be obtained by usb_host_get_device_list() or usb_host_device_open_with_vid_pidi().
/// Some basic operations can be performed on closed device obtained by usb_host_device_list().
/// To perform any I/O operations the device must be opened by calling usb_host_device_open()
/// or usb_host_device_open_with_vid_pid().
///
/// @since_tizen 3.0
typedef usb_host_device_h = ffi.Pointer<usb_host_device_s>;

/// @ingroup CAPI_USB_HOST_CONFIG_MODULE
/// @brief USB config handle.
/// @details This type represents USB device configuration. Device can have multiple configurations,
/// a configuration can have multiple interfaces. This handle can be obtained by
/// usb_host_device_get_config().
/// @since_tizen 3.0
typedef usb_host_config_h = ffi.Pointer<usb_host_config_s>;

/// @ingroup CAPI_USB_HOST_INTERFACE_MODULE
/// @brief USB interface handle.
/// @details This type represents USB interface. An interface is a part of configuration and
/// can have multiple endpoints. This handle can be obtained by usb_host_config_get_interface().
/// @since_tizen 3.0
typedef usb_host_interface_h = ffi.Pointer<usb_host_interface_s>;

/// @ingroup CAPI_USB_HOST_ENDPOINT_MODULE
/// @brief USB endpoint handle.
/// @details This type represents USB endpoint. This handle can be obtained by
/// usb_host_interface_get_endpoint().
/// @since_tizen 3.0
typedef usb_host_endpoint_h = ffi.Pointer<usb_host_endpoint_s>;

/// @ingroup CAPI_USB_HOST_HOTPLUG_MODULE
/// @brief Device connected/disconnected event handler.
/// @details The device handle should be unreffed with usb_host_unref_device()
/// when no longer needed.
/// @since_tizen 4.0
/// @param[in] dev Device which was connected/disconnected
/// @param[in] user_data User data pointer passed on callback registration
typedef usb_host_hotplug_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(usb_host_device_h, ffi.Pointer<ffi.Void>)>>;

/// @ingroup CAPI_USB_HOST_HOTPLUG_MODULE
/// @brief USB hotplug callback handle.
/// @details This handle is used for managing registered hotplug callbacks.
/// @since_tizen 4.0
typedef usb_host_hotplug_h = ffi.Pointer<usb_host_hotplug_s>;

class telephony_data extends ffi.Opaque {}

/// @brief The structure type for the list of handles to use the Telephony API.
/// @remarks There are two handles in case of dual SIM device. \n
/// In this case, handle[0] means Primary SIM and handle[1] means Secondary SIM.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
class telephony_handle_list_s extends ffi.Struct {
  /// < Number of available handle
  @ffi.UnsignedInt()
  external int count;

  /// < Handle to use Telephony API
  external ffi.Pointer<telephony_h> handle;
}

/// @brief The Telephony API handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef telephony_h = ffi.Pointer<telephony_data>;

/// @brief Enumeration for Telephony error.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class telephony_error_e {
  /// < Successful
  static const int TELEPHONY_ERROR_NONE = 0;

  /// < Out of memory
  static const int TELEPHONY_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid parameter
  static const int TELEPHONY_ERROR_INVALID_PARAMETER = -22;

  /// < Permission denied
  static const int TELEPHONY_ERROR_PERMISSION_DENIED = -13;

  /// < Not supported
  static const int TELEPHONY_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Operation failed
  static const int TELEPHONY_ERROR_OPERATION_FAILED = -39845887;

  /// < SIM is not available
  static const int TELEPHONY_ERROR_SIM_NOT_AVAILABLE = -39841791;
}

/// @brief Enumeration for Telephony notification.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class telephony_noti_e {
  /// < Notification to be invoked when the SIM card state changes. @n
  /// '#telephony_sim_state_e' will be delivered in notification data @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_SIM_STATUS = 16;

  /// < Notification to be invoked when the SIM call forwarding indicator state changes. @n
  /// 'state(bool)' will be delivered in notification data (@b Since: 3.0) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_SIM_CALL_FORWARDING_INDICATOR_STATE = 17;

  /// < Notification to be invoked when the network service state changes. @n
  /// '#telephony_network_service_state_e' will be delivered in notification data @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_NETWORK_SERVICE_STATE = 32;

  /// < Notification to be invoked when the cell ID changes. @n
  /// 'cell_id(int)' will be delivered in notification data @n
  /// Privilege : http://tizen.org/privilege/location.coarse (@b Since: 3.0) @n
  /// http://tizen.org/privilege/telephony privilege is no longer required since 3.0.
  static const int TELEPHONY_NOTI_NETWORK_CELLID = 33;

  /// < Notification to be invoked when the roaming status changes. @n
  /// 'roaming_status(bool)' will be delivered in notification data @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_NETWORK_ROAMING_STATUS = 34;

  /// < Notification to be invoked when the signal strength changes. @n
  /// '#telephony_network_rssi_e' will be delivered in notification data @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_NETWORK_SIGNALSTRENGTH_LEVEL = 35;

  /// < Notification to be invoked when the network name changes. @n
  /// 'network_name(char *)' wil be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_NETWORK_NETWORK_NAME = 36;

  /// < Notification to be invoked when the ps type changes. @n
  /// '#telephony_network_ps_type_e' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_NETWORK_PS_TYPE = 37;

  /// < Notification to be invoked when the default data subscription changes. @n
  /// '#telephony_network_default_data_subs_e' wil be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_NETWORK_DEFAULT_DATA_SUBSCRIPTION = 38;

  /// < Notification to be invoked when the default subscription changes. @n
  /// '#telephony_network_default_subs_e' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_NETWORK_DEFAULT_SUBSCRIPTION = 39;

  /// < Notification to be invoked when the LAC (Location Area Code) changes. @n
  /// 'lac(int)' will be delivered in notification data (@b Since: 3.0) @n
  /// Privilege : http://tizen.org/privilege/location.coarse
  static const int TELEPHONY_NOTI_NETWORK_LAC = 40;

  /// < Notification to be invoked when the TAC (Tracking Area Code) changes. @n
  /// 'tac(int)' will be delivered in notification data (@b Since: 3.0) @n
  /// Privilege : http://tizen.org/privilege/location.coarse
  static const int TELEPHONY_NOTI_NETWORK_TAC = 41;

  /// < Notification to be invoked when the system ID changes. @n
  /// 'sid(int)' will be delivered in notification data (@b Since: 3.0) @n
  /// Privilege : http://tizen.org/privilege/location.coarse
  static const int TELEPHONY_NOTI_NETWORK_SYSTEM_ID = 42;

  /// < Notification to be invoked when the network ID changes. @n
  /// 'nid(int)' will be delivered in notification data (@b Since: 3.0) @n
  /// Privilege : http://tizen.org/privilege/location.coarse
  static const int TELEPHONY_NOTI_NETWORK_NETWORK_ID = 43;

  /// < Notification to be invoked when the base station ID changes. @n
  /// 'bs_id(int)' will be delivered in notification data (@b Since: 3.0) @n
  /// Privilege : http://tizen.org/privilege/location.coarse
  static const int TELEPHONY_NOTI_NETWORK_BS_ID = 44;

  /// < Notification to be invoked when the base station latitude changes. @n
  /// 'bs_latitude(int)' will be delivered in notification data (@b Since: 3.0) @n
  /// Privilege : http://tizen.org/privilege/location.coarse
  static const int TELEPHONY_NOTI_NETWORK_BS_LATITUDE = 45;

  /// < Notification to be invoked when the base station longitude changes. @n
  /// 'bs_longitue(int)' will be delivered in notification data (@b Since: 3.0) @n
  /// Privilege : http://tizen.org/privilege/location.coarse
  static const int TELEPHONY_NOTI_NETWORK_BS_LONGITUDE = 46;

  /// < Notification to be invoked when the voice call state changes. @n
  /// '#telephony_call_state_e' will be delivered in notification data (Deprecated Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. Use TELEPHONY_NOTI_VOICE_CALL_STATUS_XXX instead.) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VOICE_CALL_STATE = 48;

  /// < Notification to be invoked when the video call state changes. @n
  /// '#telephony_call_state_e' will be delivered in notification data (Deprecated Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. Use TELEPHONY_NOTI_VIDEO_CALL_STATUS_XXX instead.) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VIDEO_CALL_STATE = 49;

  /// < Notification to be invoked when a voice call is in idle status. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VOICE_CALL_STATUS_IDLE = 50;

  /// < Notification to be invoked when a voice call is in active status. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VOICE_CALL_STATUS_ACTIVE = 51;

  /// < Notification to be invoked when a voice call is in held status. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VOICE_CALL_STATUS_HELD = 52;

  /// < Notification to be invoked when a voice call is in dialing status. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VOICE_CALL_STATUS_DIALING = 53;

  /// < Notification to be invoked when a voice call is in alertingstatus. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VOICE_CALL_STATUS_ALERTING = 54;

  /// < Notification to be invoked when a voice call is in incoming status. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VOICE_CALL_STATUS_INCOMING = 55;

  /// < Notification to be invoked when a video call is in idle status. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VIDEO_CALL_STATUS_IDLE = 56;

  /// < Notification to be invoked when a video call is in active status. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VIDEO_CALL_STATUS_ACTIVE = 57;

  /// < Notification to be invoked when a video call is in dialing status. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VIDEO_CALL_STATUS_DIALING = 58;

  /// < Notification to be invoked when a video call is in alerting status. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VIDEO_CALL_STATUS_ALERTING = 59;

  /// < Notification to be invoked when a video call is in incoming status. @n
  /// 'handle_id(unsigned int)' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_VIDEO_CALL_STATUS_INCOMING = 60;

  /// < Notification to be invoked when the preferred voice subscription changes. @n
  /// '#telephony_call_preferred_voice_subs_e' will be delivered in notification data (@b Since: @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_CALL_PREFERRED_VOICE_SUBSCRIPTION = 61;

  /// < Notification to be invoked when the modem power status changes. @n
  /// '#telephony_modem_power_status_e' will be delivered in notification data (@b Since: 4.0) @n
  /// Privilege : http://tizen.org/privilege/telephony
  static const int TELEPHONY_NOTI_MODEM_POWER_STATUS = 62;
}

/// @brief Called when the telephony state changes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef telephony_noti_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(telephony_h, ffi.Int32, ffi.Pointer<ffi.Void>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for the telephony state.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_state_e {
  /// < Telephony state is not ready
  static const int TELEPHONY_STATE_NOT_READY = 0;

  /// < Telephony state is ready
  static const int TELEPHONY_STATE_READY = 1;
}

/// @brief Called for the telephony state changes.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef telephony_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

class telephony_call_info_s extends ffi.Opaque {}

/// @deprecated Deprecated Since @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif. Use #telephony_call_status_e instead.
///
/// @brief Enumeration for the call state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class telephony_call_state_e {
  /// < There exists no calls.
  static const int TELEPHONY_CALL_STATE_IDLE = 0;

  /// < There exists at least one call that is dialing, alerting or incoming
  static const int TELEPHONY_CALL_STATE_CONNECTING = 1;

  /// < There exist active or held calls, and no calls are dialing, alerting or incoming
  static const int TELEPHONY_CALL_STATE_CONNECTED = 2;
}

/// @brief Enumeration for the call status.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_call_status_e {
  /// < Idle status
  static const int TELEPHONY_CALL_STATUS_IDLE = 0;

  /// < Active status
  static const int TELEPHONY_CALL_STATUS_ACTIVE = 1;

  /// < Held status
  static const int TELEPHONY_CALL_STATUS_HELD = 2;

  /// < Dialing status
  static const int TELEPHONY_CALL_STATUS_DIALING = 3;

  /// < Alerting status
  static const int TELEPHONY_CALL_STATUS_ALERTING = 4;

  /// < Incoming status
  static const int TELEPHONY_CALL_STATUS_INCOMING = 5;
}

/// @brief Enumeration for the preferred voice call subscription.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_call_preferred_voice_subs_e {
  /// < Unknown status
  static const int TELEPHONY_CALL_PREFERRED_VOICE_SUBS_UNKNOWN = -1;

  /// < Current network
  static const int TELEPHONY_CALL_PREFERRED_VOICE_SUBS_CURRENT_NETWORK = 0;

  /// < ASK Always
  static const int TELEPHONY_CALL_PREFERRED_VOICE_SUBS_ASK_ALWAYS = 1;

  /// < SIM 1
  static const int TELEPHONY_CALL_PREFERRED_VOICE_SUBS_SIM1 = 2;

  /// <  SIM 2
  static const int TELEPHONY_CALL_PREFERRED_VOICE_SUBS_SIM2 = 3;
}

/// @brief Enumeration for the call type.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_call_type_e {
  /// < Voice call
  static const int TELEPHONY_CALL_TYPE_VOICE = 0;

  /// < Video call
  static const int TELEPHONY_CALL_TYPE_VIDEO = 1;

  /// < Emergency call
  static const int TELEPHONY_CALL_TYPE_E911 = 2;
}

/// @brief Enumeration for the call direction.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_call_direction_e {
  /// < MO(Mobile Originated) call
  static const int TELEPHONY_CALL_DIRECTION_MO = 0;

  /// < MT(Mobile Terminated) call
  static const int TELEPHONY_CALL_DIRECTION_MT = 1;
}

/// @brief The call handle.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef telephony_call_h = ffi.Pointer<telephony_call_info_s>;

/// @brief Enumeration for the state of SIM card.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class telephony_sim_state_e {
  /// < SIM is not available on this device
  static const int TELEPHONY_SIM_STATE_UNAVAILABLE = 0;

  /// < SIM is locked
  static const int TELEPHONY_SIM_STATE_LOCKED = 1;

  /// < SIM is available on this device (SIM is not locked)
  static const int TELEPHONY_SIM_STATE_AVAILABLE = 2;

  /// < SIM is in transition between states
  static const int TELEPHONY_SIM_STATE_UNKNOWN = 3;
}

/// @brief Enumeration for the lock state of SIM card.
/// @since_tizen 3.0
abstract class telephony_sim_lock_state_e {
  /// < SIM is not in lock
  static const int TELEPHONY_SIM_LOCK_STATE_UNKNOWN = 0;

  /// < SIM is PIN(Personal Identification Number) locked
  static const int TELEPHONY_SIM_LOCK_STATE_PIN_REQUIRED = 1;

  /// < SIM is PUK(Personal Unblocking Code) locked
  static const int TELEPHONY_SIM_LOCK_STATE_PUK_REQUIRED = 2;

  /// < SIM is permanently blocked(All the attempts for PIN/PUK failed)
  static const int TELEPHONY_SIM_LOCK_STATE_PERM_LOCKED = 3;

  /// < SIM is NCK(Network Control Key) locked
  static const int TELEPHONY_SIM_LOCK_STATE_NCK_REQUIRED = 4;
}

/// @brief Enumeration for the type of SIM card.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_sim_application_type_e {
  /// < SIM(GSM) Application
  static const int TELEPHONY_SIM_APP_TYPE_SIM = 1;

  /// < USIM Application
  static const int TELEPHONY_SIM_APP_TYPE_USIM = 2;

  /// < CDMA Application
  static const int TELEPHONY_SIM_APP_TYPE_CSIM = 4;

  /// < ISIM Application
  static const int TELEPHONY_SIM_APP_TYPE_ISIM = 8;
}

/// @brief Enumeration for RSSI (Receive Signal Strength Indicator).
/// @details #TELEPHONY_NETWORK_RSSI_6 indicates the highest strength.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class telephony_network_rssi_e {
  /// < Strength 0
  static const int TELEPHONY_NETWORK_RSSI_0 = 0;

  /// < Strength 1
  static const int TELEPHONY_NETWORK_RSSI_1 = 1;

  /// < Strength 2
  static const int TELEPHONY_NETWORK_RSSI_2 = 2;

  /// < Strength 3
  static const int TELEPHONY_NETWORK_RSSI_3 = 3;

  /// < Strength 4
  static const int TELEPHONY_NETWORK_RSSI_4 = 4;

  /// < Strength 5
  static const int TELEPHONY_NETWORK_RSSI_5 = 5;

  /// < Strength 6
  static const int TELEPHONY_NETWORK_RSSI_6 = 6;
}

/// @brief Enumeration for Network Type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class telephony_network_type_e {
  /// < Unknown
  static const int TELEPHONY_NETWORK_TYPE_UNKNOWN = 0;

  /// < 2G GSM network type
  static const int TELEPHONY_NETWORK_TYPE_GSM = 1;

  /// < 2.5G GPRS network type
  static const int TELEPHONY_NETWORK_TYPE_GPRS = 2;

  /// < 2.5G EDGE network type
  static const int TELEPHONY_NETWORK_TYPE_EDGE = 3;

  /// < 3G UMTS network type
  static const int TELEPHONY_NETWORK_TYPE_UMTS = 4;

  /// < HSDPA network type
  static const int TELEPHONY_NETWORK_TYPE_HSDPA = 5;

  /// < LTE network type
  static const int TELEPHONY_NETWORK_TYPE_LTE = 6;

  /// < IS95A network type (Since: 3.0)
  static const int TELEPHONY_NETWORK_TYPE_IS95A = 7;

  /// < IS95B network type (Since: 3.0)
  static const int TELEPHONY_NETWORK_TYPE_IS95B = 8;

  /// < CDMA 1x network type (Since: 3.0)
  static const int TELEPHONY_NETWORK_TYPE_CDMA_1X = 9;

  /// < EVDO revision 0 network type (Since: 3.0)
  static const int TELEPHONY_NETWORK_TYPE_EVDO_REV_0 = 10;

  /// < EVDO revision A network type (Since: 3.0)
  static const int TELEPHONY_NETWORK_TYPE_EVDO_REV_A = 11;

  /// < EVDO revision B network type (Since: 3.0)
  static const int TELEPHONY_NETWORK_TYPE_EVDO_REV_B = 12;

  /// < EVDV network type (Since: 3.0)
  static const int TELEPHONY_NETWORK_TYPE_EVDV = 13;

  /// < EHRPD network type (Since: 3.0)
  static const int TELEPHONY_NETWORK_TYPE_EHRPD = 14;
}

/// @brief Enumeration for PS Type.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_network_ps_type_e {
  /// < Unknown
  static const int TELEPHONY_NETWORK_PS_TYPE_UNKNOWN = 0;

  /// < HSDPA ps type
  static const int TELEPHONY_NETWORK_PS_TYPE_HSDPA = 1;

  /// < HSUPA ps type
  static const int TELEPHONY_NETWORK_PS_TYPE_HSUPA = 2;

  /// < HSPA ps type
  static const int TELEPHONY_NETWORK_PS_TYPE_HSPA = 3;

  /// < HSPAP ps type
  static const int TELEPHONY_NETWORK_PS_TYPE_HSPAP = 4;
}

/// @brief Enumeration for Network Service State.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class telephony_network_service_state_e {
  /// < In service
  static const int TELEPHONY_NETWORK_SERVICE_STATE_IN_SERVICE = 0;

  /// < Out of service
  static const int TELEPHONY_NETWORK_SERVICE_STATE_OUT_OF_SERVICE = 1;

  /// < Only emergency call is allowed
  static const int TELEPHONY_NETWORK_SERVICE_STATE_EMERGENCY_ONLY = 2;
}

/// @brief Enumeration for Network Name Priority.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_network_name_option_e {
  /// < Unknown
  static const int TELEPHONY_NETWORK_NAME_OPTION_UNKNOWN = 0;

  /// < Network name displayed by SPN
  static const int TELEPHONY_NETWORK_NAME_OPTION_SPN = 1;

  /// < Network name displayed by Network
  static const int TELEPHONY_NETWORK_NAME_OPTION_NETWORK = 2;

  /// < Network name displayed by SPN or Network
  static const int TELEPHONY_NETWORK_NAME_OPTION_ANY = 3;
}

/// @brief Enumeration for the possible 'default' Data Subscriptions for Packet Switched(PS).
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_network_default_data_subs_e {
  /// < Unknown status
  static const int TELEPHONY_NETWORK_DEFAULT_DATA_SUBS_UNKNOWN = -1;

  /// < SIM 1
  static const int TELEPHONY_NETWORK_DEFAULT_DATA_SUBS_SIM1 = 0;

  /// < SIM 2
  static const int TELEPHONY_NETWORK_DEFAULT_DATA_SUBS_SIM2 = 1;
}

/// @brief Enumeration for defining possible 'default' Subscriptions for Circuit Switched(CS).
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_network_default_subs_e {
  /// < Unknown status
  static const int TELEPHONY_NETWORK_DEFAULT_SUBS_UNKNOWN = -1;

  /// < SIM 1 network
  static const int TELEPHONY_NETWORK_DEFAULT_SUBS_SIM1 = 0;

  /// < SIM 2 network
  static const int TELEPHONY_NETWORK_DEFAULT_SUBS_SIM2 = 1;
}

/// @brief Enumeration for network selection mode.
/// @since_tizen 3.0
abstract class telephony_network_selection_mode_e {
  /// < Automatic mode
  static const int TELEPHONY_NETWORK_SELECTION_MODE_AUTOMATIC = 0;

  /// < Manual mode
  static const int TELEPHONY_NETWORK_SELECTION_MODE_MANUAL = 1;
}

/// @brief Enumeration for Modem Power Status.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class telephony_modem_power_status_e {
  /// < Unknown
  static const int TELEPHONY_MODEM_POWER_STATUS_UNKNOWN = -1;

  /// < Modem power ON
  static const int TELEPHONY_MODEM_POWER_STATUS_ON = 0;

  /// < Modem power OFF
  static const int TELEPHONY_MODEM_POWER_STATUS_OFF = 1;

  /// < Modem power RESET
  static const int TELEPHONY_MODEM_POWER_STATUS_RESET = 2;

  /// < Modem power LOW
  static const int TELEPHONY_MODEM_POWER_STATUS_LOW = 3;
}

/// @brief Enumeration for Clipboard Data Type.
/// @since_tizen 3.0
abstract class cbhm_sel_type_e {
  static const int CBHM_SEL_TYPE_NONE = 0;

  /// Content is from outside of Elementary
  static const int CBHM_SEL_TYPE_TEXT = 1;

  /// Plain unformatted text: Used for things that don't want rich markup
  static const int CBHM_SEL_TYPE_MARKUP = 2;

  /// Edje textblock markup, including inline images
  static const int CBHM_SEL_TYPE_IMAGE = 4;

  /// Images
  static const int CBHM_SEL_TYPE_HTML = 8;
}

/// @brief Enumeration for Clipboard State Type.
/// @since_tizen 3.0
abstract class cbhm_state_type_e {
  static const int CBHM_STATE_NONE = 0;
  static const int CBHM_STATE_SHOW = 1;
  static const int CBHM_STATE_HIDE = 2;
}

/// @brief Enumeration for Clipboard Error Codes.
/// @since_tizen 3.0
abstract class cbhm_error_e {
  /// < Successful
  static const int CBHM_ERROR_NONE = 0;

  /// < Out of memory
  static const int CBHM_ERROR_OUT_OF_MEMORY = -12;

  /// < Not supported
  static const int CBHM_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Invalid parameter
  static const int CBHM_ERROR_INVALID_PARAMETER = -22;

  /// < No data available
  static const int CBHM_ERROR_NO_DATA = -61;

  /// < Connection refused
  static const int CBHM_ERROR_CONNECTION_REFUSED = -111;

  /// < Address already in use
  static const int CBHM_ERROR_ADDRES_IN_USE = -98;
}

class cbhm extends ffi.Opaque {}

/// @brief Clipboard handle.
/// @since_tizen 3.0
typedef cbhm_h = ffi.Pointer<cbhm>;

/// @brief Event callback signature of selecting a clipboard item.
/// @since_tizen 3.0
/// @param[in] cbhm_handle Clipboard handle
/// @param[in] user_data User data to be passed to the given event callback function
/// @return This is reserved
/// @see cbhm_item_selected_callback_add()
typedef cbhm_selected_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Int Function(cbhm_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Event callback signature of receiving data from clipboard.
/// @since_tizen 3.0
/// @param[in] Clipboard handle
/// @param[out] buf Buffer for receiving data
/// @param[in] len The length of buffer
/// @param[in] user_data User data to be passed to the given event callback function
/// @return This is reserved
/// @see cbhm_item_selected_callback_add()
typedef cbhm_selection_data_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(
            cbhm_h, ffi.Pointer<ffi.Char>, ffi.Size, ffi.Pointer<ffi.Void>)>>;

/// @brief Event callback signature for receiving changed event of clipboard items.
/// @since_tizen 4.0
/// @param[in] cbhm_handle The clipboard handle
/// @remarks @a cbhm_handle is the same handle as the one used in the cbhm_item_changed_callback_add() call with which the callback was added
/// @param[in] item_count The number of clipboard items
/// @param[in] user_data User data to be passed to the given event callback function
/// @return #CBHM_ERROR_NONE on success,
/// otherwise a negative error value
/// @retval #CBHM_ERROR_NONE Successful
/// @see cbhm_item_selected_callback_add()
typedef cbhm_item_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(cbhm_h, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Event callback signature of receiving monitored event of clipboard.
/// @since_tizen 4.0
/// @param[in] cbhm_handle Clipboard handle
/// @param[in] active_state Clipboard is active if @c true, inactive otherwise
/// @param[in] user_data User data to be passed to the given event callback function
/// @see cbhm_monitor_callback_add()
/// @see cbhm_monitor_callback_remove()
typedef cbhm_monitor_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(cbhm_h, ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration of External Output Manager (EOM) error type
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class eom_error_e {
  /// < Success
  static const int EOM_ERROR_NONE = 0;

  /// < Memory allocation failure
  static const int EOM_ERROR_OUT_OF_MEMORY = -12;

  /// < Invalid input parameter
  static const int EOM_ERROR_INVALID_PARAMETER = -22;

  /// < Invalid external output instance
  static const int EOM_ERROR_NO_SUCH_DEVICE = -6;

  /// < Connection failure
  static const int EOM_ERROR_CONNECTION_FAILURE = -42205183;

  /// < Message sending failure
  static const int EOM_ERROR_MESSAGE_SENDING_FAILURE = -42205182;

  /// < Message operation failure
  static const int EOM_ERROR_MESSAGE_OPERATION_FAILURE = -42205181;
}

/// @brief Enumeration of external output type
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class eom_output_type_e {
  /// < Unknown output type
  static const int EOM_OUTPUT_TYPE_UNKNOWN = 0;

  /// < VGA output
  static const int EOM_OUTPUT_TYPE_VGA = 1;

  /// < DVII output type
  static const int EOM_OUTPUT_TYPE_DVII = 2;

  /// < DVID output type
  static const int EOM_OUTPUT_TYPE_DVID = 3;

  /// < DVIA output type
  static const int EOM_OUTPUT_TYPE_DVIA = 4;

  /// < Composite output type
  static const int EOM_OUTPUT_TYPE_COMPOSITE = 5;

  /// < SVIDEO output type
  static const int EOM_OUTPUT_TYPE_SVIDEO = 6;

  /// < LVDS output type
  static const int EOM_OUTPUT_TYPE_LVDS = 7;

  /// < Component output type
  static const int EOM_OUTPUT_TYPE_COMPONENT = 8;

  /// < 9PinDIN output type
  static const int EOM_OUTPUT_TYPE_9PINDIN = 9;

  /// < DisplayPort output type
  static const int EOM_OUTPUT_TYPE_DISPLAYPORT = 10;

  /// < HDMIA output type
  static const int EOM_OUTPUT_TYPE_HDMIA = 11;

  /// < HDMIB output type
  static const int EOM_OUTPUT_TYPE_HDMIB = 12;

  /// < TV output type
  static const int EOM_OUTPUT_TYPE_TV = 13;

  /// < EDP output type
  static const int EOM_OUTPUT_TYPE_EDP = 14;

  /// < VIRTUAL output type
  static const int EOM_OUTPUT_TYPE_VIRTUAL = 15;

  /// < DSI output type
  static const int EOM_OUTPUT_TYPE_DSI = 16;
  static const int EOM_OUTPUT_TYPE_MAX = 17;
}

/// @brief Enumeration of external output mode
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class eom_output_mode_e {
  /// < None
  static const int EOM_OUTPUT_MODE_NONE = 0;

  /// < Mirror mode
  static const int EOM_OUTPUT_MODE_MIRROR = 1;

  /// < Presentation mode
  static const int EOM_OUTPUT_MODE_PRESENTATION = 2;
  static const int EOM_OUTPUT_MODE_MAX = 3;
}

/// @brief Enumeration of External Output Manager (EOM) attributes
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class eom_output_attribute_e {
  /// < None
  static const int EOM_OUTPUT_ATTRIBUTE_NONE = 0;

  /// < Normal presentation mode window showing on external output
  static const int EOM_OUTPUT_ATTRIBUTE_NORMAL = 1;

  /// < Exclusive share presentation mode window showing on external output
  static const int EOM_OUTPUT_ATTRIBUTE_EXCLUSIVE_SHARE = 2;

  /// < Exclusive presentation mode window showing on external output
  static const int EOM_OUTPUT_ATTRIBUTE_EXCLUSIVE = 3;
  static const int EOM_OUTPUT_ATTRIBUTE_MAX = 4;
}

/// @brief Enumeration of External Output Manager (EOM) attribute state
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class eom_output_attribute_state_e {
  /// < None
  static const int EOM_OUTPUT_ATTRIBUTE_STATE_NONE = 0;

  /// < Output attribute is active
  static const int EOM_OUTPUT_ATTRIBUTE_STATE_ACTIVE = 1;

  /// < Output attribute is inactive
  static const int EOM_OUTPUT_ATTRIBUTE_STATE_INACTIVE = 2;

  /// < Cannot use external output
  static const int EOM_OUTPUT_ATTRIBUTE_STATE_LOST = 3;
  static const int EOM_OUTPUT_ATTRIBUTE_STATE_MAX = 4;
}

/// @brief Called when External Output Manager (EOM) module sends output
/// connection notification.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] output_id  The output id which is connected output
/// @param[in] user_data  The pointer of user data which is passed to
/// eom_output_added_cb function
/// @see eom_set_output_added_cb()
/// @see eom_unset_output_added_cb()
typedef eom_output_added_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(eom_output_id, ffi.Pointer<ffi.Void>)>>;

/// @brief Definition for external output ID
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef eom_output_id = ffi.UnsignedInt;

/// @brief Called when External Output Manager (EOM) module sends output
/// disconnection notification.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] output_id  The output id which is connected output
/// @param[in] user_data  The pointer of user data which is passed to
/// eom_output_removed_cb function
/// @see eom_set_output_removed_cb()
/// @see eom_unset_output_removed_cb()
typedef eom_output_removed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(eom_output_id, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when External Output Manager (EOM) module sends output
/// mode changing notification.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] output_id  The output id which is connected output
/// @param[in] user_data  The pointer of user data which is passed to
/// eom_mode_changed_cb function
/// @see eom_set_mode_changed_cb()
/// @see eom_unset_mode_changed_cb()
typedef eom_mode_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(eom_output_id, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when External Output Manager (EOM) module sends output
/// attribute changing notification.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] output_id  The output id which is connected output
/// @param[in] user_data  The pointer of user data which is passed to
/// eom_attribute_changed_cb function
/// @see eom_set_attribute_changed_cb()
/// @see eom_unset_attribute_changed_cb()
typedef eom_attribute_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(eom_output_id, ffi.Pointer<ffi.Void>)>>;

/// @typedef Evas_Object
/// An Evas Object handle.
/// @ingroup Evas_Object_Group
typedef Evas_Object = Eo;

/// @typedef Eo
/// The basic Object type.
typedef Eo = _Eo_Opaque;

class _Eo_Opaque extends ffi.Opaque {}

/// @brief Enumeration for input method function error
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class ime_error_e {
  /// < Successful
  static const int IME_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int IME_ERROR_INVALID_PARAMETER = -22;

  /// < Permission denied
  static const int IME_ERROR_PERMISSION_DENIED = -13;

  /// < Necessary callback function is not set
  static const int IME_ERROR_NO_CALLBACK_FUNCTION = -49414143;

  /// < IME main loop isn't started yet
  static const int IME_ERROR_NOT_RUNNING = -49414142;

  /// < Operation failed
  static const int IME_ERROR_OPERATION_FAILED = -49414141;

  /// < out of memory
  static const int IME_ERROR_OUT_OF_MEMORY = -12;
}

/// @brief Enumeration of the option window type
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @see ime_option_window_created_cb()
abstract class ime_option_window_type_e {
  /// < Open from Keyboard
  static const int IME_OPTION_WINDOW_TYPE_KEYBOARD = 0;

  /// < Open from Setting application
  static const int IME_OPTION_WINDOW_TYPE_SETTING_APPLICATION = 1;
}

/// @brief Enumeration of layout variation
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @see ime_context_get_layout_variation()
abstract class ime_layout_variation_e {
  /// < The plain normal layout
  static const int IME_LAYOUT_NORMAL_VARIATION_NORMAL = 0;

  /// < Filename layout; symbols such as '/', '*', '\', '|', '&lt;', '&gt;', '?', '&quot;' and ':' should be disabled
  static const int IME_LAYOUT_NORMAL_VARIATION_FILENAME = 1;

  /// < The name of a person
  static const int IME_LAYOUT_NORMAL_VARIATION_PERSON_NAME = 2;

  /// < The plain normal number layout
  static const int IME_LAYOUT_NUMBERONLY_VARIATION_NORMAL = 0;

  /// < The number layout to allow a negative sign
  static const int IME_LAYOUT_NUMBERONLY_VARIATION_SIGNED = 1;

  /// < The number layout to allow decimal point to provide fractional value
  static const int IME_LAYOUT_NUMBERONLY_VARIATION_DECIMAL = 2;

  /// < The number layout to allow decimal point and negative sign
  static const int IME_LAYOUT_NUMBERONLY_VARIATION_SIGNED_AND_DECIMAL = 3;

  /// < The normal password layout
  static const int IME_LAYOUT_PASSWORD_VARIATION_NORMAL = 0;

  /// < The password layout to allow only number
  static const int IME_LAYOUT_PASSWORD_VARIATION_NUMBERONLY = 1;
}

/// @brief Enumeration of string attribute type
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @remarks Currently, a font style is available to use.
///
/// @see ime_preedit_attribute()
/// @see ime_update_preedit_string()
abstract class ime_attribute_type {
  /// < No attribute
  static const int IME_ATTR_NONE = 0;

  /// < A font style attribute, e.g., underline, etc.
  static const int IME_ATTR_FONTSTYLE = 1;
}

/// @brief The structure type to contain the attributes for preedit string.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @remarks A preedit string may have one or more different attributes. This structure describes each attribute of the string.
///
/// @see ime_update_preedit_string()
/// @see ime_attribute_type
class ime_preedit_attribute extends ffi.Struct {
  /// < The start position in the string of this attribute
  @ffi.UnsignedInt()
  external int start;

  /// < The character length of this attribute, the range is [start, start+length]
  @ffi.UnsignedInt()
  external int length;

  /// < The type of this attribute
  @ffi.Int32()
  external int type;

  /// < The value of this attribute
  @ffi.UnsignedInt()
  external int value;
}

class _ime_context extends ffi.Opaque {}

class _ime_device_info extends ffi.Opaque {}

/// @brief The structure type to contain the set of the essential callback functions for IME application lifecycle and appearance.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @remarks These four callback functions are mandatory for IME application.
///
/// @see ime_run()
class ime_callback_s extends ffi.Struct {
  /// < Called when the input panel is created
  external ime_create_cb create;

  /// < Called when the input panel is terminated
  external ime_terminate_cb terminate;

  /// < Called when the input panel is requested to show itself
  external ime_show_cb show1;

  /// < Called when the input panel is requested to hide itself
  external ime_hide_cb hide1;
}

/// @brief Called when the input panel is created.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks This callback function is mandatory and must be registered using ime_run(). The
/// ime_get_main_window() can be used to get the created input panel window.
///
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The ime_run() function calls this callback function.
///
/// @see ime_run()
/// @see ime_set_size()
/// @see ime_get_main_window()
typedef ime_create_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the input panel is terminated.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks This callback function is mandatory and must be registered using ime_run(). The
/// ime_get_main_window() can be used to get the created input panel window.
///
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @see ime_run()
/// @see ime_get_main_window()
typedef ime_terminate_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an associated text input UI control requests the input panel to show itself.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks This callback function is mandatory and must be registered using ime_run().
/// IME application should configure its input panel with #ime_context_h structure information.
/// The ime_get_main_window() can be used to get the created input panel window.
///
/// @param[in] context_id The input context identification value of an associated text input UI control
/// @param[in] context The input context information handle
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @see ime_run()
/// @see ime_get_main_window()
/// @see ime_context_get_layout()
/// @see ime_context_get_layout_variation()
/// @see ime_context_get_cursor_position()
/// @see ime_context_get_autocapital_type()
/// @see ime_context_get_return_key_type()
/// @see ime_context_get_return_key_state()
/// @see ime_context_get_prediction_mode()
/// @see ime_context_get_password_mode()
/// @see ime_context_get_input_hint()
/// @see ime_context_get_bidi_direction()
/// @see ime_context_get_language()
typedef ime_show_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int, ime_context_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Handle of an associated text input UI control's input context.
///
/// @details This is one of parameters of ime_show_cb() callback function. IME application
/// should configure its input panel with this structure information.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @see ime_context_get_layout()
/// @see ime_context_get_layout_variation()
/// @see ime_context_get_cursor_position()
/// @see ime_context_get_autocapital_type()
/// @see ime_context_get_return_key_type()
/// @see ime_context_get_return_key_state()
/// @see ime_context_get_prediction_mode()
/// @see ime_context_get_password_mode()
/// @see ime_context_get_input_hint()
/// @see ime_context_get_bidi_direction()
/// @see ime_context_get_language()
typedef ime_context_h = ffi.Pointer<_ime_context>;

/// @brief Called when an associated text input UI control requests the input panel to hide itself.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks This callback function is mandatory and must be registered using ime_run(). The
/// ime_get_main_window() can be used to get the created input panel window.
///
/// @param[in] context_id The input context identification value of an associated text input UI control
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @see ime_run()
/// @see ime_get_main_window()
typedef ime_hide_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an associated text input UI control has focus.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @param[in] context_id The input context identification value of an associated text input UI control
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_focus_in_cb() function.
///
/// @see ime_event_set_focus_in_cb()
typedef ime_focus_in_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an associated text input UI control loses focus.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @param[in] context_id The input context identification value of an associated text input UI control
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_focus_out_cb() function.
///
/// @see ime_event_set_focus_out_cb()
typedef ime_focus_out_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an associated text input UI control responds to a request with the surrounding text.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks The ime_request_surrounding_text() must be called to invoke this callback function, asynchronously.
///
/// @param[in] context_id The input context identification value of an associated text input UI control
/// @param[in] text The UTF-8 string requested
/// @param[in] cursor_pos The cursor position
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_surrounding_text_updated_cb() function.
///
/// @see ime_event_set_surrounding_text_updated_cb()
/// @see ime_request_surrounding_text()
typedef ime_surrounding_text_updated_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Int, ffi.Pointer<ffi.Char>, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to reset the input context of an associated text input UI control.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_input_context_reset_cb() function.
///
/// @see ime_event_set_input_context_reset_cb()
typedef ime_input_context_reset_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Void Function(ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the position of the cursor in an associated text input UI control changes.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @param[in] cursor_pos The cursor position
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_cursor_position_updated_cb() function.
///
/// @see ime_event_set_cursor_position_updated_cb()
typedef ime_cursor_position_updated_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an associated text input UI control requests the language from the input panel.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks The allocated @a lang_code will be released internally.
///
/// @param[in] user_data User data to be passed from the callback registration function
/// @param[out] lang_code Input panel's current input language code (e.g., &quot;en_US&quot;)
///
/// @pre The callback can be registered using ime_event_set_language_requested_cb() function.
///
/// @see ime_event_set_language_requested_cb()
typedef ime_language_requested_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>;

/// @brief Called to set the preferred language to the input panel.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks @a language information is already set to the input panel when it is shown
/// through #ime_context_h. This callback function will be only called when the client
/// application changes the edit field's language attribute after the input panel is shown.
///
/// @param[in] language The preferred language that the client application wants
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_language_set_cb() function.
///
/// @see ime_event_set_language_set_cb()
typedef ime_language_set_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @typedef Ecore_IMF_Input_Panel_Lang
///
/// Input panel (virtual keyboard) language modes.
///
/// @see ecore_imf_context_input_panel_language_set()
abstract class Ecore_IMF_Input_Panel_Lang {
  /// < Automatic @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_LANG_AUTOMATIC = 0;

  /// < Alphabet @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_LANG_ALPHABET = 1;
}

/// @brief Called to set the application specific data to deliver to the input panel.
///
/// @details This API is used by the applications to deliver the specific data to the input panel.
/// The data format MUST be negotiated by both application and input panel.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @param[in] data The specific data to be set to the input panel
/// @param[in] data_length The length of data, in bytes, to send to the input panel
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_imdata_set_cb() function.
///
/// @see ime_event_set_imdata_set_cb()
typedef ime_imdata_set_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<ffi.Void>, ffi.UnsignedInt, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an associated text input UI control requests the application specific data from the input panel.
///
/// @details This API is used by the applications to request the specific data from the input panel.
/// The data format MUST be negotiated by both application and input panel.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks The allocated @a data will be released internally.
///
/// @param[in] user_data User data to be passed from the callback registration function
/// @param[out] data Input panel's data to be set to the application
/// @param[out] data_length The length of data, in bytes, to send to the application
///
/// @pre The callback can be registered using ime_event_set_imdata_requested_cb() function.
///
/// @see ime_event_set_imdata_requested_cb()
typedef ime_imdata_requested_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Void>,
            ffi.Pointer<ffi.Pointer<ffi.Void>>, ffi.Pointer<ffi.UnsignedInt>)>>;

/// @brief Called when an associated text input UI control requests the input panel to set its layout.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks @a layout information is already set to the input panel when it is shown
/// through #ime_context_h. This callback function will be only called when the client
/// application changes the edit field's layout attribute after the input panel is shown.
///
/// @param[in] layout The input panel layout
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_layout_set_cb() function.
///
/// @see ime_event_set_layout_set_cb()
typedef ime_layout_set_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @typedef Ecore_IMF_Input_Panel_Layout
///
/// Input panel (virtual keyboard) layout types.
///
/// @see ecore_imf_context_input_panel_layout_set()
abstract class Ecore_IMF_Input_Panel_Layout {
  /// < Default layout
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_NORMAL = 0;

  /// < Number layout
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_NUMBER = 1;

  /// < Email layout
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_EMAIL = 2;

  /// < URL layout
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_URL = 3;

  /// < Phone Number layout
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_PHONENUMBER = 4;

  /// < IP layout
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_IP = 5;

  /// < Month layout
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_MONTH = 6;

  /// < Number Only layout
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_NUMBERONLY = 7;

  /// < Never use this
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_INVALID = 8;

  /// < Hexadecimal layout @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_HEX = 9;

  /// < Command-line terminal layout including ESC, Alt, Ctrl key, so on (no auto-correct, no auto-capitalization) @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_TERMINAL = 10;

  /// < Like normal, but no auto-correct, no auto-capitalization etc. @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_PASSWORD = 11;

  /// < Date and time layout @since 1.8
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_DATETIME = 12;

  /// < Emoticon layout @since 1.10
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_EMOTICON = 13;

  /// < Voice layout, but if the IME does not support voice layout, then normal layout will be shown @since 1.19
  static const int ECORE_IMF_INPUT_PANEL_LAYOUT_VOICE = 14;
}

/// @brief Called when an associated text input UI control requests the input panel to set the @c Return key label.
/// The input panel can show text or image on the @c Return button according to the @c Return key action.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks @a type information is already set to the input panel when it is shown
/// through #ime_context_h. This callback function will be only called when the client
/// application changes the edit field's @c Return key type attribute after the input panel
/// is shown.
///
/// @param[in] type The type of @c Return key on the input panel
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_return_key_type_set_cb() function.
///
/// @see ime_event_set_return_key_type_set_cb()
typedef ime_return_key_type_set_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @typedef Ecore_IMF_Input_Panel_Return_Key_Type
///
/// "Return" Key types on the input panel (virtual keyboard).
///
/// @see ecore_imf_context_input_panel_return_key_type_set()
abstract class Ecore_IMF_Input_Panel_Return_Key_Type {
  /// < Default @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_RETURN_KEY_TYPE_DEFAULT = 0;

  /// < Done @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_RETURN_KEY_TYPE_DONE = 1;

  /// < Go @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_RETURN_KEY_TYPE_GO = 2;

  /// < Join @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_RETURN_KEY_TYPE_JOIN = 3;

  /// < Login @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_RETURN_KEY_TYPE_LOGIN = 4;

  /// < Next @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_RETURN_KEY_TYPE_NEXT = 5;

  /// < Search or magnifier icon @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_RETURN_KEY_TYPE_SEARCH = 6;

  /// < Send @since 1.2
  static const int ECORE_IMF_INPUT_PANEL_RETURN_KEY_TYPE_SEND = 7;

  /// < Sign-in @since 1.8
  static const int ECORE_IMF_INPUT_PANEL_RETURN_KEY_TYPE_SIGNIN = 8;
}

/// @brief Called when an associated text input UI control requests the input panel to enable
/// or disable the @c Return key state.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks @a disabled information is already set to the input panel when it is shown
/// through #ime_context_h. This callback function will be only called when the client
/// application changes the edit field's @c Return key disable attribute after the input panel
/// is shown.
///
/// @param[in] disabled The Boolean state to disable @c Return key. The @c Return key is enabled by default
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_return_key_state_set_cb() function.
///
/// @see ime_event_set_return_key_state_set_cb()
typedef ime_return_key_state_set_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an associated text input UI control requests the position and size from the input panel.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @param[in] user_data User data to be passed from the callback registration function
/// @param[out] x The x position in screen
/// @param[out] y The y position in screen
/// @param[out] w The window width
/// @param[out] h The window height
///
/// @pre The callback can be registered using ime_event_set_geometry_requested_cb() function.
///
/// @see ime_event_set_geometry_requested_cb()
typedef ime_geometry_requested_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Void>, ffi.Pointer<ffi.Int>,
            ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>, ffi.Pointer<ffi.Int>)>>;

/// @brief Called when the key event is received from the external devices or ime_send_key_event() function.
///
/// @details This function processes the key event before an associated text input UI control does.
///
/// @remarks If the key event is from the external device, @a dev_info will have its name, class and subclass information.
///
/// @param[in] keycode The key code to be sent
/// @param[in] keymask The modifier key mask
/// @param[in] dev_info The device information handle
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @return @c true if the event is processed, otherwise the event is not processed and is forwarded to the client application.
///
/// @pre The callback can be registered using ime_event_set_process_key_event_cb() function.
///
/// @see ime_event_set_process_key_event_cb()
/// @see ime_device_info_get_name()
/// @see ime_device_info_get_class()
/// @see ime_device_info_get_subclass()
/// @see ime_send_key_event()
/// @see ime_commit_string()
/// @see ime_show_preedit_string()
/// @see ime_hide_preedit_string()
/// @see ime_update_preedit_string()
typedef ime_process_key_event_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            ffi.Int32, ffi.Int32, ime_device_info_h, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for the key codes.
/// If keycode & 0xff000000 == 0x01000000 then this key code is directly encoded 24-bit UCS character.
/// The UCS value is keycode & 0x00ffffff.
/// @details Defines the list of keys supported by the system.
/// Note that certain keys may not be available on all devices.
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class ime_key_code_e {
  /// < The backspace key
  static const int IME_KEY_BackSpace = 65288;

  /// < The tab key
  static const int IME_KEY_Tab = 65289;

  /// < The linefeed key
  static const int IME_KEY_Linefeed = 65290;

  /// < The clear key
  static const int IME_KEY_Clear = 65291;

  /// < The return key
  static const int IME_KEY_Return = 65293;

  /// < The pause key
  static const int IME_KEY_Pause = 65299;

  /// < The scroll lock key
  static const int IME_KEY_Scroll_Lock = 65300;

  /// < The sys req key
  static const int IME_KEY_Sys_Req = 65301;

  /// < The escape key
  static const int IME_KEY_Escape = 65307;

  /// < The delete key
  static const int IME_KEY_Delete = 65535;

  /// < The home key
  static const int IME_KEY_Home = 65360;

  /// < The left directional key
  static const int IME_KEY_Left = 65361;

  /// < The up directional key
  static const int IME_KEY_Up = 65362;

  /// < The right directional key
  static const int IME_KEY_Right = 65363;

  /// < The down directional key
  static const int IME_KEY_Down = 65364;

  /// < The prior, previous key
  static const int IME_KEY_Prior = 65365;

  /// < The page up key
  static const int IME_KEY_Page_Up = 65365;

  /// < The next key
  static const int IME_KEY_Next = 65366;

  /// < The page down key
  static const int IME_KEY_Page_Down = 65366;

  /// < The end key
  static const int IME_KEY_End = 65367;

  /// < The begin key
  static const int IME_KEY_Begin = 65368;

  /// < The select key
  static const int IME_KEY_Select = 65376;

  /// < The print key
  static const int IME_KEY_Print = 65377;

  /// < The execute, run, do key
  static const int IME_KEY_Execute = 65378;

  /// < The insert key
  static const int IME_KEY_Insert = 65379;

  /// < The undo key
  static const int IME_KEY_Undo = 65381;

  /// < The redo key
  static const int IME_KEY_Redo = 65382;

  /// < The menu key
  static const int IME_KEY_Menu = 65383;

  /// < The find key
  static const int IME_KEY_Find = 65384;

  /// < The cancel, stop, abort, exit key
  static const int IME_KEY_Cancel = 65385;

  /// < The help key
  static const int IME_KEY_Help = 65386;

  /// < The break key
  static const int IME_KEY_Break = 65387;

  /// < The character set switch key
  static const int IME_KEY_Mode_switch = 65406;

  /// < The num lock key
  static const int IME_KEY_Num_Lock = 65407;

  /// < The Numpad space key
  static const int IME_KEY_KP_Space = 65408;

  /// < The Numpad tab key
  static const int IME_KEY_KP_Tab = 65417;

  /// < The Numpad enter key
  static const int IME_KEY_KP_Enter = 65421;

  /// < The Numpad function 1 key
  static const int IME_KEY_KP_F1 = 65425;

  /// < The Numpad function 2 key
  static const int IME_KEY_KP_F2 = 65426;

  /// < The Numpad function 3 key
  static const int IME_KEY_KP_F3 = 65427;

  /// < The Numpad function 4 key
  static const int IME_KEY_KP_F4 = 65428;

  /// < The Numpad home key
  static const int IME_KEY_KP_Home = 65429;

  /// < The Numpad left key
  static const int IME_KEY_KP_Left = 65430;

  /// < The Numpad up key
  static const int IME_KEY_KP_Up = 65431;

  /// < The Numpad right key
  static const int IME_KEY_KP_Right = 65432;

  /// < The Numpad down key
  static const int IME_KEY_KP_Down = 65433;

  /// < The Numpad prior, previous key
  static const int IME_KEY_KP_Prior = 65434;

  /// < The Numpad page up key
  static const int IME_KEY_KP_Page_Up = 65434;

  /// < The Numpad next key
  static const int IME_KEY_KP_Next = 65435;

  /// < The Numpad page down key
  static const int IME_KEY_KP_Page_Down = 65435;

  /// < The Numpad end key
  static const int IME_KEY_KP_End = 65436;

  /// < The Numpad begin key
  static const int IME_KEY_KP_Begin = 65437;

  /// < The Numpad insert key
  static const int IME_KEY_KP_Insert = 65438;

  /// < The Numpad delete key
  static const int IME_KEY_KP_Delete = 65439;

  /// < The Numpad equal key
  static const int IME_KEY_KP_Equal = 65469;

  /// < The Numpad multiply key
  static const int IME_KEY_KP_Multiply = 65450;

  /// < The Numpad add key
  static const int IME_KEY_KP_Add = 65451;

  /// < The Numpad separator key
  static const int IME_KEY_KP_Separator = 65452;

  /// < The Numpad subtract key
  static const int IME_KEY_KP_Subtract = 65453;

  /// < The Numpad decimal key
  static const int IME_KEY_KP_Decimal = 65454;

  /// < The Numpad divide key
  static const int IME_KEY_KP_Divide = 65455;

  /// < The Numpad 0 key
  static const int IME_KEY_KP_0 = 65456;

  /// < The Numpad 1 key
  static const int IME_KEY_KP_1 = 65457;

  /// < The Numpad 2 key
  static const int IME_KEY_KP_2 = 65458;

  /// < The Numpad 3 key
  static const int IME_KEY_KP_3 = 65459;

  /// < The Numpad 4 key
  static const int IME_KEY_KP_4 = 65460;

  /// < The Numpad 5 key
  static const int IME_KEY_KP_5 = 65461;

  /// < The Numpad 6 key
  static const int IME_KEY_KP_6 = 65462;

  /// < The Numpad 7 key
  static const int IME_KEY_KP_7 = 65463;

  /// < The Numpad 8 key
  static const int IME_KEY_KP_8 = 65464;

  /// < The Numpad 9 key
  static const int IME_KEY_KP_9 = 65465;

  /// < The function 1 key
  static const int IME_KEY_F1 = 65470;

  /// < The function 2 key
  static const int IME_KEY_F2 = 65471;

  /// < The function 3 key
  static const int IME_KEY_F3 = 65472;

  /// < The function 4 key
  static const int IME_KEY_F4 = 65473;

  /// < The function 5 key
  static const int IME_KEY_F5 = 65474;

  /// < The function 6 key
  static const int IME_KEY_F6 = 65475;

  /// < The function 7 key
  static const int IME_KEY_F7 = 65476;

  /// < The function 8 key
  static const int IME_KEY_F8 = 65477;

  /// < The function 9 key
  static const int IME_KEY_F9 = 65478;

  /// < The function 10 key
  static const int IME_KEY_F10 = 65479;

  /// < The function 11 key
  static const int IME_KEY_F11 = 65480;

  /// < The function 12 key
  static const int IME_KEY_F12 = 65481;

  /// < The function 13 key
  static const int IME_KEY_F13 = 65482;

  /// < The function 14 key
  static const int IME_KEY_F14 = 65483;

  /// < The function 15 key
  static const int IME_KEY_F15 = 65484;

  /// < The function 16 key
  static const int IME_KEY_F16 = 65485;

  /// < The function 17 key
  static const int IME_KEY_F17 = 65486;

  /// < The function 18 key
  static const int IME_KEY_F18 = 65487;

  /// < The function 19 key
  static const int IME_KEY_F19 = 65488;

  /// < The function 20 key
  static const int IME_KEY_F20 = 65489;

  /// < The function 21 key
  static const int IME_KEY_F21 = 65490;

  /// < The function 22 key
  static const int IME_KEY_F22 = 65491;

  /// < The function 23 key
  static const int IME_KEY_F23 = 65492;

  /// < The function 24 key
  static const int IME_KEY_F24 = 65493;

  /// < The function 25 key
  static const int IME_KEY_F25 = 65494;

  /// < The function 26 key
  static const int IME_KEY_F26 = 65495;

  /// < The function 27 key
  static const int IME_KEY_F27 = 65496;

  /// < The function 28 key
  static const int IME_KEY_F28 = 65497;

  /// < The function 29 key
  static const int IME_KEY_F29 = 65498;

  /// < The function 30 key
  static const int IME_KEY_F30 = 65499;

  /// < The function 31 key
  static const int IME_KEY_F31 = 65500;

  /// < The function 32 key
  static const int IME_KEY_F32 = 65501;

  /// < The function 33 key
  static const int IME_KEY_F33 = 65502;

  /// < The function 34 key
  static const int IME_KEY_F34 = 65503;

  /// < The function 35 key
  static const int IME_KEY_F35 = 65504;

  /// < The left shift key
  static const int IME_KEY_Shift_L = 65505;

  /// < The right shift key
  static const int IME_KEY_Shift_R = 65506;

  /// < The left control key
  static const int IME_KEY_Control_L = 65507;

  /// < The right control key
  static const int IME_KEY_Control_R = 65508;

  /// < The caps lock key
  static const int IME_KEY_Caps_Lock = 65509;

  /// < The shift lock key
  static const int IME_KEY_Shift_Lock = 65510;

  /// < The left meta key
  static const int IME_KEY_Meta_L = 65511;

  /// < The right meta key
  static const int IME_KEY_Meta_R = 65512;

  /// < The left alt key
  static const int IME_KEY_Alt_L = 65513;

  /// < The right alt key
  static const int IME_KEY_Alt_R = 65514;

  /// < The left super key
  static const int IME_KEY_Super_L = 65515;

  /// < The right super key
  static const int IME_KEY_Super_R = 65516;

  /// < The left hyper key
  static const int IME_KEY_Hyper_L = 65517;

  /// < The right hyper key
  static const int IME_KEY_Hyper_R = 65518;

  /// < The space key
  static const int IME_KEY_space = 32;

  /// < The exclamation key
  static const int IME_KEY_exclam = 33;

  /// < The quotedbl key
  static const int IME_KEY_quotedbl = 34;

  /// < The number sign key
  static const int IME_KEY_numbersign = 35;

  /// < The dollar key
  static const int IME_KEY_dollar = 36;

  /// < The percent key
  static const int IME_KEY_percent = 37;

  /// < The ampersand key
  static const int IME_KEY_ampersand = 38;

  /// < The apostrophe key
  static const int IME_KEY_apostrophe = 39;

  /// < The parenleft key
  static const int IME_KEY_parenleft = 40;

  /// < The parenright key
  static const int IME_KEY_parenright = 41;

  /// < The asterisk key
  static const int IME_KEY_asterisk = 42;

  /// < The plus key
  static const int IME_KEY_plus = 43;

  /// < The comma key
  static const int IME_KEY_comma = 44;

  /// < The minus key
  static const int IME_KEY_minus = 45;

  /// < The period key
  static const int IME_KEY_period = 46;

  /// < The slash key
  static const int IME_KEY_slash = 47;

  /// < The 0 key
  static const int IME_KEY_0 = 48;

  /// < The 1 key
  static const int IME_KEY_1 = 49;

  /// < The 2 key
  static const int IME_KEY_2 = 50;

  /// < The 3 key
  static const int IME_KEY_3 = 51;

  /// < The 4 key
  static const int IME_KEY_4 = 52;

  /// < The 5 key
  static const int IME_KEY_5 = 53;

  /// < The 6 key
  static const int IME_KEY_6 = 54;

  /// < The 7 key
  static const int IME_KEY_7 = 55;

  /// < The 8 key
  static const int IME_KEY_8 = 56;

  /// < The 9 key
  static const int IME_KEY_9 = 57;

  /// < The colon key
  static const int IME_KEY_colon = 58;

  /// < The semicolon key
  static const int IME_KEY_semicolon = 59;

  /// < The less key
  static const int IME_KEY_less = 60;

  /// < The equal key
  static const int IME_KEY_equal = 61;

  /// < The greater key
  static const int IME_KEY_greater = 62;

  /// < The question key
  static const int IME_KEY_question = 63;

  /// < The at key
  static const int IME_KEY_at = 64;

  /// < The A key
  static const int IME_KEY_A = 65;

  /// < The B key
  static const int IME_KEY_B = 66;

  /// < The C key
  static const int IME_KEY_C = 67;

  /// < The D key
  static const int IME_KEY_D = 68;

  /// < The E key
  static const int IME_KEY_E = 69;

  /// < The F key
  static const int IME_KEY_F = 70;

  /// < The G key
  static const int IME_KEY_G = 71;

  /// < The H key
  static const int IME_KEY_H = 72;

  /// < The I key
  static const int IME_KEY_I = 73;

  /// < The J key
  static const int IME_KEY_J = 74;

  /// < The K key
  static const int IME_KEY_K = 75;

  /// < The L key
  static const int IME_KEY_L = 76;

  /// < The M key
  static const int IME_KEY_M = 77;

  /// < The N key
  static const int IME_KEY_N = 78;

  /// < The O key
  static const int IME_KEY_O = 79;

  /// < The P key
  static const int IME_KEY_P = 80;

  /// < The Q key
  static const int IME_KEY_Q = 81;

  /// < The R key
  static const int IME_KEY_R = 82;

  /// < The S key
  static const int IME_KEY_S = 83;

  /// < The T key
  static const int IME_KEY_T = 84;

  /// < The U key
  static const int IME_KEY_U = 85;

  /// < The V key
  static const int IME_KEY_V = 86;

  /// < The W key
  static const int IME_KEY_W = 87;

  /// < The X key
  static const int IME_KEY_X = 88;

  /// < The Y key
  static const int IME_KEY_Y = 89;

  /// < The Z key
  static const int IME_KEY_Z = 90;

  /// < The left bracket key
  static const int IME_KEY_bracketleft = 91;

  /// < The backslash key
  static const int IME_KEY_backslash = 92;

  /// < The right bracket key
  static const int IME_KEY_bracketright = 93;

  /// < The circumflex key
  static const int IME_KEY_asciicircum = 94;

  /// < The underscore key
  static const int IME_KEY_underscore = 95;

  /// < The grave key
  static const int IME_KEY_grave = 96;

  /// < The a key
  static const int IME_KEY_a = 97;

  /// < The b key
  static const int IME_KEY_b = 98;

  /// < The c key
  static const int IME_KEY_c = 99;

  /// < The d key
  static const int IME_KEY_d = 100;

  /// < The e key
  static const int IME_KEY_e = 101;

  /// < The f key
  static const int IME_KEY_f = 102;

  /// < The g key
  static const int IME_KEY_g = 103;

  /// < The h key
  static const int IME_KEY_h = 104;

  /// < The i key
  static const int IME_KEY_i = 105;

  /// < The j key
  static const int IME_KEY_j = 106;

  /// < The k key
  static const int IME_KEY_k = 107;

  /// < The l key
  static const int IME_KEY_l = 108;

  /// < The m key
  static const int IME_KEY_m = 109;

  /// < The n key
  static const int IME_KEY_n = 110;

  /// < The o key
  static const int IME_KEY_o = 111;

  /// < The p key
  static const int IME_KEY_p = 112;

  /// < The q key
  static const int IME_KEY_q = 113;

  /// < The r key
  static const int IME_KEY_r = 114;

  /// < The s key
  static const int IME_KEY_s = 115;

  /// < The t key
  static const int IME_KEY_t = 116;

  /// < The u key
  static const int IME_KEY_u = 117;

  /// < The v key
  static const int IME_KEY_v = 118;

  /// < The w key
  static const int IME_KEY_w = 119;

  /// < The x key
  static const int IME_KEY_x = 120;

  /// < The y key
  static const int IME_KEY_y = 121;

  /// < The z key
  static const int IME_KEY_z = 122;

  /// < The left brace key
  static const int IME_KEY_braceleft = 123;

  /// < The bar key
  static const int IME_KEY_bar = 124;

  /// < The right brace key
  static const int IME_KEY_braceright = 125;

  /// < The tilde key
  static const int IME_KEY_asciitilde = 126;
}

/// @brief Enumeration for the key masks.
/// The key masks indicate which modifier keys is pressed down during the keyboard hit.
/// The special IME_KEY_MASK_RELEASED indicates the key release event.
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class ime_key_mask_e {
  /// < Key press event without modifier key
  static const int IME_KEY_MASK_PRESSED = 0;

  /// < The Shift key is pressed down
  static const int IME_KEY_MASK_SHIFT = 1;

  /// < The CapsLock key is pressed down
  static const int IME_KEY_MASK_CAPSLOCK = 2;

  /// < The Control key is pressed down
  static const int IME_KEY_MASK_CONTROL = 4;

  /// < The Alt key is pressed down
  static const int IME_KEY_MASK_ALT = 8;

  /// < The Meta key is pressed down
  static const int IME_KEY_MASK_META = 16;

  /// < The Win (between Control and Alt) is pressed down
  static const int IME_KEY_MASK_WIN = 32;

  /// < The Hyper key is pressed down
  static const int IME_KEY_MASK_HYPER = 64;

  /// < The NumLock key is pressed down
  static const int IME_KEY_MASK_NUMLOCK = 128;

  /// < Key release event
  static const int IME_KEY_MASK_RELEASED = 32768;
}

/// @brief Handle of the device information of the key event.
///
/// @details This is one of parameters of ime_process_key_event_cb() callback function. IME application
/// may distinguish the key event by using this if necessary.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @see ime_process_key_event_cb()
/// @see ime_device_info_get_name()
/// @see ime_device_info_get_class()
/// @see ime_device_info_get_subclass()
typedef ime_device_info_h = ffi.Pointer<_ime_device_info>;

/// @brief Called when the system display language is changed.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @param[in] language The language code
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_display_language_changed_cb() function.
///
/// @see ime_event_set_display_language_changed_cb()
typedef ime_display_language_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the device is rotated.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @param[in] degree The rotation degree
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_rotation_degree_changed_cb() function.
///
/// @see ime_event_set_rotation_degree_changed_cb()
typedef ime_rotation_degree_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when Accessibility in Settings application is on or off.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @param[in] state Accessibility option state
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_accessibility_state_changed_cb() function.
///
/// @see ime_event_set_accessibility_state_changed_cb()
typedef ime_accessibility_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to create the option window.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks if Input panel requests to open the option window, @a type will be #IME_OPTION_WINDOW_TYPE_KEYBOARD.
/// And if Settings application requests to open it, @a type will be #IME_OPTION_WINDOW_TYPE_SETTING_APPLICATION.
///
/// @param[in] window The created window object
/// @param[in] type The type of option window
/// @param[in] user_data User data to be passed from the callback registration function
///
/// @pre The callback can be registered using ime_event_set_option_window_created_cb() function. The
/// ime_create_option_window() calls this callback function or Settings application can call this callback function.
///
/// @see ime_event_set_option_window_created_cb()
/// @see ime_create_option_window()
typedef ime_option_window_created_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(
            ffi.Pointer<Evas_Object>, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called to destroy the option window.
///
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @param[in] window The window object to destroy
/// @param[in] user_data User data to be passed to the callback function
///
/// @pre The callback can be registered using ime_event_set_option_window_destroyed_cb() function.
/// ime_destroy_option_window() calls this callback function.
///
/// @see ime_event_set_option_window_destroyed_cb()
typedef ime_option_window_destroyed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<Evas_Object>, ffi.Pointer<ffi.Void>)>>;

/// @typedef Eina_List
/// Type for a generic double linked list.
typedef Eina_List = _Eina_List;

/// @struct _Eina_List
/// Type for a generic double linked list.
class _Eina_List extends ffi.Opaque {}

/// @typedef Ecore_IMF_Autocapital_Type
///
/// Autocapitalization Types.
///
/// @see ecore_imf_context_autocapital_type_set()
abstract class Ecore_IMF_Autocapital_Type {
  /// < No auto-capitalization when typing @since 1.1
  static const int ECORE_IMF_AUTOCAPITAL_TYPE_NONE = 0;

  /// < Autocapitalize each word typed @since 1.1
  static const int ECORE_IMF_AUTOCAPITAL_TYPE_WORD = 1;

  /// < Autocapitalize the start of each sentence @since 1.1
  static const int ECORE_IMF_AUTOCAPITAL_TYPE_SENTENCE = 2;

  /// < Autocapitalize all letters @since 1.1
  static const int ECORE_IMF_AUTOCAPITAL_TYPE_ALLCHARACTER = 3;
}

/// @typedef Ecore_IMF_Input_Hints
/// @brief Enumeration for defining the types of Ecore_IMF Input Hints.
/// @since 1.12
abstract class Ecore_IMF_Input_Hints {
  /// < No active hints @since 1.12
  static const int ECORE_IMF_INPUT_HINT_NONE = 0;

  /// < Suggest word auto completion @since 1.12
  static const int ECORE_IMF_INPUT_HINT_AUTO_COMPLETE = 1;

  /// < Typed text should not be stored. @since 1.12
  static const int ECORE_IMF_INPUT_HINT_SENSITIVE_DATA = 2;

  /// < Multiline text @since 1.18
  static const int ECORE_IMF_INPUT_HINT_MULTILINE = 4;
}

/// @typedef Ecore_IMF_BiDi_Direction
/// @brief Enumeration for defining the types of Ecore_IMF bidirectionality.
/// @since 1.12
abstract class Ecore_IMF_BiDi_Direction {
  /// < The Neutral mode @since 1.12
  static const int ECORE_IMF_BIDI_DIRECTION_NEUTRAL = 0;

  /// < The Left to Right mode @since 1.12
  static const int ECORE_IMF_BIDI_DIRECTION_LTR = 1;

  /// < The Right to Left mode @since 1.12
  static const int ECORE_IMF_BIDI_DIRECTION_RTL = 2;
}

abstract class Ecore_IMF_Device_Class {
  /// < Not a device @since 1.14
  static const int ECORE_IMF_DEVICE_CLASS_NONE = 0;

  /// < The user/seat (the user themselves) @since 1.14
  static const int ECORE_IMF_DEVICE_CLASS_SEAT = 1;

  /// < A regular keyboard, numberpad or attached buttons @since 1.14
  static const int ECORE_IMF_DEVICE_CLASS_KEYBOARD = 2;

  /// < A mouse, trackball or touchpad relative motion device @since 1.14
  static const int ECORE_IMF_DEVICE_CLASS_MOUSE = 3;

  /// < A touchscreen with fingers or stylus @since 1.14
  static const int ECORE_IMF_DEVICE_CLASS_TOUCH = 4;

  /// < A special pen device @since 1.14
  static const int ECORE_IMF_DEVICE_CLASS_PEN = 5;

  /// < A laser pointer, wii-style or "minority report" pointing device @since 1.14
  static const int ECORE_IMF_DEVICE_CLASS_POINTER = 6;

  /// <  A gamepad controller or joystick @since 1.14
  static const int ECORE_IMF_DEVICE_CLASS_GAMEPAD = 7;
}

abstract class Ecore_IMF_Device_Subclass {
  /// < Not a device @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_NONE = 0;

  /// < The normal flat of your finger @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_FINGER = 1;

  /// < A fingernail @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_FINGERNAIL = 2;

  /// < A Knuckle @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_KNUCKLE = 3;

  /// < The palm of a users hand @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_PALM = 4;

  /// < The side of your hand @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_HAND_SIZE = 5;

  /// < The flat of your hand @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_HAND_FLAT = 6;

  /// < The tip of a pen @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_PEN_TIP = 7;

  /// < A trackpad style mouse @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_TRACKPAD = 8;

  /// < A trackpoint style mouse @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_TRACKPOINT = 9;

  /// < A trackball style mouse @since 1.14
  static const int ECORE_IMF_DEVICE_SUBCLASS_TRACKBALL = 10;

  /// < A remote controller @since_tizen 4.0
  static const int ECORE_IMF_DEVICE_SUBCLASS_REMOCON = 11;

  /// < A virtual keyboard @since_tizen 4.0
  static const int ECORE_IMF_DEVICE_SUBCLASS_VIRTUAL_KEYBOARD = 12;
}

/// @brief Called to set the prediction hint string to deliver to the input panel.
///
/// @since_tizen 4.0
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks @a prediction_hint is valid only in the callback. To use outside the callback, make a copy.
/// This function is used by the applications to deliver the prediction hint message to the input panel.
///
/// @param[in] prediction_hint The prediction hint to be set to the input panel
/// @param[in] user_data User data to be passed to the callback function
///
/// @pre The callback can be registered using ime_event_set_prediction_hint_set_cb() function.
///
/// @see ime_event_set_prediction_hint_set_cb()
typedef ime_prediction_hint_set_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an associated text input UI control requests the text entry to set the MIME type.
///
/// @since_tizen 4.0
///
/// @privlevel public
///
/// @privilege %http://tizen.org/privilege/ime
///
/// @remarks @a mime_type is valid only in the callback. To use outside the callback, make a copy.
/// This function is used by the applications to deliver the MIME type to the input panel.
///
/// @param[in] mime_type The MIME type to be set to the input panel
/// @param[in] user_data User data to be passed to the callback function
///
/// @pre The callback can be registered using ime_event_set_mime_type_set_request_cb() function.
///
/// @see ime_event_set_mime_type_set_request_cb()
typedef ime_mime_type_set_request_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for input method manager function error.
/// @since_tizen @if MOBILE 2.4 @else 3.0 @endif
abstract class ime_manager_error_e {
  /// < Successful
  static const int IME_MANAGER_ERROR_NONE = 0;

  /// < Invalid parameter
  static const int IME_MANAGER_ERROR_INVALID_PARAMETER = -22;

  /// < Permission denied
  static const int IME_MANAGER_ERROR_PERMISSION_DENIED = -13;

  /// < Operation failed
  static const int IME_MANAGER_ERROR_OPERATION_FAILED = -49414128;
}

/// @brief Enumeration for error codes.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class stt_error_e {
  /// < Successful
  static const int STT_ERROR_NONE = 0;

  /// < Out of Memory
  static const int STT_ERROR_OUT_OF_MEMORY = -12;

  /// < I/O error
  static const int STT_ERROR_IO_ERROR = -5;

  /// < Invalid parameter
  static const int STT_ERROR_INVALID_PARAMETER = -22;

  /// < No answer from the STT service
  static const int STT_ERROR_TIMED_OUT = -1073741823;

  /// < Device or resource busy
  static const int STT_ERROR_RECORDER_BUSY = -16;

  /// < Network is down
  static const int STT_ERROR_OUT_OF_NETWORK = -100;

  /// < Permission denied
  static const int STT_ERROR_PERMISSION_DENIED = -13;

  /// < STT NOT supported
  static const int STT_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Invalid state
  static const int STT_ERROR_INVALID_STATE = -49283071;

  /// < Invalid language
  static const int STT_ERROR_INVALID_LANGUAGE = -49283070;

  /// < No available engine
  static const int STT_ERROR_ENGINE_NOT_FOUND = -49283069;

  /// < Operation failed
  static const int STT_ERROR_OPERATION_FAILED = -49283068;

  /// < Not supported feature of current engine
  static const int STT_ERROR_NOT_SUPPORTED_FEATURE = -49283067;

  /// < Recording timed out @if MOBILE (Since 3.0) @elseif WEARABLE (Since 2.3.2) @endif
  static const int STT_ERROR_RECORDING_TIMED_OUT = -49283066;

  /// < No speech while recording @if MOBILE (Since 3.0) @elseif WEARABLE (Since 2.3.2) @endif
  static const int STT_ERROR_NO_SPEECH = -49283065;

  /// < Progress to ready is not finished @if MOBILE (Since 3.0) @elseif WEARABLE (Since 2.3.2) @endif
  static const int STT_ERROR_IN_PROGRESS_TO_READY = -49283064;

  /// < Progress to recording is not finished @if MOBILE (Since 3.0) @elseif WEARABLE (Since 2.3.2) @endif
  static const int STT_ERROR_IN_PROGRESS_TO_RECORDING = -49283063;

  /// < Progress to processing is not finished @if MOBILE (Since 3.0) @elseif WEARABLE (Since 2.3.2) @endif
  static const int STT_ERROR_IN_PROGRESS_TO_PROCESSING = -49283056;

  /// < Service reset @if MOBILE (Since 3.0) @elseif WEARABLE (Since 2.3.2) @endif
  static const int STT_ERROR_SERVICE_RESET = -49283055;
}

/// @brief Enumeration for state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class stt_state_e {
  /// < 'CREATED' state
  static const int STT_STATE_CREATED = 0;

  /// < 'READY' state
  static const int STT_STATE_READY = 1;

  /// < 'RECORDING' state
  static const int STT_STATE_RECORDING = 2;

  /// < 'PROCESSING' state
  static const int STT_STATE_PROCESSING = 3;
}

/// @brief Enumeration for result event.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class stt_result_event_e {
  /// < Event when the recognition full or last result is ready
  static const int STT_RESULT_EVENT_FINAL_RESULT = 0;

  /// < Event when the recognition partial result is ready
  static const int STT_RESULT_EVENT_PARTIAL_RESULT = 1;

  /// < Event when the recognition has failed
  static const int STT_RESULT_EVENT_ERROR = 2;
}

/// @brief Enumeration for result time callback event.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class stt_result_time_event_e {
  /// < Event when the token is beginning type
  static const int STT_RESULT_TIME_EVENT_BEGINNING = 0;

  /// < Event when the token is middle type
  static const int STT_RESULT_TIME_EVENT_MIDDLE = 1;

  /// < Event when the token is end type
  static const int STT_RESULT_TIME_EVENT_END = 2;
}

/// @brief Enumeration for silence detection type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class stt_option_silence_detection_e {
  /// < Silence detection type - False
  static const int STT_OPTION_SILENCE_DETECTION_FALSE = 0;

  /// < Silence detection type - True
  static const int STT_OPTION_SILENCE_DETECTION_TRUE = 1;

  /// < Silence detection type - Auto
  static const int STT_OPTION_SILENCE_DETECTION_AUTO = 2;
}

class stt_s extends ffi.Opaque {}

/// @brief A structure of STT handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef stt_h = ffi.Pointer<stt_s>;

/// @brief Called to get the engine information.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] engine_id Engine ID
/// @param[in] engine_name Engine name
/// @param[in] user_data User data passed from the stt_setting_foreach_supported_engines()
/// @return @c true to continue with the next iteration of the loop,
/// otherwise @c false to break out of the loop
/// @pre stt_foreach_supported_engines() will invoke this callback.
/// @see stt_foreach_supported_engines()
typedef stt_supported_engine_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(stt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called to retrieve the supported languages.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks The language is specified as an ISO 3166 alpha-2 two letter country-code followed by ISO 639-1 for the two-letter language code. For example, "ko_KR" for Korean, "en_US" for American English.
/// @param[in] stt The STT handle
/// @param[in] language The language
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// @c false to break out of the loop
/// @pre stt_foreach_supported_languages() will invoke this callback.
/// @see stt_foreach_supported_languages()
typedef stt_supported_language_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            stt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when STT get the result time stamp in free partial type.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] stt The STT handle
/// @param[in] index The result index
/// @param[in] event The token event
/// @param[in] text The result text
/// @param[in] start_time The start time of result text
/// @param[in] end_time The end time of result text
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop
/// otherwise @c false to break out of the loop
/// @pre stt_recognition_result_cb() should be called.
/// @see stt_recognition_result_cb()
typedef stt_result_time_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(stt_h, ffi.Int, ffi.Int32, ffi.Pointer<ffi.Char>,
            ffi.Long, ffi.Long, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when STT gets the recognition result from the engine.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @remarks After stt_stop() is called, silence is detected from recording, or partial result is occured, this function is called.
/// @param[in] stt The STT handle
/// @param[in] event The result event
/// @param[in] data Result texts
/// @param[in] data_count Result text count
/// @param[in] msg Engine message (e.g. #STT_RESULT_MESSAGE_NONE, #STT_RESULT_MESSAGE_ERROR_TOO_SHORT)
/// @param[in] user_data The user data passed from the callback registration function
/// @pre stt_stop() will invoke this callback if you register it using stt_set_result_cb().
/// @post If this function is called and event is #STT_RESULT_EVENT_FINAL_RESULT, the STT state will be #STT_STATE_READY.
/// @see stt_stop()
/// @see stt_set_recognition_result_cb()
/// @see stt_unset_recognition_result_cb()
typedef stt_recognition_result_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(stt_h, ffi.Int32, ffi.Pointer<ffi.Pointer<ffi.Char>>,
            ffi.Int, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the state of STT is changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] stt The STT handle
/// @param[in] previous A previous state
/// @param[in] current A current state
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers this callback using stt_set_state_changed_cb() to detect changing state.
/// @see stt_set_state_changed_cb()
/// @see stt_unset_state_changed_cb()
typedef stt_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(stt_h, ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an error occurs.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] stt The STT handle
/// @param[in] reason The error type (e.g. #STT_ERROR_OUT_OF_NETWORK, #STT_ERROR_IO_ERROR)
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers this callback using stt_set_error_cb() to detect error.
/// @see stt_set_error_cb()
/// @see stt_unset_error_cb()
typedef stt_error_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(stt_h, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the default language is changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] stt The STT handle
/// @param[in] previous_language A previous language
/// @param[in] current_language A current language
/// @param[in] user_data The user data passed from the callback registration function
/// @see stt_set_default_language_changed_cb()
typedef stt_default_language_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(stt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the engine is changed.
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
/// @remarks The language is specified as an ISO 3166 alpha-2 two letter country-code followed by ISO 639-1 for the two-letter language code. For example, "ko_KR" for Korean, "en_US" for American English.
/// @param[in] stt The STT handle
/// @param[in] engine_id Engine ID
/// @param[in] language The default language
/// @param[in] support_silence Whether the silence detection is supported or not
/// @param[in] need_credential The necessity of credential
/// @param[in] user_data The user data passed from the callback registration function
/// @see stt_set_engine_changed_cb()
typedef stt_engine_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(stt_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Bool, ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for error codes.
/// @since_tizen 3.0
abstract class stte_error_e {
  /// < Successful
  static const int STTE_ERROR_NONE = 0;

  /// < Out of Memory
  static const int STTE_ERROR_OUT_OF_MEMORY = -12;

  /// < I/O error
  static const int STTE_ERROR_IO_ERROR = -5;

  /// < Invalid parameter
  static const int STTE_ERROR_INVALID_PARAMETER = -22;

  /// < Network down(Out of network)
  static const int STTE_ERROR_NETWORK_DOWN = -100;

  /// < Invalid state
  static const int STTE_ERROR_INVALID_STATE = -49283071;

  /// < Invalid language
  static const int STTE_ERROR_INVALID_LANGUAGE = -49283070;

  /// < Operation failed
  static const int STTE_ERROR_OPERATION_FAILED = -49283068;

  /// < Not supported feature
  static const int STTE_ERROR_NOT_SUPPORTED_FEATURE = -49283067;

  /// < Not supported
  static const int STTE_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Permission denied
  static const int STTE_ERROR_PERMISSION_DENIED = -13;

  /// < Recording timed out
  static const int STTE_ERROR_RECORDING_TIMED_OUT = -49283066;
}

/// @brief Enumeration for audio type.
/// @since_tizen 3.0
abstract class stte_audio_type_e {
  /// < Signed 16bit audio type, Little endian
  static const int STTE_AUDIO_TYPE_PCM_S16_LE = 0;

  /// < Unsigned 8bit audio type
  static const int STTE_AUDIO_TYPE_PCM_U8 = 1;
}

/// @brief Enumeration for callback event.
/// @since_tizen 3.0
abstract class stte_result_event_e {
  /// < Event when either the full matched or the final result is delivered
  static const int STTE_RESULT_EVENT_FINAL_RESULT = 0;

  /// < Event when the partial matched result is delivered
  static const int STTE_RESULT_EVENT_PARTIAL_RESULT = 1;

  /// < Event when the recognition has failed
  static const int STTE_RESULT_EVENT_ERROR = 2;
}

/// @brief Enumeration for result time callback event.
/// @since_tizen 3.0
abstract class stte_result_time_event_e {
  /// < Event when the token is beginning type
  static const int STTE_RESULT_TIME_EVENT_BEGINNING = 0;

  /// < Event when the token is middle type
  static const int STTE_RESULT_TIME_EVENT_MIDDLE = 1;

  /// < Event when the token is end type
  static const int STTE_RESULT_TIME_EVENT_END = 2;
}

/// @brief Enumeration for speech status.
/// @since_tizen 3.0
abstract class stte_speech_status_e {
  /// < Beginning point of speech is detected
  static const int STTE_SPEECH_STATUS_BEGINNING_POINT_DETECTED = 0;

  /// < End point of speech is detected
  static const int STTE_SPEECH_STATUS_END_POINT_DETECTED = 1;
}

/// @brief A structure for the STT engine functions.
/// @details This structure contains essential callback functions for operating STT engine.
/// @since_tizen 3.0
/// @remarks These functions are mandatory for operating STT engine. Therefore, all functions MUST be implemented.
class stte_request_callback_s extends ffi.Struct {
  /// < The version of the structure 'stte_request_callback_s'
  @ffi.Int()
  external int version;

  /// < Called when the engine service user requests the basic information of STT engine
  external stte_get_info_cb get_info;

  /// < Called when the engine service user initializes STT engine
  external stte_initialize_cb initialize;

  /// < Called when the engine service user deinitializes STT engine
  external stte_deinitialize_cb deinitialize;

  /// < Called when the engine service user gets the whole supported language list
  external stte_foreach_supported_langs_cb foreach_langs;

  /// < Called when the engine service user checks whether the corresponding language is valid or not
  external stte_is_valid_language_cb is_valid_lang;

  /// < Called when the engine service user checks whether STT engine supports silence detection
  external stte_support_silence_detection_cb support_silence;

  /// < Called when the engine service user checks whether STT engine supports the corresponding recognition type
  external stte_support_recognition_type_cb support_recognition_type;

  /// < Called when the engine service user gets the proper recording format of STT engine
  external stte_get_recording_format_cb get_audio_format;

  /// < Called when the engine service user gets the result time information(stamp)
  external stte_foreach_result_time_cb foreach_result_time;

  /// < Called when the engine service user sets the silence detection
  external stte_set_silence_detection_cb set_silence_detection;

  /// < Called when the engine service user starts to recognize the recording data
  external stte_start_cb start;

  /// < Called when the engine service user sets and sends the recording data for speech recognition
  external stte_set_recording_data_cb set_recording;

  /// < Called when the engine service user stops to recognize the recording data
  external stte_stop_cb stop;

  /// < Called when the engine service user cancels to recognize the recording data
  external stte_cancel_cb cancel;

  /// < Called when the engine service user requests for STT engine to check whether the application agreed the usage of STT engine
  external stte_check_app_agreed_cb check_app_agreed;

  /// < Called when the engine service user checks whether STT engine needs the application's credential
  external stte_need_app_credential_cb need_app_credential;
}

/// @brief Called when the engine service user requests the basic information of STT engine.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// The allocated @a engine_uuid, @a engine_name, and @a engine_setting will be released internally.
/// In order to upload the engine at Tizen Appstore, both a service app and a ui app are necessary.
/// Therefore, @a engine_setting must be transferred to the engine service user.
/// @param[out] engine_uuid UUID of engine
/// @param[out] engine_name Name of engine
/// @param[out] engine_setting The engine setting application(ui app)'s app ID
/// @param[out] use_network A variable for checking whether the network is used or not
/// @return @c 0 on success,
/// otherwise a negative error code on failure
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
typedef stte_get_info_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(
            ffi.Pointer<ffi.Pointer<ffi.Char>>,
            ffi.Pointer<ffi.Pointer<ffi.Char>>,
            ffi.Pointer<ffi.Pointer<ffi.Char>>,
            ffi.Pointer<ffi.Bool>)>>;

/// @brief Called when the engine service user initializes STT engine.
/// @details This callback function is called by the engine service user to request for STT engine to be started.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #STTE_ERROR_INVALID_STATE Already initialized
/// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
/// @see stte_deinitialize_cb()
typedef stte_initialize_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Int Function()>>;

/// @brief Called when the engine service user deinitializes STT engine
/// @details This callback function is called by the engine service user to request for STT engine to be deinitialized.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// NOTE that the engine may be terminated automatically.
/// When this callback function is invoked, the release of resources is necessary.
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_STATE Not initialized
/// @see stte_initialize_cb()
typedef stte_deinitialize_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Int Function()>>;

/// @brief Called when the engine service user gets the whole supported language list.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// In this function, the engine service user's callback function 'stte_supported_language_cb()' is invoked repeatedly for getting all supported languages, and @a user_data must be transferred to 'stte_supported_language_cb()'.
/// If 'stte_supported_language_cb()' returns @c false, it should be stopped to call 'stte_supported_language_cb()'.
/// @param[in] callback The callback function
/// @param[in] user_data The user data which must be passed to the callback function 'stte_supported_language_cb()'
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #STTE_ERROR_INVALID_STATE Not initialized
/// @post This callback function invokes stte_supported_language_cb() repeatedly for getting supported languages.
/// @see stte_supported_language_cb()
typedef stte_foreach_supported_langs_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(stte_supported_language_cb, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when STT engine informs the engine service user about whole supported language list.
/// @details This callback function is implemented by the engine service user. Therefore, the engine developer does NOT have to implement this callback function.
/// @since_tizen 3.0
/// @remarks This callback function is called in stte_foreach_supported_langs_cb() to inform the whole supported language list.
/// @a user_data must be transferred from stte_foreach_supported_langs_cb().
/// @param[in] language The language is specified as an ISO 3166 alpha-2 two letter country-code
/// followed by ISO 639-1 for the two-letter language code
/// For example, "ko_KR" for Korean, "en_US" for American English
/// @param[in] user_data The user data passed from stte_foreach_supported_langs_cb()
/// @return @c true to continue with the next iteration of the loop
/// @c false to break out of the loop
/// @pre stte_foreach_supported_langs_cb() will invoke this callback function.
/// @see stte_foreach_supported_langs_cb()
typedef stte_supported_language_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the engine service user checks whether the corresponding language is valid or not in STT engine.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// @param[in] language The language is specified as an ISO 3166 alpha-2 two letter country-code
/// followed by ISO 639-1 for the two-letter language code
/// For example, "ko_KR" for Korean, "en_US" for American English
/// @param[out] is_valid A variable for checking whether the corresponding language is valid or not.
/// @c true to be valid,
/// @c false to be invalid
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
/// @see stte_foreach_supported_languages_cb()
typedef stte_is_valid_language_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>>;

/// @brief Called when the engine service user checks whether STT engine supports silence detection.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// @return @c true to support silence detection,
/// @c false not to support silence detection
/// @see stte_set_silence_detection_cb()
typedef stte_support_silence_detection_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Bool Function()>>;

/// @brief Called when the engine service user checks whether STT engine supports the corresponding recognition type.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// @param[in] type The type for recognition (e.g. #STTE_RECOGNITION_TYPE_FREE)
/// @param[out] is_supported A variable for checking whether STT engine supports the corresponding recognition type.
/// @c true to support recognition type,
/// @c false not to support recognition type
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
typedef stte_support_recognition_type_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>>;

/// @brief Called when the engine service user gets the proper recording format of STT engine.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// The recording format is used for creating the recorder.
/// @param[out] types The format used by the recorder
/// @param[out] rate The sample rate used by the recorder
/// @param[out] channels The number of channels used by the recorder
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_STATE Not initialized
typedef stte_get_recording_format_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<ffi.Int32>, ffi.Pointer<ffi.Int>,
            ffi.Pointer<ffi.Int>)>>;

/// @brief Called when the engine service user gets the result time information(stamp).
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// In this function, the engine service user's callback function 'stte_result_time_cb()' is invoked repeatedly for sending the time information to the engine service user, and @a user_data must be transferred to 'stte_result_time_cb()'.
/// If 'stte_result_time_cb()' returns @c false, it should be stopped to call 'stte_result_time_cb()'.
/// @a time_info is transferred from stte_send_result(). The type of @a time_info is up to the STT engine developer.
/// @param[in] time_info The time information
/// @param[in] callback The callback function
/// @param[in] user_data The user data which must be passed to the callback function 'stte_result_time_cb()'
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #STTE_ERROR_INVALID_STATE Not initialized
/// @pre stte_send_result() will invoke this function.
/// @post This function invokes stte_result_time_cb() repeatedly for getting result time information.
/// @see stte_result_time_cb()
typedef stte_foreach_result_time_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<ffi.Void>, stte_result_time_cb,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when STT engine provides the time stamp of result to the engine service user.
/// @details This callback function is implemented by the engine service user. Therefore, the engine developer does NOT have to implement this callback function.
/// @since_tizen 3.0
/// @remarks This callback function is called in stte_foreach_result_time_cb() for adding time information.
/// @a user_data must be transferred from stte_foreach_result_time_cb().
/// @param[in] index The result index
/// @param[in] event The token event
/// @param[in] text The result text
/// @param[in] start_time The time started speaking the result text
/// @param[in] end_time The time finished speaking the result text
/// @param[in] user_data The user data passed from stte_foreach_result_time_cb()
/// @return @c true to continue with the next iteration of the loop
/// @c false to break out of the loop
/// @pre stte_send_result() should be called.
/// @see stte_send_result()
/// @see stte_foreach_result_time_cb()
typedef stte_result_time_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Int, ffi.Int32, ffi.Pointer<ffi.Char>, ffi.Long,
            ffi.Long, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the engine service user sets the silence detection.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// If the engine service user sets this option as 'TRUE', STT engine will detect the silence (EPD) and send the callback event about it.
/// @param[in] is_set A variable for setting the silence detection.
/// @c true to detect the silence,
/// @c false not to detect the silence
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_STATE Not initialized
/// @retval #STTE_ERROR_NOT_SUPPORTED_FEATURE Not supported feature
typedef stte_set_silence_detection_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Int Function(ffi.Bool)>>;

/// @brief Called when the engine service user starts to recognize the recording data.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// In this callback function, STT engine must transfer the recognition result and @a user_data to the engine service user using stte_send_result().
/// Also, if STT engine needs the application's credential, it sets the credential granted to the application.
/// @param[in] language The language is specified as an ISO 3166 alpha-2 two letter country-code
/// followed by ISO 639-1 for the two-letter language code
/// For example, "ko_KR" for Korean, "en_US" for American English
/// @param[in] type The recognition type. (e.g. #STTE_RECOGNITION_TYPE_FREE)
/// @param[in] appid The Application ID
/// @param[in] credential The credential granted to the application
/// @param[in] user_data The user data to be passed to the callback function
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #STTE_ERROR_INVALID_STATE Invalid state
/// @retval #STTE_ERROR_INVALID_LANGUAGE Invalid language
/// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
/// @retval #STTE_ERROR_NETWORK_DOWN Out of network
/// @pre The engine is not in recognition processing.
/// @see stte_set_recording_data_cb()
/// @see stte_stop_cb()
/// @see stte_cancel_cb()
/// @see stte_need_app_credential_cb()
typedef stte_start_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the engine service user sets and sends the recording data for speech recognition.
/// @details This callback function is called by the engine service user to send the recording data to STT engine.
/// The engine receives the recording data and uses for speech recognition.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// Also, this function should be returned immediately after recording data copy.
/// @param[in] data The recording data
/// @param[in] length The length of recording data
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #STTE_ERROR_INVALID_STATE Invalid state
/// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
/// @pre stte_start_cb() should succeed.
/// @post If the engine supports partial result, stte_send_result() should be invoked.
/// @see stte_start_cb()
/// @see stte_cancel_cb()
/// @see stte_stop_cb()
typedef stte_set_recording_data_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<ffi.Void>, ffi.UnsignedInt)>>;

/// @brief Called when the engine service user stops to recognize the recording data.
/// @details This callback function is called by the engine service user to stop recording and to get the recognition result.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_STATE Invalid state
/// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
/// @retval #STTE_ERROR_NETWORK_DOWN Out of network
/// @pre stte_start_cb() should succeed.
/// @post After processing of the engine, stte_send_result() must be called.
/// @see stte_start_cb()
/// @see stte_set_recording_data_cb()
/// @see stte_cancel_cb()
/// @see stte_send_result()
typedef stte_stop_cb = ffi.Pointer<ffi.NativeFunction<ffi.Int Function()>>;

/// @brief Called when the engine service user cancels to recognize the recording data.
/// @details This callback function is called by the engine service user to cancel to recognize the recording data.
/// Also, when starting the recorder is failed, this function is called.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful.
/// @retval #STTE_ERROR_INVALID_STATE Invalid state.
/// @pre STT engine is in recognition processing or recording.
/// @see stte_start_cb()
/// @see stte_stop_cb()
typedef stte_cancel_cb = ffi.Pointer<ffi.NativeFunction<ffi.Int Function()>>;

/// @brief Called when the engine service user requests for STT engine to check whether the application agreed the usage of STT engine.
/// @details This callback function is called when the engine service user requests for STT engine to check the application's agreement about using the engine.
/// According to the need, the engine developer can provide some user interfaces to check the agreement.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// If the STT engine developer wants not to check the agreement, the developer has need to return proper values as @a is_agreed in accordance with the intention. @c true if the developer regards that every application agreed the usage of the engine, @c false if the developer regards that every application disagreed.
/// NOTE that, however, there may be any legal issue unless the developer checks the agreement. Therefore, we suggest that the engine developers should provide a function to check the agreement.
/// @param[in] appid The Application ID
/// @param[out] is_agreed A variable for checking whether the application agreed to use STT engine or not.
/// @c true to agree,
/// @c false to disagree
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_STATE Not initialized
/// @retval #STTE_ERROR_NOT_SUPPORTED_FEATURE Not supported feature
typedef stte_check_app_agreed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>>;

/// @brief Called when the engine service user checks whether STT engine needs the application's credential.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using stte_main().
/// @return @c true if STT engine needs the application's credential,
/// otherwise @c false
typedef stte_need_app_credential_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Bool Function()>>;

/// @brief Called when STT engine receives the private data from the engine service user.
/// @details This callback function is called when the engine service user sends the private data to STT engine.
/// @since_tizen 3.0
/// @remarks This callback function is optional and is registered using stte_set_private_data_set_cb().
/// @param[in] key The key field of private data
/// @param[in] data The data field of private data
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
/// @see stte_private_data_requested_cb()
/// @see stte_set_private_data_set_cb()
typedef stte_private_data_set_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>>;

/// @brief Called when STT engine provides the engine service user with the private data.
/// @details This callback function is called when the engine service user gets the private data from STT engine.
/// @since_tizen 3.0
/// @remarks This callback function is optional and is registered using stte_set_private_data_requested_cb().
/// @param[out] key The key field of private data
/// @param[out] data The data field of private data
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #STTE_ERROR_NONE Successful
/// @retval #STTE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #STTE_ERROR_OPERATION_FAILED Operation failure
/// @see stte_private_data_set_cb()
/// @see stte_set_private_data_requested_cb()
typedef stte_private_data_requested_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>;

/// @brief Enumeration for error code.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class tts_error_e {
  /// < Successful
  static const int TTS_ERROR_NONE = 0;

  /// < Out of Memory
  static const int TTS_ERROR_OUT_OF_MEMORY = -12;

  /// < I/O error
  static const int TTS_ERROR_IO_ERROR = -5;

  /// < Invalid parameter
  static const int TTS_ERROR_INVALID_PARAMETER = -22;

  /// < Network is down
  static const int TTS_ERROR_OUT_OF_NETWORK = -100;

  /// < No answer from the daemon
  static const int TTS_ERROR_TIMED_OUT = -1073741823;

  /// < Permission denied
  static const int TTS_ERROR_PERMISSION_DENIED = -13;

  /// < TTS NOT supported
  static const int TTS_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Invalid state
  static const int TTS_ERROR_INVALID_STATE = -49348607;

  /// < Invalid voice
  static const int TTS_ERROR_INVALID_VOICE = -49348606;

  /// < No available engine
  static const int TTS_ERROR_ENGINE_NOT_FOUND = -49348605;

  /// < Operation failed
  static const int TTS_ERROR_OPERATION_FAILED = -49348604;

  /// < Audio policy blocked
  static const int TTS_ERROR_AUDIO_POLICY_BLOCKED = -49348603;

  /// < Not supported feature of current engine @if MOBILE (Since 3.0) @elseif WEARABLE (Since 2.3.2) @endif
  static const int TTS_ERROR_NOT_SUPPORTED_FEATURE = -49348602;

  /// < Service reset @if MOBILE (Since 3.0) @elseif WEARABLE (Since 2.3.2) @endif
  static const int TTS_ERROR_SERVICE_RESET = -49348601;
}

/// @brief Enumeration for TTS mode.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class tts_mode_e {
  /// < Default mode for normal application
  static const int TTS_MODE_DEFAULT = 0;

  /// < Notification mode
  static const int TTS_MODE_NOTIFICATION = 1;

  /// < Accessibiliity mode
  static const int TTS_MODE_SCREEN_READER = 2;
}

/// @brief Enumeration for state.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
abstract class tts_state_e {
  /// < 'CREATED' state
  static const int TTS_STATE_CREATED = 0;

  /// < 'READY' state
  static const int TTS_STATE_READY = 1;

  /// < 'PLAYING' state
  static const int TTS_STATE_PLAYING = 2;

  /// < 'PAUSED' state
  static const int TTS_STATE_PAUSED = 3;
}

class tts_s extends ffi.Opaque {}

/// @brief The TTS handle.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
typedef tts_h = ffi.Pointer<tts_s>;

/// @brief Called to retrieve the supported voice.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] tts The TTS handle
/// @param[in] language Language specified as an ISO 3166 alpha-2 two letter country-code followed by ISO 639-1 for the two-letter language code (for example, "ko_KR" for Korean, "en_US" for American English)
/// @param[in] voice_type A voice type (e.g. #TTS_VOICE_TYPE_MALE, #TTS_VOICE_TYPE_FEMALE)
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// @c false to break out of the loop
/// @pre tts_foreach_supported_voices() will invoke this callback function.
/// @see tts_foreach_supported_voices()
typedef tts_supported_voice_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            tts_h, ffi.Pointer<ffi.Char>, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the state of TTS is changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @details If the daemon must stop player because of changing engine and
/// the daemon must pause player because of other requests, this callback function is called.
/// @param[in] tts The TTS handle
/// @param[in] previous The previous state
/// @param[in] current The current state
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers this callback using tts_set_state_changed_cb() to detect changing state.
/// @see tts_set_state_changed_cb()
/// @see tts_unset_state_changed_cb()
typedef tts_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(tts_h, ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when utterance has started.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] tts The TTS handle
/// @param[in] utt_id The utterance ID passed from the add text function
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers this callback using tts_set_utterance_started_cb() to detect utterance started.
/// @see tts_add_text()
/// @see tts_set_utterance_started_cb()
/// @see tts_unset_utterance_started_cb()
typedef tts_utterance_started_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(tts_h, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when utterance is finished.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] tts The TTS handle
/// @param[in] utt_id The utterance ID passed from the add text function
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers this callback using tts_set_utterance_completed_cb() to detect utterance completed.
/// @see tts_add_text()
/// @see tts_set_utterance_completed_cb()
/// @see tts_unset_utterance_completed_cb()
typedef tts_utterance_completed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(tts_h, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when an error occurs.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] tts The TTS handle
/// @param[in] utt_id The utterance ID passed from the add text function
/// @param[in] reason The error code
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers this callback using tts_set_error_cb() to detect error.
/// @see tts_play()
/// @see tts_pause()
/// @see tts_stop()
/// @see tts_set_error_cb()
/// @see tts_unset_error_cb()
typedef tts_error_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(tts_h, ffi.Int, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the default voice is changed.
/// @since_tizen @if MOBILE 2.3 @elseif WEARABLE 2.3.1 @endif
/// @param[in] tts The TTS handle
/// @param[in] previous_language The previous language
/// @param[in] previous_voice_type The previous voice type
/// @param[in] current_language The current language
/// @param[in] current_voice_type The current voice type
/// @param[in] user_data The user data passed from the callback registration function
/// @see tts_set_default_voice_changed_cb()
typedef tts_default_voice_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(tts_h, ffi.Pointer<ffi.Char>, ffi.Int,
            ffi.Pointer<ffi.Char>, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the engine is changed.
/// @since_tizen @if MOBILE 3.0 @elseif WEARABLE 2.3.2 @endif
/// @param[in] tts The TTS handle
/// @param[in] engine_id Engine ID
/// @param[in] language The default language specified as an ISO 3166 alpha-2 two letter country-code followed by ISO 639-1 for the two-letter language code (for example, "ko_KR" for Korean, "en_US" for American English)
/// @param[in] voice_type The default voice type
/// @param[in] need_credential The necessity of credential
/// @param[in] user_data The user data passed from the callback registration function
/// @see tts_set_engine_changed_cb()
typedef tts_engine_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(tts_h, ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Int, ffi.Bool, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for error codes.
/// @since_tizen 3.0
abstract class ttse_error_e {
  /// < Successful
  static const int TTSE_ERROR_NONE = 0;

  /// < Out of Memory
  static const int TTSE_ERROR_OUT_OF_MEMORY = -12;

  /// < I/O error
  static const int TTSE_ERROR_IO_ERROR = -5;

  /// < Invalid parameter
  static const int TTSE_ERROR_INVALID_PARAMETER = -22;

  /// < Out of network
  static const int TTSE_ERROR_NETWORK_DOWN = -100;

  /// < Permission denied
  static const int TTSE_ERROR_PERMISSION_DENIED = -13;

  /// < Invalid state
  static const int TTSE_ERROR_INVALID_STATE = -49348607;

  /// < Invalid voice
  static const int TTSE_ERROR_INVALID_VOICE = -49348606;

  /// < Operation failed
  static const int TTSE_ERROR_OPERATION_FAILED = -49348604;

  /// < Not supported feature
  static const int TTSE_ERROR_NOT_SUPPORTED_FEATURE = -49348602;

  /// < Not supported
  static const int TTSE_ERROR_NOT_SUPPORTED = -1073741822;
}

/// @brief Enumeration for audio type.
/// @since_tizen 3.0
abstract class ttse_audio_type_e {
  /// < Signed 16-bit audio type
  static const int TTSE_AUDIO_TYPE_RAW_S16 = 0;

  /// < Unsigned 8-bit audio type
  static const int TTSE_AUDIO_TYPE_RAW_U8 = 1;
  static const int TTSE_AUDIO_TYPE_MAX = 2;
}

/// @brief Enumeration for result event type.
/// @since_tizen 3.0
abstract class ttse_result_event_e {
  /// < Event when the voice synthesis is failed
  static const int TTSE_RESULT_EVENT_FAIL = -1;

  /// < Event when the sound data is first data by callback function
  static const int TTSE_RESULT_EVENT_START = 1;

  /// < Event when the next sound data exist, not first and not last
  static const int TTSE_RESULT_EVENT_CONTINUE = 2;

  /// < Event when the sound data is last data or sound data is only one result
  static const int TTSE_RESULT_EVENT_FINISH = 3;
}

/// @brief A structure for the TTS engine functions.
/// @details This structure contains essential callback functions for operating TTS engine.
/// @since_tizen 3.0
/// @remarks These functions are mandatory for operating TTS engine. Therefore, all functions MUST be implemented.
class ttse_request_callback_s extends ffi.Struct {
  /// < The version of the structure 'ttse_request_callback_s'
  @ffi.Int()
  external int version;

  /// < Called when the engine service user requests the basic information of TTS engine
  external ttse_get_info_cb get_info;

  /// < Called when the engine service user initializes TTS engine
  external ttse_initialize_cb initialize;

  /// < Called when the engine service user deinitializes TTS engine
  external ttse_deinitialize_cb deinitialize;

  /// < Called when the engine service user gets the whole supported voice list
  external ttse_foreach_supported_voices_cb foreach_voices;

  /// < Called when the engine service user checks whether the voice is valid or not in TTS engine
  external ttse_is_valid_voice_cb is_valid_voice;

  /// < Called when the engine service user sets the default pitch of TTS engine
  external ttse_set_pitch_cb set_pitch;

  /// < Called when the engine service user requests to load the corresponding voice type for the first time
  external ttse_load_voice_cb load_voice;

  /// < Called when the engine service user requests to unload the corresponding voice type or to stop using voice
  external ttse_unload_voice_cb unload_voice;

  /// < Called when the engine service user starts to synthesize a voice, asynchronously
  external ttse_start_synthesis_cb start_synth;

  /// < Called when the engine service user cancels to synthesize a voice
  external ttse_cancel_synthesis_cb cancel_synth;

  /// < Called when the engine service user requests for TTS engine to check whether the application agreed the usage of TTS engine
  external ttse_check_app_agreed_cb check_app_agreed;

  /// < Called when the engine service user checks whether TTS engine needs the application's credential
  external ttse_need_app_credential_cb need_app_credential;
}

/// @brief Called when the engine service user requests the basic information of TTS engine.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// The allocated @a engine_uuid, @a engine_name, and @a engine_setting will be released internally.
/// In order to upload the engine at Tizen Appstore, both a service app and a ui app are necessary.
/// Therefore, @a engine_setting must be transferred to the engine service user.
/// @param[out] engine_uuid UUID of engine
/// @param[out] engine_name Name of engine
/// @param[out] engine_setting The engine setting application(ui app)'s app ID
/// @param[out] use_network The status for using network
/// @return @c 0 on success,
/// otherwise a negative error code on failure
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
typedef ttse_get_info_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(
            ffi.Pointer<ffi.Pointer<ffi.Char>>,
            ffi.Pointer<ffi.Pointer<ffi.Char>>,
            ffi.Pointer<ffi.Pointer<ffi.Char>>,
            ffi.Pointer<ffi.Bool>)>>;

/// @brief Called when the engine service user initializes TTS engine.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #TTSE_ERROR_INVALID_STATE Already initialized
/// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
/// @retval #TTSE_ERROR_PERMISSION_DENIED Permission denied
/// @see ttse_deinitialize_cb()
typedef ttse_initialize_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Int Function()>>;

/// @brief Called when the engine service user deinitializes TTS engine.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// NOTE that the engine may be terminated automatically.
/// When this callback function is invoked, the release of resources is necessary.
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_STATE Not initialized
/// @see ttse_initialize_cb()
typedef ttse_deinitialize_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Int Function()>>;

/// @brief Called when the engine service user gets the whole supported voice list.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// In this function, the engine service user's callback function 'ttse_supported_voice_cb()' is invoked repeatedly for getting all supported voices, and @a user_data must be transferred to 'ttse_supported_voice_cb()'.
/// If 'ttse_supported_voice_cb()' returns @c false, it should be stopped to call 'ttse_supported_voice_cb()'.
/// @param[in] callback The callback function
/// @param[in] user_data The user data which must be passed to ttse_supported_voice_cb()
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #TTSE_ERROR_INVALID_STATE Not initialized
/// @post	This callback function invokes ttse_supported_voice_cb() repeatedly for getting all supported voices.
/// @see ttse_supported_voice_cb()
typedef ttse_foreach_supported_voices_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ttse_supported_voice_cb, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when TTS engine informs the engine service user about whole supported language and voice type list.
/// @details This callback function is implemented by the engine service user. Therefore, the engine developer does NOT have to implement this callback function.
/// @since_tizen 3.0
/// @remarks This callback function is called by ttse_foreach_supported_voices_cb() to inform the whole supported voice list.
/// @a user_data must be transferred from ttse_foreach_supported_voices_cb().
/// @param[in] language The language is specified as an ISO 3166 alpha-2 two-letter country code
/// followed by ISO 639-1 for the two-letter language code.
/// For example, "ko_KR" for Korean, "en_US" for American English
/// @param[in] type The voice type
/// @param[in] user_data The user data passed from ttse_foreach_supported_voices_cb()
/// @return @c true to continue with the next iteration of the loop
/// @c false to break out of the loop
/// @pre ttse_foreach_supported_voices_cb() will invoke this callback function.
/// @see ttse_foreach_supported_voices_cb()
typedef ttse_supported_voice_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(
            ffi.Pointer<ffi.Char>, ffi.Int, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the engine service user checks whether the voice is valid or not in TTS engine.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// @param[in] language The language is specified as an ISO 3166 alpha-2 two-letter country code
/// followed by ISO 639-1 for the two-letter language code.
/// For example, "ko_KR" for Korean, "en_US" for American English
/// @param[in] type The voice type
/// @param[out] is_valid A variable for checking whether the corresponding voice is valid or not.
/// @c true to be valid,
/// @c false to be invalid
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @see ttse_foreach_supported_voices_cb()
typedef ttse_is_valid_voice_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(
            ffi.Pointer<ffi.Char>, ffi.Int, ffi.Pointer<ffi.Bool>)>>;

/// @brief Called when the engine service user sets the default pitch of TTS engine.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// @param[in] pitch The default pitch
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #TTSE_ERROR_INVALID_STATE Not initialized
/// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
typedef ttse_set_pitch_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Int Function(ffi.Int)>>;

/// @brief Called when the engine service user requests to load the corresponding voice type for the first time.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// @param[in] language The language is specified as an ISO 3166 alpha-2 two-letter country code
/// followed by ISO 639-1 for the two-letter language code.
/// For example, "ko_KR" for Korean, "en_US" for American English
/// @param[in] type The voice type
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #TTSE_ERROR_INVALID_STATE Not initialized
/// @retval #TTSE_ERROR_OUT_OF_MEMORY Out of memory
/// @retval #TTSE_ERROR_INVALID_VOICE Invalid voice
/// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
/// @see ttse_unload_voice_cb()
typedef ttse_load_voice_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int)>>;

/// @brief Called when the engine service user requests to unload the corresponding voice type or to stop using voice.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// @param[in] language The language is specified as an ISO 3166 alpha-2 two-letter country code
/// followed by ISO 639-1 for the two-letter language code.
/// For example, "ko_KR" for Korean, "en_US" for American English
/// @param[in] type The voice type
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #TTSE_ERROR_INVALID_STATE Not initialized
/// @retval #TTSE_ERROR_INVALID_VOICE Invalid voice
/// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
/// @see ttse_load_voice_cb()
typedef ttse_unload_voice_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Int)>>;

/// @brief Called when the engine service user starts to synthesize a voice, asynchronously.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// In this callback function, TTS engine must transfer the synthesized result and @a user_data to the engine service user using ttse_send_result().
/// Also, if TTS engine needs the application's credential, it can set the credential granted to the application.
/// @param[in] language The language is specified as an ISO 3166 alpha-2 two-letter country code
/// followed by ISO 639-1 for the two-letter language code.
/// For example, "ko_KR" for Korean, "en_US" for American English
/// @param[in] type The voice type
/// @param[in] text Texts
/// @param[in] speed The speed of speaking
/// @param[in] appid The Application ID
/// @param[in] credential The credential granted to the application
/// @param[in] user_data The user data which must be passed to ttse_send_result()
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #TTSE_ERROR_INVALID_STATE Not initialized or already started synthesis
/// @retval #TTSE_ERROR_INVALID_VOICE Invalid voice
/// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
/// @retval #TTSE_ERROR_NETWORK_DOWN Out of network
/// @retval #TTSE_ERROR_PERMISSION_DENIED Permission denied
/// @post This function invokes ttse_send_result().
/// @see ttse_send_result()
/// @see ttse_cancel_synthesis_cb()
/// @see ttse_need_app_credential_cb()
typedef ttse_start_synthesis_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(
            ffi.Pointer<ffi.Char>,
            ffi.Int,
            ffi.Pointer<ffi.Char>,
            ffi.Int,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the engine service user cancels to synthesize a voice.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_STATE Not initialized or not started synthesis
/// @pre The ttse_start_synthesis_cb() should be performed
/// @see ttse_start_synthesis_cb()
typedef ttse_cancel_synthesis_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Int Function()>>;

/// @brief Called when the engine service user requests for TTS engine to check whether the application agreed the usage of TTS engine.
/// @details This callback function is called when the engine service user requests for TTS engine to check the application's agreement about using the engine.
/// According to the need, the engine developer can provide some user interfaces to check the agreement.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// If the TTS engine developer wants not to check the agreement, the developer has need to return proper values as @a is_agreed in accordance with the intention. @c true if the developer regards that every application agreed the usage of the engine, @c false if the developer regards that every application disagreed.
/// NOTE that, however, there may be any legal issue unless the developer checks the agreement. Therefore, we suggest that the engine developers should provide a function to check the agreement.
/// @param[in] appid The Application ID
/// @param[out] is_agreed A variable for checking whether the application agreed to use TTS engine or not.
/// @c true to agree,
/// @c false to disagree
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_STATE Not initialized
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #TTSE_ERROR_NOT_SUPPORTED_FEATURE Not supported feature
typedef ttse_check_app_agreed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Bool>)>>;

/// @brief Called when the engine service user checks whether TTS engine needs the application's credential.
/// @since_tizen 3.0
/// @remarks This callback function is mandatory and must be registered using ttse_main().
/// @return @c true if TTS engine needs the application's credential,
/// otherwise @c false
typedef ttse_need_app_credential_cb
    = ffi.Pointer<ffi.NativeFunction<ffi.Bool Function()>>;

/// @brief Called when TTS engine receives the private data from the engine service user.
/// @details This callback function is called when the engine service user sends the private data to TTS engine.
/// @since_tizen 3.0
/// @remarks This callback function is optional and is registered using ttse_set_private_data_set_cb().
/// @param[in] key The key field of private data
/// @param[in] data The data field of private data
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
/// @retval #TTSE_ERROR_NOT_SUPPORTED_FEATURE Not supported feature
/// @see ttse_private_data_requested_cb()
/// @see ttse_set_private_data_set_cb()
typedef ttse_private_data_set_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>)>>;

/// @brief Called when TTS engine provides the engine service user with the private data.
/// @details This callback function is called when the engine service user gets the private data from TTS engine.
/// @since_tizen 3.0
/// @remarks This callback function is optional and is registered using ttse_set_private_data_requested_cb().
/// @param[out] key The key field of private data
/// @param[out] data The data field of private data
/// @return @c 0 on success,
/// otherwise a negative error value
/// @retval #TTSE_ERROR_NONE Successful
/// @retval #TTSE_ERROR_INVALID_PARAMETER Invalid parameter
/// @retval #TTSE_ERROR_OPERATION_FAILED Operation failure
/// @retval #TTSE_ERROR_NOT_SUPPORTED_FEATURE Not supported feature
/// @see ttse_private_data_set_cb()
/// @see ttse_set_private_data_requested_cb()
typedef ttse_private_data_requested_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Int Function(
            ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Pointer<ffi.Char>>)>>;

/// @brief Called to retrieve supported language.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] language A language is specified as an ISO 3166 alpha-2 two letter country-code
/// followed by ISO 639-1 for the two-letter language code.
/// For example, "ko_KR" for Korean, "en_US" for American English
/// @param[in] user_data The user data passed from the foreach function
/// @return @c true to continue with the next iteration of the loop,
/// @c false to break out of the loop
/// @pre The function will invoke this callback.
typedef vc_supported_language_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Bool Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for client state.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class vc_state_e {
  /// < 'None' state
  static const int VC_STATE_NONE = 0;

  /// < 'Initialized' state
  static const int VC_STATE_INITIALIZED = 1;

  /// < 'Ready' state
  static const int VC_STATE_READY = 2;
}

/// @brief Enumeration for service state.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class vc_service_state_e {
  /// < 'None' state
  static const int VC_SERVICE_STATE_NONE = 0;

  /// < 'Ready' state
  static const int VC_SERVICE_STATE_READY = 1;

  /// < 'Recording' state
  static const int VC_SERVICE_STATE_RECORDING = 2;

  /// < 'Processing' state
  static const int VC_SERVICE_STATE_PROCESSING = 3;
}

/// @brief The voice command list handle.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
typedef vc_cmd_list_h = ffi.Pointer<vc_cmd_list_s>;

class vc_cmd_list_s extends ffi.Opaque {}

/// @brief Called when client gets the recognition result.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @remarks If the duplicated commands are recognized, the event(e.g. #VC_RESULT_EVENT_REJECTED) of command may be rejected
/// for selecting command as priority. If you set similar or same commands or the recognized results are multi-results,
/// vc_cmd_list has the multi commands.
/// @param[in] event The result event (e.g. #VC_RESULT_EVENT_RESULT_SUCCESS, #VC_RESULT_EVENT_REJECTED)
/// @param[in] vc_cmd_list The recognized command list
/// @param[in] result The spoken text
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers callback function.
/// @see vc_set_result_cb()
typedef vc_result_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, vc_cmd_list_h, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for result event.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class vc_result_event_e {
  /// < Normal result
  static const int VC_RESULT_EVENT_RESULT_SUCCESS = 0;

  /// < Rejected result
  static const int VC_RESULT_EVENT_REJECTED = 1;
}

/// @brief Called when the state of voice control service is changed.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] previous A previous state
/// @param[in] current A current state
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers this callback to detect changing service state.
/// @see vc_set_service_state_changed_cb()
typedef vc_service_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when the state of voice control client is changed.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] previous A previous state
/// @param[in] current A current state
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers this callback to detect changing state.
/// @see vc_set_state_changed_cb()
typedef vc_state_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Int32, ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Called when default language is changed.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] previous Previous language
/// @param[in] current Current language
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers this callback to detect changing mode.
/// @see vc_set_current_language_changed_cb()
typedef vc_current_language_changed_cb = ffi.Pointer<
    ffi.NativeFunction<
        ffi.Void Function(ffi.Pointer<ffi.Char>, ffi.Pointer<ffi.Char>,
            ffi.Pointer<ffi.Void>)>>;

/// @brief Called when error occurred.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
/// @param[in] reason The error type (e.g. #VC_ERROR_OUT_OF_MEMORY, #VC_ERROR_TIMED_OUT)
/// @param[in] user_data The user data passed from the callback registration function
/// @pre An application registers this callback to detect error.
/// @see vc_set_error_cb()
typedef vc_error_cb = ffi.Pointer<
    ffi.NativeFunction<ffi.Void Function(ffi.Int32, ffi.Pointer<ffi.Void>)>>;

/// @brief Enumeration for error codes.
/// @since_tizen @if MOBILE 2.4 @elseif WEARABLE 3.0 @endif
abstract class vc_error_e {
  /// < Successful
  static const int VC_ERROR_NONE = 0;

  /// < Out of Memory
  static const int VC_ERROR_OUT_OF_MEMORY = -12;

  /// < I/O error
  static const int VC_ERROR_IO_ERROR = -5;

  /// < Invalid parameter
  static const int VC_ERROR_INVALID_PARAMETER = -22;

  /// < No answer from service
  static const int VC_ERROR_TIMED_OUT = -1073741823;

  /// < Busy recorder
  static const int VC_ERROR_RECORDER_BUSY = -16;

  /// < Permission denied
  static const int VC_ERROR_PERMISSION_DENIED = -13;

  /// < VC NOT supported
  static const int VC_ERROR_NOT_SUPPORTED = -1073741822;

  /// < Invalid state
  static const int VC_ERROR_INVALID_STATE = -49610735;

  /// < Invalid language
  static const int VC_ERROR_INVALID_LANGUAGE = -49610734;

  /// < No available engine
  static const int VC_ERROR_ENGINE_NOT_FOUND = -49610733;

  /// < Operation failed
  static const int VC_ERROR_OPERATION_FAILED = -49610732;

  /// < Operation rejected
  static const int VC_ERROR_OPERATION_REJECTED = -49610731;

  /// < List reached end
  static const int VC_ERROR_ITERATION_END = -49610730;

  /// < List empty
  static const int VC_ERROR_EMPTY = -49610729;

  /// < Service daemon reset (Since 3.0)
  static const int VC_ERROR_SERVICE_RESET = -49610728;

  /// < In progress to ready (Since 3.0)
  static const int VC_ERROR_IN_PROGRESS_TO_READY = -49610727;

  /// < In progress to recording (Since 3.0)
  static const int VC_ERROR_IN_PROGRESS_TO_RECORDING = -49610720;

  /// < In progress to processing (Since 3.0)
  static const int VC_ERROR_IN_PROGRESS_TO_PROCESSING = -49610719;
}

const int TIZEN_ERROR_MAX_PLATFORM_ERROR = 0;

const int TIZEN_ERROR_MIN_PLATFORM_ERROR = -1073741824;

const int TIZEN_ERROR_MIN_MODULE_ERROR = -2147483648;

const int TIZEN_ERROR_MAX_MODULE_ERROR = -1073741825;

const int TIZEN_ERROR_APPLICATION_CLASS = -512;

const int TIZEN_ERROR_BASE_CLASS = -1024;

const int TIZEN_ERROR_CONTENT_CLASS = -2048;

const int TIZEN_ERROR_LOCATION_CLASS = -4096;

const int TIZEN_ERROR_MULTIMEDIA_CLASS = -8192;

const int TIZEN_ERROR_MESSAGING_CLASS = -16384;

const int TIZEN_ERROR_NETWORK_CLASS = -32768;

const int TIZEN_ERROR_SOCIAL_CLASS = -65536;

const int TIZEN_ERROR_SYSTEM_CLASS = -131072;

const int TIZEN_ERROR_TELEPHONY_CLASS = -262144;

const int TIZEN_ERROR_UI_CLASS = -524288;

const int TIZEN_ERROR_UIX_CLASS = -1048576;

const int TIZEN_ERROR_AD_CLASS = -2097152;

const int TIZEN_ERROR_WEB_CLASS = -4194304;

const int TIZEN_ERROR_DRM_CLASS = -8388608;

const int TIZEN_ERROR_ACCOUNT_CLASS = -16777216;

const int TIZEN_ERROR_ACCOUNT = -16777216;

const int TIZEN_ERROR_ACCOUNT_OAUTH = -16842752;

const int TIZEN_ERROR_SYNC_MANAGER = -16908288;

const int TIZEN_ERROR_FIDO = -16973824;

const int TIZEN_ERROR_APPLICATION = -17825792;

const int TIZEN_ERROR_APPLICATION_MANAGER = -17891328;

const int TIZEN_ERROR_BADGE = -17956864;

const int TIZEN_ERROR_MESSAGE_PORT = -18022400;

const int TIZEN_ERROR_NOTIFICATION = -18087936;

const int TIZEN_ERROR_PACKAGE_MANAGER = -18153472;

const int TIZEN_ERROR_SHORTCUT = -18219008;

const int TIZEN_ERROR_BUNDLE = -18350080;

const int TIZEN_ERROR_DATA_CONTROL = -18415616;

const int TIZEN_ERROR_SERVICE_APPLICATION = -18874368;

const int TIZEN_ERROR_MINICONTROL = -18939904;

const int TIZEN_ERROR_UTILITY_ICU = -22020096;

const int TIZEN_ERROR_MIME_TYPE = -23068672;

const int TIZEN_ERROR_MEDIA_CONTENT = -23134208;

const int TIZEN_ERROR_EMAIL_SERVICE = -24117248;

const int TIZEN_ERROR_MESSAGING_SERVICE = -24182784;

const int TIZEN_ERROR_PUSH = -24248320;

const int TIZEN_ERROR_AUDIO_IO = -26214400;

const int TIZEN_ERROR_CAMERA = -26279936;

const int TIZEN_ERROR_IMAGE_UTIL = -26345472;

const int TIZEN_ERROR_METADATA_EXTRACTOR = -26411008;

const int TIZEN_ERROR_PLAYER = -26476544;

const int TIZEN_ERROR_RECORDER = -26542080;

const int TIZEN_ERROR_SOUND_MANAGER = -26607616;

const int TIZEN_ERROR_TONE_PLAYER = -26673152;

const int TIZEN_ERROR_VIDEO_UTIL = -26738688;

const int TIZEN_ERROR_WAV_PLAYER = -26804224;

const int TIZEN_ERROR_RADIO = -26869760;

const int TIZEN_ERROR_MEDIACODEC = -26935296;

const int TIZEN_ERROR_METADATA_EDITOR = -27000832;

const int TIZEN_ERROR_MEDIA_VISION = -27066368;

const int TIZEN_ERROR_MEDIA_DEMUXER = -27131904;

const int TIZEN_ERROR_MEDIA_MUXER = -27197440;

const int TIZEN_ERROR_MEDIA_STREAMER = -27262976;

const int TIZEN_ERROR_STREAMRECORDER = -27328512;

const int TIZEN_ERROR_MEDIA_TOOL = -27394048;

const int TIZEN_ERROR_BLUETOOTH = -29360128;

const int TIZEN_ERROR_CONNECTION = -29425664;

const int TIZEN_ERROR_NFC = -29491200;

const int TIZEN_ERROR_SERIAL = -29556736;

const int TIZEN_ERROR_TETHERING = -29622272;

const int TIZEN_ERROR_WIFI = -29687808;

const int TIZEN_ERROR_WIFI_DIRECT = -29753344;

const int TIZEN_ERROR_SMARTCARD = -29818880;

const int TIZEN_ERROR_IOTCON = -29884416;

const int TIZEN_ERROR_SSDP = -29949952;

const int TIZEN_ERROR_DNSSD = -30015488;

const int TIZEN_ERROR_VPNSVC = -30081024;

const int TIZEN_ERROR_MTP = -30146560;

const int TIZEN_ERROR_HTTP = -30212096;

const int TIZEN_ERROR_WIFI_MANAGER = -30277632;

const int TIZEN_ERROR_PRIVACY_MANAGER = -31457280;

const int TIZEN_ERROR_KEY_MANAGER = -31522816;

const int TIZEN_ERROR_PRIVILEGE_INFORMATION = -31588352;

const int TIZEN_ERROR_CSR = -31653888;

const int TIZEN_ERROR_CALENDAR = -33554432;

const int TIZEN_ERROR_CONTACTS = -33619968;

const int TIZEN_ERROR_PHONENUMBER_UTILS = -33685504;

const int TIZEN_ERROR_STORAGE = -35651584;

const int TIZEN_ERROR_VCONF = -35717120;

const int TIZEN_ERROR_DEVICE = -37748736;

const int TIZEN_ERROR_DLOG = -37814272;

const int TIZEN_ERROR_MEDIA_KEY = -37879808;

const int TIZEN_ERROR_RUNTIME_INFORMATION = -37945344;

const int TIZEN_ERROR_SENSOR = -38010880;

const int TIZEN_ERROR_SYSTEM_INFORMATION = -38076416;

const int TIZEN_ERROR_SYSTEM_SETTING = -38141952;

const int TIZEN_ERROR_SYSTEM_RESOURCE = -38207488;

const int TIZEN_ERROR_CONTEXT = -38273024;

const int TIZEN_ERROR_HEALTH = -38338560;

const int TIZEN_ERROR_FEEDBACK = -38404096;

const int TIZEN_ERROR_USB_HOST = -38469632;

const int TIZEN_ERROR_TELEPHONY = -39845888;

const int TIZEN_ERROR_EFL_UTIL = -41943040;

const int TIZEN_ERROR_UTILX = -42008576;

const int TIZEN_ERROR_NATIVE_BUFFER = -42074112;

const int TIZEN_ERROR_TBM = -42139648;

const int TIZEN_ERROR_EOM = -42205184;

const int TIZEN_ERROR_PANEL = -42270720;

const int TIZEN_ERROR_TZSH = -42336256;

const int TIZEN_ERROR_DOWNLOAD = -44040192;

const int TIZEN_ERROR_WEBVIEW = -44105728;

const int TIZEN_ERROR_LOCATION_MANAGER = -46137344;

const int TIZEN_ERROR_GEOFENCE_MANAGER = -46202880;

const int TIZEN_ERROR_MAPS_SERVICE = -46268416;

const int TIZEN_ERROR_STT = -49283072;

const int TIZEN_ERROR_TTS = -49348608;

const int TIZEN_ERROR_IME = -49414144;

const int TIZEN_ERROR_SERVICE_ADAPTOR = -49479680;

const int TIZEN_ERROR_WIDGET = -49545216;

const int TIZEN_ERROR_VOICE_CONTROL = -49610752;

const int TIZEN_ERROR_ASP = -49676288;

const int TIZEN_ZIGBEE_ERROR = -49741824;

const int TIZEN_ERROR_STC = -49807360;

const int TIZEN_ERROR_THUMBNAIL_UTIL = -49872896;

const int TIZEN_ERROR_JOB_SCHEDULER = -49938432;

const String APP_CONTROL_OPERATION_MAIN =
    'http://tizen.org/appcontrol/operation/main';

const String APP_CONTROL_OPERATION_DEFAULT =
    'http://tizen.org/appcontrol/operation/default';

const String APP_CONTROL_OPERATION_EDIT =
    'http://tizen.org/appcontrol/operation/edit';

const String APP_CONTROL_OPERATION_VIEW =
    'http://tizen.org/appcontrol/operation/view';

const String APP_CONTROL_OPERATION_PICK =
    'http://tizen.org/appcontrol/operation/pick';

const String APP_CONTROL_OPERATION_CREATE_CONTENT =
    'http://tizen.org/appcontrol/operation/create_content';

const String APP_CONTROL_OPERATION_CALL =
    'http://tizen.org/appcontrol/operation/call';

const String APP_CONTROL_OPERATION_SEND =
    'http://tizen.org/appcontrol/operation/send';

const String APP_CONTROL_OPERATION_SEND_TEXT =
    'http://tizen.org/appcontrol/operation/send_text';

const String APP_CONTROL_OPERATION_SHARE =
    'http://tizen.org/appcontrol/operation/share';

const String APP_CONTROL_OPERATION_MULTI_SHARE =
    'http://tizen.org/appcontrol/operation/multi_share';

const String APP_CONTROL_OPERATION_SHARE_TEXT =
    'http://tizen.org/appcontrol/operation/share_text';

const String APP_CONTROL_OPERATION_DIAL =
    'http://tizen.org/appcontrol/operation/dial';

const String APP_CONTROL_OPERATION_SEARCH =
    'http://tizen.org/appcontrol/operation/search';

const String APP_CONTROL_OPERATION_DOWNLOAD =
    'http://tizen.org/appcontrol/operation/download';

const String APP_CONTROL_OPERATION_PRINT =
    'http://tizen.org/appcontrol/operation/print';

const String APP_CONTROL_OPERATION_COMPOSE =
    'http://tizen.org/appcontrol/operation/compose';

const String APP_CONTROL_OPERATION_LAUNCH_ON_EVENT =
    'http://tizen.org/appcontrol/operation/launch_on_event';

const String APP_CONTROL_OPERATION_ADD =
    'http://tizen.org/appcontrol/operation/add';

const String APP_CONTROL_OPERATION_IMAGE_CAPTURE =
    'http://tizen.org/appcontrol/operation/image_capture';

const String APP_CONTROL_OPERATION_VIDEO_CAPTURE =
    'http://tizen.org/appcontrol/operation/video_capture';

const String APP_CONTROL_OPERATION_SETTING_BT_ENABLE =
    'http://tizen.org/appcontrol/operation/setting/bt_enable';

const String APP_CONTROL_OPERATION_SETTING_BT_VISIBILITY =
    'http://tizen.org/appcontrol/operation/setting/bt_visibility';

const String APP_CONTROL_OPERATION_SETTING_LOCATION =
    'http://tizen.org/appcontrol/operation/setting/location';

const String APP_CONTROL_OPERATION_SETTING_NFC =
    'http://tizen.org/appcontrol/operation/setting/nfc';

const String APP_CONTROL_OPERATION_SETTING =
    'http://tizen.org/appcontrol/operation/setting';

const String APP_CONTROL_OPERATION_SETTING_WIFI =
    'http://tizen.org/appcontrol/operation/setting/wifi';

const String APP_CONTROL_OPERATION_SETTING_VPN =
    'http://tizen.org/appcontrol/operation/setting/vpn';

const String APP_CONTROL_OPERATION_GET_INPUT =
    'http://tizen.org/appcontrol/operation/get_input';

const String APP_CONTROL_DATA_SUBJECT =
    'http://tizen.org/appcontrol/data/subject';

const String APP_CONTROL_DATA_TO = 'http://tizen.org/appcontrol/data/to';

const String APP_CONTROL_DATA_CC = 'http://tizen.org/appcontrol/data/cc';

const String APP_CONTROL_DATA_BCC = 'http://tizen.org/appcontrol/data/bcc';

const String APP_CONTROL_DATA_TEXT = 'http://tizen.org/appcontrol/data/text';

const String APP_CONTROL_DATA_TITLE = 'http://tizen.org/appcontrol/data/title';

const String APP_CONTROL_DATA_SELECTED =
    'http://tizen.org/appcontrol/data/selected';

const String APP_CONTROL_DATA_PATH = 'http://tizen.org/appcontrol/data/path';

const String APP_CONTROL_DATA_SELECTION_MODE =
    'http://tizen.org/appcontrol/data/selection_mode';

const String APP_CONTROL_DATA_CALENDAR_ALL_DAY =
    'http://tizen.org/appcontrol/data/calendar/all_day';

const String APP_CONTROL_DATA_CALENDAR_START_TIME =
    'http://tizen.org/appcontrol/data/calendar/start_time';

const String APP_CONTROL_DATA_CALENDAR_END_TIME =
    'http://tizen.org/appcontrol/data/calendar/end_time';

const String APP_CONTROL_DATA_EMAIL = 'http://tizen.org/appcontrol/data/email';

const String APP_CONTROL_DATA_PHONE = 'http://tizen.org/appcontrol/data/phone';

const String APP_CONTROL_DATA_URL = 'http://tizen.org/appcontrol/data/url';

const String APP_CONTROL_DATA_ID = 'http://tizen.org/appcontrol/data/id';

const String APP_CONTROL_DATA_TYPE = 'http://tizen.org/appcontrol/data/type';

const String APP_CONTROL_DATA_TOTAL_COUNT =
    'http://tizen.org/appcontrol/data/total_count';

const String APP_CONTROL_DATA_TOTAL_SIZE =
    'http://tizen.org/appcontrol/data/total_size';

const String APP_CONTROL_DATA_NAME = 'http://tizen.org/appcontrol/data/name';

const String APP_CONTROL_DATA_LOCATION =
    'http://tizen.org/appcontrol/data/location';

const String APP_CONTROL_DATA_INPUT_TYPE =
    'http://tizen.org/appcontrol/data/input_type';

const String APP_CONTROL_DATA_INPUT_DEFAULT_TEXT =
    'http://tizen.org/appcontrol/data/input_default_text';

const String APP_CONTROL_DATA_INPUT_GUIDE_TEXT =
    'http://tizen.org/appcontrol/data/input_guide_text';

const String APP_CONTROL_DATA_INPUT_PREDICTION_HINT =
    'http://tizen.org/appcontrol/data/input_prediction_hint';

const String APP_CONTROL_DATA_INPUT_RETURNKEY_TYPE =
    'http://tizen.org/appcontrol/data/input_returnkey_type';

const String APP_CONTROL_DATA_INPUT_MAX_TEXT_LENGTH =
    'http://tizen.org/appcontrol/data/input_max_text_length';

const String APP_CONTROL_DATA_INPUT_CURSOR_POSITION_SET =
    'http://tizen.org/appcontrol/data/input_cursor_position_set';

const String APP_CONTROL_DATA_INPUT_CURSOR_POSITION_GET =
    'http://tizen.org/appcontrol/data/input_cursor_position_get';

const String APP_CONTROL_DATA_INPUT_REPLY_TYPE =
    'http://tizen.org/appcontrol/data/input_reply_type';

const String APP_CONTROL_DATA_WIDGET_INSTANCE_ID =
    'http://tizen.org/appcontrol/data/widget_instance_id';

const String APP_CONTROL_DATA_WIDGET_CONTENT =
    'http://tizen.org/appcontrol/data/widget_content';

const String APP_CONTROL_DATA_WIDGET_APP_ID =
    'http://tizen.org/appcontrol/data/widget_app_id';

const int NOTIFICATION_DO_NOT_SHOW_TIME_STAMP = -1;

const String APP_CONTROL_DATA_ALARM_ID =
    'http://tizen.org/appcontrol/data/alarm_id';

const String SYSTEM_EVENT_BATTERY_CHARGER_STATUS =
    'tizen.system.event.battery_charger_status';

const String EVENT_KEY_BATTERY_CHARGER_STATUS = 'battery_charger_status';

const String EVENT_VAL_BATTERY_CHARGER_DISCONNECTED = 'disconnected';

const String EVENT_VAL_BATTERY_CHARGER_CONNECTED = 'connected';

const String EVENT_VAL_BATTERY_CHARGER_CHARGING = 'charging';

const String EVENT_VAL_BATTERY_CHARGER_DISCHARGING = 'discharging';

const String SYSTEM_EVENT_BATTERY_LEVEL_STATUS =
    'tizen.system.event.battery_level_status';

const String EVENT_KEY_BATTERY_LEVEL_STATUS = 'battery_level_status';

const String EVENT_VAL_BATTERY_LEVEL_EMPTY = 'empty';

const String EVENT_VAL_BATTERY_LEVEL_CRITICAL = 'critical';

const String EVENT_VAL_BATTERY_LEVEL_LOW = 'low';

const String EVENT_VAL_BATTERY_LEVEL_HIGH = 'high';

const String EVENT_VAL_BATTERY_LEVEL_FULL = 'full';

const String SYSTEM_EVENT_USB_STATUS = 'tizen.system.event.usb_status';

const String EVENT_KEY_USB_STATUS = 'usb_status';

const String EVENT_VAL_USB_DISCONNECTED = 'disconnected';

const String EVENT_VAL_USB_CONNECTED = 'connected';

const String EVENT_VAL_USB_AVAILABLE = 'available';

const String SYSTEM_EVENT_EARJACK_STATUS = 'tizen.system.event.earjack_status';

const String EVENT_KEY_EARJACK_STATUS = 'earjack_status';

const String EVENT_VAL_EARJACK_DISCONNECTED = 'disconnected';

const String EVENT_VAL_EARJACK_CONNECTED = 'connected';

const String SYSTEM_EVENT_DISPLAY_STATE = 'tizen.system.event.display_state';

const String EVENT_KEY_DISPLAY_STATE = 'display_state';

const String EVENT_VAL_DISPLAY_NORMAL = 'normal';

const String EVENT_VAL_DISPLAY_DIM = 'dim';

const String EVENT_VAL_DISPLAY_OFF = 'off';

const String SYSTEM_EVENT_BOOT_COMPLETED = 'tizen.system.event.boot_completed';

const String SYSTEM_EVENT_SYSTEM_SHUTDOWN =
    'tizen.system.event.system_shutdown';

const String SYSTEM_EVENT_LOW_MEMORY = 'tizen.system.event.low_memory';

const String EVENT_KEY_LOW_MEMORY = 'low_memory';

const String EVENT_VAL_MEMORY_NORMAL = 'normal';

const String EVENT_VAL_MEMORY_SOFT_WARNING = 'soft_warning';

const String EVENT_VAL_MEMORY_HARD_WARNING = 'hard_warning';

const String SYSTEM_EVENT_WIFI_STATE = 'tizen.system.event.wifi_state';

const String EVENT_KEY_WIFI_STATE = 'wifi_state';

const String EVENT_VAL_WIFI_OFF = 'off';

const String EVENT_VAL_WIFI_ON = 'on';

const String EVENT_VAL_WIFI_CONNECTED = 'connected';

const String SYSTEM_EVENT_BT_STATE = 'tizen.system.event.bt_state';

const String EVENT_KEY_BT_STATE = 'bt_state';

const String EVENT_VAL_BT_OFF = 'off';

const String EVENT_VAL_BT_ON = 'on';

const String EVENT_KEY_BT_LE_STATE = 'bt_le_state';

const String EVENT_VAL_BT_LE_OFF = 'off';

const String EVENT_VAL_BT_LE_ON = 'on';

const String EVENT_KEY_BT_TRANSFERING_STATE = 'bt_transfering_state';

const String EVENT_VAL_BT_NON_TRANSFERING = 'non_transfering';

const String EVENT_VAL_BT_TRANSFERING = 'transfering';

const String SYSTEM_EVENT_LOCATION_ENABLE_STATE =
    'tizen.system.event.location_enable_state';

const String EVENT_KEY_LOCATION_ENABLE_STATE = 'location_enable_state';

const String EVENT_VAL_LOCATION_DISABLED = 'disabled';

const String EVENT_VAL_LOCATION_ENABLED = 'enabled';

const String SYSTEM_EVENT_GPS_ENABLE_STATE =
    'tizen.system.event.gps_enable_state';

const String EVENT_KEY_GPS_ENABLE_STATE = 'gps_enable_state';

const String EVENT_VAL_GPS_DISABLED = 'disabled';

const String EVENT_VAL_GPS_ENABLED = 'enabled';

const String SYSTEM_EVENT_NPS_ENABLE_STATE =
    'tizen.system.event.nps_enable_state';

const String EVENT_KEY_NPS_ENABLE_STATE = 'nps_enable_state';

const String EVENT_VAL_NPS_DISABLED = 'disabled';

const String EVENT_VAL_NPS_ENABLED = 'enabled';

const String SYSTEM_EVENT_INCOMING_MSG = 'tizen.system.event.incoming_msg';

const String EVENT_KEY_MSG_TYPE = 'msg_type';

const String EVENT_VAL_SMS = 'sms';

const String EVENT_VAL_MMS = 'mms';

const String EVENT_VAL_PUSH = 'push';

const String EVENT_VAL_CB = 'cb';

const String EVENT_KEY_MSG_ID = 'msg_id';

const String SYSTEM_EVENT_OUTGOING_MSG = 'tizen.system.event.outgoing_msg';

const String EVENT_KEY_OUT_MSG_TYPE = 'msg_type';

const String EVENT_KEY_OUT_MSG_ID = 'msg_id';

const String SYSTEM_EVENT_TIME_CHANGED = 'tizen.system.event.time_changed';

const String SYSTEM_EVENT_TIME_ZONE = 'tizen.system.event.time_zone';

const String EVENT_KEY_TIME_ZONE = 'time_zone';

const String SYSTEM_EVENT_HOUR_FORMAT = 'tizen.system.event.hour_format';

const String EVENT_KEY_HOUR_FORMAT = 'hour_format';

const String EVENT_VAL_HOURFORMAT_12 = '12';

const String EVENT_VAL_HOURFORMAT_24 = '24';

const String SYSTEM_EVENT_LANGUAGE_SET = 'tizen.system.event.language_set';

const String EVENT_KEY_LANGUAGE_SET = 'language_set';

const String SYSTEM_EVENT_REGION_FORMAT = 'tizen.system.event.region_format';

const String EVENT_KEY_REGION_FORMAT = 'region_format';

const String SYSTEM_EVENT_SILENT_MODE = 'tizen.system.event.silent_mode';

const String EVENT_KEY_SILENT_MODE = 'silent_mode';

const String EVENT_VAL_SILENTMODE_ON = 'on';

const String EVENT_VAL_SILENTMODE_OFF = 'off';

const String SYSTEM_EVENT_VIBRATION_STATE =
    'tizen.system.event.vibration_state';

const String EVENT_KEY_VIBRATION_STATE = 'vibration_state';

const String EVENT_VAL_VIBRATION_ON = 'on';

const String EVENT_VAL_VIBRATION_OFF = 'off';

const String SYSTEM_EVENT_SCREEN_AUTOROTATE_STATE =
    'tizen.system.event.screen_autorotate_state';

const String EVENT_KEY_SCREEN_AUTOROTATE_STATE = 'screen_autorotate_state';

const String EVENT_VAL_SCREEN_AUTOROTATE_ON = 'on';

const String EVENT_VAL_SCREEN_AUTOROTATE_OFF = 'off';

const String SYSTEM_EVENT_MOBILE_DATA_STATE =
    'tizen.system.event.mobile_data_state';

const String EVENT_KEY_MOBILE_DATA_STATE = 'mobile_data_state';

const String EVENT_VAL_MOBILE_DATA_OFF = 'off';

const String EVENT_VAL_MOBILE_DATA_ON = 'on';

const String SYSTEM_EVENT_DATA_ROAMING_STATE =
    'tizen.system.event.data_roaming_state';

const String EVENT_KEY_DATA_ROAMING_STATE = 'data_roaming_state';

const String EVENT_VAL_DATA_ROAMING_OFF = 'off';

const String EVENT_VAL_DATA_ROAMING_ON = 'on';

const String SYSTEM_EVENT_FONT_SET = 'tizen.system.event.font_set';

const String EVENT_KEY_FONT_SET = 'font_set';

const String SYSTEM_EVENT_NETWORK_STATUS = 'tizen.system.event.network_status';

const String EVENT_KEY_NETWORK_STATUS = 'network_status';

const String EVENT_VAL_NETWORK_DISCONNECTED = 'disconnected';

const String EVENT_VAL_NETWORK_WIFI = 'wifi';

const String EVENT_VAL_NETWORK_CELLULAR = 'cellular';

const String EVENT_VAL_NETWORK_ETHERNET = 'ethernet';

const String EVENT_VAL_NETWORK_BT = 'bt';

const String EVENT_VAL_NETWORK_NET_PROXY = 'net_proxy';

const String PACKAGE_INFO_PROP_APP_ID = 'PACKAGE_INFO_PROP_APP_ID';

const String PACKAGE_INFO_PROP_APP_TYPE = 'PACKAGE_INFO_PROP_APP_TYPE';

const String PACKAGE_INFO_PROP_APP_CATEGORY = 'PACKAGE_INFO_PROP_APP_CATEGORY';

const String PACKAGE_INFO_PROP_APP_INSTALLED_STORAGE =
    'PACKAGE_INFO_PROP_APP_INSTALLED_STORAGE';

const String PACKAGE_INFO_PROP_APP_NODISPLAY =
    'PACKAGE_INFO_PROP_APP_NODISPLAY';

const String PACKAGE_INFO_PROP_APP_TASKMANAGE =
    'PACKAGE_INFO_PROP_APP_TASKMANAGE';

const String PACKAGE_INFO_PROP_APP_DISABLED = 'PACKAGE_INFO_PROP_APP_DISABLED';

const String PACKAGE_INFO_PROP_APP_COMPONENT_TYPE =
    'PACKAGE_INFO_PROP_APP_COMPONENT_TYPE';

const String PACKAGE_MANAGER_PKGINFO_PROP_REMOVABLE =
    'PMINFO_PKGINFO_PROP_PACKAGE_REMOVABLE';

const String PACKAGE_MANAGER_PKGINFO_PROP_READONLY =
    'PMINFO_PKGINFO_PROP_PACKAGE_READONLY';

const String PACKAGE_MANAGER_PKGINFO_PROP_SUPPORT_DISABLE =
    'PMINFO_PKGINFO_PROP_PACKAGE_SUPPORT_DISABLE';

const String PACKAGE_MANAGER_PKGINFO_PROP_DISABLE =
    'PMINFO_PKGINFO_PROP_PACKAGE_DISABLE';

const String PACKAGE_MANAGER_PKGINFO_PROP_PRELOAD =
    'PMINFO_PKGINFO_PROP_PACKAGE_PRELOAD';

const int MEDIA_CONTENT_ERROR_CLASS = -23134208;

const String MEDIA_ID = 'MEDIA_ID';

const String MEDIA_PATH = 'MEDIA_PATH';

const String MEDIA_DISPLAY_NAME = 'MEDIA_DISPLAY_NAME';

const String MEDIA_TYPE = 'MEDIA_TYPE';

const String MEDIA_MIME_TYPE = 'MEDIA_MIME_TYPE';

const String MEDIA_SIZE = 'MEDIA_SIZE';

const String MEDIA_ADDED_TIME = 'MEDIA_ADDED_TIME';

const String MEDIA_MODIFIED_TIME = 'MEDIA_MODIFIED_TIME';

const String MEDIA_TIMELINE = 'MEDIA_TIMELINE';

const String MEDIA_THUMBNAIL_PATH = 'MEDIA_THUMBNAIL_PATH';

const String MEDIA_TITLE = 'MEDIA_TITLE';

const String MEDIA_ALBUM = 'MEDIA_ALBUM';

const String MEDIA_ARTIST = 'MEDIA_ARTIST';

const String MEDIA_ALBUM_ARTIST = 'MEDIA_ALBUM_ARTIST';

const String MEDIA_GENRE = 'MEDIA_GENRE';

const String MEDIA_COMPOSER = 'MEDIA_COMPOSER';

const String MEDIA_YEAR = 'MEDIA_YEAR';

const String MEDIA_RECORDED_DATE = 'MEDIA_RECORDED_DATE';

const String MEDIA_COPYRIGHT = 'MEDIA_COPYRIGHT';

const String MEDIA_TRACK_NUM = 'MEDIA_TRACK_NUM';

const String MEDIA_DESCRIPTION = 'MEDIA_DESCRIPTION';

const String MEDIA_BITRATE = 'MEDIA_BITRATE';

const String MEDIA_BITPERSAMPLE = 'MEDIA_BITPERSAMPLE';

const String MEDIA_SAMPLERATE = 'MEDIA_SAMPLERATE';

const String MEDIA_CHANNEL = 'MEDIA_CHANNEL';

const String MEDIA_DURATION = 'MEDIA_DURATION';

const String MEDIA_LONGITUDE = 'MEDIA_LONGITUDE';

const String MEDIA_LATITUDE = 'MEDIA_LATITUDE';

const String MEDIA_ALTITUDE = 'MEDIA_ALTITUDE';

const String MEDIA_WIDTH = 'MEDIA_WIDTH';

const String MEDIA_HEIGHT = 'MEDIA_HEIGHT';

const String MEDIA_DATETAKEN = 'MEDIA_DATETAKEN';

const String MEDIA_ORIENTATION = 'MEDIA_ORIENTATION';

const String MEDIA_BURST_ID = 'BURST_ID';

const String MEDIA_PLAYED_COUNT = 'MEDIA_PLAYED_COUNT';

const String MEDIA_LAST_PLAYED_TIME = 'MEDIA_LAST_PLAYED_TIME';

const String MEDIA_LAST_PLAYED_POSITION = 'MEDIA_LAST_PLAYED_POSITION';

const String MEDIA_RATING = 'MEDIA_RATING';

const String MEDIA_FAVOURITE = 'MEDIA_FAVOURITE';

const String MEDIA_AUTHOR = 'MEDIA_AUTHOR';

const String MEDIA_PROVIDER = 'MEDIA_PROVIDER';

const String MEDIA_CONTENT_NAME = 'MEDIA_CONTENT_NAME';

const String MEDIA_CATEGORY = 'MEDIA_CATEGORY';

const String MEDIA_LOCATION_TAG = 'MEDIA_LOCATION_TAG';

const String MEDIA_AGE_RATING = 'MEDIA_AGE_RATING';

const String MEDIA_KEYWORD = 'MEDIA_KEYWORD';

const String MEDIA_WEATHER = 'MEDIA_WEATHER';

const String MEDIA_IS_DRM = 'MEDIA_IS_DRM';

const String MEDIA_STORAGE_TYPE = 'MEDIA_STORAGE_TYPE';

const String MEDIA_EXPOSURE_TIME = 'MEDIA_EXPOSURE_TIME';

const String MEDIA_FNUMBER = 'MEDIA_FNUMBER';

const String MEDIA_ISO = 'MEDIA_ISO';

const String MEDIA_MODEL = 'MEDIA_MODEL';

const String MEDIA_FILE_NAME_PINYIN = 'MEDIA_FILE_NAME_PINYIN';

const String MEDIA_TITLE_PINYIN = 'MEDIA_TITLE_PINYIN';

const String MEDIA_ALBUM_PINYIN = 'MEDIA_ALBUM_PINYIN';

const String MEDIA_ARTIST_PINYIN = 'MEDIA_ARTIST_PINYIN';

const String MEDIA_ALBUM_ARTIST_PINYIN = 'MEDIA_ALBUM_ARTIST_PINYIN';

const String MEDIA_GENRE_PINYIN = 'MEDIA_GENRE_PINYIN';

const String MEDIA_COMPOSER_PINYIN = 'MEDIA_COMPOSER_PINYIN';

const String MEDIA_COPYRIGHT_PINYIN = 'MEDIA_COPYRIGHT_PINYIN';

const String MEDIA_DESCRIPTION_PINYIN = 'MEDIA_DESCRIPTION_PINYIN';

const String MEDIA_AUTHOR_PINYIN = 'MEDIA_AUTHOR_PINYIN';

const String MEDIA_PROVIDER_PINYIN = 'MEDIA_PROVIDER_PINYIN';

const String MEDIA_CONTENT_NAME_PINYIN = 'MEDIA_CONTENT_NAME_PINYIN';

const String MEDIA_CATEGORY_PINYIN = 'MEDIA_CATEGORY_PINYIN';

const String MEDIA_LOCATION_TAG_PINYIN = 'MEDIA_LOCATION_TAG_PINYIN';

const String MEDIA_AGE_RATING_PINYIN = 'MEDIA_AGE_RATING_PINYIN';

const String MEDIA_KEYWORD_PINYIN = 'MEDIA_KEYWORD_PINYIN';

const String MEDIA_360 = 'MEDIA_360';

const String FOLDER_ID = 'FOLDER_ID';

const String FOLDER_PATH = 'FOLDER_PATH';

const String FOLDER_NAME = 'FOLDER_NAME';

const String FOLDER_MODIFIED_TIME = 'FOLDER_MODIFIED_TIME';

const String FOLDER_STORAGE_TYPE = 'FOLDER_STORAGE_TYPE';

const String FOLDER_NAME_PINYIN = 'FOLDER_NAME_PINYIN';

const String FOLDER_ORDER = 'FOLDER_ORDER';

const String FOLDER_PARENT_FOLDER_ID = 'FOLDER_PARENT_FOLDER_ID';

const String PLAYLIST_NAME = 'PLAYLIST_NAME';

const String MEDIA_PLAYLIST_ID = 'PLAYLIST_ID';

const String PLAYLIST_MEMBER_ORDER = 'PLAYLIST_MEMBER_ORDER';

const String PLAYLIST_MEDIA_COUNT = 'PLAYLIST_MEDIA_COUNT';

const String TAG_NAME = 'TAG_NAME';

const String MEDIA_TAG_ID = 'TAG_ID';

const String TAG_MEDIA_COUNT = 'TAG_MEDIA_COUNT';

const String BOOKMARK_MARKED_TIME = 'BOOKMARK_MARKED_TIME';

const String MEDIA_BOOKMARK_ID = 'BOOKMARK_ID';

const String BOOKMARK_NAME = 'BOOKMARK_NAME';

const String MEDIA_STORAGE_ID = 'STORAGE_ID';

const String MEDIA_STORAGE_PATH = 'STORAGE_PATH';

const String MEDIA_FACE_TAG = 'MEDIA_FACE_TAG';

const String MEDIA_FACE_ID = 'MEDIA_FACE_ID';

const int TBM_SURF_PLANE_MAX = 4;

const int TBM_SURF_OPTION_READ = 1;

const int TBM_SURF_OPTION_WRITE = 2;

const int TBM_FORMAT_C8 = 538982467;

const int TBM_FORMAT_RGB332 = 943867730;

const int TBM_FORMAT_BGR233 = 944916290;

const int TBM_FORMAT_XRGB4444 = 842093144;

const int TBM_FORMAT_XBGR4444 = 842089048;

const int TBM_FORMAT_RGBX4444 = 842094674;

const int TBM_FORMAT_BGRX4444 = 842094658;

const int TBM_FORMAT_ARGB4444 = 842093121;

const int TBM_FORMAT_ABGR4444 = 842089025;

const int TBM_FORMAT_RGBA4444 = 842088786;

const int TBM_FORMAT_BGRA4444 = 842088770;

const int TBM_FORMAT_XRGB1555 = 892424792;

const int TBM_FORMAT_XBGR1555 = 892420696;

const int TBM_FORMAT_RGBX5551 = 892426322;

const int TBM_FORMAT_BGRX5551 = 892426306;

const int TBM_FORMAT_ARGB1555 = 892424769;

const int TBM_FORMAT_ABGR1555 = 892420673;

const int TBM_FORMAT_RGBA5551 = 892420434;

const int TBM_FORMAT_BGRA5551 = 892420418;

const int TBM_FORMAT_RGB565 = 909199186;

const int TBM_FORMAT_BGR565 = 909199170;

const int TBM_FORMAT_RGB888 = 875710290;

const int TBM_FORMAT_BGR888 = 875710274;

const int TBM_FORMAT_XRGB8888 = 875713112;

const int TBM_FORMAT_XBGR8888 = 875709016;

const int TBM_FORMAT_RGBX8888 = 875714642;

const int TBM_FORMAT_BGRX8888 = 875714626;

const int TBM_FORMAT_ARGB8888 = 875713089;

const int TBM_FORMAT_ABGR8888 = 875708993;

const int TBM_FORMAT_RGBA8888 = 875708754;

const int TBM_FORMAT_BGRA8888 = 875708738;

const int TBM_FORMAT_XRGB2101010 = 808669784;

const int TBM_FORMAT_XBGR2101010 = 808665688;

const int TBM_FORMAT_RGBX1010102 = 808671314;

const int TBM_FORMAT_BGRX1010102 = 808671298;

const int TBM_FORMAT_ARGB2101010 = 808669761;

const int TBM_FORMAT_ABGR2101010 = 808665665;

const int TBM_FORMAT_RGBA1010102 = 808665426;

const int TBM_FORMAT_BGRA1010102 = 808665410;

const int TBM_FORMAT_YUYV = 1448695129;

const int TBM_FORMAT_YVYU = 1431918169;

const int TBM_FORMAT_UYVY = 1498831189;

const int TBM_FORMAT_VYUY = 1498765654;

const int TBM_FORMAT_AYUV = 1448433985;

const int TBM_FORMAT_NV12 = 842094158;

const int TBM_FORMAT_NV21 = 825382478;

const int TBM_FORMAT_NV16 = 909203022;

const int TBM_FORMAT_NV61 = 825644622;

const int TBM_FORMAT_YUV410 = 961959257;

const int TBM_FORMAT_YVU410 = 961893977;

const int TBM_FORMAT_YUV411 = 825316697;

const int TBM_FORMAT_YVU411 = 825316953;

const int TBM_FORMAT_YUV420 = 842093913;

const int TBM_FORMAT_YVU420 = 842094169;

const int TBM_FORMAT_YUV422 = 909202777;

const int TBM_FORMAT_YVU422 = 909203033;

const int TBM_FORMAT_YUV444 = 875713881;

const int TBM_FORMAT_YVU444 = 875714137;

const int TBM_FORMAT_NV12MT = 842091860;

const int CAMERA_ERROR_CLASS = -26279936;

const String MEDIA_STREAMER_PARAM_CAMERA_ID = 'camera-id';

const String MEDIA_STREAMER_PARAM_CAPTURE_WIDTH = 'capture-width';

const String MEDIA_STREAMER_PARAM_CAPTURE_HEIGHT = 'capture-height';

const String MEDIA_STREAMER_PARAM_IS_LIVE_STREAM = 'is-live';

const String MEDIA_STREAMER_PARAM_URI = 'uri';

const String MEDIA_STREAMER_PARAM_USER_AGENT = 'user-agent';

const String MEDIA_STREAMER_PARAM_STREAM_TYPE = 'stream-type';

const String MEDIA_STREAMER_PARAM_PORT = 'port';

const String MEDIA_STREAMER_PARAM_VIDEO_IN_PORT = 'video_in_port';

const String MEDIA_STREAMER_PARAM_AUDIO_IN_PORT = 'audio_in_port';

const String MEDIA_STREAMER_PARAM_VIDEO_OUT_PORT = 'video_out_port';

const String MEDIA_STREAMER_PARAM_AUDIO_OUT_PORT = 'audio_out_port';

const String MEDIA_STREAMER_PARAM_IP_ADDRESS = 'address';

const String MEDIA_STREAMER_PARAM_AUDIO_DEVICE = 'audio_device';

const String MEDIA_STREAMER_PARAM_CLOCK_SYNCHRONIZED = 'sync';

const String MEDIA_STREAMER_PARAM_ROTATE = 'rotate';

const String MEDIA_STREAMER_PARAM_FLIP = 'flip';

const String MEDIA_STREAMER_PARAM_DISPLAY_GEOMETRY_METHOD =
    'display-geometry-method';

const String MEDIA_STREAMER_PARAM_DISPLAY = 'display';

const String MEDIA_STREAMER_PARAM_VISIBLE = 'visible';

const String MEDIA_STREAMER_PARAM_HOST = 'host';

const String MEDIA_STREAMER_PARAM_SEGMENT_LOCATION = 'location';

const String MEDIA_STREAMER_PARAM_PLAYLIST_LOCATION = 'playlist-location';

const String MV_BARCODE_DETECT_ATTR_TARGET = 'MV_BARCODE_DETECT_ATTR_TARGET';

const String MV_BARCODE_GENERATE_ATTR_TEXT = 'MV_BARCODE_GENERATE_ATTR_TEXT';

const String MV_BARCODE_GENERATE_ATTR_COLOR_FRONT =
    'MV_BARCODE_GENERATE_ATTR_COLOR_FRONT';

const String MV_BARCODE_GENERATE_ATTR_COLOR_BACK =
    'MV_BARCODE_GENERATE_ATTR_COLOR_BACK';

const String MV_FACE_DETECTION_MODEL_FILE_PATH =
    'MV_FACE_DETECTION_MODEL_FILE_PATH';

const String MV_FACE_RECOGNITION_MODEL_TYPE = 'MV_FACE_RECOGNITION_MODEL_TYPE';

const String MV_FACE_DETECTION_ROI_X = 'MV_FACE_DETECTION_ROI_X';

const String MV_FACE_DETECTION_ROI_Y = 'MV_FACE_DETECTION_ROI_Y';

const String MV_FACE_DETECTION_ROI_WIDTH = 'MV_FACE_DETECTION_ROI_WIDTH';

const String MV_FACE_DETECTION_ROI_HEIGHT = 'MV_FACE_DETECTION_ROI_HEIGHT';

const String MV_FACE_DETECTION_MIN_SIZE_WIDTH =
    'MV_FACE_DETECTION_MIN_SIZE_WIDTH';

const String MV_FACE_DETECTION_MIN_SIZE_HEIGHT =
    'MV_FACE_DETECTION_MIN_SIZE_HEIGHT';

const String MV_IMAGE_RECOGNITION_OBJECT_SCALE_FACTOR =
    'MV_IMAGE_RECOGNITION_OBJECT_SCALE_FACTOR';

const String MV_IMAGE_RECOGNITION_OBJECT_MAX_KEYPOINTS_NUM =
    'MV_IMAGE_RECOGNITION_OBJECT_MAX_KEYPOINTS_NUM';

const String MV_IMAGE_RECOGNITION_SCENE_SCALE_FACTOR =
    'MV_IMAGE_RECOGNITION_SCENE_SCALE_FACTOR';

const String MV_IMAGE_RECOGNITION_SCENE_MAX_KEYPOINTS_NUM =
    'MV_IMAGE_RECOGNITION_SCENE_MAX_KEYPOINTS_NUM';

const String MV_IMAGE_RECOGNITION_MIN_MATCH_NUM =
    'MV_IMAGE_RECOGNITION_MIN_MATCH_NUM';

const String MV_IMAGE_RECOGNITION_REQ_MATCH_PART =
    'MV_IMAGE_RECOGNITION_REQ_MATCH_PART';

const String MV_IMAGE_RECOGNITION_TOLERANT_MATCH_PART_ERR =
    'MV_IMAGE_RECOGNITION_TOLERANT_MATCH_PART_ERR';

const String MV_IMAGE_TRACKING_HISTORY_AMOUNT =
    'MV_IMAGE_TRACKING_HISTORY_AMOUNT';

const String MV_IMAGE_TRACKING_EXPECTED_OFFSET =
    'MV_IMAGE_TRACKING_EXPECTED_OFFSET';

const String MV_IMAGE_TRACKING_USE_STABLIZATION =
    'MV_IMAGE_TRACKING_USE_STABLIZATION';

const String MV_IMAGE_TRACKING_STABLIZATION_TOLERANT_SHIFT =
    'MV_IMAGE_TRACKING_STABLIZATION_TOLERANT_SHIFT';

const String MV_IMAGE_TRACKING_STABLIZATION_SPEED =
    'MV_IMAGE_TRACKING_STABLIZATION_SPEED';

const String MV_IMAGE_TRACKING_STABLIZATION_ACCELERATION =
    'MV_IMAGE_TRACKING_STABLIZATION_ACCELERATION';

const String MV_SURVEILLANCE_EVENT_TYPE_MOVEMENT_DETECTED =
    'MV_SURVEILLANCE_EVENT_MOVEMENT_DETECTED';

const String MV_SURVEILLANCE_MOVEMENT_NUMBER_OF_REGIONS =
    'NUMBER_OF_MOVEMENT_REGIONS';

const String MV_SURVEILLANCE_MOVEMENT_REGIONS = 'MOVEMENT_REGIONS';

const String MV_SURVEILLANCE_EVENT_TYPE_PERSON_APPEARED_DISAPPEARED =
    'MV_SURVEILLANCE_EVENT_PERSON_APPEARED_DISAPEARED';

const String MV_SURVEILLANCE_PERSONS_APPEARED_NUMBER =
    'NUMBER_OF_APPEARED_PERSONS';

const String MV_SURVEILLANCE_PERSONS_DISAPPEARED_NUMBER =
    'NUMBER_OF_DISAPPEARED_PERSONS';

const String MV_SURVEILLANCE_PERSONS_TRACKED_NUMBER =
    'NUMBER_OF_TRACKED_PERSONS';

const String MV_SURVEILLANCE_PERSONS_APPEARED_LOCATIONS =
    'APPEARED_PERSONS_LOCATIONS';

const String MV_SURVEILLANCE_PERSONS_DISAPPEARED_LOCATIONS =
    'DISAPPEARED_PERSONS_LOCATIONS';

const String MV_SURVEILLANCE_PERSONS_TRACKED_LOCATIONS =
    'TRACKED_PERSONS_LOCATIONS';

const String MV_SURVEILLANCE_EVENT_TYPE_PERSON_RECOGNIZED =
    'MV_SURVEILLANCE_EVENT_PERSON_RECOGNIZED';

const String MV_SURVEILLANCE_PERSONS_RECOGNIZED_NUMBER = 'NUMBER_OF_PERSONS';

const String MV_SURVEILLANCE_PERSONS_RECOGNIZED_LOCATIONS = 'PERSONS_LOCATIONS';

const String MV_SURVEILLANCE_PERSONS_RECOGNIZED_LABELS = 'PERSONS_LABELS';

const String MV_SURVEILLANCE_PERSONS_RECOGNIZED_CONFIDENCES =
    'PERSONS_CONFIDENCES';

const String MV_SURVEILLANCE_FACE_RECOGNITION_MODEL_FILE_PATH =
    'MV_SURVEILLANCE_FACE_RECOGNITION_MODEL_FILE_PATH';

const String MV_SURVEILLANCE_MOVEMENT_DETECTION_THRESHOLD =
    'MV_SURVEILLANCE_MOVEMENT_DETECTION_THRESHOLD';

const String MV_SURVEILLANCE_SKIP_FRAMES_COUNT =
    'MV_SURVEILLANCE_SKIP_FRAMES_COUNT';

const int METADATA_EDITOR_ERROR_CLASS = -27000832;

const int METADATA_EXTRACTOR_ERROR_CLASS = -26411008;

const int PLAYER_ERROR_CLASS = -26476512;

const int PLAYER_CUSTOM_ERROR_CLASS = -26472448;

const int RECORDER_ERROR_CLASS = -26542064;

const int THUMBNAIL_UTIL_ERROR_CLASS = -49872896;

const int TONE_PLAYER_ERROR_CLASS = -8096;

const int VIDEO_UTIL_ERROR_CLASS = -26738688;

const String TRANSCODER_FEATURE_PATH =
    'http://tizen.org/feature/multimedia.transcoder';

const int WAV_PLAYER_ERROR_CLASS = -8112;

const int IOTCON_MULTICAST_ADDRESS = 0;

const int IOTCON_FUNC_STOP = 0;

const int IOTCON_FUNC_CONTINUE = 1;

const String IOTCON_INTERFACE_DEFAULT = 'oic.if.baseline';

const String IOTCON_INTERFACE_LINK = 'oic.if.ll';

const String IOTCON_INTERFACE_BATCH = 'oic.if.b';

const String IOTCON_INTERFACE_GROUP = 'oic.mi.grp';

const String IOTCON_INTERFACE_READONLY = 'oic.if.r';

const int SMARTCARD_ERROR_CLASS = -29818880;

const int YACA_KEYLEN_COMPONENT_TYPE_MASK = -268435456;

const int YACA_KEYLEN_COMPONENT_TYPE_BITS = 0;

const int YACA_KEYLEN_COMPONENT_TYPE_DH = 268435456;

const int YACA_KEYLEN_COMPONENT_TYPE_DH_RFC = 536870912;

const int YACA_KEYLEN_COMPONENT_TYPE_EC = 805306368;

const int YACA_KEYLEN_COMPONENT_DH_GEN_MASK = 251658240;

const int YACA_KEYLEN_COMPONENT_DH_GEN_2 = 0;

const int YACA_KEYLEN_COMPONENT_DH_GEN_5 = 16777216;

const int YACA_KEYLEN_COMPONENT_DH_PRIME_MASK = 65535;

const int YACA_KEYLEN_COMPONENT_DH_RFC_MASK = 251658240;

const int YACA_KEYLEN_COMPONENT_DH_RFC_160 = 0;

const int YACA_KEYLEN_COMPONENT_DH_RFC_224 = 16777216;

const int YACA_KEYLEN_COMPONENT_DH_RFC_256 = 33554432;

const int YACA_KEYLEN_COMPONENT_EC_PRIME = 0;

const int YACA_KEYLEN_COMPONENT_EC_SECP = 16777216;

const int YACA_KEYLEN_COMPONENT_EC_SECT = 33554432;

const int YACA_KEYLEN_COMPONENT_EC_BRAINPOOL = 50331648;

const int YACA_KEYLEN_COMPONENT_EC_V = 0;

const int YACA_KEYLEN_COMPONENT_EC_R = 1048576;

const int YACA_KEYLEN_COMPONENT_EC_K = 2097152;

const int YACA_KEYLEN_COMPONENT_EC_T = 3145728;

const int YACA_KEYLEN_COMPONENT_EC_1 = 0;

const int YACA_KEYLEN_COMPONENT_EC_2 = 65536;

const int YACA_KEYLEN_COMPONENT_EC_3 = 131072;

const int YACA_KEYLEN_COMPONENT_EC_4 = 196608;

const int YACA_KEY_LENGTH_DH_GENERATOR_2 = 268435456;

const int YACA_KEY_LENGTH_DH_GENERATOR_5 = 285212672;

const int TIZEN_ERROR_YACA = -31653888;

const int CALENDAR_CONNECT_FLAG_NONE = 0;

const int CALENDAR_CONNECT_FLAG_RETRY = 1;

const int DEFAULT_EVENT_CALENDAR_BOOK_ID = 1;

const int DEFAULT_TODO_CALENDAR_BOOK_ID = 2;

const int DEFAULT_BIRTHDAY_CALENDAR_BOOK_ID = 3;

const int CALENDAR_TODO_NO_DUE_DATE = 9223372036854775807;

const int CALENDAR_TODO_NO_START_DATE = -9223372036854775807;

const int CALENDAR_RECORD_NO_UNTIL = 9223372036854775807;

const double CALENDAR_RECORD_NO_COORDINATE = 1000.0;

const int CALENDAR_BOOK_FILTER_ALL = -1;

const int CONTACTS_CONNECT_FLAG_RETRY = 1;

const int CONTACTS_CONNECT_FLAG_NONE = 0;

const int LOG_TAG = 0;

const int MAX_VALUE_SIZE = 16;

const int IME_ATTR_FONTSTYLE_UNDERLINE = 1;

const int IME_ATTR_FONTSTYLE_HIGHLIGHT = 2;

const int IME_ATTR_FONTSTYLE_REVERSAL = 4;

const String STT_RECOGNITION_TYPE_FREE = 'stt.recognition.type.FREE';

const String STT_RECOGNITION_TYPE_FREE_PARTIAL =
    'stt.recognition.type.FREE.PARTIAL';

const String STT_RECOGNITION_TYPE_SEARCH = 'stt.recognition.type.SEARCH';

const String STT_RECOGNITION_TYPE_WEB_SEARCH =
    'stt.recognition.type.WEB_SEARCH';

const String STT_RECOGNITION_TYPE_MAP = 'stt.recognition.type.MAP';

const String STT_RESULT_MESSAGE_NONE = 'stt.result.message.none';

const String STT_RESULT_MESSAGE_ERROR_TOO_SOON =
    'stt.result.message.error.too.soon';

const String STT_RESULT_MESSAGE_ERROR_TOO_SHORT =
    'stt.result.message.error.too.short';

const String STT_RESULT_MESSAGE_ERROR_TOO_LONG =
    'stt.result.message.error.too.long';

const String STT_RESULT_MESSAGE_ERROR_TOO_QUIET =
    'stt.result.message.error.too.quiet';

const String STT_RESULT_MESSAGE_ERROR_TOO_LOUD =
    'stt.result.message.error.too.loud';

const String STT_RESULT_MESSAGE_ERROR_TOO_FAST =
    'stt.result.message.error.too.fast';

const String STTE_RECOGNITION_TYPE_FREE = 'stt.recognition.type.FREE';

const String STTE_RECOGNITION_TYPE_FREE_PARTIAL =
    'stt.recognition.type.FREE.PARTIAL';

const String STTE_RESULT_MESSAGE_NONE = 'stt.result.message.none';

const String STTE_RESULT_MESSAGE_ERROR_TOO_SOON =
    'stt.result.message.error.too.soon';

const String STTE_RESULT_MESSAGE_ERROR_TOO_SHORT =
    'stt.result.message.error.too.short';

const String STTE_RESULT_MESSAGE_ERROR_TOO_LONG =
    'stt.result.message.error.too.long';

const String STTE_RESULT_MESSAGE_ERROR_TOO_QUIET =
    'stt.result.message.error.too.quiet';

const String STTE_RESULT_MESSAGE_ERROR_TOO_LOUD =
    'stt.result.message.error.too.loud';

const String STTE_RESULT_MESSAGE_ERROR_TOO_FAST =
    'stt.result.message.error.too.fast';

const int TTS_SPEED_AUTO = 0;

const int TTS_VOICE_TYPE_AUTO = 0;

const int TTS_VOICE_TYPE_MALE = 1;

const int TTS_VOICE_TYPE_FEMALE = 2;

const int TTS_VOICE_TYPE_CHILD = 3;

const int TTSE_VOICE_TYPE_MALE = 1;

const int TTSE_VOICE_TYPE_FEMALE = 2;

const int TTSE_VOICE_TYPE_CHILD = 3;

const int VC_COMMAND_TYPE_FOREGROUND = 1;

const int VC_COMMAND_TYPE_BACKGROUND = 2;

const int VC_DIALOG_END = 0;

const int VC_DIALOG_CONTINUE = 1;
